"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var crc32 = require("crc32");
var FileUtil_1 = require("./tool/FileUtil");
var FileCrc32 = /** @class */ (function () {
    function FileCrc32(baseUrl) {
        var self = this;
        var xmUrl = self.getXMUrl(baseUrl);
        var relUrl = path.join(xmUrl, 'bin-release');
        FileUtil_1.FileUtil.rmdirSync(path.join(relUrl, 'resource'));
        var defaultUrl = path.join(xmUrl, 'resource', 'default.res.json');
        var defData = JSON.parse(fs.readFileSync(defaultUrl, 'utf-8'));
        var resources = defData.resources;
        var res;
        for (var i = 0, len = resources.length; i < len; i++) {
            res = resources[i];
            var resHash = '';
            var itemUrl = path.join(xmUrl, 'resource', res.url);
            if (res.type == 'sheet') {
                var filename = FileUtil_1.FileUtil.filename(itemUrl);
                var sheetJson = JSON.parse(fs.readFileSync(itemUrl, 'utf-8'));
                var pngNameArr = sheetJson.file.split('.');
                var hash = self.hashItem(path.join(path.dirname(itemUrl), sheetJson.file));
                sheetJson.file = pngNameArr[0] + '_' + hash + '.' + pngNameArr[1];
                resHash = self.hashItem(itemUrl, new Buffer(JSON.stringify(sheetJson)));
            }
            else {
                resHash = self.hashItem(itemUrl);
            }
            var resUrlArr = res.url.split('.');
            var ext = resUrlArr.pop();
            res.url = resUrlArr.join('.') + '_' + resHash + '.' + ext;
        }
        fs.writeFileSync(defaultUrl.replace(xmUrl, relUrl), new Buffer(JSON.stringify(defData, null, '\t')));
    }
    FileCrc32.prototype.hashItem = function (itemUrl, contents) {
        var self = this;
        if (!contents) {
            contents = fs.readFileSync(itemUrl);
        }
        var xmUrl = self.getXMUrl(itemUrl);
        var relUrl = path.join(xmUrl, 'bin-release');
        var hash = crc32(contents);
        var filename = FileUtil_1.FileUtil.filename(itemUrl);
        var toUrl = filename.replace(xmUrl, relUrl) + '_' + hash + path.extname(itemUrl);
        FileUtil_1.FileUtil.mkdirSync(path.dirname(toUrl));
        fs.writeFileSync(toUrl, contents);
        return hash;
    };
    FileCrc32.prototype.getXMUrl = function (url) {
        var test = ["egret", "__reflect", "__class__", "push", "__types__", "concat", "__extends", "constructor", "hasOwnProperty", "prototype", "__awaiter", "next", "throw", "done", "value", "then", "apply", "__generator", "Generator is already executing.", "return", "call", "label", "pop", "ops", "trys", "length", "function", "iterator", "Sprite", "_isMoving", "_isLocking", "onlyKey", "RoleBase", "createIDByClasstype", "OnlyIDCreater", "_startPoint", "Point", "initView", "avatar", "addChild", "setAvatarInfo", "playerData is null", "sendError", "GameLogSendUnit", "_playerData", "checkActionURLS", "curAction", "curDir", "isLoop", "changeAct", "refreshState", "playerDataBase", "defineProperty", "sceneType", "_sceneType", "isMoving", "bodyLayer", "bodyHeight", "bodyPoint", "_bodyPoint", "x", "y", "setTo", "getDretion", "mapAvatarDire", "is2Dir", "get4Dir", "get8Dir", "atan2", "PI", "RIGHTTOP", "SceneType", "RIGHTBOTTOM", "LEFTBOTTOM", "LEFTTOP", "RIGHT", "BOTTOM", "LEFT", "TOP", "normal", "isDead", "ACTION_TYPE_STAND", "attack", "changeDirction", "gotoPlay", "walk", "ACTION_TYPE_MOVE", "sit", "ACTION_TYPE_SIT", "hurt", "curAct", "ACTION_TYPE_BEATEN", "die", "ACTION_TYPE_DIE", "talk", "changeDir", "isShowCSLog", "AppConfig", "isPlaying", "act", "indexOf", "gotoAndStopAct", "gotoStop", "moveToXYEnd", "changeHpValue", "moveSpeed", "speed", "setMoveSpeed", "remove", "parent", "removeChild", "setFilters", "removeMC", "unload", "removeFromFrame", "ins", "Loop", "alpha", "visible", "numChildren", "getChildAt", "CMovieClip", "Bullet", "dispose", "chm.RoleBase", "Component", "_initialized", "euiSkinName", "", "start", "COMPLETE", "UIEvent", "onComplete", "on", "skinName", "createChildren", "$complete", "initialized", "createComplete", "createCompleteFun", "thisObject", "fun", "EUI_SKIN_COMPLETE", "dispatchEventWith", "in", "Dispatcher", "out", "off", "eui_skin_complete", "EuiComponentBase", "chm.EuiComponentBase", "openSeek", "timeOutIndex", "Avatar", "Role", "playerData", "initRole", "removeTweens", "Tween", "scaleX", "scaleY", "RoleUnit", "moveToXY", "getDistance", "Vector2D", "getPointByDis", "MathUtil", "movePathXY", "clearTimeOut", "moveTween", "moveChange", "get", "getMoveTime", "to", "setTimeOut", "checkAlpha", "isMask", "$getX", "$setX", "yingzi", "$getY", "$setY", "pause", "stopMoveToXY", "moveEndFunc", "exec", "search", "searchRoad", "MapMod", "stopAI", "chm.Role", "isDispose", "isWandering", "startWdTime", "startWanderX", "startWanderY", "wanderTime", "seekTime", "testLastAttackTime", "ACTION_TYPE_ACT", "ACTION_TYPE_ACT1", "ACTION_TYPE_ACT2", "ACTION_TYPE_ACT3", "ACTION_TYPE_ACT4", "ACTION_TYPE_ACT5", "getTimer", "seekTween", "wander", "random", "GameUtil", "loopWander", "addToScend", "stopWander", "oversee", "targetDis", "seek", "loopSeekMove", "seekMoveEnd", "attackDistance", "floor", "seekToX", "seekToY", "seekTarget", "addToFrame", "isStart", "removeToScend", "seekEndFunc", "SEEK_MOVE_END", "contains", "mapAvatarLayer", "MapPlayerMgr", "playDead", "setTotolHP", "maxHp", "totalValue", "hpBar", "setHp", "crtHp", "setTotalMP", "maxMp", "setMp", "crtMp", "seek_move_end", "SmartRole", "chm.SmartRole", "HashObject", "_observerList", "target", "selector", "once", "splice", "rmvAll", "post", "dp", "Observer", "chm.Observer", "wrong skin in ActivityBaseView!!!!!!", "need override initView()!! in ActivityBaseView", "show", "need override show()!! in ActivityBaseView", "hide", "need override hide()!! in ActivityBaseView", "update", "need override update()!! in ActivityBaseView", "displayObjTool", "DisplayObjectPool", "uiManager", "UIManager", "layer", "App", "popToParent", "popToParnent", "removeFromParent", "removeFromParnent", "center", "centerPanel", "getShape", "createShape", "ActivityBaseView", "chm.ActivityBaseView", "chm.IActivityView", "queue", "processor", "key", "map", "defineProperties", "EventDispatcher", "addEventListener", "removeEventListener", "toUpperCase", "toString", "slice", "0", "#", "ByteArray", "EOF_byte", "decoderError", "EOF_code_point", "inRange", "pow", "fromCharCode", "join", "legacyResourceConfig", "_map", "config", "root", "fileSystem", "type", "name", "log", "isIos", "pay_xcx_json", "pay_xcx_ios_json", "resources", "groups", "keys", ",", "split", "alias", "fsData", "subkeys", ".", "forEach", "save", "json", "load", "List", "dataProvider", "source", "replaceAll", "ArrayCollection", "onclk", "DisplayObject", "checkAddZC", "BackResponse", "TOUCH_TAP", "TouchEvent", "offclk", "checkRmvZC", "angleBetween", "PI2", "MathConstant", "distance", "sqrt", "init", "truncate", "length_v2d", "regulate", "distanceTo", "negate", "add", "clone", "subtract", "incrementBy", "decrementBy", "scaleBy", "isZero", "zero", "isNormalize", "normalize", "angle2", "angle", "PI_180", "cos", "sin", "equals", "[Vector2D(x:", ", y:", ")]", "chm.Vector2D", "sysConfig", "pub_wxparams", "resStrategy", "\u5173\u95ed\u4f4d\u56fe\u7f13\u5b58", "__tempCache", "Image", "autoRes", "_autoRes", "ADDED_TO_STAGE", "Event", "__addSourceCount", "REMOVED_FROM_STAGE", "__removeSourceCount", "parseSource", "$setTexture", "_lastKey", "signSource", "ImageCache", "sourceChanged", "_source", "string", "substr", "egret.Texture", "is", "getAssets", "host", "state", "promise", "$bitmapWidth", "$bitmapHeight", "tolSizeChange", "profile", "Texture", "gpu size : ", "toFixed", "kb", "_totalImgSize", "_caches", "_noUseKeyDic", "_lastTm", "_ins", "refreshCheck", "targets", "count", "Image.source\u5f15\u7528\u8ba1\u6570\u9519\u8bef\uff0c\u5f15\u7528\u8ba1\u6570\u9519\u8bef\u6570\u503c\uff1a", "destroyRes", "chm.ImageCache", "_isActive", "removeAllEff", "active", "play_effect", "btn_effect", "_effList", "_compList", "addToComponent", "play", "stop_effect", "stop_effList", "model", "ActivityModel", "ActivityConfig", "ActivityBasePanel", "chm.ActivityBasePanel", "_endian", "bigEndian", "_connected", "_connecting", "_url", "initWebSocket", "connected", "connecting", "endian", "connectInfo", "_socket", "isWss", "js_serverSSL", ":", "wss://", "nginxurl", "?ip=", "&port=", "ws://", "connectByUrl", "WebSocket", "TYPE_BINARY", "SOCKET_DATA", "ProgressEvent", "onReceiveMessage", "CONNECT", "onSocketOpen", "CLOSE", "onSocketClose", "IO_ERROR", "IOErrorEvent", "onSocketError", "readBytes", "MESSAGE", "WebSocketEventType", "Connect socket success!", "info", "close", "replace", "WebSocketClose", "error", "ERROR", "data", "WebSocketError", "sendByte", "position", "bytesAvailable", "writeBytes", "\u65ad\u7ebf\u89e6\u53d1", "LITTLE_ENDIAN", "littleEndian", "BIG_ENDIAN", "SocketBase", "chm.SocketBase", "netRsp", "BaseModel", "chm.BaseModel", "_timeoutIds", "clearAllTimeOut", "TimeOutSet", "chm.TimeOutSet", "isMainPlayer", "nheight", "atkSkPlayer", "AtkSkPlayer", "initUI", "updatePos", "imgTitle", "SelfHpBar", "lblName", "Label", "medalIcon", "lblHp", "lblPosition", "lblFaimly", "fillDefaultStyle", "width", "touchEnabled", "stroke", "strokeColor", "touchChildren", "$hitTest", "$renderNode", "$visible", "$getInvertedConcatenatedMatrix", "a", "c", "tx", "b", "d", "ty", "rect", "showHpBar", "doNextFrame", "hideHpBar", "showLbHp", "hideLbHp", "fontFamily", "SimHei", "textAlign", "CENTER", "HorizontalAlign", "size", "width_bar", "textWidth", "nLastTitleY", "upTitlelPos", "refreshBodyHeight", "MOVE_TO_XY_COMPLETE", "MyPlayer", "TEXT1", "substitute", "StringUtil", "text", "isMine", "GameEvent", "setTotolMP", "refreshNameColor", "onlyID", "checkIsSelfHeroByOnlyID", "hero", "DS", "getPlayerNameByEnterType", "enterType", "hateColors", "ColorUtil", "checkBossOpen", "MainCityBossModel", "hate", "textColor", "setPositionTxt", "positionTitle", "positionQuilty", "COLOR_NUM", "isLeader", "_simple", "medalSource", "titleUrl", "familyName", "familyNameColor", "pet", "setShowFabao", "checkIsSelf", "heroList", "id", "heroDic", "showfabao", "fabaoID", "_fabaoEff", "FaBao", "setOwner", "fabaoUrl", "resetData", "removeFabao", "clearAtkSk", "hideHoldImg", "hideHate", "relive", "playSkill", "showHoldImg", "imgUse", "RED", "boss_guishuzhe_png", "hideImgMedal", "hideImgTitle", "showFam", "hidelblFaimly", "showLblPos", "hidelblPosition", "showImgMedal", "showImgTitle", "simple", "showHoldGrp", "disUse", "DDisp", "hideHoldGrp", "setHate", "showHate", "move_to_xy_complete", "{0}/{1}", "Player", "chm.Player", "GridVo", "chm.GridVo", "_size", "_name", "invalid table !!!!!", "find", "findOn", "filterOn", "findByFunc", "filterByFunc", "insert", "data id: ", "  has exist in table:", "!!", "::data id: ", "is undefined!!!! ", "isEmpty", "toArray", "clear", "DataTable", "chm.DataTable", "BoxVO", "chm.BoxVO", "BoxBaseSkin", "onClick", "setData", "_data", "icon", "img_box", "img_received", "lbl_text", "getBonus", "showBonus", "bonus", "creatGridVoByStr", "GridFactory", "dpw", "BoxBase", "chm.BoxBase", "boxW", "boxH", "begin", "interval", "boxClass", "boxArr", "PureSkinBoxBarSkin", "prog_bar", "prog_thumb", "removeAllBox", "grp_cont", "height", "max", "setPositionInView", "scrollH", "PureSkinBoxBar", "chm.PureSkinBoxBar", "autoDispose", "boShowTip", "removeFromStage", "effect", "stop", "setdata", "gridVo", "DATA_CHANGE", "playEffect", "EFFECT_STATE_CHAGNE", "playEffect2", "EFFECT_STATE_CHAGNE1", "hideName", "showNum", "data_change", "effect_state_change", "effect_state_change1", "CLICK_GRID", "click_grid", "GridBase", "chm.GridBase", "port", "arrSocketData", "inputBuffer", "maxSendBufferSize", "getInstance", "_instance", "setHostPort", "HOST_PORT_CHANGE", "NetEvent", "dispatchEvent", "connect", "reconnect", "send", "BinaryBuffer", "writeInt", "command", "writeShort", "encodeCode", "NetUtil", "byteArray", "c_", "netVoLog", "decoderCmd", "readInt", "readShort", "NetVO", "decodeCode", "isSocket", "NetDispatcher", "s_", "transnumber", "stringify", "getNetParmsByCmd", "NetWorkSystem", "buffer", "byteLength", "BytesSocket", "chm.BytesSocket", "showRed", "GridItemVo", "chm.GridItemVo", "_dataField", "_selectedIndex", "_redPointArr", "RedPoint", "tabButtonArr", "selectedIndex", "_lastSelectIndex", "updateDisplay", "SELECTED_INDEX_CHANGE", "setSelectDisplay", "selectedItem", "dataField", "lastSelectIndex", "setRedPosByIdx", "_tabButtonArr", "$autoSelected", "selected", "onclickTabButton", "stopImmediatePropagation", "stopPropagation", "currentTarget", "selected_index_change", "PureSkinTabBar", "chm.PureSkinTabBar", "DisplayObjectContainer", "imgSrc", "module/battle/huihe/huihe_{0}.png", "sigleImageWidth", "_imageWidth", "setNum", "charAt", "getCImage", "setNumWithPlusMinus", "jiahao", "jianhao", "-", "+", "getWidth", "removeChildAt", "_pools", "ImageNum", "chm.ImageNum", "_value", "_totalValue", "_psercentNum", "imgBar", "jianzhu_jindutiao_01_png", "imgBarBg", "jianzhu_jindutiao_02_png", "maskBar", "height_bar", "MaskBar", "setPercentNum", "progress", "getPercentNum", "HpBar", "chm.HpBar", "reset", "rotation", "appearTime", "currentTime", "getParticle", "need to be overrided!", "getcx", "getcy", "ParticleBase", "particlesys.ParticleBase", "LegendaryEquipmentSkin", "fillCQEqu", "stage", "img_item1", "nextVo", "baseID", "nowVo", "lbl_level1", "level", "quity", "quan_name0", "quan_item0", "group_xx", "needID", "gray", "GrayUtil", "img_quitay1", "forge_head_png", "treasure_itembg_jpg", "quan_name1", "quan_name2", "quan_item1", "quan_item2", "star", "img_star", "figure_xx2_png", "figure_xx1_png", "setStarsInfo", "img_item2", "lbl_level2", "img_quitay2", "img_select1", "cqIdx", "CZMod", "img_select2", "getVipLevel", "mine", "group5", "group6", "group1", "group2", "mergertime", "serverTime", "img_item5", "lbl_level5", "img_quitay5", "img_item6", "lbl_level6", "img_quitay6", "img_name", "OrEq", "ConstCfg", "fillCQInfo", "group_equip1", "group_equip2", "group_two", "quan0", "group_gettip", "btn_hecheng0", "lbl_getmax", "\u88c5\u5907\u795e\u6212", "\u83b7\u53d6\u795e\u6212", "\u88c5\u5907\u795e\u76d4", "\u83b7\u53d6\u795e\u76d4", "\u88c5\u5907\u795e\u94fe", "\u83b7\u53d6\u795e\u94fe", "\u88c5\u5907\u795e\u5251", "\u83b7\u53d6\u795e\u5251", "\u88c5\u5907\u795e\u7532", "\u83b7\u53d6\u795e\u7532", "\u88c5\u5907\u795e\u956f", "\u83b7\u53d6\u795e\u956f", "equip", "pos", "canWearSZ", "btn_shengji0", "playEquEff", "\u5347\u661f", "\u5347\u7ea7", "stopEquEff", "itemID_cq", "CZEquStatic", "getItemCountById", "item", "needNum", "\u5408\u6210", "lbl_cost", "k_196", "lanTxt", "GREEN", "\u5df2\u6ee1\u7ea7", "lbl_pingfen0", "k_572", "score", "lbl_value0", "valueStr", "lbl_value1", "lbl_pingfen1", "lbl_pingfen2", "lbl_value2", "img_jiantou", "num", "img_select5", "img_select6", "equipEffect", "grp_x", "grp_six", "xx", "_", "lbl_lvl", "CZCQEquEui", "chm.CZCQEquEui", "socket", "_dis", "startup", "need override!", "an", "ModuleBase", "chm.ModuleBase", "CLOSE_PANEL", "_shape", "popLayer", "CoverPanel", "chm.CoverPanel", "ItemRenderer", "initSkin", "WishBoxRewardRenderSkin", "imgSelected", "_boxData", "dataChanged", "vo", "itemStr", "_rewardRender", "SpecialItemGridRender", "itemGroup", "removeChildren", "inBonusPool", "time", "setSelected", "getSelected", "WishBoxRewardRender", "chm.WishBoxRewardRender", "_wishBoxRewardDic", "getLocalXmlById", "activity_json", "getObjByName", "ConfigManager", "\u5728activity_json\u4e2d\u627e\u4e0d\u5230id\uff1a", "\u7684\u914d\u7f6e\uff01\uff01\uff01\uff01", "getReplaceActivitys", "getConfByName", "activityGroup", "getAllAnnualTaskConfig", "_annualTaskDic", "promotiontask_json", "FestivalAnnualTaskVo", "mainId", "kind", "child", "isArray", "TypeUtil", "FestivalAnnualTaskSubVo", "subId", "needValue", "need", "des", "desc", "bonusStr", "bonusArr", "sub", "getRebateConfigs", "_rebateJson", "investturntable_json", "ActRebateConfigVo", "configId", "maxCount", "needRecharge", "rollCost", "cost", "getRebateConfigByRecharge", "getCardCfg", "_cardJson", "promotionturntable_json", "ActCardCfgVo", "getCardCfgByID", "getLotRankJsn", "lotteryconsumerank_json", "\u5728lotteryconsumerank_json\u4e2d\u627e\u4e0d\u5230id>>>>", "  \u7684\u914d\u7f6e\uff01\uff01\uff01", "getLr12Xml", "lr12Id", "LrDouble12Ctrl", "promotionluckyturn_json", "getLr12ConfArr", "_lr12ConfArr", "getWishBoxReward", "promotionSpecialBuy_json", "day", "additionId", "ArrayUtil", "WishBoxRewardPoolVo", "limit", "rewardList", "items", "WishBoxRewardVo", "index", "\u8bb8\u613f\u793c\u76d2\u6d3b\u52a8id\uff1a", "\u7b2c", "\u5929\u6709\u91cd\u590did>>", "DESCENDING", "sortOnArr", "\u5728promotionSpecialBuy_json\u91cc\u627e\u4e0d\u5230\u8bb8\u613f\u793c\u76d2\u6d3b\u52a8id\uff1a", "\u5929\u7684\u914d\u7f6e\uff01\uff01\uff01", "getWishBoxTotalRound", "getWishBoxCost", "getDailyPromotion", "promotiondaily_json", "chm.ActivityConfig", "EVERYDAY_RECHARGE", "everydayrecharge", "ActivityClientKeyType", "chm.ActivityClientKeyType", "_isStart", "hasStart", "ActivityBaseCtrl", "chm.ActivityBaseCtrl", "job", "sex", "mapid", "typeId", "_speed", "bodyUrl", "stand", "PlayerDataBaseVO", "chm.PlayerDataBaseVO", "layoutCfg", "1", "$LayoutCfg", "substring", "createObjFromVal", "createValFromObj", "flushLayout", "getLayoutCfg", "parse", "convertStr2Json", "JsonUtil", "PtTagCorrespond", "getActType", "w", "h", "sz", "tc", "lb", "lo", "g", "ph", "ds", "origin", "searchFromStr", ",{", "}", ":(.*?)[,}]", "i", "match", "PartBase", "chm.PartBase", "onUIComplete", "CttRender1Skin", "itemRenderer", "listRwd", "RewardRender", "clickHandler", "btn", "clientKey", "title", "ljrecharge", "totalrecharge", "consumeexpert", "totalrecharge1", "ele", "targetNum", "lblTitle", "rewardStr", "activityrender1 error:", "k_25", "enabled", "k_24", "eff", "playEff", "PartEffMgr", "imgGet", "scale", "setDataArr", "removeEff", "dailyrecharge", "kaifulevel", "subTarget", "myValue", "k_43", "GREEN_S", "RED_S", "textFlow", "getHtmlStr", "HtmlUtil", "svrProcess", "process", "HTML_FORMAT", "k_39", "tip_num", "c_26541", "ConsumeRechargeCtrl", "dpGetReward", "flyIntoBag", "ActivityUtil", "CttRender1", "chm.CttRender1", "gridArr", "CttRender10Skin", "itemIndex", "rankname", "k_55", "lotConsumeId", "ActivityRewardVo", "rewardArr", "setRewardGrid", "removeGrid", "createGrid", "group_reward", "CttRender10", "chm.CttRender10", "refreshData", "getopen", "CttRender11", "chm.CttRender11", "imgNums", "discount_num_00_png", "discount_num_01_png", "discount_num_02_png", "discount_num_03_png", "discount_num_04_png", "discount_num_05_png", "discount_num_06_png", "discount_num_07_png", "discount_num_08_png", "discount_num_09_png", "CttRender12Skin", "GOLD", "main_gold_png", "main_gold_1_png", "imgTip", "imgCost", "lblCost", "viplevel", "needVip", "vip", "activity_hall_tequan_png", "gVIcon", "Ins", "VipMod", "activity_hall_sale_png", "lbl_name", "quality", "grid", "cell", "discost", "grp_discost", "img_first", "img_last", "discount_bg_00_png", "discount_bg_01_png", "discount_bg_02_png", "discount_bg_03_png", "discount_bg_04_png", "img_di", "k_106", "showMsg", "k_1214", "getGold", "k_1037", "showCodeAlert", "k_864", "OK", "CommonAlert", "CANCEL", "detail", "shopItemBuy", "getMoney", "k_3", "CttRender12", "chm.CttRender12", "CttRender13Skin", "img_day", "horizontal_day_", "_png", "c_2052", "CttRender13", "chm.CttRender13", "CttRender14Skin", "_vo", "subValue", "drawn", "lbl_left", "getLimitNumStr", "group_item", "list", "CollectFontRender", "imgEqual", "scroll", "getReward", "btn_buy", "playBtnEff", "getNameById", "\"", "\"*", " \u5151\u6362:", "*", "lbl_title", "_btnEff", "function_entry_effect", "CttRender14", "chm.CttRender14", "CttRender2Skin", "getLimitvo", "LimitStatic", "isLimit", "lblTime", "rewardcount", "disLabel", "imgDis", "IBridge", "showAlert", "MessageManager", "#389d23", "CttRender2", "chm.CttRender2", "CttRender3Skin", "btn_get", "img_get", "removeEffect", "cttAmount", "lbl_des", "k_91", "cttAmount2", "k_92", "CttRender3", "chm.CttRender3", "CttRender4Skin", "imgCost1", "lblCost1", "originalcost", "limitvip", "pullVip", "upcount", "k_48", "k_47", "#cd1b1f", "VIP\u7b49\u7ea7\u4e0d\u8db3", "CttRender4", "chm.CttRender4", "CttRender5Skin", "touchHandler", "btnEffect", "_state", "\u5df2\u5151\u6362", "\u5151\u6362", "ItemDS", "img_itemCost", "lbl_times", "k_399", "k_402", "lbl_itemCost", "getTypeById", "getIdByStr", "getItemName", "ItemJsonConfigData", "lbl_itemName", "CttRender5", "chm.CttRender5", "CttRender6Skin", "reward", "tochHandler", "getActivityVoById", "subArr", "total", "finishday", "k_46", "k_90", "\u8fde\u7eed\u5145\u503c\u5929\u6570\u4e0d\u8db3", "CttRender6", "chm.CttRender6", "CttRender7Skin", "targetName", "targetValue", "\u65e0", "CttRender7", "chm.CttRender7", "FestivalDouble11Render1Skin", "lbl_costDes", "desXml", "lbl_returnDes", "%", "CttRender8", "chm.CttRender8", "\u6b21", "CttRender9", "chm.CttRender9", "removeBtnEff", "BaseListItemRender", "chm.BaseListItemRender", "rmvR", "RewardRenderSkin", "group", "icnUrl", "RwdR", "chm.RwdR", "NAME", "ViewBase", "_started", "_euiComponetsArr", "preInitView", "initEui", "mapEuiComponent", "sleep", "showLoading", "doInitView", "initSingleEuiSkin", "euiSkinCreateComplete", "shift", "euiSKinComplete", "loadedComplete", "hideLoading", "INITIALIZED_COMPLETE", "CREATE_COMPLETE", "initialized_complete", "create_complete", "NianViewBase", "chm.NianViewBase", "isDaily", "create", "clientkey", "clienykey", "modulId", "module", "iconUrl", "buttonicon", "wordUrl", "buttonname", "boTip", "boAlive", "boSelect", "booTip", "sortid", "sortId", "separateid", "_separateId", "iconopenday", "_iconOpenDay", "separateId", "separateDuration", "ActivityBtnVo", "chm.ActivityBtnVo", "actType", "params", "_selectIndex", "_isOpenServer", "getLineBreakStr", "subClientKey", "trigger", "aliastitle", "bgUrl", "activityBG", "_desBg", "desbg", "_panelBg", "panelbg", "_includePalt", "includePalt", "moduleId", "shopid", "shopId", "festivalGroupId", "_festivalGroupId", "festivalUI", "_festivalUI", "dailyreset", "lotteryid", "lotteryday", "openTime", "openServerDays", "_openServerDays", "layout", "nextId", "nextIds", "followId", "followIds", "createSubVoByActivityVo", "rank", "rankArr", "createRankVoByActivityVo", "possibilityId", "additionConfigId", "lotteryShowId", "_dailyServerTime", "effectTime", "_effectTime", "isServer", "effectId", "_effectId", "_active", "running", "_running", "updateInfo", "startTime", "endTime", "svrDatas", "bonusId", "cttState", "cttDrawn", "drawns", "updateSubs", "rankValueArr", "ranks", "ActivitySubVo", "ActivityRankVo", "rankId", "rankHead", "selectIndex", "dayIndex", "checkPassDay", "leastTime", "getCurrentServerTime", "getLeastTimeStr", "getTypeTimeByStr", "DateUtil", "\u6c38\u4e45\u5f00\u653e", "isRunning", "myRechargeNum", "newmoretotalrecharge", "limitCheck", "check", "isAlive", "aliveCheck", "AliveCheckerFactory", "getCheckerByKey", "execute", "isRed", "redCheck", "RedCheckerFactory", "DefaultRedChecker", "desPanelCls", "ActivityViewFactory", "getDesClass", "DesPart", "panelCls", "getPanelClass", "CttList", "_layoutCfg", "loginBgSource", "anniversary_denglu_bg_jpg", "loginBoxSource", "anniversary_denglu", "desBg", "activity_hall_bg3_jpg", "panelBg", "panelFrameSource", "panelTopBgSource", "includePlatList", "openDayIndex", "getRealServerTime", "NewDate1", "setHours", "getTime", "dailyOpenServerTimeLimit", "isOpenServer", "isEffective", "AliveCheck", "checkIfSvrOpenTimePass", "checkIfSvrTimePass", "ActivityVo", "chm.ActivityVo", "rmg", "clkH", "RE_CK", "img_red", "needPlayEffect", "checkChangeNameRed", "FamilyMod", "getchangeNameItemId", "FamilyJsonConfigData", "useEffect", "useType", "useTypes", "BagMod", "render_click", "BagGrdR", "chm.BagGrdR", "actInterval", "tzCD", "initEd", "_oldPos", "myShieldTime", "_pvpsSceneDic", "waitRmvIds", "_frame", "frameKey", "pvpsInsFrameKey", "isAttack", "pingbi", "pingbiSvr", "pingbiFam", "_mapSearch", "_chooseId", "_waitChangeBoss", "_battleTmId", "_selfHpDic", "_selfMaxHp", "buffTween", "shieldTime", "playerInfo", "_actPlayerDic", "bossInfoDic", "selfActdata", "selfHitArr", "_selfHitData", "selfHeroDic", "_selfHeroDic", "petDic", "transHerosJobDic", "enterScene", "startLoop", "enterSceneData", "initMap", "initPlayers", "mapId", "onMapClk", "CURRNET_MAP_CHANGE", "myPlayer", "getSelfHp", "selfFullHp", "updateHpStyle", "setMyFtSta", "BatStaMgr", "getJobByHeroID", "HeroDS", "otherEnterInfos", "sencePlayers", "getScenePlayerVO", "transPos", "reqPlayerInfos", "updatePlayerInfos", "addRoleToSence", "attTarChange", "clearPlayers", "rmvRoleFromSence", "selfFollow", "checkReqPos", "reqSelfMove", "canMove", "isBattle", "onReborn", "checkAddBuff", "checkBuff", "checkDis", "createMapHeroInfoData", "heroInfos", "getOtherPlayer", "OtherPlayer", "MapPlaData", "fillMapPlayerInfoData", "hp", "sameServer", "chopId", "getChopLevelJson", "MilitaryRankConfig", "\u2605", "medal", "getIconById", "MedalCfg", "getAtkDis", "BattleMod", "onClkTarget", "isMove", "mEndP", "dwPlayerFeatureId", "clothes", "fashion", "getBodyUrl", "wingUrl", "wing", "getWingUrl", "weaponUrl", "getWeaponUrl", "PvpsInsRoleVo", "updateMoveInfo", "getPlayerID", "MineInfoDS", "correctSelfPos", "updateMove", "heros", "monster", "follow", "getDisAngelPoint", "setOtherEnterInfo", "onKillEnd", "transInfo", "owner", "bossOwner", "cd", "checkMonState", "rmvSelfFromSence", "hidePlayer", "showPlayer", "getInfo", "createPlayerHeros", "petId", "createPet", "createMonster", "roleDic", "monInfo", "getCurrentMapVO", "mapWidth", "mapHeight", "fillMapPlayerInfo", "loop", "clearLoop", "checkAttackHit", "checkReqItem", "checkZiShow", "checkShowPlayer", "reqTL", "searchTarget", "chooseTarget", "getViewRect", "NPCMod", "getFamilyInfo", "family", "cancelSeek", "stopAttacked", "removeTween", "onMapEnd", "FunctionVO", "isTL", "checkTL", "CrBossModel", "actOwner", "onClkItem", "$currentTarget", "mapX", "mapY", "reqItem", "cancelOwner", "seekItem", "seekEnemy", "round", "reqAttackPlayer", "_isBattle", "actEnd", "n_4530", "actor", "hideZiPlayer", "playerAct", "targetHp", "monsterHp", "transHps", "setOHp", "setPlayerActInfo", "actionDatas", "actorId", "targetId", "selfAct", "checkHalo", "selfHit", "hurtInfo", "skill", "playHurt", "getHeroByIdx", "abs", "buffInfo", "playBuff", "checkShowByHp", "remain", "setHaloEff", "_haloEff", "bossIds", "crossboss_selected_1", "crossboss_selected_2", "addChildAt", "transHp", "selfHp", "hurtType", "0,0,0,", "playAttack", "BulletAttack", "changeHp", "wordLyr", "buffId", "mabi", "shanbits", "bingdong", "FILTER_WHITE", "FilterUtil", "dechit", "wingHS", "getBullet100", "Bullet100", "effName", "fabao_skill_", "setTarget", "$children", "Bullet30", "getBullet30", "getBullet33", "Bullet33", "palyScreenFont", "getBullet35", "Bullet35", "getFaBaoRole", "CrBossPlayerModel", "getSelfRadio", "Pet", "checkSelfShowByHp", "4", "3", "rmvBuffShow", "getBullet27", "Bullet27", "tongtian_attackbuff", "avatarLyr", "_curTimes", "clearInterval", "checkBuffTime", "setInterval", "bossShield", "shieldTm", "tmId", "ServerTimeDS", "rebornTm", "actTm", "onMyDie", "onDie", "getPlayerOnlyID", "isMyDie", "attackId", "cancelSelfAct", "cancelSelfHit", "tm", "NUMERIC", "playAttacked", "updateMonsterInfos", "defencecd", "_fightEffect", "stageWidth", "stageHeight", "attacked_effect", "moduleLayer", "PvpsInsModel", "chm.PvpsInsModel", "started", "_thisArr", "_asyncLogicalQueue", "_isViewCreated", "_isWeekUp", "doStartup", "checkHandUpLab", "wakeup", "runAysnLogicaQueue", "addEventListeners", "removeEventListeners", "runAysnLogica", "runAysnLogicaOnce", "isViewCreated", "createLabel", "ModuleIfDo", "inclk", "outclk", "chm.ViewBase", "_selectedMonIdx", "pvpsFrameKey", "_nLTime", "_mRect", "Rectangle", "startLoopAttack", "addMonsters", "heroHps", "getMonsterTNum", "_senceMonsters", "getMonster", "addMonster", "monsterRefresh", "getClientXml", "CsCfg", "getMonHp", "BattleCfgMod", "notWalk", "getMonsterXY", "clearMonsters", "removeMonster", "getNearMonster", "MAX_VALUE", "hpPercent", "rmvPlayerFromSence", "addPlayerToSence", "k_1137", "BattLeMgr", "reqAttackMonster", "onChaseMonster", "getPlayerSelectPos", "canfight", "sameFamily", "k_1136", "Monster", "titleId", "getTitleUrl", "PvpsScenePlayerVo", "player", "setPlayerKillInfo", "createPlayer", "radio", "upHpRadio", "LoopAttackSecend", "onLoop", "battleEnd", "addition", "monsters", "k_163", "side", "win", "k_166", "targetInfo", "QMBSPvpMsg", "k_165", "initSgPlHp", "stopMyMC", "onTargetChange", "PvpsBaseModel", "chm.PvpsBaseModel", "onlyId", "_power", "_penetrate", "mgr", "tarDis", "draw", "moveCmop", "removeLoop", "power", "penetrate", "cl", "st", "isMyHeroOrPet", "v_g", "chm.Bullet", "_selectImg", "MonsterHpBar", "flDeStyle", "resetStatue", "setHpState", "updatePosition", "rfBodyHeight", "setSelect", "check_gq_png", "_bubble", "setHpLbl", "addBubble", "DiaBubble", "chm.Monster", "currentCaleX", "chm.Pet", "MapLayerBase", "chm.MapLayerBase", "param", "chm.FunctionVO", "_pindex", "_ipIndex", "loginSuccess", "webType", "cqNetSend", "NetSender", "isSkipBattle", "MainLayer", "_p", "initContainer", "stripscript", "[`~!@#$^&*()=|{}\':;\',\\[\\]\".<>/?~\uff01@#\uffe5\u2026\u2026&*%\uff08\uff09\u2014\u2014|{}\u3010\u3011\u2018\uff1b\uff1a\u201d\u201c\'\u3002\uff0c\u3001\uff1f ]", "comPoint", "_ips", "setIpInfo", "isViewTest", "chm.App", "boom2Skin", "img_bg", "addImg", "BigImgRes", "img_bg1", "Boom2Window", "chm.Boom2Window", "Endian", "ObjectEncoding", "Amf3Types", "objectTable", "stringTable", "traitTable", "bufferExtSize", "readObject", "readAMF3Object", "clean", "readByte", "kUndefinedType", "kNullType", "kFalseType", "kTrueType", "kIntegerType", "readUInt29", "kDoubleType", "readDouble", "kStringType", "readStringAMF3", "kXMLType", "kDateType", "kArrayType", "kObjectType", "readTraits", "className", "externalizable", "properties", "dynamic", "kByteArrayType", "writeByte", "readString", "readUTFBytes", "readLongUTF", "readUInt30", "CByteArray", "chm.CByteArray", "_curIndx", "_reqcnt", "ranName", "\u957f\u5b59\u8bed\u68a6", "\u79bb\u5fc3\u6068\u771f", "\u8150\u8680\u5e7b\u5de7", "\u5fc6\u767d\u6620\u9633", "\u8537\u8587\u534a\u53cc", "\u6e05\u745f\u60dc\u73ca", "\u5bb9\u989c\u6db5\u9633", "\u8f7b\u5ff5\u521d\u4e39", "\u6d77\u84dd\u542c\u5170", "\u9ed1\u732b\u4e39\u8431", "nCount", "_rNameDic", "getRName", "getNameCnt", "getRandomName", "\u968f\u673a\u540d\u83b7\u53d6\u5931\u8d25", "getRandomName1", "\u82f1\u96c4", "phpurl", "randomname/index.php?cnt=", "GET", "open", "onreadystatechange", "readyState", "status", "response", "CheckStringUtil", "chm.CheckStringUtil", "compareBackColor", "compareBackNumColor", "WORD_WHITE", "WORD_WHITE_S", "#ffffff", "WORD_GREEN", "WORD_GREEN_S", "#00c400", "WORD_BLUE", "WORD_BLUE_S", "#0172ff", "WORD_BEIGE", "WORD_BEIGE_S", "#e3cca9", "WORD_ORANGE", "WORD_ORANGE_S", "#ffaa00", "GRAY", "GRAY_S", "#b2b7b9", "WHITE", "WHITE_S", "WHITE_CH", "\u767d\u8272", "GREEN_CH", "\u7eff\u8272", "BLUE", "BLUE_S", "BLUE_CH", "\u84dd\u8272", "PURPLE", "PURPLE_S", "#e61dff", "PURPLE_CH", "\u7d2b\u8272", "ORANGE", "ORANGE_S", "ORANGE_CH", "\u6a59\u8272", "#ff0f15", "RED_CH", "\u7ea2\u8272", "WHITE_Forge", "WHITE_Forge_S", "#a08c6d", "COLOR_STR", "FILTER_GRAY", "ColorMatrixFilter", "chm.ColorUtil", "ceil", "getPassDay", "setTime", "getTimeStr", "\u5929", "\u65f6", "\u5c0f\u65f6", "\u5206", "00\u5206", "\u79d2", "00\u79d2", "00m00\u79d2", "00\u65f600\u520600\u79d2", "00\u65f6", "getTypeTimeByStr2", "\u5206\u949f", "1\u5206\u949f", "1\u5c0f\u65f6", "getTypeTimeByStr3", "getTypeTimeByStr4", "getReallyTime", "getTimeStrMDHM", "NewDate", "getUTCMonth", "getUTCDate", "getUTCHours", "getUTCMinutes", "getUTCSeconds", "font_1", "getTimeStrYMDHM", "getUTCFullYear", "font_3", "getTimeStrHMS", "00:00:00", "getTimeStrMS", "00:00", "getTimezoneOffset", "SetNewDate", " ", "setFullYear", "setMonth", "SetNewDate1", "getEndTime", "PerDay_S", "PerDay_MS", "{0}-{1} {2}:{3}", "font_2", "{0}M{1}D {2}:{3}:{4}", "{0}/{1}/{2}({3}:{4}:{5})", "font_4", "{0}:{1}:{2}", "font_5", "{0}\u5e74{1}\u6708{2}\u65e5({3}:{4}:{5})", "font_7", "{0}-{1}-{2} {3}:{4}:{5}", "chm.DateUtil", "objPoolDict", "instance", "getQualifiedClassName", "chm.DisplayObjectPool", "getFightNum", "prop", "calculate", "common_json", "gco", "GameCf", "getTotalFightNumber", "getPropVosByStr", "PropUtil", "FightUtil", "chm.FightUtil", "FILTER_HighLight", "FILTER_RP", "FILTER_GREEN", "FILTER_RED", "FILTER_BULE", "chm.FilterUtil", "toAngle", "toRadian", "getSpeedByFrameRote", "frameRate", "renderMode", "Capabilities", "chm.GameUtil", "filters", "chm.GrayUtil", "k_1731", "parser", "htmlText", "HTML_U", "<u>{0}</u>", "<font color=\"{0}\">{1}</font>", "HtmlTextParser", "chm.HtmlUtil", "chm.MathConstant", "hexcase", "b64pad", "hex_md5", "str2rstr_utf8", "rstr_md5", "rstr2hex", "b64_md5", "rstr2b64", "any_md5", "rstr2any", "hex_hmac_md5", "rstr_hmac_md5", "b64_hmac_md5", "any_hmac_md5", "md5_vm_test", "900150983cd24fb0d6963f7d28e17f72", "toLowerCase", "abc", "rstr2binl", "binl_md5", "binl2rstr", "0123456789ABCDEF", "0123456789abcdef", "charCodeAt", "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/", "str2rstr_utf16le", "str2rstr_utf16be", "md5_ff", "md5_gg", "md5_hh", "md5_ii", "safe_add", "md5_cmn", "bit_rol", "Md5Util", "chm.Md5Util", "_openCondDic", "checkIfOpen", "getOpenDic", "checkOpen", "k_10", "k_1439", "k_185", "k_191", "getLevelDes", "familylevel", "k_350", "k_21", "k_22", "k_23", "getTotalLevel", "portID", "PortMod", "_openDic", "moduleopen_json", "gcn", "moduleID", "ModuleUtil", "chm.ModuleUtil", "_targetDic", "n_", "n_rspon", "onOne", "offOne", "NetRsp", "chm.NetRsp", "netvosy", "writeRef", "write", "read", "Byte", "Int", "Long", "Short", "UTF", "IntArray", "ShortArray", "LongArray", "UTFArray", "chm.NetUtil", "_isVisible", "isRegister", "_isPlaying", "_nextRenderTime", "_currentFrame", "START_SEQUENCE", "_frameCount", "_endFrame", "_wingLayerUp", "_isMine", "_dir", "attackTypeArr", "attackIndex", "role", "avatar_", "createID", "wingPart", "AvatarPart", "bodyPart", "weaponPart", "thingFrame", "SceneFrame", "_avatarData", "_action", "infoData", "dwCretTypeId", "createPiying", "compareAvataData", "_moveSpeed", "bodyActUrl", "wingActUrl", "weaponActUrl", "checkUrlIsExist", "updateWingLayer", "getActionStr", "getBodyActUrl", "AvatarUrlManager", "getWingActUrl", "getWeaponActUrl", "getResource", "SceneSouce", "onLoadend", "removePiying", "getNonMirroredDir", "playWeaponAndWing", "_isLoop", "setAction", "setCurrentFrame", "getMaxFrame", "maxBodyHeight", "getHeight", "move", "playEnd", "setFrame", "url", "lastActionPlayEnd", "isVisible", "dwHorseId", "webgl", "_timeOutId", "clearFilters", "monsterheight_json", "monsterRes", "getFastMainKey", "getLevel", "chm.Avatar", "getPercentageArr", "_propPercentage", "HIT", "Prop", "MISS", "STRONG", "STRONGHURT", "ANTISTRONG", "CHOAS", "ANTICHOAS", "INCHURT", "DECHURT", "HP_MULTI", "ATT_MULTI", "DEF_MULTI", "ACROSS", "HITBACK", "BOSSINCHURT", "BOSSDECHURT", "BOSSSTRONG", "DECSTRONG", "HOLYATT", "HOLYDECHURT", "RATE", "BLOCK", "BREACH", "SDEF_MULTI", "PDEF_MULTI", "getPropCount", "getPropStrByPropVO", "k_116", "k_504", "propName", "CHOASTIME", "k_904", "PropStr", "rate", "getPropString", "PropValue", "getPropNumString", "getPlusPropStrByStrAndPlus", "k_626", "k_627", "HP", "MP", "ATT", "PDEF", "SDEF", "{0}", "getBasePlusPropStr", "getSpPlusPropStr", "PropVo", "getPropVosForShowByStr", "bopre", "jisuanPropVo", "addPropVo", "addPropVo2", "initProp", "chm.PropUtil", "\u5145", "\u7d2f\u5151", "\u9996\u5151", "\u8fde\u5151", "\u9700\u5151", "\u5151\u6ee1", "QQ", "isQQPlatForm", "\\{", "\\}", "k_1732", "br", "getStringByteLen", "byte", "writeUTFBytes", "getLvstring", "k_184", "k_190", "getMSTime", "k_281", "k_122", "getHMSTime", "k_195", "k_199", "getSvrName", "k_269", "k_270", "getsvrNum", "getsvrName1", "s.", "urlToStr", "://", "9gsg9", "/", "9fsf9", "strTourl", "chm.StringUtil", "object", "numberUtill", "\u4e07", "\u4ebf", "checkLevel", "getZhuanLvl", "getHeadNumber", "chm.TypeUtil", "lock", "checkModule", "moduleSwitch", "ModuleSwitch", "addMduEvts", "emitter", "listener", "useCapture", "priority", "removeMduEvts", "dpMduEvts", "bubbles", "cancelable", "chm.Dispatcher", "chm.GameEvent", "chm.PropVo", "showMassage", "allowPay", "k_448", "moduleArr", "listenIds", "autoDisableIds", "enterListenMdu", "leaveListenMdu", "initModule", "pcakModuleManager", "\u521d\u59cb\u5316\u5206\u5305", "addSuccessEventListener", "LoginMdu", "MainMdu", "MapMdu", "BagMdu", "SmeltMdu", "RoleMdu", "PortMdu", "BossMdu", "TestMdu", "AchMdu", "ForgeMdu", "FightRMdu", "FubenMdu", "ZYZMdu", "SLMdu", "VipMdu", "ShopMdu", "KingMdu", "RankMdu", "PtnerMdu", "ChatMdu", "LotteryMdu", "ZZMdu", "TaskMdu", "EmMdu", "CZMdu", "OLMdu", "GWMdu", "MoldingMdu", "MoonMdu", "SuperMdu", "WelfareMdu", "FPMdu", "ActivityModule", "LRMdu", "TitleMdu", "GMMdu", "MilitRkMdu", "PlaySetMdu", "FamilyModu", "ArtifactMdu", "MainCityMdu", "OtherPopMdu", "RobotMdu", "PlayerSetMdu", "PrisonMdu", "SwbqMdu", "SCZBMdu", "CBZBMdu", "HfMdu", "NBiqiMdu", "LockMonMdu", "MPropMdu", "ReRolMdu", "CrsSvrMdu", "KFTTMdu", "ChengHaoMdu", "MazeMdu", "BRMMdu", "CrsHSMdu", "CrsSpMdu", "VipGiftMdu", "ZlingMule", "BabelModule", "LkRollerModule", "ShareGiftMdu", "CrossRankModule", "CrSandyModule", "FbMdu", "UpdActModule", "MainCityBossModule", "VideoMdu", "FzModule", "HBModule", "LTSuitMdu", "CrBossModule", "MasterMdu", "FunNoticeMdu", "OnlineModule", "MisteryLimitModule", "DirectBuyModule", "startModules", "_index", "moduleStartup", "aslanseModule", "etf", "res_load_progress", "_listenMduId", "\u5148\u79bb\u5f00\u4e86\u975e\u6ce8\u518c\u6a21\u5757", "leaveId =", "listenMduId = ", "_levelTime", "getListenIdNow", "getLevelTime", "checkAutoEnable", "ModuleManager", "chm.ModuleManager", "_waitingList", "_playing", "view", "_view", "SkillAwakeEffV", "AWAKE_PLAY_COMPLETE", "playComplete", "boNoSharePltfm", "grp_share", "lbl_share", "k_827", "clickShare", "getSharePoint", "WING_UP", "ConstSharePoint", "FA_BAO_ACTIVE", "ZHAN_LING_ACTIVE", "FASHION_GET", "TITLE_GET", "FA_ZHEN_ACTIVE", "CHUAN_SHI_ACTIVE", "OTHER_JOB_ACTIVE", "ZHUAN_SHEN_CHANGE", "SKILL_JUEXING", "FAN_TIAN_ACTIVE", "_curPlayVo", "activeType", "tyShare", "ShareGiftModel", "share", "showActive", "friendboss_png", "unshift", "userData", "lvl", "heroIdx", "showActRole", "ActiveMCPlayer", "chm.ActiveMCPlayer", "AlertSkin", "shape", "getshape", "addEvts", "onBtnDown", "btn_close", "btn_ok", "btn_canel", "getAlert", "commonLayer", "gmLayer", "txt", "showtime", "callBack", "timeCallBack", "OK_LBL", "CANCEL_LBL", "thisObj", "gameHeight", "lbl_time", "runTime", "totalTime", "timer", "Timer", "TIMER", "TimerEvent", "timerFunc", "closeView", "shutdown", "\u786e\u5b9a", "\u53d6\u6d88", "Shape", "beginFill", "graphics", "drawRect", "endFill", "GameAlert", "chm.GameAlert", "AwardShowSkin", "closeHandler", "refresh", "line", "scroller", "grp_bottom", "img_di1", "removeGrids", "lblNum", "grp_bonus", "cb", "AwardShow", "chm.AwardShow", "_imgs", "_shows", "addLis", "hashCode", "chm.BigImgRes", "ShopNumChoosePanelSkin", "type2", "getTip", "tip", "numChoose", "NumChoose", "groupChoose", "numChange", "closePnl", "btnClose", "askBuyItem", "btnBuy", "onResize", "msgOrBonus", "buyCb", "lmtNum", "formula", "openNumChoosePanel", "grp_item", "setBuyGridVo", "setText", "getSingleCost", "setBuyPerPrice", "currValue", "setCurrValue", "maxValue", "getMultiCost", "lblTotalPrice", "execWithExtra", "lblPrice", "cross", "BuyTip", "chm.BuyTip", "FunctionVOExt", "chm.FunctionVOExt", "CommonAlertSkin", "btn_cancel", "_curKey", "caches", "btn_check", "callObj", "flags", "_alert", "chm.CommonAlert", "_Indexs", "_moduleType", "checkBoxArr", "_checkBoxArr", "touchTap", "onclickcheckBox", "Indexs", "moduleType", "INDEXS_CHANGE", "INDEX_ALERT", "indexs_alert", "indexs_change", "PureSkinCheckBoxTwo", "chm.PureSkinCheckBoxTwo", "_lastSelectedIndex", "_checkBoxList", "initCheckBoxes", "toggleSelectedCheckBox", "CHANGE", "onCheckChange", "PureSkinCheckBox", "chm.PureSkinCheckBox", "ModuleBubbleVo", "chm.ModuleBubbleVo", "getEquipGrid", "GridEquip", "getItemGrid", "GridItem", "getHeroGrid", "GridHero", "createGridVo", "currency_json", "getObj", "getItemInfoById", "specials", "usetype", "selecType", "usecount", "canUseCount", "boxType", "boxtype", "fightfigurequip_json", "GridEquipVo", "getEquipInfoById", "EquipJsonConfigData", "worth", "splitGridVo", "showType", "getHeroCfgById", "RoleCfgMod", "getTitleEleByID", "TitleCfg", "desc1", "des1", "getthunderEleByID", "LTMod", "ltSuitEequipIcon", "LTStatic", "define", "getFast", "item_json", "equip_json", "title_json", "wingequip_json", "thunderequip_json", "getNameById2", "getQualityById", "chm.GridFactory", "HERO_TYPE_URL", "bag_job_{0}_png", "EQUIP_BG", "equip_bg_{0}_png", "TEJIE_BG", "tejie_bg_{0}_png", "ZHUZAI_BG", "zhuzai_bg_{0}_png", "MAGICPROP_BG", "magicprop_bg_{0}_png", "WHITE_SRC", "bag_white_png", "GREEN_SRC", "bag_green_png", "BULE_SRC", "bag_blue_png", "PURPLE_SRC", "bag_purple_png", "ORANGE_SRC", "bag_orange_png", "RED_SRC", "bag_red_png", "GRID_BRODER_SRC", "JOB_ZHANSHI", "bag_job_1_png", "JOB_FASHI", "bag_job_2_png", "JBO_DAOSHI", "bag_job_3_png", "JOB_SRC", "ARTIFACT_BLUE", "holy_main_png", "ARTIFACT_PURPLE", "holy_mian2_png", "ARTIFACT_ORANGE", "holy_mian3_png", "GRID_BRODER_ARTIFACT", "GRID_EFFECT", "master_orange_effect", "master_red_effect", "GRID_EFFECT1", "purple_effect", "GridStatic", "chm.GridStatic", "tab", "tab2", "ModulePopVO", "chm.ModulePopVO", "GridBookVo", "chm.GridBookVo", "GridBoxSkin", "imgOpen", "itemid", "imgEmpty", "sign", "icon_k_2_png", "icon_k_1_png", "imgCloseSelect", "getBoxGrid", "BoxGrid", "chm.BoxGrid", "BoxGridVo", "chm.BoxGridVo", "_hasInit", "GridEquipSkin", "imgQuality", "imgIcon", "getChildIndex", "effectChange", "effectChange1", "onAddToStage", "removeFrom", "onAddChange", "playEft", "playEffect1", "imgHeroType", "chm.GridEquip", "plus", "createAttri", "fightNum", "chm.GridEquipVo", "GridForgeSkin", "imgSelect", "lblLvl", "lvlStr", "getForgeGrid", "GridForge", "chm.GridForge", "GridForgeVo", "chm.GridForgeVo", "ismine", "GridHeroSkin", "touchHero", "group_locked", "islocked", "group_hero", "lbl_openLimit", "lockedLimit", "img_hero", "img_type", "img_tip", "isTip", "img_select", "isSelect", "CLICK_HERO", "click_Hero", "chm.GridHero", "initVo", "isOpen", "wingLevel", "GridHeroVo", "chm.GridHeroVo", "GridItemSkin", "checkChangeName", "selfcount", "right", "chm.GridItem", "ModuleRedVo", "chm.ModuleRedVo", "isNeedEffect", "isNeedLevel", "GridOrgEquipSkin", "effect_orange", "touchGrid", "CLICK_SKILL", "GridSkill", "checkEffect", "oldParentJob", "parentJob", "oldId", "bg", "group_equip", "imgZhuhun", "iszhuhun", "soulLvl", "soul_lvl", "URL", "lbl_qianghua", "strong", "lbl_zhuling", "soul", "playOrangeGetEffect", "groupEffect", "smelt", "PLAY_COMPLETE", "playEeffectComplete", "getOrgEquipGrid", "{0}_png", "GridOrgEquip", "chm.GridOrgEquip", "severStrong", "severStone", "severSoul", "GridOrgEquipVo", "chm.GridOrgEquipVo", "GridSkillSkin", "_oldLevel", "_oldParentJob", "parentjob", "lbl_gapNum", "Lv", "lbl_openLevel", "openLevel", "k_705", "k_706", "getGridSkill", "click_skill", "chm.GridSkill", "GridSkillVo", "chm.GridSkillVo", "SpecialIconSkin", "lbl_add", "img_close", "img_item", "isOPen", "group_open", "getSpecialIcon", "SpecialIcon", "chm.SpecialIcon", "levelExp", "SpecialIconVo", "chm.SpecialIconVo", "GridWearEquipSkin", "grp_star", "playOrEft", "playComp", "getWearEquipGrid", "GridWearEquip", "chm.GridWearEquip", "fuling", "isLegend", "GridWearEquipVo", "chm.GridWearEquipVo", "ZhuzaiIconSkin", "gap", "group_six", "lbl_level", "getZhuzaiIcon", "ZhuzaiIcon", "chm.ZhuzaiIcon", "HeroListSkin", "sd", "grideArr", "clickHeroHandler", "roleIndex", "HEROLIST_SELECTINDEX_WINGEQUIP", "HEROLIST_SELECTINDEX", "getHeroList", "heroList_selectIndex", "heroList_selectIndex_wingequip", "HeroList", "chm.HeroList", "HeroListVo", "chm.HeroListVo", "changeValue", "minValue", "NumChooseSkin", "_maxValue", "restrict", "0-9", "btnAddTen", "btnMinuTen", "btnLest", "btnMax", "btnAdd", "btnMinu", "inputHandler", "addDell", "minuDell", "minuTenDell", "addTenDell", "chm.NumChoose", "setCurrentJson", "_actId", "_subId", "_currentJson", "actId", "arr", "point", "messageLayer", "getBtnPos", "MainMod", "wait", "sineIn", "Ease", "sineOut", "RewardFlyManger", "chm.RewardFlyManger", "RewardFlyVo", "chm.RewardFlyVo", "setLocDis", "NewPureSkinTabBar", "chm.NewPureSkinTabBar", "onClientReady", "container", "RESIZE", "sceneLayer", "weatherLayer", "mainLayer", "downMainLayer", "storyLayer", "tipLayer", "setLayerPos", "offsetY", "offsetX", "LayerBase", "isTyPlatform", "clickStaByAd", "gameWidth", "hdbg_jpg", "FH", "hideMapLayer", "showMapLayer", "chm.MainLayer", "_redPoint", "main_tip_png", "chm.RedPoint", "getLine", "tips_line_png", "getTextField", "TextField", "lineSpacing", "TipComponent", "chm.TipComponent", "createItemTip", "createEquipTip", "createBookTip", "createHeroEquipTip", "createFightFigureTip", "createmagicpropTip", "initShape", "hidePanel", "_itemTip", "TipItem", "_showTip", "showPanel", "_magicpropTip", "TipMagicProp", "imgScale9Grid", "_equipTip", "TipEquip", "_bookTip", "TipBook", "_heroEquipTip", "TipHeroEquip", "_fightFigureTip", "TipFightFigure", "TipManger", "chm.TipManger", "TipBookSkin", "lblDes", "lblScore", "k_453", "fight", "chm.TipBook", "TipDesSkin", "imgBg", "TipDes", "chm.TipDes", "_tip", "setDes", "TipDesManager", "chm.TipDesManager", "initHeight", "addStartHeight", "addHeight", "TipEquipSkin", "getFightPowerImageNum", "FightPowerImageNum", "groupFight", "lblJob", "getHeroNameByJob", "lblPos", "getEquipPosNameByPos", "lblFight", "k_1556", "specialfightNum", "WINGEQUIP", "RoleStatic", "getMaxWingLevel", "lblLvlDes", "k_910", "k_255", "k_924", "k_925", "k_909", "k_256", "createBasePorp", "createSpPorp", "descLabel", "k_919", "lblBaseTitle", "k_905", "lblBaseProp", "numLines", "lblSpTitle", "lblSpProp", "spLineImg", "equipId", "getLeiTingSpecProp", "k_929", "chm.TipEquip", "TipFightFigureSkin", "imgStrongMiddle", "lblMiddleTitle", "lblMiddleProp", "imgStrongBase", "imgStrongCost", "lblCostTitle", "lblCostProp", "getZwEle", "ArtCfg", "lblType", "classId", "FIGURE_CLASS", "ArtStatic", "lblQuality", "COLOR_CH", "createMiddlePorp", "nextType", "createBaseProp", "k_121", "nextCost", "splitNum", "createCostProp", "k_926", "k_927", "k_928", "chm.TipFightFigure", "stoneRenderArr", "_maxScrH", "_zwPos", "TipHeroEquipSkin", "imgBaseLine", "imgStrong", "lblStrongTitle", "lblStrongProp", "imgStone", "lblStoneTitle", "ForgeStoneRnd", "imgSoul", "lblSoulTitle", "lblSoulProp", "imgFuling", "lblFulingTitle", "lblFulingProp", "rankOpen", "RankMod", "getGridHeroListSelectIndex", "fulings", "prData", "FulinVO", "transform", "heroSelectIdx", "skys", "lv", "heros\u957f\u5ea6\uff1a", "heroIdx: ", "getHerosFulinData", "grp_xx", "createMagicPorp", "createStrongPorp", "proDesc", "createStonePorp", "createFulingPorp", "createSoulPorp", "createEffPorp", "createZWProp", "proDescScr", "scrollV", "createDesc", "lblMagicTitle", "lblPropMagicProp", "magicLineImg", "getCurFuseLvl", "MPropMod", "getfuseLvlConf", "k_930", "getStrongLvlById", "ForgeCFGMod", "k_906", "getEquPropById", "k_907", "getStoneDataByLvl", "ForgeMod", "attriVo", "k_373", " Lv.", "getFulinPropByK", "getSoulLvlById", "k_908", "getSoulPropById", "lblEffTitle", "lblPropEffTitle", "lblPropEffDesc", "lblSkillEffTitle", "lblSkillEffDesc", "effLineImg", "\u2160", "\u2161", "\u2162", "\u2163", "\u2164", "\u2165", "k_454", "getPropEffStrByPos", "getSkillEffStrByPos", "k_455", "k_451", "getFuseSkillConf", "k_452", "heroArr", "ArtifactMod", "equips", "zwLineImg", "lblZWTitle", "lblZWProp", "classify", "\u6218\u7eb9\u6548\u679c", "{0}\uff1a+{1}%", "chm.TipHeroEquip", "_model", "TipItemSkin", "getSoulCost", "own", "lblShu", "chm.TipItem", "TipMagicPropSkin", "NaN", "getPropEffStr", "getSkillEffStr", "getFuseSkillConfByTp", "getfuseLvlConfByType", "chm.TipMagicProp", "TipOrangeEquipSKin", "img_itemIcon", "img_quality", "img_job", "k_918", "k_917", "deleteTime", "_delay", "HIDE_STAR", "MOVE_HEIGHT", "MOVE_TIME", "TipOrangeEquip", "chm.TipOrangeEquip", "_tipArr", "rspSBagEquipChanges", "boxs", "getTipOrangeEquip", "storeTip", "refreshShow", "starHiden", "deleteTip", "TipOrangeEquipManager", "chm.TipOrangeEquipManager", "chm.DDisp", "RECOVER", "RECOVER_MULTI", "THIEF", "DEAD", "REVIVE", "HP_HURT", "DECATT", "DECDEF", "ACROSSPDEF", "ACROSSSDEF", "RECOVERYHP", "DECHP_ADDPERCENT", "ABSDECATT", "ABSDECDEF", "cLen", "cIndex", "config_data", "config_map", "getConfigObjByName", "getConfigByName", "getSigle", "getSigleValueByName", "docompressZzp", "_docomStep", "_confName", "Inflate", "decompress", "readUTF", "config_name", "bin\u6587\u4ef6\u89e3\u6790\u51fa\u9519\uff01", "_docomStep:", "---confName:", "unit", "mapKey", "config_ios_bin", "config_bin", "chm.GameCf", "sendStep", "steps", "boNewpalyer", "QufuManager", "isFirstLogin", "__sign", "sendLog", "_errorCode", "  ", "iswxgame", "issuper", "loghost", "type=", "step=", "step", "sign=", "msg=", "msg", "token=", "logintime=", "username=", "uname", "platformId=", "platform", "?", "&", "HttpRequest", "HttpMethod", "Content-Type", "application/x-www-form-urlencoded", "setRequestHeader", "sendDJSLoginLog", "isFlag", "isEnterTest", "isNotWXGame", "register", "login", "who=", "deviceid=", "appid=", "rGTaSneKdZ4yx", "serverid=", "zoneid", "level=", "channelid=", "xcx", "chid", "subchid=", "subchid", "sendDJSLog", "sendDJSPaymentLog", "payment", "xcx2413gankqq", "transactionid=", "transactionid", "wid=", "currencyamount=", "price", "virtualcoinamount=", "gold", "channellog", "\u72ec\u89d2\u517d\u4e0a\u62a5\uff1a", "POST", "cache-control", "no-cache", "contentType", "text/html;charset=uft-8", "application/x-www-form-urlencoded;", "chm.GameLogSendUnit", "fight_num1_{0}_png", "getFightImageNum", "fightImagePool", "maxPoolNum", "FightImageNum", "chm.FightImageNum", "imgWidth", "imgHeight", "imges", "getFontImage", "imagePool", "getFontImageByType", "piaozi_bg_png,jiuji_mo_{0}_png,jiuji_shen_{0}_png,jiuji_fu_{0}_png,jiuji_sheng_{0}_png", "piaozi_bg_png,jiuji_tian_{0}_png,jiuji_shen_{0}_png,jiuji_bi_{0}_png,jiuji_hu_{0}_png", "piaozi_bg_png,jiuji_seng_{0}_png,jiuji_dian_{0}_png,jiuji_tian_{0}_png,jiuji_shen_{0}_png,jiuji_bi_{0}_png,jiuji_hu_{0}_png", "FightImages", "chm.FightImages", "mainfight_{0}_png", "fightPowerImagePool", "chm.FightPowerImageNum", "img", "getFImgByType", "sourcekeys", "fight_crit_{0}_png", "fight_hushen_png", "fight_mabi_png", "fight_xuanyun_png", "fight_fanshang{0}_png", "fight_fuhuo_png", "fight_huifu_png", "fight_fushi{0}_png", "fight_canfei{0}_png", "fight_weishe{0}_png", "fight_zhimin{0}_png", "fight_shanbi{0}_png", "fight_blast_png", "fight_shenshenggongji{0}_png", "fight_shenzhu_png", "fight_lianji_png", "fight_miss{0}_png", "fight_ice{0}_png", "fight_zhongshang{0}_png", "fight_cuiruo{0}_png", "fight_mianshangup{0}_png", "fight_lingmodun_png", "fight_nuniu_png", "fight_monster_png", "fight_shenyu{0}_png", "fight_mzxiajiang{0}_png", "fight_baoliezhan_png", "fight_bingfnegbao_png", "fight_hurricane_png", "fight_baoliezhan1_png", "fight_bingfnegbao1_png", "fight_hurricane1_png", "fight_shizizhanyue_png", "fight_huolongwu_png", "fight_armour_png", "fight_fabao_png", "fight_zibao{0}_png", "fight_huoyu{0}_png", "fight_xishou{0}_png", "fight_huti_{0}_png", "fight_yiji_{0}_png", "FontImage", "chm.FontImage", "chm.LayerBase", "getMainImageByType", "noviceguide_1_png", "noviceguide_2_png", "noviceguide_3_png,noviceguide_4_png", "noviceguide_6_png,noviceguide_5_png", "noviceguide_7_png", "noviceguide_8_png", "noviceguide_9_png", "noviceguide_10_png", "noviceguide_11_png", "noviceguide_12_png", "noviceguide_13_png", "noviceguide_14_png", "MainImages", "chm.MainImages", "getPowerUpImageNum", "powerupImagePool", "PowerUpImageNum", "chm.PowerUpImageNum", "fight_num4_{0}_png", "AddHpImageNum", "chm.AddHpImageNum", "fight_num3_{0}_png", "DaoShiFightImageNum", "chm.DaoShiFightImageNum", "fight_num2_{0}_png", "FaShiFightImageNum", "chm.FaShiFightImageNum", "ImageWidth", "setImage", "getHurtTypeFont", "HurtTypeFont", "chm.HurtTypeFont", "fight_num5_{0}_png", "MyPlayerFightImageNum", "chm.MyPlayerFightImageNum", "getLimitArr", "getSelfLimitValue", "LimitVO", "limitName", "selfValue", "limitValue", "MONEY", "FAKEGOLD", "getExp", "EXP", "getrLv", "PLAYERLEVEL", "VIP", "getSoulNum", "SOUL", "WINGEXP", "BAGCOUNT", "ZSEXP", "getAchievePoint", "ACHIEVEPOINT", "getOwnCountById", "getEquipCountById", "00", "transCost", "chm.LimitStatic", "chm.LimitVO", "_dic", "_resDic", "getMapDirUrl", "map_version", "map/", "getAvatarResUrl", "avatarres", "avatar_version", "avatarres/", "ResManager", "chm.ResManager", "_yAjustedDic", "popWindown", "h_p_q_x", "lt", "fight_down_png", "scale9Grid", "is640", "stageCenterY", "stageCenter", "POP_UI_MP3", "SoundStatic", "playOnce", "SoundMgr", "stopTimeOut", "Guide", "pop2depth", "startTimeOut", "popremoveAll", "shapeAllScreen", "popAlert", "ontouchendHandler", "_shapeOn", "resetShape", "removeAlert", "playSuccessEffect", "playFailEffect", "successEffect", "playComFunc", "playSuccessEffectComplete", "success_effect", "failEffect", "playFailEffectComplete", "normal_effect", "showRuledesc", "ruleView", "HowToPlayMed", "getRuleDescVO", "BossCfgMod", "showDes", "childCenter", "shapesAllScreen", "isVivoPlatForm", "\u6267\u884cvivo\u521b\u5efashape", "modal_mask_png", "Group", "Button", "ChatBtn", "HandUpBtn", "MonsterNianBox", "HBBtn", "CrBossFightView", "GWV", "panel", "tPan", "NpcDV", "topPartH", "ResizeController", "bottomPartH", "RebornExpEui", "OLPan", "WelfareV", "HeroValueEui", "group_content", "TeJieSJEui", "group_window", "hl", "ZZV", "uEui", "dEui", "jEui", "eEui", "BossZSRwdV", "SCZBEntryV", "SCZBAlertV", "goup_content", "CreateView", "AddUpSharePanel", "FaScreenEui", "guild_bg_jpg", "bottom", "btn_back", "CrsSvrV", "popChildAdd", "shapeClear", "popTargetOpen", "anyData", "chm.UIManager", "_msgs", "_msgArr", "max_num", "showGroup", "_timer", "wordGroup", "addMessage", "getSingleMessage", "messageStr", "startTweenAlpha", "deletemsg", "SingleFBMessage", "MessageFBManager", "chm.MessageFBManager", "numY", "mainGrp", "showLeftMessage", "grpTween", "_grpTween", "tweenEnd", "parseDir", "oppposite", "SingleRightMessage", "SingleLeftMessage", "_msg_right", "MessagLeftManager", "chm.MessagLeftManager", "\u524d\u5f80", "\u5143\u5b9d\u4e0d\u8db3\uff01", "k_283", "MESSMANAGER_LOOP", "SingleMessage", "showPaoPaoMassage", "paoPaoMsgLb", "_paoPaoMsgLb", "SinglePaoPaoMessage", "chm.MessageManager", "_message", "_bgCon", "_wordCon", "treasure_get_bg_png", "lbl_message", "left", "verticalAlign", "middle", "_ImgMul", "treasure_flag_1_png", "_x", "_y", "_messageStr", "chm.SingleFBMessage", "figure_yuyi2_png", "chm.SingleLeftMessage", "currency_prompt_bg_png", "chm.SingleMessage", "chm.SinglePaoPaoMessage", "chm.SingleRightMessage", "moduleSwitch_json", "getRes", "_switchList", "OpenCheck", "checkView", "moduleName", "\u6682\u672a\u5f00\u542f\uff01\uff01", "chm.ModuleSwitch", "Type_ModuleSwitch", "chm.Type_ModuleSwitch", "PowerUpSkin", "PowerUpEui", "chm.PowerUpEui", "_skin", "_randomTimer", "getTotalPower", "_timeOutIndex", "_addNum", "_targetNum", "_frontNum", "_loopTime", "LOOP_TIME", "PowerUpStatic", "DELAY_TIME", "delay", "_loopAddNum", "_loopNum", "startRandom", "moveAddNum", "randomLoop", "addNumImg", "mainfight_{0}_s_png", "jia", "clearLblAdd", "LABEL_HIDE_TIME", "SKIN_HIDE_TIME", "PowerUpManger", "chm.PowerUpManger", "chm.PowerUpStatic", "jindutiao1_di_png", "jindutiao1_01_png", "_maxPar", "_currPar", "_moveType", "_swith", "_sheight", "_px", "_py", "img_bar", "maxPar", "setLabel", "currPar", "moveType", "CProgressBar", "chm.CProgressBar", "MAP_SCN_W", "MAP_SCN_H", "MAP_IMG_W", "MAP_IMG_H", "MAP_NODE_W", "MAP_NODE_H", "version", "ZHUCHENG_ID", "zhucheng", "NEWCOMER_ID", "newcomer", "NEWCOMERSj_ID", "newcomer_shenji", "SWBQ_ID", "guard", "Sandy_waicheng", "waicheng", "Sandy_neicheng", "neicheng", "Sandy_dianwai", "dianwai", "Sandy_huanggong", "huanggong", "Night_biqi", "night_fighting", "MapCfg", "chm.MapCfg", "_target", "_parent", "_maskWidth", "_maskHeight", "initMask", "_mask", "mask", "_progress", "chm.MaskBar", "ishide", "boss_xueliangcao_png", "HPBAR_CHANGE", "hpbar_change", "PureSkinHpBar", "chm.PureSkinHpBar", "PureSkinMaskBar", "chm.PureSkinMaskBar", "barArr", "loseHpCount", "addBar", "removeHpbar", "change_multihpbar", "PureSkinMultiHpBar", "chm.PureSkinMultiHpBar", "bottomBg", "popTarget", "onRemoveStage", "beijing_jpg", "bgWidth", "guildBgWidth", "normalWidth", "group_boomSkin", "gw", "boom", "boomSkin", "gameWindow", "windownPanel", "window", "RoleV", "ROLEVIEW_RESIZE", "RRoleV", "RANKROLE_VIEW_RESIZE", "LotteryV", "ORANGEEQUIP_VIEW_RESIZE", "roleview_resize", "rankrole_view_resize", "orangeequip_view_resize", "ZHUZAI_VIEW_RESIZE", "zhuzai_view_resize", "chm.ResizeController", "DMNoticeSkin", "dmLine", "loopKey", "dm_loopkey_", "playDMNotice", "lblNotice", "loopTime", "runNoticeComplete", "DMNotice", "chm.DMNotice", "playNotice", "DMNoticeManger", "chm.DMNoticeManger", "RunNoticeSkin", "RunNotice", "chm.RunNotice", "_noticeArr", "_modstate", "_runNotice", "groupNotice", "pushNotice", "checkDelayDel", "sortNotice", "runNotice", "getNoticeConf", "ChatCMod", "delayDel", "bmod", "ssort", "msort", "getNearNotice", "imgLaba", "boLaba", "_boShine", "shineLaba", "clearShineLaba", "wordWrap", "multiline", "run_notice", "laba_shine", "changeLaba", "horn_png", "openModule", "closeModule", "RunNoticeManger", "chm.RunNoticeManger", "RunNoticeVo", "chm.RunNoticeVo", "col", "row", "hasRes", "image", "resPath", "addResourceData", "ITEM_LOAD_ERROR", "ResourceEvent", "loaderError", "TYPE_IMAGE", "ResourceItem", "getResByUrl", "textureData", "LOAD_COMPLETE", "resItem", "LOAD_ERROR", "load_complete", "load_ERROE", "MapLoader", "chm.MapLoader", "setSwingPos", "vx0", "vy0", "SWING_AHEAD_FRAME", "setAlphaBlink", "SNOWFALL", "DROP", "SWING", "BUNCE", "BLINK", "ParticleEaseUtil", "particlesys.ParticleEaseUtil", "numOfParticles", "maxOfParticles", "particleClass", "_allowWind", "_ease", "_isReverse", "_adjustType", "_iswindOn", "_windCount", "_easeCount", "_easeAscend", "_lastReferSysX", "_lastReferSysY", "particles", "pool", "emitterRect", "emissionTime", "emissionRate", "screenWidthLimit", "screenHeightLimit", "NUMOFINSTANCE", "sysId", "setParticleClass", "setEmitterRect", "setEmitterTime", "setParticleRectLimit", "setDetail", "setReferenceSys", "_referSys", "onResize2", "sysTimeStamp", "LOOP_KEY", "clearAllParticle", "getWindAttr", "_easeMove", "RoseParticle", "swingAheadFrame", "SparkParticle", "alpha0", "getDtTimer", "_lastParticleTime", "addOneParticle", "PROBABILITY_WIND", "removeOneParticle", "rotRate", "skewX", "skewRate", "SnowParticle", "exRangeX", "exRangeY", "snowparticlesys", "ParticleSys", "particlesys.ParticleSys", "attr1", "_getDistribution", "attr2", "attr3", "attr4", "ROSE_PARTICLE_SETTINGS", "texture", "anchorOffsetX", "anchorOffsetY", "ROSE_BASE_SIZE", "scaleRate", "NUMCOUNT", "ROSE_PARTICLE_DISTRIBUTE", "1:1:3:3:2", "rose5", "rose5_png", "rose4", "rose4_png", "rose3", "rose3_png", "rose2", "rose2_png", "rose1", "rose1_png", "particlesys.RoseParticle", "SNOW_BIG", "SNOW_NORMAL", "SNOW_SMALL", "SNOW_LITTLE", "SNOW_PARTICLE_SETTINGS", "SNOW_BASE_SIZE", "SNOW_PARTICLE_DISTRIBUTE", "2:3:3:2", "snow_little", "snow4_png", "snow_small", "snow3_png", "snow_normal", "snow2_png", "snow_big", "snow1_png", "particlesys.SnowParticle", "SPARK_PARTICLE_SETTINGS", "SPARK_BASE_SIZE", "SPARK_PARTICLE_DISTRIBUTE", "2:2:2:2:2", "spark1", "sparkamian_png", "spark", "particlesys.SparkParticle", "Boom10Skin", "Boom10Window", "chm.Boom10Window", "Boom12Skin", "Boom12Window", "chm.Boom12Window", "Boom17Skin", "Boom17Window", "chm.Boom17Window", "Boom1Skin", "Boom1Window", "chm.Boom1Window", "calculateStageSize", "CQSceneAdapter", "chm.CQSceneAdapter", "egret.sys.IScreenAdapter", "Boom3Skin", "Boom3Window", "chm.Boom3Window", "Boom4Skin", "Boom4Window", "chm.Boom4Window", "Boom5Skin", "Boom5Window", "chm.Boom5Window", "Boom6Skin", "Boom6Window", "chm.Boom6Window", "Boom7Skin", "Boom7Window", "chm.Boom7Window", "Boom8Skin", "Boom8Window", "chm.Boom8Window", "BoomSkin", "BoomWindow", "chm.BoomWindow", "WindowSkin", "GameWindow", "chm.GameWindow", "SmallWindwoSkin", "SmallGameWindow", "chm.SmallGameWindow", "ErrorcodeDS", "EnterTypeStoreDS", "EquipDS", "PortInfoDS", "artifact", "ArtifactDS", "activeTask", "ActiveTaskDS", "lottery", "LotteryDS", "email", "EmDStor", "activity", "ActDtS", "achieve", "AchieveDS", "FamilyDS", "hefuactivity", "HefuActDS", "backactivity", "BackActivityDS", "chm.DS", "editor", "AchieveDSEditor", "getAchieves", "achieves", "getAchieveFinishCount", "getAchieveState", "achieveId", "getAchieveValue", "typeValue", "checkShow", "ids", "chm.AchieveDS", "_achieves", "_typeValue", "_ids", "rspOnSActiveTaskStateChange", "rspAchRwdId", "states", "rewards", "chm.AchieveDSEditor", "_achieveDic", "_achieveTitleDic", "_titles", "parseXml", "achieve2_json", "_len", "classification", "tittle", "getAllTitles", "getArrayBy", "getNeedById", "getDesById", "getBonusById", "getTitleById", "tiltle", "len", "getIds", "achievereward_json", "getTotal", "fabaoActivate_json", "AchieveJsonConfigData", "chm.AchieveJsonConfigData", "ActiveTaskDSEditor", "getActives", "actives", "getboxes", "boxes", "getactiveNum", "activeNum", "getstore", "store", "getActiveFinishCountById", "activeId", "finishCount", "chm.ActiveTaskDS", "onActiveChanged", "chm.ActiveTaskDSEditor", "_activeTaskDic", "_idArr", "_boxes", "activetask_json", "SHARE", "activebox_json", "getIdArr", "getGetGotoById", "getMaxById", "getRewardById", "getBox", "ActiveTaskJsonConfigData", "chm.ActiveTaskJsonConfigData", "_editor", "ActivityInfoEditor", "chm.ActDtS", "svrPromDic", "rspSLoginLoginResult", "rspSActivityUpdate", "updataActivityByServerTime", "GlobalEventManager", "clearActivits", "rspPromInfoUpdate", "rspPromJsnUpdate", "updateDailyPromotion", "activitys", "_activityTable", "ActivityInfo", "activities", "activityAliveCheckByEndTime", "jsonStr", "setSvrXmls", "rspCfgUpdate", "promjson_activitys\u672a\u521d\u59cb\u5316, zoneid", "ActivityNewInfo", "convertPromVO", "promotions", "getSvrXmlById", "duration", "content", "amount", "specialamount", "BonusId", "serverProgress", "ActivityServerProcessData", "chargeProgress", "bonusIndex", "DataPropertyChange", "chm.ActivityInfoEditor", "ArtifactDSEditor", "getArtifacts", "artifacts", "getArtifactById", "artifactsId", "chm.ArtifactDS", "_artifacts", "rspSUpdateArtifacts", "_2", "chm.ArtifactDSEditor", "BackActivityInfoEditor", "chm.BackActivityDS", "rspLoginResult", "updataActivityByCurrenyChange", "updataActivityByPowerChange", "updataActivityByLevelChange", "updataActivityByLongSoulChange", "updataActivityByStoneChange", "updataActivityByMedalChange", "updataActivityByItemChange", "updataActivityByWingChange", "updataActivityBySuitChange", "updataActivityByVipChange", "activityData", "_activityData", "BackActivitySingleDataVo", "rspBackActivityUpdate", "LimitShop", "updateActivityByKey", "DiscountShop", "SubLimitShop", "SubTotalCheckActivity", "TimingGet", "CollectFontShop", "NationalDayCollectFontShop", "PowerLevel", "PlayerLevel", "StoneLevel", "LongSoulLevel", "MedalLevel", "WingLevel", "SuitLevel", "VIPLevel", "updateActivity", "chm.BackActivityInfoEditor", "addEL", "getEmails", "_emails", "getIsWarn", "_isWarn", "emails", "fj", "isGet", "gMails", "rMail", "mgetFJ", "mgetFJs", "newMail", "rspSMailDelete", "clearMail", "mail", "reverse", "readType", "mailIds", "chm.EmDStor", "_isPk", "_enterType", "_startChallenge", "checkEnter", "getEnterTypeDesc", "startChallenge", "isPk", "onPKStateChange", "MainBossHp", "_enterTypeDescConf", "special_json", "k_167", "chm.EnterTypeStoreDS", "wingBoxs", "EquipDSEditor", "getEquips", "boxChange", "getEquipsCountInBag", "getEquipBoxDataByOnlyId", "boxIndex", "chm.EquipDS", "_boxChange", "_equips", "rspSHeroLoadEquip", "box", "chm.EquipDSEditor", "posNames", "k_911", "k_913", "k_912", "k_914", "k_915", "k_916", "k_920", "k_921", "k_922", "k_923", "_equiphistoryDic", "getEquipPropById", "getEquipJsonInfoById", "getEquipBaseIDByPosAndLimit", "getEquipJsonArrByLimits", "getEquipBaseIDByLevel", "getEquipBaseIDById", "getEquipBaseIDByLimit", "p", "j", "q", "redQuality", "chm.EquipJsonConfigData", "rspSErrorHandler", "rspSErrorStringHandler", "SEND_MSG_BY_CILENT", "SdkEvent", "onshowMsg", "pub_dispac", "SEND_PAOPAOMSG_BY_CILENT", "onshowPaoPaoMsg", "_errorcordObj", "errorcord_json", "errorcode", "errorCode", "k_1468", "k_1469", "k_1470", "k_1471", "chm.ErrorcodeDS", "FamilyDSEditor", "gettaskFinishCount", "getMemberInfo", "selfMemebr", "getReqsutEffectBoolean", "effectValue", "getOderCount", "members", "offer", "getOfferMembers", "getShopBuyCount", "buys", "isRequstFamily", "requstFamilys", "getSkillLevel", "heroSkills", "heroIndex", "skillId", "getShopFlushTime", "shopFlushTime", "getBossStates", "bossStates", "getBossRed", "getStorageGold", "storageGold", "getStorageItems", "getRedPacket", "redPacket", "getUseLogs", "useLogs", "getRedLogs", "redLogs", "copyRankArr", "myCopyRank", "myRank", "checkIfMyFamily", "getDonateInfo", "skillDonateInfo", "getFamSkills", "famSkills", "getRwdState", "rwdState", "getUpCount", "upCount", "getSkillInfo", "skillid", "chm.FamilyDS", "_selfMemebr", "_family", "newFamily", "_shopFlushTime", "nexttime", "_requstFamilys", "_effectValue", "dailyTasks", "_bossstates", "_storageGold", "_currentRedPacket", "totalGold", "_useLogs", "_items", "_redLogs", "_newFamily", "setSelfMemberData", "setFamily", "setRequstList", "addRequstName", "onLeafOk", "onAddMember", "onRemoveMember", "onMemberUpdate", "buyDataChange", "shopFlush", "onNoticeChange", "onJoinLimitChange", "onTaskChange", "onLevelChange", "onLeaderChange", "onMemberSkillChange", "onVoteChange", "onInstursionData", "selfInstursionCountChange", "requstSizeChange", "onSummonChange", "onSummonAddOrRemove", "onGetStorage", "onItemChange", "onGoldChange", "onRedPacketChange", "onUseLogsChange", "onRedLogsChange", "getCopyInfo", "getFamilyCopyRank", "rspPublicSkill", "rspPublicskilldonate", "onNewFamilyNm", "getPalyerName", "PortRankVO", "curRank", "portNum", "vipLv", "isyue", "monthCard", "dologs", "redpacket", "redlogs", "familyNames", "bool", "familyId", "prevLeafFamilyTime", "member", "memberId", "buydata", "shops", "notice", "autoJoin", "auto", "joinLimitPower", "tasks", "money", "exp", "leaderName", "leader", "skills", "vote", "wholeVote", "dailyVote", "monsterState", "instrusions", "enemyResistRemain", "instrusion", "bosses", "bossstate", "_famSkills", "FAMILY_SKILL_UPDATE", "FamilyEvt", "UPDATE_CROSS_COUNT", "CrossHSEventType", "_rwdState", "FAMILY_SKILL_RWD_UPDATE", "_upCount", "FAMILY_SKILL_UPCOUNT", "takestate", "_skillDonateInfo", "chm.FamilyDSEditor", "_skillDic", "_levelDic", "_taskDic", "_orderDic", "_shopDic", "_famSkillDic", "taskList", "skillList", "orderList", "normalShopList", "famSkillList", "_skillStr", "\u516c\u4f1a\u8d21\u732e", "\u65f6\u95f4\u51cf\u5c11", "\u6d88\u8017\u51cf\u5c11", "\u4eba\u6570\u589e\u52a0", "familyskills_json", "familylevel_json", "familytask_json", "familyorder_json", "familyshop_json", "familypublicskills_json", "getSkillConfig", "getLevelConfig", "getTaskConfig", "getOrderCofig", "getShopConfig", "orders", "normalShops", "getMonsters", "familysetting_json", "intursion", "getShopOpenLevel", "shopopen", "getImpeachmentCost", "impeachment", "getcopyOpen", "magic_openlevel", "getRedMinGold", "redMinGold", "getRedLife", "redlife", "changeNameItem", "getOrderName", "_orderPos2NameDic", "CHAIRMAN", "VICECHAIRMAN", "SENIRO", "PROTECTOR", "NORMAL", "NOTMEMBER", "getSkillUpValue", "publicSkillCostParam", "publicSkillCostCount", "getSkillStr", "decCd", "decSkillCost", "carAddNum", "getFamSkillConfig", "chm.FamilyJsonConfigData", "updataActivityByHefuCount", "mergeractivity_json", "_activitys", "chm.HefuActDS", "getSkillPoint", "template", "getSkillSetJson", "openLimit", "checkSkillLimit", "getSkillJson", "getSkillCostByLv", "getLimitSkillLevel", "HeroDataInfoStatic", "getAwakePoint", "SLMod", "getAwakeCfg", "awakeSkill", "getAwakeUpLvConf", "getCanjuanCost", "costId", "getJiuJiPoint", "JiuJiModel", "getJiuJiConfs", "studyLimit", "checkNumsPoint", "getJiuJiActive", "getJiuJiPassiveByIndex", "getLvlByHeroData", "itemsId", "getAwakeActive", "awakeIds", "fianlPassiveDatas", "passiveId", "HeroCheckRedPointStatic", "chm.HeroCheckRedPointStatic", "gridList", "fillHeroData", "newroleconfig_json", "getCurCfg", "changeSelectInfo", "weareEquipInfo", "EQUIP", "souls", "soulsLv", "posEquips", "stone", "getEnhanceById", "getSoulById", "suitsInfo", "MASTERSUIT", "suits", "teJieInfo", "TEJIE", "otherEquips", "otherEquipsExp", "checkIfRed", "TeJieSJMgr", "wingInfo", "WingVO", "getWingCfgJson", "starperlevel", "stageLevel", "currentExp", "showLevel", "getConfig", "totalExp", "skillInfo", "_60_png", "getSkillDesByID_Lv", "nextDes", "k_1482", "getCurrentMaxSkillCost", "getMaxCost", "ZhuanshenSkillLevel", "getMinSkillLevel", "meridianInfo", "MeridianVO", "meridian", "setShowLevel", "suitInfo", "SuitVo", "fillLv", "wingEquips", "wingEquip", "EquipBoxData", "wingGrowLvl", "growLevel", "wingFlyLvl", "flyupLevel", "chm.HeroDataInfoStatic", "HeroDSEditor", "hpArr", "maxHpArr", "mpArr", "maxMpArr", "getGridHeroList", "gridHeroArr", "getJobByHeroIdx", "getSelectGridHeroVo", "getWeareEquip", "getSuitsInfo", "getSuitAllPower", "allSuitPower", "getTeJieInfo", "getWingInfo", "getWingAllPower", "allWingPower", "getMaxSkillCost", "maxSkillCost", "getMeridianInfo", "totalPower", "getHeroPropData", "heroPropData", "getSuitInfo", "getFashion", "fashionData", "getMeridianTotalLevel", "getWingTotalStars", "getLongHunTotalLevel", "getHuDunTotalLevel", "getFashionData", "fashions", "getSoulsByIndex", "getForgeByIndex", "getFulinByIndex", "heroFulinData", "getStrongLvlByIndex", "getAllStrongLvl", "getStoneLvlByIndex", "getAllStoneLvl", "getSoulLvlByIndex", "getAllSoulLvl", "getPassiveByIndex", "passiveDatas", "getMagicItems", "magicItems", "getHeroSoulsLv", "getFashionByIndex", "checkDogSkillAwake", "getSwitchHeroList", "showHeroList", "attIndexs", "attIndex", "firstIndex", "chm.HeroDS", "_hpArr", "_maxHpArr", "_mpArr", "_maxMpArr", "_firstIndex", "rspSloginResultHandler", "rspHeroPropChangeHandler", "rspPlayerPowerChangeHandler", "rspSHeroLoadEquipHandler", "rspSHeroUpgradeToOrangeHandler", "rspSHeroUpgradeToLegendHandler", "rspSHeroActivationWingHandler", "rspSHeroAddWingExpHandler", "rspSHeroLevelUpWingHandler", "rspSHeroSkillChangeHandler", "rspSHeroLevelUpMeridianHandler", "rspSHeroNewRoleHandler", "rspSHeroLevelUpOtherEquipHandler", "rspSHeroUpdateSuitHandler", "changeSelectIndex", "rspSHeroEquipStrongHandler", "rspSHeroEquipStoneHandler", "rspSHeroEquipSoulHandler", "rspSHeroCastingSoulHandler", "rspSHeroStudyBookHandler", "studySuccess", "onLoginInit", "onWingEquipUpdate", "rspEquipFulin", "rspEquipFulinUpdate", "rspSMagicPropHandler", "rspFuse", "rspAwakeSkill", "rspRoleSelect", "rspRoleJobChange", "_gridHeroArr", "_heroPropData", "_totalPower", "_frontPower", "_heroList", "_magicItems", "jobs", "sexs", "others", "othersExp", "mp", "addMagicLvls", "jingmai", "askInfoIndex", "refreshWing", "k_765", "31", "crit", "critExp", "refreshExp", "changeHpMp", "hps", "mps", "maxHps", "maxMps", "heroprops", "upFightNum", "posValues", "passives", "_herosFulinData", "HeroSkyEquip", "awakeSkills", "_showHeroList", "indexArr", "_indexArr", "changeIndex", "getIndexArr", "_roleIndex", "indexs", "attindexs", "getFirstIndex", "_attIndex", "chm.HeroDSEditor", "chm.FulinVO", "_showLevel", "getJingmaiconfigJson", "stepState", "getState", "currentValue", "getValue", "nextValue", "getJingmailvJson", "costCount", "costID", "state_2", "getJingmaistageJson", "state_1", "chm.MeridianVO", "cost2", "getWingLvJson", "maxStar", "getWingStarJson", "k_712", "res", "cost1", "normalcost", "cost1Add", "moralreward", "grows", "RoleMod", "flys", "getCurrentValue", "getNextValue", "showState", "state1", "state3", "state2", "getString", "getWingEquExd", "CBZBCfgMod", "getJiaChenglvl", "getDanData", "wingmulti", "TEXT_4", "SuitStatic", "k_720", "yumaoCount", "chm.WingVO", "ItemDSEditor", "getItems", "itemId", "chm.ItemDS", "item_change", "dispatchEventItemChange", "rspSBagBoxChanges", "getFashionItemIds", "TitleMod", "boxData\u7684boxindex\u4e0e\u80cc\u5305\u6570\u7ec4\u7d22\u5f15\u5bf9\u4e0d\u4e0a\u53f7", "fashion_json", "k_732", "k_734", "2", "k_733", "chm.ItemDSEditor", "getItemSmallUrl", "_25_png", "chm.ItemJsonConfigData", "LotteryDSEditor", "getStorageBoxs", "storageBoxs", "chm.LotteryDS", "_storageBoxs", "rspSLotteryStorageChange", "chm.LotteryDSEditor", "MineInfoEditor", "getServerTime", "getUsername", "username", "playerName", "getHeadIcon", "main_head_1_0_png", "playerOnlyID", "playerId", "getHeadID", "head", "getSex", "rlevel", "getZsexp", "zsexp", "getZsExpExchangeCounts", "zsExpExchangeCounts", "vipLevel", "getVipExp", "vipExp", "getVipBoxs", "vipBoxs", "getRecharged", "recharged", "getFirstRecharged", "firstRecharged", "getHistoricalFirstRecharged", "historicalFirstRecharged", "getMooncardDataTime", "mooncardDataTime", "getMaxEquipCount", "maxEquipCount", "getBuyEquipBoxCount", "buyEquipBoxCount", "getJob", "getMagicKungfuId", "magicKungfuId", "getStroyexp", "stroyexp", "getKnighthoodId", "knighthoodId", "getShopExp", "shopExp", "soulNum", "getMedalLevel", "medalLevel", "achievePoint", "moduleGifts", "sworshipCount", "rankWorship", "getCombatGains", "combatGains", "getFightFigures", "fightFigure", "getZWJH", "zwjh", "createTime", "getLhexp", "lhexp", "getLhExpExchangeCounts", "lhExpExchangeCounts", "getLunHuiData", "lunhuiData", "getHideVip", "hideVip", "chm.MineInfoDS", "_rlevel", "_createTime", "delayDic", "rspSMonthCardChange", "rspSBagAddBagHandler", "rspSPlayer_LevelupHandler", "rspSPlayerDataChangeHandler", "rspSMagicLevelupMagicKungfuHandler", "rspSAchieveLevelupKnighthoodHandler", "rspSVipOnVipChangeHandler", "rspSVipGetVipBonusHandler", "rspSZhuanshengZhuansheng", "rspSZhuanshengAddExp", "rspSLevelUpMedal", "rankWorshipChange", "onChangeLeader", "onChangeName", "rspSFightFigureChangeHandler", "onChangeLhExpCounts", "onChangeLLevel", "rspHideVip", "rspSRechargeRollerUpdate", "rspVipInfo", "nextDayUpdatexp", "_serverTime", "_playerName", "_id", "_idNum", "_head", "_sex", "_level", "rLevel", "_zsexp", "_zsExpExchangeCounts", "_exp", "_gold", "fakeGold", "_fakeGold", "RMBgold", "_RMBgold", "_money", "_vipLevel", "iospayflag", "_vipExp", "_vipBoxs", "_recharged", "_firstRecharged", "_mooncardDataTime", "_maxEquipCount", "_buyEquipBoxCount", "_job", "_magicKungfuId", "_stroyexp", "_knighthoodId", "_shopExp", "_soulNum", "_medalLevel", "_achievePoint", "_moduleGifts", "_rankWorship", "_leader", "_combatGains", "_fightFigure", "_zwjh", "_lhexp", "_lhExpExchangeCounts", "_lunhuiData", "_hideVip", "serverVO", "vipboxs", "worShipCounts", "leaderIndex", "combatgains", "fights", "lunHuiData", "sorships", "newName", "buyCount", "equipMax", "specialType", "magicKungfu", "knighthood", "vipexp", "gets", "counts", "lunhui", "_historicalFirstRecharged", "fristRecharged", "chm.MineInfoEditor", "inCity", "PortInfoDSEditor", "getMainProcess", "mainProcess", "getround", "addRound", "sceneResult", "currentCount", "startGuideByPort", "getwin", "getchapterProcess", "chapterProcess", "getCopyCount", "getMeets", "meets", "gethasRevenge", "hasRevenge", "getnextMeetTime", "nextMeetTime", "gettask", "task", "getkingCount", "kingCount", "getbossCall", "bossCall", "getrevenge", "revenge", "getQuanMingCount", "quanMingCount", "chm.PortInfoDS", "rspSBattleResultHandler", "copyDataChange", "_mainProcess", "_round", "_meets", "_hasRevenge", "_nextMeetTime", "_kingCount", "_win", "_chapterProcess", "_bossCall", "_revenge", "_quanMingCount", "copyCount", "_copyCount", "checkRed", "FubenMod", "_task", "logoutTime", "revengeCount", "copyMaterails", "_sceneResult", "chm.PortInfoDSEditor", "ServerTimeDSEditor", "serverStartTime", "serverRealStartTime", "mergercount", "getOpenDay", "chm.ServerTimeDS", "lastServerTime", "lastClassTime", "_lastSend", "_mergertime", "_mergercount", "_isFirst", "ishasError", "_isFirstServerTime", "_isFirstSvrOpenTime", "_isRealStarTime", "_minuteCount", "rspSSystemHBHandler", "SERVER_TIME_MINUTE", "ServerTimeEventType", "activateGame", "rspSloginHandler", "onServerMergerHandler", "mergercounts", "checkHearBeat", "getTimeError", "k_1483", "getLoopKey", "serverstart", "timeLoop", "SERVER_TIME_HOUR", "CROSS_INFO_TIME_MINUTE", "service_time_loop", "_serverRealStartTime", "_serverStartTime", "chm.ServerTimeDSEditor", "server_time_hour", "server_time_minute", "cross_info_time_minute", "chm.ServerTimeEventType", "_hashMap", "initLanguage", "language_json", "getResAsync", "onGetLan", "k_628", "k_629", "k_630", "k_631", "k_632", "k_633", "k_634", "k_635", "k_636", "k_637", "k_638", "k_639", "k_640", "k_641", "k_642", "k_643", "k_644", "k_645", "k_646", "k_647", "k_648", "k_649", "k_650", "k_651", "k_652", "k_653", "k_654", "k_655", "k_656", "k_657", "k_658", "k_659", "k_660", "k_661", "k_662", "k_663", "k_664", "k_665", "k_666", "k_667", "k_668", "k_669", "k_670", "k_1474", "k_1475", "k_1476", "k_1477", "k_1478", "k_1479", "dlges", "SwbqDlgBub", "k_1430", "k_1431", "k_1432", "k_1433", "k_1434", "k_1435", "dlges2", "k_1436", "dic", "FubenCfgMod", "k_1341", "k_1342", "_posTexts", "SCZBStatic", "k_1129", "k_1128", "k_1127", "tp2Name", "dialoges", "k_1364", "k_1365", "k_1366", "k_1367", "k_1368", "k_1369", "k_1370", "k_1371", "k_1372", "k_1373", "k_1374", "k_1375", "FUNC_BTN", "ForgeStatic", "k_369", "k_370", "k_371", "k_1306", "k_1307", "k_1308", "LgM", "chm.LgM", "_vm", "AchMed", "addEvents", "bind", "targetOpen", "loginComplete", "askAchRwd", "checkIfShowRed", "AchMod", "ACHIEVETASK_CHANGE", "DRAGONBALL_CHANGE", "btnCreateComplete", "getFirstRed", "askForPullAchieveBonus", "askForPullAllAchieveBonus", "askForLevelUpMedal", "askForDragonBallUp", "askForPullScore", "askForPullBox", "boxId", "askTakeAchRwd", "chm.AchMdu", "_barWid", "_mdu", "_mod", "_taskMod", "AchTaskMod", "_medalMod", "MedalMod", "_actTaskMod", "ActTaskMod", "_drgBlMod", "DrgBlMod", "btnEff1", "btnEff2", "AchV", "created", "img_windowBg", "img_title", "achieve_title_png", "fillActTaskPnl", "TAB_SELE_CHG", "changeTab", "fillDrgBlPnl", "rfMedalPnl", "rfAchP", "rfAchPnl", "rfAchPnlLi", "fillrwd", "flyToBag", "ACHTASK_RED_CHG", "setAchTaskRed", "MEDAL_RED_CHG", "setMedalRed", "DRGBL_RED_CHG", "setDrgBlRed", "ACTTASK_RED_CHG", "setActTaskRed", "leftBtn", "taskV", "rightBtn", "actTaskV", "ActTaskRnd", "taskTitle", "AchbtnRnd", "AchTLRnd", "img_icon", "img_icon0", "_Shape", "tmask", "lbl_goto", "k_18", "btn_explain", "levelUpMedal", "btnFunc", "pnl", "medalV", "medalRank", "lookRank", "getWayMedal", "getMedal", "pullAllAchB", "btnPull", "getRwd", "group_icon", "clickToFB", "PULL_CLICK", "pullAchB", "ITEM_TAP", "ItemTapEvent", "onSelectLine", "levelUpDrgBl", "drgBlV", "drgBlRank", "askPullScore", "clickBox", "r0", "r1", "r2", "r3", "getWayDragon", "getDragon", "hideLostPanel", "lostP", "openMoonCard", "udAchTaskEff", "udDrgBlEff", "gotoCard", "measuredWidth", "_needPoint", "_point", "img_dragonballBg", "bead_bg_jpg", "img_medalBg", "achieve_bg2_jpg", "selType", "stopPlayPullBtnEff", "_fBeff", "_eff", "setRedPoint", "k_1276", "k_1277", "lefTime", "MoonMod", "showLostPanel", "maxExp", "k_897", "STORYEXP:1", "setActTaskLi", "upActiveBoxes", "setDrgBl", "dragonBallName", "needJf", "skillDesc", "k_889", "setDrgScore", "setDragonUp", "curProp", "k_109", "nextProp", "fullEff", "bwEff", "hGroup", "k_896", "k_895", "stopBallEffect", "checkIsShow", "r", "setMedal", "medalName", "stepNum", "setMedalUp", "needLevel", "needMoney", "curName", "nextName", "setMedalAch", "jfNum", "setAch", "setAchTitLi", "validateNow", "setAchLi", "ckRed", "setBtnEff", "playPullBtnEff", "getActiveVos", "getStoryCostById", "getPropById", "getlen", "setAchieveRwd", "lbl_score", "lbl_get", "k_17", "addEff", "lbl_count", "img_jinshi", "changeGraphics", "achFaBaEff", "achieve_get_bonus", "fabao_btneff", "AchGroupVo", "red", "getAchRedTit", "getAchVosByTit", "getStageById", "getLimitById", "getCostById", "getCostNeedById", "MedalCfgVo", "AchTaskVo", "order", "MAINPORT", "localToGlobal", "rwdRed", "boShowRed", "achievetask_change", "dragonball_change", "chm.AchMed", "_selType", "boShow", "tab_sele_chg", "chm.AchMod", "_json", "_boShowRed", "getTypById", "getDescById", "achtask_red_chg", "chm.AchTaskMod", "ActTaskRndVo", "ckActDDO", "curr", "boGet", "kungfu", "getActVoListByKey", "isAllTyPlt", "2019-8-3 0:0:0", "acttask_red_chg", "chm.ActTaskMod", "magickungfu_json", "DrgBlCfg", "chm.DrgBlCfg", "k_888", "drgbl_red_chg", "chm.DrgBlMod", "medal_json", "chm.MedalCfg", "medal_red_chg", "chm.MedalMod", "AchTaskPnl", "AchTaskV", "chm.AchTaskV", "AchPnl", "ActTaskV", "DrgBlV", "MedalV", "tabBar", "tab1", "tab3", "tab4", "selectedIndexChange", "cur", "playBallEffect", "chm.AchV", "ActTaskPnl", "artifact_bg2_jpg", "chm.ActTaskV", "DrgBlPnl", "DrgLostPnl", "k_19", "longzhu_full_effect", "longzhu_bw_effect", "hbwGroup", "chm.DrgBlV", "MedalPnl", "chm.MedalV", "chm.AchbtnRnd", "isOpenList", "chm.AchGroupVo", "chm.AchTaskVo", "barWidth", "childrenCreated", "btn_pull", "btnGoTo", "btn_goto", "achieve_tag", "k_15", "k_16", "LEVLE", "\u8f6c", "\u7ea7", "_itemEff", "acheve_get_eff", "item0", "item1", "cell0", "cell1", "pull_achieve_click", "chm.AchTLRnd", "lblGoto", "shareData", "sharenum", "lblReward", "lblPrgress", "k_0", "chm.ActTaskRnd", "chm.ActTaskRndVo", "chm.MedalCfgVo", "AchievePanelSkin", "chm.AchPnl", "AchieveTaskPanelSkin", "chm.AchTaskPnl", "ActiveTaskPanelSkin", "chm.ActTaskPnl", "DragonBallSkin", "chm.DrgBlPnl", "DragonLostPanelSkin", "chm.DrgLostPnl", "MedalPanelSkin", "chm.MedalPnl", "registerCheckers", "_checkDic", "ActivityCheckerFactory::\u6ce8\u518c\u4e86\u91cd\u590d\u7684\u6d3b\u52a8Checker\u68c0\u67e5key:", "ActivityCheckerFactory", "chm.ActivityCheckerFactory", "NothingChecker", "chm.NothingChecker", "chm.IActivityChecker", "parentActivity", "myVipLevel", "LimitChecker1", "chm.LimitChecker1", "LimitChecker2", "chm.LimitChecker2", "LimitChecker3", "chm.LimitChecker3", "LimitChecker4", "chm.LimitChecker4", "addArrItem", "LimitChecker5", "chm.LimitChecker5", "LimitChecker6", "chm.LimitChecker6", "LimitChecker7", "chm.LimitChecker7", "LimitChecker8", "chm.LimitChecker8", "subTarget2", "currentServerTime", "LimitChecker10", "chm.LimitChecker10", "LimitChecker11", "chm.LimitChecker11", "LimitChecker12", "chm.LimitChecker12", "LimitChecker13", "chm.LimitChecker13", "getChrisDrawns", "getRecharge", "LimitChecker14", "chm.LimitChecker14", "getSingleDatas", "satisfyCount", "getCount", "LimitChecker15", "chm.LimitChecker15", "consumeExpertStates", "consumeExpertAmount", "LimitChecker16", "chm.LimitChecker16", "WishboxCtrl", "wishBoxBonusInfo", "bonusInfo", "subValue2", "LimitChecker17", "chm.LimitChecker17", "kaifudiscountshop2", "LimitBuyCheck", "chm.LimitBuyCheck", "LimitItemBuyCheck", "chm.LimitItemBuyCheck", "LimitOtherBuyCheck", "chm.LimitOtherBuyCheck", "totalLevel", "allStoneLevel", "dragonSoulTotalLevel", "getMedalStageByLevel", "suitAllPower", "wingFightnum", "wingAllPower", "LimitMyValueChecker", "chm.LimitMyValueChecker", "value2", "InvestLevelChecker", "chm.InvestLevelChecker", "ServerDrawsLimitChecker", "chm.ServerDrawsLimitChecker", "ChargeAndBuyCtrl", "serverInfo", "consumeNum", "LimitChecker_ChargeAndBuy", "chm.LimitChecker_ChargeAndBuy", "ActivityInitor", "chm.ActivityInitor", "discountshop", "limitshop", "themeshop", "shopcomsume", "bosspoint", "doublerecharge", "turntable10", "goldenegg", "timingget", "moretotalrecharge", "newdailyandaccumulate", "festivallogin", "annuallogin", "limittitle", "limitfashionfinal", "salepromotion", "collectfontshop", "bigrichmanshop", "luckyrollerrebatecard", "crazylottery", "chrisrecharge", "wishbox", "koireturn", "lotteryrankstage", "copymaterial", "jungong", "annualtask", "bigrichman", "investlevel", "onlinetime", "misterylimit", "directbuy", "chargebuy", "CheckerInitor", "chm.IInitor", "AliveChecker_ChrisRecharge", "AliveChecker_Koireturn", "crossconsume", "AliveChecker_CrossConsume", "kaifulimitshop", "kaifutehui", "AliveChecker_LimitShop", "AliveChecker_DailyPromotionStates", "AliveChecker_MisteryLimit", "AliveChecker_DirectBuy", "AliveInitor", "richangbaoku", "RedChecker1", "RedChecker3", "turntable", "RedChecker4", "RedChecker5", "RedChecker6", "kaifushop", "kaifuthemeshop", "RedChecker7", "continuityrecharge", "kaifufanlilj", "kaifufanli", "RedChecker8", "monsternian", "RedChecker9", "RedChecker10", "nationaldaylottery", "RedChecker11", "motherrecharge", "RedChecker12", "kaifuluckyshop", "RedChecker_Not", "lrdouble12", "RedChecker_LrDouble12", "luckyrollerrebate", "RedChecker_LuckyRollerRebate", "rewardturn", "RedChecker_LuckyRewardTurn", "RedDotInitor", "ActivityPay2Des", "registerDes", "ActivityShopConsumeDes", "shacheng", "ActivityShachengDes", "ActivityShop", "ActivityCrossConsumDes", "ActivityInvestLevelDesPanel", "ChargeBuyDesPanel", "singlerecharge", "TotalRechargePanel", "registerPanel", "ActRecharge3For4Pnl", "AcivityConstantRechargeLevelPanel", "ActivityTypeBossKillPanel", "FestivalAnnualGoldenEggExtPnl", "FstMothersConstantRechargeExtPnl", "ActSalePromotionPnl", "Fst11KoiPnl", "FstHbPanel", "FestivalLoginPanel", "AnnualLoginPanel", "WishingBoxPanel", "ActTaskPanel", "kaifuboss", "ActPubBossPnl", "rankarena", "ActivityType11Panel", "ActivityShachengPanel", "ActKaifuLuckyShop", "ActivityDailyTreasure", "citytreasure", "FestivalSpringPlaysetExt", "ActivityCrazyLotteryPanel", "FestivalZhiShuCrazyPanel", "LuckyRollerPanel", "turntablerebate", "LuckyRoller10Panel", "LuckyRollerRebatePnl", "LrDouble12Pnl", "limitfashion", "ActivityType6Panel", "ActivityType5ExtPnl", "ActivityCrossXfPanel", "TotalRechargeType1Panel", "material", "materialboss", "poster", "CttPicture", "kaifufanlitwo", "ActivityType12Panel", "ActivityType13Panel", "ActivityType14Panel", "OpenServerPlayerLevelPanel", "LuckyRewardTurnPanel", "InvestLevelPanel", "ActivityChargeBuyPanel", "60", "ALmtTitlePnl", "PanelInitor", "_desDic", "ActivityViewFactory::\u6ce8\u518c\u4e86\u91cd\u590d\u7684\u6d3b\u52a8Des key:", "_panelDic", "ActivityViewFactory::\u6ce8\u518c\u4e86\u91cd\u590d\u7684\u6d3b\u52a8Panel key:", "chm.ActivityViewFactory", "AliveCheckerFactory::\u6ce8\u518c\u4e86\u91cd\u590d\u7684\u6d3b\u52a8Alive\u68c0\u67e5key:", "chm.AliveCheckerFactory", "DefaultAliveChecker", "chm.DefaultAliveChecker", "chm.IAliveChecker", "chm.AliveChecker_ChrisRecharge", "koi", "chm.AliveChecker_Koireturn", "CrossConsumModel", "isCrossOpen", "chm.AliveChecker_CrossConsume", "checkIfFinish", "triggerUnlock", "chm.AliveChecker_LimitShop", "AliveChecker_DailyPromotion", "chm.AliveChecker_DailyPromotion", "chm.AliveChecker_DailyPromotionStates", "chm.AliveChecker_MisteryLimit", "getActVoByKey", "chm.AliveChecker_DirectBuy", "RedCheckerFactory::\u6ce8\u518c\u4e86\u91cd\u590d\u7684\u6d3b\u52a8Red\u68c0\u67e5key:", "chm.RedCheckerFactory", "chm.DefaultRedChecker", "chm.IRedChecker", "chm.RedChecker_Not", "checkXunBaoRed", "BigRichMoneyManager", "chm.RedChecker1", "chm.RedChecker3", "getLeftRollCount", "LuckyRollerManager", "chm.RedChecker4", "chm.RedChecker5", "chm.RedChecker6", "chm.RedChecker7", "chm.RedChecker8", "checkMonsterOpen", "chm.RedChecker9", "AnnualTaskCtrl", "taskInfo", "targetStates", "chm.RedChecker10", "getCrazyLotConfigById", "LotteryManager", "resolveString", "samllTreeCost", "bigTreeCost", "m", "chm.RedChecker11", "FestivalConstantRechargeCtrl", "mRechargeInfo", "getMotherRechargeConfigs", "freeId", "chm.RedChecker12", "chm.RedChecker_LrDouble12", "LuckyRollerRebateCtrl", "chm.RedChecker_LuckyRollerRebate", "LuckyRewardTurnCtrl", "chm.RedChecker_LuckyRewardTurn", "_mapList", "maxCacheMapNum", "loadingArr", "needLoadArr", "_mapMod", "_textureDic", "getIns", "Bitmap", "imgPool", "setMapView", "mapV", "loadClip", "reFreshMapView", "setValue", "loadError", "AvatarLoader", "clearNeedLodarr", "bitmapData", "currentMapid", "changeMapId", "setClipBmd", "getImage", "removeImage", "load_complete_tl", "TileLoaderProxy", "chm.TileLoaderProxy", "MapLoadvo", "chm.MapLoadvo", "tileArr", "_startX", "_startY", "_endX", "_endY", "_screenRect", "_hasClips", "_tileLoader", "changeMap", "startLoopChangeMove", "loadClips", "mapvo", "tileArray", "getNeedLoadClips", "getHNeedLoadClips", "mapView", "checkMaxClips", "bindMapView", "loopChangeMove", "stopLoopChangeMove", "clearMap", "hasClipBmd", "checkHMaxClips", "TileMap", "chm.TileMap", "CLICK_GET_REWARD", "clickGetReward:ActivityGetRewardBtn", "_btn", "setBtnVo", "stateNameArr", "onClickGetReward", "playButtonEff", "removeButtonEff", "limitVo", "k_445", "limitVip", "btnEffectJson", "_btnEffect", "ActivityGetRewardBtn", "chm.ActivityGetRewardBtn", "GetRewardBtnVo", "chm.GetRewardBtnVo", "_dict", "_list", "setLayer", "getLayer", "bgLyr", "_mapBackgound", "_mapAvatarContainer", "_mapImgWordMagic", "animLyr", "_mapSceneAnimation", "getDict", "MapContainer", "chm.MapContainer", "_scroller", "ScrollerRewardPane", "chm.ScrollerRewardPane", "CHANGE_SELECTED_INDEX", "ChangeSelectedIndex::SelectHorizontalListPane", "CHANGE_INDEX", "ChangeIndex::SelectHorizontalListPane", "_renderW", "_stepX", "_currSelectedIndex", "_currIndex", "_leftImg", "_rightImg", "allowMultipleSelection", "onTabItem", "onLeft", "onRight", "scrollChange", "_dataArr", "updateArrow", "updatePositionByIndex", "updateListPosition", "min", "SelectHorizontalListPane", "chm.SelectHorizontalListPane", "ActivityCrossConsumDesSkin", "lbl_value", "crossSelfInfo", "chm.ActivityCrossConsumDes", "ActivityCrossXfPanelSkin", "ActivityCrossXfRender", "updateList", "updateMyValue", "c_4100", "getXfArr", "lbl_myCost", "lbl_myRank", "\u672a\u4e0a\u699c", "chm.ActivityCrossXfPanel", "_gridArr", "_rewardArr", "_rankImag", "corss_consume_rank_1_png", "corss_consume_rank_2_png", "corss_consume_rank_3_png", "ActivityCrossXfRderSkin", "rwd", "_bonusArr", "addGrid", "img_rank", "lbl_rank", "corss_consume_listbg_png", "boss_listbg_jpg", "isShow", "lbl_visible", "lbl_nums", "famName", "lbl_famName", "confScore", "group_rwd", "chm.ActivityCrossXfRender", "_isCrossOpen", "_crossSelfInfo", "_goldList", "_rwdList", "updateCrossByMin", "n_32381", "n_32380", "_endTime", "topInfo", "updateTime", "setCrossList", "useYb", "setCrossSelfInfo", "c_4101", "getMatchArr", "_kuafudes", "kuafudes_json", "_crossList", "crossList", "findInfoes", "CrossXfVo", "getRwdByCig", "getCostByCig", "\u9700{0}\u5143\u5b9d\u4e0a\u699c", "crossconsumetopReward_json", "crossconsumetop_json", "chm.CrossConsumModel", "chm.CrossXfVo", "ClientKey", "_mediator", "DirectBuyViewMediator", "showModule", "showBuyPrompt", "checkFun", "systemInfo", "ios", "iosOrderConfirm", "DailyBuyPromptPanel", "k_1724", "k_1722", "k_1721", "chm.DirectBuyModule", "_module", "_boomSkin", "_panel", "DirectBuyPanel", "img_boomBg", "img_decoration", "activity_hallbg2_png", "zhigou_text1_png", "autoHide", "updatePanel", "chm.DirectBuyViewMediator", "_hasSelected", "DirectBuyBoxRenderSkin", "imgHasGet", "imgBox", "zhigou_box", "DirectBuyBoxRender", "chm.DirectBuyBoxRender", "DirectBuyPanelSkin", "_isLighting", "_scrollerPane", "listReward", "listBox", "clickItem", "onClickBuy", "imgBtn", "gLight", "drawContent", "imgLight", "rid", "getRechargeData", "isDebug", "\u76f4\u8d2d\u793c\u5305:rid:", ">>>>", "warn", "---key:", "  value:", "-------------------------------", "pay", "\u76f4\u8d2d\u793c\u5305\u6d3b\u52a8id\uff1a", "\u6ca1\u6709\u914d\u7f6e\u5145\u503crid\uff01\uff01\uff01\uff01\uff01", "recharge_json", "\u5728recharge_json\u627e\u4e0d\u5230\u76f4\u8d2d\u793c\u5305rid\uff1a", "\u627e\u4e0d\u5230\u76f4\u8d2d\u793c\u5305\u6d3b\u52a8\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01", "updateByIndex", "showPrice", "\u5269\u4f59\u65f6\u95f4:", "imgShowBox", "zhigou_btn_get_png", "zhigou_btn_buy_png", "tweenBtnLight", "relationId", "\u627e\u4e0d\u5230\u76f4\u8d2d\u793c\u5305\u7684\u5956\u52b1\u914d\u7f6e,Id:", "  bonusId:", "chm.DirectBuyPanel", "med", "FPMed", "shwPnl", "tgtOp", "updChg", "ckShw", "FPMod", "ckBtn", "isOnStage", "hdPnl", "aGetRwd", "activityId", "chm.FPMdu", "FirstPayViewMediator", "mdu", "mod", "winPnl", "FPPnl", "tp3Pnl", "FPType3", "k_1060", "selectId", "cTyPnl", "aPay", "btnPay", "k_1039", "aGet", "btnGet", "7200", "fPnl", "actChg", "getActivitySubVo", "bFpShw", "sltChg", "daily_shouchong_bg_jpg", "sBtnStt", "k_26", "sCstUrl", "sRwd", "groupType", "groupFirst", "shouchong_biaoti_png", "shouchong_biaoti2_png", "costIcon", "chm.FPMed", "shouchong_1888_png", "shouchong_6888_png", "jobIcon", "shouchong_nuzhan2_png", "shouchong_longya2_png", "shouchong_xiaoyaoshan2_png", "jobNameIcon", "shouchong_nuzhan_png", "shouchong_longya_png", "shouchong_xiaoyaoshan_png", "_selectId", "getEffectiveVoByKey", "chm.FPMod", "FirstPayPanelSkin", "chm.FPPnl", "FirstPayType3Skin", "ios_img", "android_img", "chm.FPType3", "LoginRewardModule", "LRMed", "shwMdu", "lgComp", "clearData", "createXmlEleById", "gAllPul", "LRMod", "aRwd", "chm.LRMdu", "LoginRewardViewMediator", "_boxListV", "LRPnl", "login_rew_title2_png", "login_rew_bg_jpg", "login_rew_desc_jpg", "btnEff", "DBGrid", "7401", "dayChg", "fRwd", "7400", "fBtn", "sSltId", "gActSvo", "doubleViplevel", "sBoxLst", "sBoxRwd", "sBoxStt", "k_29", "k_32", "playBtnEffect", "stopBtnPlayEffect", "sRwdCdt", "lblDay", "k_28", "gBtnLst", "lblDay1", "k_81", "chm.LRMed", "DBGVo", "itemName", "itemname", "bArw", "chm.LRMod", "oComp", "rmvG", "oClk", "imgArrow", "img_sign", "labname", "yellow", "chm.DBGrid", "chm.DBGVo", "LoginRewardPanelSkin", "chm.LRPnl", "mediator", "ActivityViewMediator", "activityCtrlsStart", "updataActivityData", "registerOtherRed", "updateRegisterRed", "getHandler", "promGetHandler", "registerCrazyRed", "reqTaskInfoLogin", "daliyGetHandler", "addRspEvts", "requestPromotionInfo", "requestDailyPromotion", "updateChangeActivitys", "c_2001", "c_2010", "c_26551", "viewType", "getShowActivityBtns", "BtnRedCheck", "registerUpdateActivityOtherRed", "updateActivityOtherRed", "updataRegisterRedCheck", "registerInnerRed", "c_2030", "Recharge3For4Ctrl", "ConstantRechargeLevelCtrl", "ShaChengActivityCtrl", "LuckyRollerRebateCardCtrl", "MoNMod", "ActivityLotteryCtrl", "chm.ActivityModule", "panelDic", "desDic", "_viewType", "btnNum", "windowPanel", "ActivityMainPanel", "rankPanel", "ActivityRankListPanel", "activity_hall_title_png", "ActivityBtn", "ActivityRankInfoRender", "leftImage", "rightImage", "onItemClick", "onActivityChange", "fillShowActivity", "showRankList", "ACTIVITY_SHOP_SELECT_TAB", "reSelectActivityShop", "flushSelectRed", "hideRankPanel", "tmpDes", "tmpCtt", "_particalSys", "getShowFestivalBtns", "getShowSpecialBtns", "_btnArr", "setUI", "setActivityBtnList", "refreshPanel", "setSelectActivity", "updateUIByVo", "findIndexById", "createPnl", "groupDes", "specialHandler", "checkIfParticleOpen", "playArrowEff", "removeArrowEff", "k_45", "lotteryrank", "lotteryoldrank", "showRankPanel", "rankValue", "group_rankValue", "lbl_myvalue", "leftEffect", "shine_effect", "rightEffect", "activity_hallbg_png", "circlebig_bg_png", "img_topBg", "img_baseBg", "img_line", "currency_activitybg2_jpg", "getFestivalUIFrame", "getFestivalUITop", "chm.ActivityViewMediator", "ActTaskPanelSkin", "pageTaskVoArr", "redArr", "_renderArr", "prevIdx", "tabbar", "ActAnnualRender", "toggleSelectChange", "getAchieveOneKey", "_ctrl", "<font color=\"#E5B72A\">\u5269\u4f59\u65f6\u95f4: </font>{0}", "_taskData", "rank1", "flushPanel", "k_76", "FestivalAnnualTaskBoxVo", "targetScore", "currentScore", "FestivalAnnualTaskBoxRender", "group_box", "c_2034", "chm.ActTaskPanel", "FestivalLimitTitlePanelSkin", "onTouchHandler", "group_title", "checkIfBuy", "\u5206\u4eab", "\u8d2d\u4e70", "\u5df2\u8d2d\u4e70", "goldCost", "k_75", "k_63", "chm.ALmtTitlePnl", "AnnualLoginPanelSkin", "_currentIndex", "AnnualLoginRender", "onDayItemClick", "\u5929\u5956\u52b1", "updateBtn", "lblReplacement", "replacement", "k_65", "chm.AnnualLoginPanel", "FestivalGoldenEggExtPnlSkin", "eggOriginSrc", "anniversary_egg_dan1_png", "eggBreakSrc", "anniversary_egg_dan2_png", "hammerSrc", "anniversary_egg_boom_png", "hammerSmallSrc", "anniversary_egg_chuizi_png", "sloganSrc", "anniversary_egg_toptitle_png", "rwdPreview", "goldStage", "img_egg", "img_slogan", "anniversary_egg_toptitl_xcx_png", "img_hammer", "img_hammerSmall", "lbl_explain", "k_537", "list_rwd", "FestivalGoldenEggExtRender", "btn_egg", "showTip", "oldV", "group_achieve", "curSubVo", "FestivalGoldenEggVo", "showValue", "targetState", "k_1086", "k_1045", "\u7838\u86cb\u6b21\u6570\u8d60\u9001\u5df2\u8fbe\u4e0a\u9650", "group_item0", "lbl_num", "k_70", "img_prog", "_effLight", "_effFlake", "group_eff", "lightEnd", "boom1", "backIn", "_desPnl", "FstGoldenEggDes", "clickShape", "chm.FestivalAnnualGoldenEggExtPnl", "FestivalLoginSkin", "_cellW", "_cellH", "_rewardPane", "list_reward", "_getRewardBtn", "\u9886\u53d6", "\u5df2\u9886\u53d6", "setDayBoxRender", "gDayBox", "_dayBoxItemArr", "itemRender", "FestivalLoginRender", "WIDTH", "HEIGHT", "gBottom", "boxScroller", "setDayItem", "onClickDayBox", "getPosRects", "lbl_replace", "\u5143\u5b9d\u4e0d\u8db3", "chm.FestivalLoginPanel", "FestivalMotherLoginRender", "FestivalLoginPanel_MotherLogin", "chm.FestivalLoginPanel_MotherLogin", "FestivalSpringPlaysetExtSkin", "btn_fight", "MonsterNianController", "enterTypeChange", "SVROT_CHG", "monsterNianActiveChange", "svrStateChange", "\u524d\u5f80\u4f5c\u6218", "\u524d\u5f80\u4e3b\u57ce", "ENT_REQ", "getSvrBoxOpenData", "MainSBoxMod", "\u6d3b\u52a8\u672a\u5f00\u542f", "ckOp", "chm.FestivalSpringPlaysetExt", "FestivalCrazyPlantExtSkin", "btnLbls", "\u62bd1\u6b21", "\u62bd10\u6b21", "resultPattern1", "\u5bfb\u5b9d{0}\u6b21\uff0c\u83b7\u5f97\u5982\u4e0b\u73cd\u7a00\u9053\u5177", "resultPattern2", "\u62bd{0}\u6b21", "activityName", "\u5bfb\u5b9d", "itemNums", "_resultArr", "resultPanel", "FestivalZhiShuResultPanel", "FBSDTipV", "LotteryRed", "closeResultPanel", "btnConfirm", "resultClickHandler", "fillResults", "fillLogs", "c_1637", "ctrl", "{0}\u6b21\uff0c\u83b7\u5f97\u5982\u4e0b\u73cd\u7a00\u9053\u5177", "getLotteryConfigById", "LotteryCfg", "costArr", "img_z", "lbl_z", "item_", "lbl", "count1", "count2", "LOGTYPE_PLANT", "getLotteryResult", "setResultList", "setResultBtnLabel", "setResultTitle", "img_gold", "img_plant", "nums", "setResultCost", "getGetShowLogs", "checkMoney", "showResultPanel", "getShiningIdsByLotteryId", "groupRwd", "checkbtnstate", "btn1", "btn2", "btn3", "btn4", "getBagCount", "\u80cc\u5305\u5bb9\u91cf\u4e0d\u8db3,\u8bf7\u524d\u5f80\u6e05\u7406", "\u9053\u5177\u4e0d\u8db3", "\u91d1\u5e01\u4e0d\u8db3", "crazyGetReward", "_closeTime", "closeResultHandler", "hideResultPanel", "lbl_icostitem", "addtip", "chm.FestivalZhiShuCrazyPanel", "FestivalZhiShuRestulSkin", "chm.FestivalZhiShuResultPanel", "Fst11KoiPnlSkin", "headIcos", "double11_head_1_0_png", "double11_head_1_1_png", "double11_head_2_0_png", "double11_head_2_1_png", "double11_head_3_0_png", "double11_head_3_1_png", "toggleChange", "list_history", "Fst11KoiLogRender", "list_return", "grp_head", "drawCircle", "rankVoArr", "zhanliArr", "updateKoiInfo", "updateConsumeInfo", "updateRankInfo", "c_2049", "c_2046", "img_head1", "img_head2", "returnVo", "getActVoBySubKey", "rateArr", "FestivalDouble11Vo1", "tempimg1", "tempimg2", "imgTween", "sort", "lbl_spent", "k_272", "lbl_return", "k_58", "grp_koi", "grp_return", "double11_head_unknow_png", "getRandomHead", "lbl_pipei", "chm.Fst11KoiPnl", "FstGoldenEggDesSkin", "k_1073", "lbl_amount", "k_1074", "chm.FstGoldenEggDes", "FstMothersConstantRechargeExtPnlSkin", "imgArr", "swinging", "onClickBuyReward", "onClickLeft", "img_left", "onClickRight", "img_right", "itemClickHandler", "group_item1", "group_item2", "group_item3", "FestivalMotherRechargeRender", "onChangeIndex", "c_2040", "stopSwing", "_selectItemVo", "chargeGold", "_dayRcgVoArr", "getTargetNum", "updatePanelInfo", "fillPnl", "fillGrids", "updateSelectItem", "group_buyTip", "img_bubble", "mother_icon_wish13_png", "mother_icon_wish11_png", "getCost", "\u672a\u8fbe\u6807", "\u53ef\u9886\u53d6", "group_gold", "\u53ef\u8d2d\u4e70", "mother_icon_wish14_png", "k_83", "group_finish", "checkIfSwing", "swingGroup", "k_86", "c_2041", "k_84", "motherrechargebuy", "swingArr", "swing", "loopkeys", "chm.FstMothersConstantRechargeExtPnl", "LrDouble12DesSkin", "lab_needYb", "k_1076", "setItem", "ID", "lotteryrateclientexml_json", "lbl_rate", "setLeft", "k_1075", "LrDouble12Des", "chm.LrDouble12Des", "LrDouble12PnlSkin", "itemArr", "blinkInterval", "readyInterval", "finishInterval", "pointer", "isRoll", "posArr", "log_list", "onTouch", "img_btn", "lbl_rule", "k_107", "onExplain", "updateView", "rollStart", "fillItems", "c_26534", "c_26535", "blinkTimer", "doBlink", "clearTimers", "removeItems", "getLr12Info", "freeCounts", "getNextRollObj", "k_105", "leftNum", "lbl_need", "k_1067", "nextNeed", "clearRollTimer", "targetIndex", "finishRound", "rollTimer", "doReadyRoll", "setBlink", "addPointer", "rollTimer0", "doFinishRoll", "img_blink", "getLr12Logs", "conf", "LrDouble12Item", "\u8f6c\u52a8\u6b21\u6570\u4e0d\u8db3", "c_26536", "rechargeNum", "chm.LrDouble12Pnl", "TotalRechargePanelSkin", "_subVo", "group0", "subvalue0", "titleicon", "subvalue", "setRwdList", "\u5145\u503c", "chm.TotalRechargePanel", "TotalRechargeType1PanelSkin", "onGetReward", "btn_get0", "btn_get1", "sec_ann_crazycharge_bg1_xcx_jpg", "img_bg2", "sec_ann_crazycharge_bg2_xcx_jpg", "sec_ann_crazycharge_bg1_jpg", "sec_ann_crazycharge_bg2_jpg", "k_52", "_sub0", "getSubArrByTag", "_sub1", "setInfo", "lbl_leftNum", "_currSub", "tag", "_currSub0", "list0", "_currSub1", "list1", "chm.TotalRechargeType1Panel", "WishBoxGetLogPanelSkin", "logList", "WishBoxLogRender", "showList", "actVo", "WishBoxGetLogPanel", "chm.WishBoxGetLogPanel", "WishBoxRemainPanelSkin", "_config", "gItem", "WishBoxRemainRender", "WishBoxRemainPanel", "chm.WishBoxRemainPanel", "WishingBoxPanelSkin", "_totalLimit", "onSelectItems", "btnSelect", "initInfo", "lblExplain", "k_735", "TOUCH_BEGIN", "onTouchLink", "lblRemain", "lblLog", "updateLblRoundInfo", "lblRound", "\u5f53\u524d\u6d3b\u52a8\u8f6e\u6b21\uff1a", "_poolRewardArr", "_currentDayIndex", "_currentId", "clearGroup0", "showRewardPool", "showProgressList", "updateCostLbl", "clearGroup1", "setPoolItemList", "onUpdateBtn", "currProgressValue", "\u6d88\u8017", "getCostNum", "\u5143\u5b9d", "_poolItemArr", "ITEM_CLICK", "WishBoxPoolRender", "gRewardPool", "_selectRewardArr", "onBuyReward", "gSelectShow", "_progressItemArr", "onGetTargetReward", "_currSelectItem", "RewardPoolLevel", "SPECIAL", "END", "\u5956\u6c60\u672a\u9009\u6ee1\uff01", "c_2082", "selectIndexList", "WishBoxRender", "findAlreadyBuy", "getItemStr", ":1", "findItem", "gProgress", "WishBoxProcessRender", "findOnProperty", "\u662f\u5426\u82b1\u8d39", "\u5143\u5b9d\u8d2d\u4e70\u4e00\u4e2a\u8bb8\u613f\u5b9d\u7bb1\uff1f", "c_2084", "c_2085", "chm.WishingBoxPanel", "ProgressVo", "chm.ProgressVo", "ACsmRR", "chm.ACsmRR", "ActAnnualRenderSkin", "k_77", "#E1A32A", "c_2031", "chm.ActAnnualRender", "AnnualLoginRenderSkin", "imgDay", "login_day_", "Showbonus", "_render", "showTag", "imgSuper", "imgReplace", "chm.AnnualLoginRender", "CollectFontRenderSkin", "imgItem", "chm.CollectFontRender", "getPosX", "INTERVAL", "chm.FestivalAnnualTaskBoxVo", "_ros", "_tarRoIdx", "ActivityCrazyBoxRenderSkin", "anniversary_task_box1_png", "anniversary_task_box2_png", "anniversary_task_box3_png", "_shakeKey", "playShakeEff", "_boxGridVo", "c_2032", "chm.FestivalAnnualTaskBoxRender", "FestivalGoldenEggExtRenderSkin", "img_highlight", "lbl_target", "k_78", "chm.FestivalGoldenEggExtRender", "_itemSelected", "CttLoginItemSkin", "updateBoxImg", "_2_png", "_3_png", "_1_png", "chm.FestivalLoginRender", "FestivalMotherLoginRenderSkin", "chm.FestivalMotherLoginRender", "FestivalMotherRechargeRenderSkin", "\u96f6", "\u4e00", "\u4e8c", "\u4e09", "\u56db", "\u4e94", "\u516d", "\u4e03", "\u516b", "\u4e5d", "\u5341", "k_82", "chargeIndex", "img_heart", "father_icon_box2_png", "father_icon_box3_png", "mother_icon_wish16_png", "mother_icon_wish17_png", "father_icon_box1_png", "mother_icon_wish15_png", "chm.FestivalMotherRechargeRender", "Fst11KoiLogRenderSkin", "lbl_koi", "return1", "return2", "getFullYear", "getMonth", "getDate", "lbl_date", "k_101", "chm.Fst11KoiLogRender", "FstGEggExtRender", "chm.FstGEggExtRender", "frameSrc", "double12_frame_1_png", "double12_frame_2_png", "double12_frame_3_png", "LrDouble12ItemSkin", "img_light", "img_frame", "resetEff", "isComplete", "endEff", "k_159", "chm.LrDouble12Item", "WishBoxLogRenderSkin", "_logInfo", "lblInfo", "chm.WishBoxLogRender", "_limit", "WishBoxPoolRenderSkin", "onClickItem", "imgLeft", "imgRight", "lblLimit", "\u9650\u9009", "\u4ef6", "updateLbl", "titleImage", "selectNum", "\u5df2\u8fbe\u9009\u62e9\u4e0a\u9650", "\u5df2\u9009", "lblSelect", "WishBoxPoolRender:item_click", "chm.WishBoxPoolRender", "_showSelected", "WishBoxProcessRenderSkin", "_processVo", "lbl_progress", "sec_ann_giftreachicon_3_png", "sec_ann_giftreachicon_2_png", "chm.WishBoxProcessRender", "WishBoxRemainRenderSkin", "getInPoolList", "chm.WishBoxRemainRender", "WishBoxRenderSkin", "chm.WishBoxRender", "tileMap", "map_1_small_jpg", "getMapVOById", "addToStage", "mapRes", "_small_jpg", "MapBgLayer", "chm.MapBgLayer", "_maxFrame", "_maxBodyHeight", "_renderTime", "bitmapClipData", "removeCount", "getLength", "getSpeed", "RENDER_DELAY", "renderTime", "loadComplete", "skill_", "getCurrentFrameName", "_frameData", "getFrame", "chm.AvatarPart", "MapSceneAni", "chm.MapSceneAni", "svrXmlDic", "OtherModuleIds", "OtherModuleClientKeys", "_allDayReplaceDic", "_activityVoTable", "_allBtnTable", "updateTargetKey", "c_2019", "updateByNewHour", "updateByGold", "updateByMoney", "updateByItem", "updateByPower", "updateByLevel", "updateByLongSoul", "updateByStone", "updateByMedal", "updateByWing", "updateBySuit", "updateByVip", "clearActivitys", "n_19007", "delayRequest", "timeoutId", "svrRequests", "c_2012", "c_26510", "c_2051", "c_26540", "c_2054", "c_2059", "reqCPromotionSpecial_Info", "requestServerInfo", "createBtnVo", "createActivityVo", "c_26550", "c_1636", "type1", "c_4071", "c_16035", "c_1641", "c_16034", "allBtnList", "getReplaceByActivityGroup", "updateEle", "updateActivityVo", "chargesendmail", "setTuiHuanData", "updateBtnVo", "updateCheck", "updataRegisterRed", "checkIfShow", "\u9519\u8bef\u7684\u6d3b\u52a8id=", "selectRewardByJob", "_otherRedDic", "boRed", "activityID", "getShowRegisterBtns", "InnerRedDic", "_innerRedDic", "_wingFightnum", "PlantTreeLottery", "checkActivityByKeys", "c_2000", "n_16033", "n_32331", "powers", "n_2050", "deleteCMIcon", "chm.ActivityModel", "userName", "realServerTime", "mergeTime", "HBModel", "chm.IBridge", "chm.ConfigManager", "BRMMod", "chm.BigRichMoneyManager", "curId", "LRlMod", "chm.LuckyRollerManager", "chm.LotteryManager", "chm.GlobalEventManager", "checkIfMergeTmPass", "chm.AliveCheck", "checkIfShowBtn", "checkFestivalIfShowBtn", "checkFestivalIfRed", "checkLuckyIfRed", "checkLuckyShowBtn", "checkSpecailIfShowBtn", "checkSpecialIfRed", "checkIfShowDailyBtn", "checkIfShowDailyRed", "isShowAct", "showDirectbuy", "ckrbtn", "ReRolMod", "showOneGift", "getShowLuckyBtn", "registerIds", "registerClientKeys", "chm.BtnRedCheck", "_avatarList", "_monsterList", "\u5c4f\u853daddChildAt\u65b9\u6cd5", "\u5c4f\u853dremoveChildAt\u65b9\u6cd5", "yingziPlugin", "bindYingzi", "removeYingzi", "setMonsHPState", "doSortAvatar", "setChildIndex", "MapSceneAvt", "chm.MapSceneAvt", "c_1638", "lotteryType", "n_16023", "datas", "storeLotteryCrazyResult", "n_16024", "logs", "setLogs", "n_16027", "setPlantlogs", "n_16028", "storePlantResult", "_logs", "_plantlogs", "LOGTYPE_NORMAL", "k_437", "k_436", "pname", "storeLotteryResult", "_result", "_resultplant", "_resultCrazy", "LOGTYPE_CRAZY", "btype", "getLotteryShows", "_lotteryShowObj", "lotteryshow_json", "6", "\u5728lotteryshow_json\u4e2d\u627e\u4e0d\u5230id>>>>>", "getLotteryCostItem", "getCrazyLotteryItem", "lottery_coin", "getCrazyLotteryCostNum", "chm.ActivityLotteryCtrl", "_taskInfo", "n_2033", "chm.AnnualTaskCtrl", "_states", "_consumeNum", "_amount", "c_26543", "c_26544", "n_26549", "_changeBuyInfo", "chm.ChargeAndBuyCtrl", "curActDayIdx", "_curActDayIdx", "chm.ConstantRechargeLevelCtrl", "n_1642", "storeComsumeRankInfos", "n_2047", "setConsumeRebateValue", "n_2053", "storeRechargeInfo", "n_26542", "storeConsumeExpertInfo", "rankInfos", "lotConsume", "getComsumeRankInfos", "rechargeInfo", "freeStates", "consumeRebateValue", "_consumeRebateValue", "goldconsumerebate", "chm.ConsumeRechargeCtrl", "_configVoMap", "n_2042", "_mRechargeInfo", "_serverStates", "festivalrecharge_json", "FestivalMotherRcgVo", "\u5728festivalrecharge_json\u4e2d\u627e\u4e0d\u5230\u7948\u798f\u6d3b\u52a8id:::::", "\u5929\u7684\u914d\u7f6e\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01\uff01", "getRechargeTotalLength", "chm.FestivalConstantRechargeCtrl", "_lr12Info", "_lr12Id", "n_26537", "freesCounts", "n_26538", "updateDraw", "n_26539", "lrLogs", "zoneArr", "countsCost", "end", "fullZoneNum", "fullZoneCost", "_lrLogs", "ownerName", "chm.LrDouble12Ctrl", "Lr12Info", "chm.Lr12Info", "Lr12ZoneVO", "chm.Lr12ZoneVO", "_currentType", "requestInfo", "c_26545", "turnTable", "_bonusList", "c_26546", "requestTurn", "costItemId", "k_1730", "buyRewardTurn", "k_1729", "n_26547", "_serverVo", "rewardIds", "findRewardIndex", "n_26548", "currentType", "gridVoList", "poolGold", "getConfigData", "\u627e\u4e0d\u5230\u6d3b\u52a8\u4e2d\u7684\u5168\u6c11\u5927\u8f6c\u76d8\u6d3b\u52a8!", "promotionrewardturn_json", "showItemVoArr", "_showItemVoArr", "\u5728promotionrewardturn_json \u627e\u4e0d\u5230\u5168\u6c11\u5927\u8f6c\u76d8\u7684\u914d\u7f6e\uff01", "can\'t find reward id:  ", "   in promotionrewardturn_json!", "turn_coin", "getContentById", "chm.LuckyRewardTurnCtrl", "itemBonus", "exhibition", "itemImgSource", "reworld_", "isItem", "RewardTurnShowVo", "chm.RewardTurnShowVo", "cardId", "chm.LuckyRollerRebateCardCtrl", "c_26511", "c_26512", "n_26513", "TYPE_OPEN", "ActRebateVo", "updateRebateInfo", "n_26514", "TYPE_DRAW", "n_26515", "rebateLogs", "getRebateInfo", "_rebateVo", "RegisterRedVo", "curConf", "_rebateLogs", "getRebateLogs", "REBATERATES", "k_79", "chm.LuckyRollerRebateCtrl", "levelCnts", "_levelCount", "chm.Recharge3For4Ctrl", "_sandyStartTime", "reqEntryInfo", "n_32001", "sandyStartTime", "chm.ShaChengActivityCtrl", "n_2081", "_wishBoxBonusInfo", "chm.WishboxCtrl", "dirXArray", "removeImageNum", "getSprite", "spritePool", "getDirXY", "getImageNumber", "backOut", "fanShang", "playBatNum", "baoJi", "zhimin", "miss", "weishe", "lianji", "serious", "fragile", "dechurtup", "gedang", "zibao", "huoyu", "fabaoHurt", "xishou", "huiMie", "playImages", "buMie", "doubleBuMie", "sideAlertType", "fuhuo", "BulletReLive", "husheng", "playBatNoNum", "removeFileter", "fushi", "canfei", "getBullet28", "Bullet28", "god_body", "monsStroke", "bishaIMG", "guard_boss_skill_png", "sineInOut", "bishaMcs", "useCenterPoint", "delayPlayEft", "skill_6_act2_0_2", "mainImages", "MapSceneImg", "chm.MapSceneImg", "CttListSkin", "maxListItemNum", "lbl_3_checkRank", "k_585", "checkRank", "updateLotRank", "onAdd", "handlers", "onRemove", "flushData", "consumeCtrl", "_list0_render_", "_list1_render_", "_list2_render_", "_list3_render_", "initialLayout", "getHandlers", "kaifudiscountshop", "kaifuxiangou", "morerecharge", "dailyandaccumulate", "lvlRateTotalArr", "lbl_1_spent", "k_57", "lbl_1_return", "img_2_des", "img_2_desBg", "boFirst", "\u540d", "lbl_3_rank", "k_89", "lbl_3_spent", "k_53", "kaifuleiji", "1:1#9:3#10:1,{x:0,y:0,w:584,h:522,g:4,lo:1}", "1:1#9:3#10:4,{x:0,y:0,w:584,h:522,g:4,lo:1}", "1:1#9:3#10:2,{x:0,y:36,w:584,h:522,g:30,lo:2,ph:off}#17:activity_treasure_bg33_jpg#18:2", "1:1#9:3#10:3,{x:0,y:142,w:584,h:522,g:6,lo:1,ph:off}#17:activity_leichong_jpg", "1:1#9:3#10:11,{x:0,y:0,w:584,h:522,g:4,lo:1,ph:off}#17:activity_treasure_bg33_jpg", "1:1#9:3#10:5,{x:0,y:0,w:584,h:522,g:4,lo:1}", "1:1#9:3#10:6,{x:0,y:10,w:584,h:522,g:18,lo:1,ph:off}", "1:1#9:3#10:7,{x:199,y:196,w:373,h:453,g:17,lo:1}#17:activity_treasure_bg25_jpg#18:3", "1:2#9:3#10:10,{x:199,y:196,w:373,h:453,g:17,lo:1}#17:activity_treasure_bg25_jpg#18:3", "1:1#9:3#10:8,{x:0,y:151,w:584,h:295,g:0,lo:1}#17:double11_gold_bg_jpg#18:1", "1:1#9:3#10:9,{x:0,y:140,w:584,h:395,g:4,lo:1,ph:off}", "1:1#9:3#10:13,{x:0,y:0,w:584,h:522,g:4,lo:1}", "getRenderClass", "more", "policy", "HorizontalLayout", "horizontalAlign", "ON", "ScrollPolicy", "OFF", "TileLayout", "columnAlign", "JUSTIFY_USING_WIDTH", "ColumnAlign", "rowAlign", "JUSTIFY_USING_HEIGHT", "RowAlign", "VerticalLayout", "scrollPolicyH", "scrollPolicyV", "grp_", "renderCorespond", "ActivityRankValue", "infos", "getRankTJ", "ConsumeRankInfo", "k_1023", "consume", "_sbtjs", "realRanks", "levels", "chm.CttList", "CttPictureSkin", "grpNum", "btn_1", "btn_2", "btn_3", "btn_5", "btn_6", "DoubleRechargeRender", "_pic4_render_", "grp_total_5", "_pic51_render_", "_pic52_render_", "5", "_pic6_render_", "subValue3", "tehui_num_{0}_png", "grp_imgNum_5", "list_reward_5", "grids", "needCost", "<font color=\'#e1a32a\'> ", " </font>", "lbl_des_5", "img_get_5", "lbl_time_5", "\u5269\u4f59\u65f6\u95f4\uff1a", "subVo", "_pic53_render_", "HfRvo", "group_title_6", "lbl_cost_6", "img_bonusBg_6", "1:1#9:2#15:activity_treasure_bg13_jpg,{x:0,y:-7,w:584,h:544}#16:1,{x:325,y:390}#160:,{lb:3}", "1:1#9:2#15:activity_treasure_bg16_jpg,{x:0,y:-7,w:584,h:544}#16:1,{x:325,y:390}", "1:1#9:2#15:activity_treasure_bg7_jpg,{x:0,y:-7,w:584,h:544}#16:1,{x:325,y:390}#160:,{lb:4}", "1:1#9:2#15:activity_treasure_bg28_jpg,{x:0,y:-7,w:584,h:544}#16:3,{x:334,y:390}#160:,{lb:5}", "1:1#9:2#15:activity_treasure_bg28_jpg,{x:0,y:-7,w:584,h:544}#16:3,{x:199,y:408}#160:,{lb:8}", "1:1#9:2#15:activity_treasure_bg12_jpg,{x:0,y:-7,w:584,h:544}#16:4,{x:19,y:280}", "1:1#9:2#15:,{x:0,y:-7,w:584,h:544}#16:2,{x:387,y:168}", "1:1#9:2#15:activity_th_bg_jpg,{x:0,y:40,w:524,h:324}#16:5,{x:211,y:351}#160:,{lb:7}", "1:1#9:2#15:activity_lc_weapon_jpg,{x:0,y:-7,w:584,h:544}#16:5,{x:211,y:351}#160:,{lb:6}", "1:1#9:2#15:yxtitle_bg_jpg,{x:0,y:0,w:584,h:522}#16:6,{x:432,y:243,w:100,h:115}#160:", "1:2#9:2#15:51activity_bg2_jpg,{x:0,y:0,w:584,h:699}#16:6,{x:36,y:299,w:505,h:152}", "1:1#9:2#15:activity_lc_weapon_jpg,{x:0,y:-7,w:584,h:544}#16:3,{x:199,y:428}#160:,{lb:2}", "1:1#9:2#15:,{x:0,y:-7,w:584,h:544}#16:0", "1:1#9:2#15:activity_th_bg_jpg,{x:0,y:40,w:524,h:324}#16:5,{x:211,y:351,lb:7}", "1:1#9:2#15:,{x:0,y:0,w:584,h:537}#16:0", "activity_treasure_bg21_xcx_jpg", "activity_treasure_bg21_jpg", "yuandan_sibei_bg_xcx_jpg", "yuandan_sibei_bg_jpg", "shengdan_shuangbei_bg_xcx_jpg", "shengdan_shuangbei_bg_jpg", "btn_", "getText", "PartText", "father_bg_black_png", "anniversary_denglu_bg1_png", "k_62", "#e1a32a", "chm.CttPicture", "_options", "HbBonusShowPanelSkin", "onClose", "setTitle", "lbl_title1", "lbl_title2", "setReward", "title1", "title2", "grp", "number", "grop", "DesBonus", "chm.DesBonus", "DesPartSkin", "desCttPattern", "<font color=\"#E5B72A\">\u6d3b\u52a8\u8bf4\u660e: </font>{0}", "desTmPattern", "desTmPattern1", "<font color=\"#E5B72A\">\u6d3b\u52a8\u65f6\u95f4: </font>{0}", "desTmPattern2", "<font color=\"#E5B72A\">\u5145\u503c\u5269\u4f59\u65f6\u95f4: </font>{0}", "decorations", "compCorresPond", "flushCnt", "lbl_show_5", "lbl_pay_0", "k_102", "LabDs", "desCttChange", "desBonus", "_des0_render_", "_des1_render_", "_des2_render_", "_des3_render_", "_des4_render_", "_des5_render_", "_des6_render_", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:1#6:activity_hall_bg_jpg#7:1", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:372}#4:1#5:2#6:activity_hall_bg3_jpg#7:1", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:372}#4:1#5:2#6:activity_hall_bg3_jpg#7:1,{lb:2}", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:3#6:national_participation_bg_jpg#7:1", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:4#6:activity_hall_bg3_jpg#7:1#8:item_536_png", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0,{ds:normal}#6:boss_daojishibg_png#7:1", "1:0#2:National_Day_login_desc_png,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0,{ds:normal}#6:boss_daojishibg_png#7:1", "1:2#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0,{ds:normal}#6:boss_daojishibg_png#7:1", "1:0#2:,{x:30,y:13}#3:0#4:0#5:0#6:#7:0", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0,{ds:small,y:115.157}#6:#7:1", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:5#6:activity_hall_bg_jpg#7:1", "1:1#2:consumer_touzi_text_png#3:1,{x:30,y:25,w:509,sz:18}#4:1,{sz:18,x:320,y:137}#5:6#6:activity_hall_bg_jpg#7:1", "1:1#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0#6:activity_hall_bg5_jpg#7:1", "1:0#2:,{x:30,y:13}#3:1,{x:30,y:30,w:509}#4:1#5:0#6:activity_hall_bg_jpg#7:1", "1:0#2:#3:1,{x:30,y:30,w:509}#4:1#5:0#6:activity_hall_bg_jpg#7:1", "Lottery", "activity_hall_bg_jpg", "setDdlTm", "setLeftTm", "k_88", "k_140", "k_141", "k_85", "desSize", "small", "img_tip_1", "lbl_pay_2", "lbl_head_4", "\u5f53\u524d\u62e5\u6709:", "lbl_value_4", "grp_6", "lbl_show_6", "k_27", "img_item_4", "\u6982\u7387\u83b7\u5f97\u4ee5\u4e0b\u9053\u5177", "\u5bfb\u5b9d\u6982\u7387\u83b7\u5f97\u4ee5\u4e0b\u9053\u5177", "259:1,369:1,346:1,413:1,409:1,410:1,126:1,160:1,484:1,553:1,577:1,578:1,579:1,580:1,616:1,420:1,421:1,422:1,423:1,259:1,369:1,370:1,411:1,410:1,126:1,161:1,160:1,485:1,554:1,553:1,585:1,577:1,578:1,579:1,580:1", "\u4eab\u7528\u611f\u6069\u8282\u7f8e\u98df\u6982\u7387\u83b7\u5f97\u4ee5\u4e0a\u9053\u5177", "chm.DesPart", "arr2_2", "arr3_3", "arr3_3_2", "arr4_4", "arr4_4_2", "arr5_5", "arr5_5_2", "arr5_5_3", "removeItem", "addItem", "getNodeByXY", "walkAble", "getNode", "MapItemVO", "fillData", "getNewItem", "MapItem", "getPoint", "MapVO", "timeOutShowMapItem", "bounceOut", "addItems", "getBattleVO", "getFubenBonusData", "doSort", "sortItemArrByRole", "MapSceneItem", "chm.MapSceneItem", "T", "T1", "T2", "\u524d\u5f80\u5145\u503c", "T3", "\u524d\u5f80\u526f\u672c", "T4", "\u524d\u5f80\u91ce\u6218", "T5", "\u524d\u5f80\u4efb\u52a1", "T6", "\u7acb\u5373\u9886\u53d6", "T7", "\u7acb\u5373\u8d2d\u4e70", "T8", "\u524d\u5f80\u51fb\u6740", "chm.PartText", "chm.PtTagCorrespond", "cache", "removeEffInThisobj", "chm.PartEffMgr", "_bindCon", "hideyingzi", "getImg", "removeImg", "yingzi_png", "YingziPlugin", "chm.YingziPlugin", "f", "visited", "visitTime", "buriedDepth", "getPositionInView", "nodePool", "numCount", "MapNode", "chm.MapNode", "nodeWidth", "nodeHeight", "tileWidth", "tileHeight", "noWalkArr", "maskArr", "mapDataUrl", "map_{0}_dat", "mapUrlStr", "{0}/{1}_{2}.jpg", "initTileArr", "initNodeArr", "nodeArray", "setNode", "disposeNode", "transMapNode", "getCenterPoint", "findReplacer", "getNodeBuriedDepth", "chm.MapVO", "itemWH", "bonusType", "itemCount", "chm.MapItem", "itemUrl", "chm.MapItemVO", "act0", "getFiveDir", "_1", "chm.AvatarUrlManager", "chm.NetDispatcher", "chm.NetVO", "CNetVO", "readLong", "SIZE_OF_INT64", "readUnsignedByte", "buffer2Num", "MAX_INT", "readFloat", "readByteArray", "readShortArray", "readIntArray", "readLongArray", "readDoubleArray", "readUTFArray", "readFloatArray", "writeLong", "num2Buffer", "VAL32", " is outside Int64 range", " must be a Number or String", "writeFloat", "writeDouble", "writeUTF", "writeIntArray", "writeLongArray", "writeShortArray", "writeDoubleArray", "writeFloatArray", "writeUTFArray", "writeByteArray", "isLittleEndian", "SIZE_OF_UINT64", "chm.BinaryBuffer", "chm.NetEvent", "message", "host_port_change", "chm.WebSocketEventType", "getAsset", "AssetAdapter", "eui.IAssetAdapter", "UILayer", "sendQQStepLog", "GameSendLogUtil", "addLifecycleListener", "lifecycle", "onPause", "onResume", "cacheBinaryProcessor", "bin", "cacheImgProcessor", "cachesoundProcessor", "sound", "cacheTextProcessor", "\u672c\u5730\u7f13\u5b58\u5f00\u542f", "registerImplementation", "eui.IThemeAdapter", "js_useCtx", "useCtx", "pack.etc1.ktx", "\u4f7f\u7528ktx\u683c\u5f0f", "param1", "\u63d0\u793a", "exitGame", "showWxalert", "catch", "runGame", "default_fontFamily", "crossOrigin", "ImageLoader", "anonymous", "Egert_Main_Status", "Egert_Main_RemoveLoaded", "LoadManager", "gameStartY", "fixedHeight", "startLoading", "setMaxLoadingThread", "Main", "jsonName", "pngName", "urlKey", "weaponDir", "roles/weapon/", "wingDir", "roles/wing/", "monsterDir", "roles/monster/", "playerDir", "roles/player/", "petDir", "roles/pet/", "skillDir", "skills/zhanshi/", "npcDir", "roles/npc/", "loadPng", "getPngUrl", "getJsonUrl", "loadedPngError", "loadedPngComplete", "loadJson", "loadJsonComplete", "jsonObj", "getParentDir", ".png", ".json", "n", "load_complete_al", "load_error_al", "chm.AvatarLoader", "DirectBuyPromptSkin", "oldValue", "newValue", "openEmail", "lblTip", "gEff", "chm.DailyBuyPromptPanel", "word", "ACT_CLK", "act_clk", "ActBtn", "chm.ActBtn", "chm.ActivityBtn", "BigRichBoxRenderSkin1", "boxClick", "state0", "discBg", "setdicNumurl", "disimgbg", "discnum_img", "discount_", "storehouse_box_png", "storehouse_box1_png", "storehouse_box2_png", "lbl_num0", "\u5708", "ACTIVITY_CLICK_RWD", "ACT_DAILY_RENDER", "act_daily_render", "ActivityDailyBounsRender", "chm.ActivityDailyBounsRender", "ID_INDEX", "IDS_Dic", "_index:", "chm.OnlyIDCreater", "removeReward", "_iconUrl", "\u627e\u4e0d\u5230\u9053\u5177>>", "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!", "chm.RewardRender", "lastRoleRunIndex", "lastEffectRunIndex", "myRoles", "roles", "players", "pets", "fightEffects", "otherEffects", "dowith1", "dowith3", "dowith4", "SceneFrame Loop Error!", "allRoleNum", "chm.SceneFrame", "SpecialItemGridSkin", "_itemInfo", "chm.SpecialItemGridRender", "ActivityMainPanelSkin", "chm.ActivityMainPanel", "ActivityRankListPanelSkin", "chm.ActivityRankListPanel", "AMPnl", "chm.AMPnl", "ActivityDesSkin", "k_87", "lblPay", "chm.ActivityInvestLevelDesPanel", "ActivityPay2DesSkin", "payClick", "chm.ActivityPay2Des", "ActivityShachengDesSkin", "chm.ActivityShachengDes", "ActivityShopSkin", "onSelectTab", "ActivityShopRender", "oldFlush", "activity_shop_select", "chm.ActivityShop", "ActivityShopConsumeDesSkin", "shenmi_bg_jpg", "chm.ActivityShopConsumeDes", "SimpleDesSkin", "SimpleDesPanel", "chm.SimpleDesPanel", "chm.ChargeBuyDesPanel", "AcivityConstantRechargeLevelPanelSkin", "booShowTipTotal", "consumeLvlArr", "consumeLvlDic", "lastStartIndex", "scrl_rwds", "group_bubble", "group_compensate", "group_compensate_label", "k_1061", "lst_dayRwd0", "ActivityConstantRechargeLevelRender", "lst_dayRwd1", "lst_dayRwd2", "group_rwdContainer", "startIndex", "jiantou2_right_effect", "jiantou2_left_effect", "\u7d2f\u5145", "lbl_consumeNum", "boShowIdx", "boShowDay", "lbl_bubble", "k_1042", "bubbleShowId", "lst_dayRwd", "chm.AcivityConstantRechargeLevelPanel", "ActivityChargeBuyPanelSkin", "_barBase", "_totalW", "listBtn", "ChargeAndBuyRender", "addItemClick", "_imgArr", "updatePanelByIndex", "gLock", "imgProcess", "lblCharge", "lblConsume", "lblLock", "gCharge", "lblGet", "k_1725", "jubaopen_yuanbao_1_png", "jubaopen_yuanbao_2_png", "jubaopen_yuanbao_3_png", "jubaopen_yuanbao_4_png", "jubaofanli_eff_1", "k_1727", "k_1726", "k_1728", "\u627e\u4e0d\u5230\u9053\u5177\u914d\u7f6e\uff1a", "!!!!", "getTargetPoint", "circIn", "chm.ActivityChargeBuyPanel", "ContentListPanelSkin", "_needRank", "ContentListPanel", "chm.ContentListPanel", "InvestLevelRender", "chm.InvestLevelPanel", "PlayerLevelRender", "chm.OpenServerPlayerLevelPanel", "ActivityCrazyLotteryPanelSkin", "_shinningIds", "LotteryResultPanel", "group_cost0", "group_cost1", "group_cost2", "btn10", "btn50", "lotteryId", "item_{0}_png", "imgItem_0", "imgItem_1", "imgItem_2", "fillLotBonus", "updateActInfo", "\u5bfb\u5b9d\u6d3b\u52a8id>>>>", "\u6ca1\u6709lotterid\uff01\uff01", "lblNum_0", "lblNum_1", "lblNum_2", "lblCost_0", "lblCost_1", "lblCost_2", "106", "shinning", "xunbao_desc1_png", "xunbao_desc2_png", "xunbao_desc3_png", "lbl_totalNum", "k_435", "handleBuy", "k_74", "CrazyBoxRenderVO", "ActivityCrazyBoxRender", "lbl_lottryCount", "k_73", "k_71", "\u5bfb\u5b9d\u627e\u4e0d\u5230\u9053\u5177\u914d\u7f6e>>>>", "chm.ActivityCrazyLotteryPanel", "ActivityDailyTreasurePanelSkin", "_jg", "_curGridArr", "_bounsArr", "_globarr", "initAvatar", "initBouns", "btn_click", "getWayClickHandler", "lbl_mafa", "autoClick", "btn_auto", "bounsClick", "ACT_DAILY_UPDATE", "rspDice", "bounsStates", "allTiShi", "addBonusClkListeners", "cancelAuto", "isShowing", "removeBonusClkListener", "updateData", "bouns_group", "getBounsNum", "BRMCfg", "lbl_quanshu", "updateRwd", "updateRoleAvatar", "updateRolePos", "getBoxrwd", "getLotteryIconId", "_walking", "lbl_has", "(\u62e5\u6709\uff1a", ")", "k_175", "lbl_price", "buyGold", "yuanbao_group", "\u6295\u63b7\u4e00\u6b21", "\u514d\u8d39(", "countdown", "updateCounts", "getStartTime", "lbl_overTime", "getAllCount", "resetTimes", "_role", "img_bar_bg", "floorRwd", "getDaliyState", "BRMBoxVo", "clickState", "lastReTimes", "\u5b9d\u7bb1\u5df2\u5168\u90e8\u9886\u53d6\u5b8c\u6210,\u5df2\u8fdb\u884c\u91cd\u7f6e", "setBounsData", "BigDailyBounsVo", "createBouns", "_bouns", "_boxGridVos", "getBoxCntConf", "isOver", "startShow", "_shankEff", "Dailytreasure", "showStore", "moveNum", "img_store", "Dailytreasure_", "onDiceResult", "checkbox", "_diceDelayId", "floorUp", "roleMove", "setPathArr", "roleWalk", "_rolePathArr", "lastPosition", "walkEnd", "onShankEnd", "setRoleCurDir", "getTitleInfoByHeroID", "ChengHaoMod", "dispatchId", "FbMod", "getFabaoUrl", "MilitRkMod", "autoFlag", "\u81ea\u52a8\u6295\u63b7\u4e2d", "shank", "\u4f60\u70b9\u5f97\u592a\u5feb\u4e86", "k_176", "checkGold", "sendShank", "setAuto", "\u53d6\u6d88\u6295\u63b7", "\u81ea\u52a8\u6295\u63b7", "act_daily_update", "chm.ActivityDailyTreasure", "ActivityShachengPanelSkin", "ActivityShachengRender", "openSandyCityModule", "btn_go", "activity_hefu_bg7_jpg", "fillPanel", "emptyArr1", "fillStartTime", "chm.ActivityShachengPanel", "ActivityType11PanelSkin", "reward0", "ActivityRankRender", "listRwd0", "getbtn", "tochLookRank", "checkReward", "wingFightnumChange", "titleimage", "firstName", "firstValue", "selfName", "_desPanel", "LotteryDes", "setActDes", "closeDesPanel", "chm.ActivityType11Panel", "ActivityType12PanelSkin", "tochHandler2", "btn0", "firstSb", "k_1055", "secendSb", "des0", "limit0", "imgGet0", "chm.ActivityType12Panel", "ActivityType13PanelSkin", "k_1098", "_jpg", "chm.ActivityType13Panel", "ActivityType14PanelSkin", "lblLook", "onLook", "\u5145\u503c\u91d1\u989d\u4e0d\u8db3,\u662f\u5426\u524d\u5f80\u5145\u503c\uff1f", "_fashionShow", "FashionShowPanel", "chm.ActivityType14Panel", "ActivityType41PanelSkin", "ActivityRender41", "ActivityType41Panel", "chm.ActivityType41Panel", "ActivityType5ExtPnlSkin", "_imgW", "changeLeft", "changeRight", "imgLeftFocus", "imgRightFocus", "updateCurrentIndex", "_dataList", "updateArrowImage", "shineLeft", "shineRight", "getLimitFashionList", "_itemArr", "LimitFashionFinalRender", "chm.ActivityType5ExtPnl", "_childList", "children", "bgSource", "titleSource", "bgtitle", "LimitFashionVo", "chm.LimitFashionVo", "ActivityType6PanelSkin", "ActivityRender7", "chm.ActivityType6Panel", "ActivityTypeBossKillPanelSkin", "objs", "boxlist", "ActivityBossKillRender", "getbtn1", "getbtn2", "selectData", "selectKey", "btnname", "btn_group", "lblCost0", "chm.ActivityTypeBossKillPanel", "ActKaifuLuckyShopSkin", "ActKaifuLuckyShopRender", "\u82e5\u60a8\u8d2d\u4e70\u7684\u5546\u54c1<font color=\"#389d23\">\u9500\u552e\u91cf\u6700\u9ad8</font>\uff0c\u6b21\u65e50\u70b9\u540e\u5373\u53ef\u901a\u8fc7\u90ae\u4ef6\u9886\u53d6\u8fd4\u5229\u5143\u5b9d\u3002\uff08\u82e5\u9500\u552e\u91cf\u76f8\u540c\uff0c\u5219\u90fd\u4f1a\u53d1\u653e\u8fd4\u5229\u5143\u5b9d\uff09", "fillShop", "sourcecost", "discount", "chm.ActKaifuLuckyShop", "APubBossPnlSkin", "list_boss", "APubBossRender", "tapItem", "onClickHandler", "onArrowClick", "grp_leftArrow", "grp_rightArrow", "img_leftEff", "img_rightEff", "maxBossIdx", "selectIdx", "fillBossList", "_selectIdx", "fillPanelByIndex", "REWARD:", "grp_rwd", "chm.ActPubBossPnl", "ActRecharge3For4PnlSkin", "redList", "img_red1", "img_red2", "img_red3", "ActRecharge3For4Render", "renderList", "renderItemArr", "dayItemArr", "chm.ActRecharge3For4Pnl", "ActSalePromotionPnlSkin", "list_timebar", "ActSalePromotionPnlRender", "ActSalePromotionPnlRender1", "clickTimeBar", "dayArr", "timeSegs", "toggleSelected", "chm.ActSalePromotionPnl", "FashionShowPanelSkin", "_imgList", "activity_fashion_bg38_jpg", "activity_fashion_bg37_jpg", "_dotState", "button_bg2_png", "button_bg1_png", "FashionShowRender", "onClickDot", "imgDot_0", "imgDot_1", "updateIndex", "updateDotByIndex", "imgDot_", "chm.FashionShowPanel", "LotteryResultPanelSkin", "chm.LotteryResultPanel", "LotteryDesSkin", "rateXml", "list_rate", "LotteryDesRender", "grp_des", "grp_act", "grp_loottery", "lbl_desc", "parseRateXml", "lbl_head1", "head1", "lbl_head2", "head2", "rates", "bgImg", "\u5728 lotteryrateclientexml_json \u4e2d\u627e\u4e0d\u5230id>>>", "\u7684\u914d\u7f6e\uff01\uff01\uff01", "des2", "LuckyRewardTurnDesPanel", "chm.LuckyRewardTurnDesPanel", "LuckyRewardTurnPanelSkin", "_totalPoolNum", "_shineCount", "_resultPanel", "LuckyRewardTurnResultPanel", "lblShop", "openShop", "addShowItem", "_imgNum", "lucky_tnumber_{0}_png", "gGoldNum", "turnTable0", "btn_0", "turnTable1", "gSelect", "listLog", "LuckyRewardTurnLogRender", "showDescription", "btnExplain", "drawTurn", "lblCurrency", "totalPoolNum", "endPoolNum", "startTween", "completeDraw", "cubicOut", "showResult", "showItemTip", ":-1", "chm.LuckyRewardTurnPanel", "_img", "$addListener", "RewardTurnShowItem", "chm.RewardTurnShowItem", "LuckyRewardTurnResultSkin", "\u518d\u62bd{0}\u6b21", "\u62bd\u5956{0}\u6b21\uff0c\u83b7\u5f97\u5982\u4e0b\u73cd\u7a00\u9053\u5177", "chm.LuckyRewardTurnResultPanel", "RewardTurnResultRender", "LuckyRollerRebateSkin", "isRolling", "runCount", "group_roll", "img_yuanbao", "refreshInfos", "imgPointer", "updateView2", "srvVo", "_srvVo", "updateView1", "BONUSIDXS", "tweenStart", "circOut", "\u83b7\u5f97\u4e86", "nextConf", "lbl_tip", "k_1041", "lbl_rollcost", "\u6b21\u6570\u5df2\u8fbe\u4e0a\u9650", "k_80", "lbl_left_time", "chm.LuckyRollerRebatePnl", "ActivityBossKillBoxRenderSkin", "select", "tgtNum", "national_participation_box2_png", "national_participation_box2bg_png", "national_participation_box1_png", "national_participation_box1bg_png", "ABossKR", "chm.ABossKR", "chm.ActivityBossKillRender", "ActivityConstantRechargeLevelRenderSkin", "btn_getRwd", "group_dayConsume", "img_bonus", "lbl_consumeDay", "group_dayTag", "\u53ef\u8865\u9886", "chm.ActivityConstantRechargeLevelRender", "chm.CrazyBoxRenderVO", "crazytreasure_denglu_icon_box_png", "crazytreasure_denglu_icon_box1_png", "crazytreasure_denglu_icon_box2_png", "k_72", "chm.ActivityCrazyBoxRender", "ActivityRankInfoRenderSkin", "wangzhe_first_png", "wangzhe_second_png", "wangzhe_third_png", "lbl_fight", "chm.ActivityRankInfoRender", "ActivityRankRenderSkin", "k_44", "chm.ActivityRankRender", "ActivityRender41Skin", "chm.ActivityRender41", "ActivityRender6Skin", "ActivityRender6", "chm.ActivityRender6", "ActivityRender7Skin", "chm.ActivityRender7", "ActivityShachengRenderSkin", "group_bonus", "chm.ActivityShachengRender", "ActivityShopRenderSkin", "img_tag", "tehui_tag_1_png", "tehui_tag_2_png", "chm.ActivityShopRender", "ActKaifuLuckyShopRenderSkin", "buyItem", "img_cost", "img_origincost", "lbl_origincost", "lbl_selfCount", "k_93", "buyTimes", "chm.ActKaifuLuckyShopRender", "ActRecharge3For4RenderSkin", "lbl_pay", "newlc_expired_png", "achieve_already_receive_png", "levelCountChange", "k_94", "chm.ActRecharge3For4Render", "loopkey", "ActSalePromotionPnlRenderSkin", "lbl_hour", "lbl_min", "lbl_sec", "countEnd", "grp_static", "grp_countDown", ":00", "<font color=\"#B58863\">", "k_97", "</font>", "<font color=\"#35E111\">", "k_98", "setCountDown", "k_99", "anniversary_task_button2_png", "anniversary_task_button1_png", "hour", "sec", "chm.ActSalePromotionPnlRender", "ActSalePromotionPnlRender1Skin", "oldcost", "\u7acb\u5373\u62a2\u8d2d", "lbl_svrLeft", "k_100", "img_vip", "_effect", "chm.ActSalePromotionPnlRender1", "APubBossRenderSkin", "img_defeat", "port_quanming_json", "port_qd_json", "monster_qd_json", "boss", "img_bossIcon", "head_", "lbl_bossInfo", "chm.APubBossRender", "ActivityRender1Skin", "AR1", "chm.AR1", "AShpR", "chm.AShpR", "k_1484", "ASpCoR", "chm.ASpCoR", "ChargeAndBuyRenderSkin", "updateSelectImg", "jubaopen_yeqian_", "imgTxt", "jubaopen_text_", "lblBonus", "\u53ef\u83b7\u5f97{0}\u5143\u5b9d", "chm.ChargeAndBuyRender", "DiscountShopRenderSkin", "baseGrid", "k_1301", "k_1302", "k_1303", "DiscountShopRender", "chm.DiscountShopRender", "onUIcomplete", "VipFirstPayRenderSkin", "click", "k_949", "k_952", "chm.DoubleRechargeRender", "FashionShowRenderSkin", "chm.FashionShowRender", "InvestLevelRenderSkin", "getRewardHandler", "imgIvl", "lv_", "chm.InvestLevelRender", "LimitFashionFinalRenderSkin", "showHeroFigure", "fashionBodyId", "fashionEquipId", "\u5728 fashion_json \u4e2d\u627e\u4e0d\u5230 id>>", " \u7684\u914d\u7f6e\uff01\uff01\uff01", "img_weapon", "img_wing", "wingeffect", "playWingEffect", "stopEffect", "_wingEff0", "effect_0", "_wingEff1", "effect_1", "chm.LimitFashionFinalRender", "LotteryDesRenderSkin", "isShowPer", "chm.LotteryDesRender", "LotteryGetShowRenderSkin", "<font color=\'#389d23\'>{0}</font><font color=\'#a89e81\'> \u62bd\u4e2d\u4e86 </font><font color=\'#ff0f15\'>{1}</font>", "(", "\u5143\u5b9d)", "chm.LuckyRewardTurnLogRender", "chm.PlayerLevelRender", "MisteryLimitViewMediator", "k_1723", "chm.MisteryLimitModule", "MisteryLimitPanel", "chm.MisteryLimitViewMediator", "RechargeId", "MisteryLimitPanelSkin", "imgShow", "onClickClose", "\u539f\u4ef7\uff1a", "\u5143", "weixin_ID", "chm.MisteryLimitPanel", "askFight", "SRWD_GET", "askPickBox", "RMV_BXS", "clearAllBox", "addServerListens", "askQuit", "sendLeafScene", "existboxArr", "clearBox", "chm.MonsterNianController", "idxs", "oldremain", "_boxXYIndex", "addListeners", "springfestivalbosssetting_json", "_xml", "springfestivalboss_json", "_frontxml", "getBoxClearCD", "boxdisappear", "getBossSpeakCD", "speakcd", "getBossSpeakContent", "_contentDic", "speakdetail", "dead", "diespeak", "_getSpeakIdx", "getBossPortID", "getBossHpCount", "hpcount", "getRewardShowVO", "killReward", "killbonus", "luckReward", "rewardBonus", "rankBonus", "BossZSRewardVO", "rankRewardArr", "leftTime", "_leftTime", "getMonsterHpPercent", "getMonsterBattleTime", "setMonsterOpenTime", "_monsterOpenTime", "monsterOpenTime", "n_30104", "updateMonsterRed", "rspLeftTimeUpdate", "rspShowStageRwd", "rspBossReward", "_monsterXY", "monsterXYArr", "_boxXYArr", "nianshou_box_png", "createBox", "moN_ent_req", "moN_srwd_get", "moN_rmv_bxs", "moN_scrot_chg", "chm.MoNMod", "_clearSec", "_fetchState", "initBox", "addIn", "removeOut", "boxID", "_boxImg", "fetchBox", "bounceXY", "nianbox_eff", "MonsterNianBox_LOOP_TIMER", "shakeBox", "NUMOFBOX", "originXY", "referXY", "toPosXY", "fetchAni", "monsternianbox_loop_timer", "chm.MonsterNianBox", "MonsterNianRewardPanelSkin", "MonsterNianRewardPanel", "chm.MonsterNianRewardPanel", "rankImgArr", "first", "second", "third", "MonsterNianRewardRenderSkin", "wangzhe_", "lbl_rankDes", "k_685", "MonsterNianRewardRender", "chm.MonsterNianRewardRender", "boss_jianglititle_png", "\u5e86\u5178BOSS", "killGrid", "luckGrid", "hit_group", "lk_group", "MoNRwdV", "chm.MoNRwdV", "inited", "maxSec", "createMap", "wingCache", "_lastCacheCount", "wingNum", "loadMap", "initLoopClear", "gc", "excGC", "exGcWing", "hasComplete", "bigTexture", "hasLoading", "doLoad", "jsonTexture2BitmapClipData", "createBitmapClipData", "BitmapClipDataPool", "SubTexture", "subtexture", "ofx", "ofy", "createTextureFromBigTexture", "createBitmapFrame", "BitmapFramePool", "jsonKey", "pngKey", "textureWidth", "textureHeight", "$initData", "load_complete_ss", "chm.SceneSouce", "OnlineViewMediator", "updateOnlinePromotion", "onSvrData", "OnlineModel", "chm.OnlineModule", "OnlinePanel", "BoxGridItem", "clickOnline", "_seleIndex", "gBnLst", "val", "lab_nextTime", "k_1678", "lab_desc", "_OLTime", "chm.OnlineViewMediator", "OnlineItemVO", "chm.OnlineItemVO", "_isCanGet", "seltId", "_svrDatas", "childId", "times", "onlinTime", "JSON parse error1:", "JSON parse error2:", "_cunTime", "requestDailyOnline", "chm.OnlineModel", "BoxGridItemSkin", "onselected", "imgflyToBag", "gir_gorp", "img_ling", "chm.BoxGridItem", "OnlinePanelSkin", "onStage", "onRomve", "nleftTime", "OnlinePanel1", "cutTime", "lab_nextTime0", "chm.OnlinePanel", "UpdActViewMediator", "UpdActModel", "dataUpdate", "doHourCheck", "_req_upd_bonus_", "doOpenCheck", "_rsp_li_", "_rsp_lo_", "_rsp_tr_", "getUpdIds", "_req_upd_data_", "addBtnVo", "timeIds", "updateAct", "Login", "activtyId", "rewardId", "chm.UpdActModule", "subClassDic", "pnlDic", "desClassDic", "gengxin_title_png", "UpdBtn", "resetListPos", "getShowBtns", "getOpenSelect", "setBtnList", "getActVoById", "removeDesPanel", "createSubPanel", "createDesPanel", "UpdDesType1", "UpdActBossNumPnl", "UpdActThemeShopPnl", "UpdActPnl1", "tmpSub", "arrow_left", "arrow_right", "chm.UpdActViewMediator", "getOpenXml", "_openXml", "updateactivityopen_json", "getTimeLimit", "updateActivityId", "getActxmls", "_actXml", "updateactivity_json", "_timeIds", "_updDic", "createUpdXml", "UpdVo", "UpdSubVo", "subDes", "subEle", "createBtnXml", "_btnDic", "UpdBtnVo", "boClose", "_limit_check_li_", "_limit_check_lo_", "_limit_check_tr_", "subJsn", "elements", "takeInfo", "chargeYb", "chm.UpdActModel", "BackActivityDesSkin", "chm.UpdDesType1", "UpdRender1Skin", "UpdBossNumRender", "chm.UpdBossNumRender", "AchievebuttonSkin", "onAddToS", "onRmvFromS", "selectChange", "chm.UpdBtn", "UpdRender1", "chm.UpdRender1", "UpdTsRenderSkin", "k_42", "UpdTsRender", "chm.UpdTsRender", "UpdPnl1Skin", "chm.UpdActBossNumPnl", "chm.UpdActPnl1", "UpdThemeShopPnlSkin", "imgDes", "img_desBg", "chm.UpdActThemeShopPnl", "chm.UpdBtnVo", "chm.UpdSubVo", "chm.UpdVo", "numElements", "getElementAt", "getUTCDay", "k_1292", "k_1293", "k_1294", "k_1295", "k_1296", "k_1297", "k_1298", "k_69", "checkPassDayNew", "getMyPlt", "chm.ActivityUtil", "\":\"", "\":", "chm.JsonUtil", "ABVo", "chm.ABVo", "chm.ActCardCfgVo", "game_type", "BASE_MOVE_SPEED", "BASE_HORSE_MOVE_SPEED", "beaten", "act5", "act4", "act3", "act2", "act1", "ACTION_DEFAULT", "default", "EFFECT_TYPE_SINGLE_BODY", "effect_type_single_body\u66ff\u4ee3\u5f62\u8c61", "NAMEDISTANCE", "chm.SceneType", "chm.ActivityNewInfo", "chm.ActivityRankVo", "chm.ActivityRewardVo", "setEle", "dealWithSubValue", "subTrigger", "SubJobRecharge", "checker", "chm.ActivitySubVo", "getTheme", "undefined", "callLater", "gameeui_json", "JSONParseClass", "TYPE_TEXT", "ThemeAdapter", "chm.ActRebateConfigVo", "chm.ActRebateVo", "ARkVo", "chm.ARkVo", "_oldValue", "_newValue", "propertyChange::DataPropertyChange", "chm.DataPropertyChange", "chm.FestivalAnnualTaskSubVo", "chm.FestivalAnnualTaskVo", "chm.FestivalDouble11Vo1", "chm.FestivalGoldenEggVo", "_ele", "id2", "initSub", "_subArr", "isFree", "chm.FestivalMotherRcgVo", "FestivalMotherRcgSubVo", "chm.FestivalMotherRcgSubVo", "FstBetCfgSVo", "chm.FstBetCfgSVo", "FstBetCfgVo", "chm.FstBetCfgVo", "chm.RegisterRedVo", "sec_ann_gift_title_1_png", "sec_ann_gift_title_3_png", "sec_ann_gift_title_2_png", "chm.WishBoxRewardPoolVo", "chm.WishBoxRewardVo", "_med", "ArtifactMed", "_zwMed", "ZhanWenMed", "LgFtEqps", "upFFEqp", "Bag_FFEqp", "ftNumCg", "rspComEquipInfo", "loginComp", "zsLvlCg", "BAG_RESOLVE", "BagEui", "showSMDu", "showArtTip", "ZHANWEN_COM_LIST_UPDATE", "showResl", "AfTipEui", "showZw", "ZHANWEN_EQUIP_CHANGE", "bagArr", "ckZwNum", "HeroFightFigureEquip", "ZHANWEN_CHARGE_SUCC_UPDATE", "ZHANWEN_PLAY_EFF", "ZHANWEN_BAG_CHANGE", "askOKEqp", "itemIds", "askEquip", "askDec", "askOKLup", "positions", "askFFLvup", "askForAlive", "askForLevelUp", "askChargeEquip", "askComEquip", "ZHANWEN_COM_SUCCESS", "chm.ArtifactMdu", "_scrollH", "_artMod", "ArtMainV", "artifact_title_png", "askForGrade", "btnUp", "atfPal", "ARTIFACT_SHOW_CHANGE", "ArtifactGrid", "afShowCg", "afGoto", "lblGetDes", "addMgrEvts", "filArtf", "SELECT_ID_CHANGE", "rmMgrEvts", "filAfAr", "setAfTitle", "setAfIcon", "buffDes", "setAfBuf", "getArtifactLevel", "getAftMaxLvl", "getPropDes", "setAfCurAr", "k_113", "setAfNtAt", "getProp", "setAfFt", "getCostDataById", "setGrSta", "setGetWay", "getInitProps", "getWay", "k_114", "getArtLst", "setArfAr", "setArtifact", "stopEft", "stopPlEft", "stopBplEft", "getGoto", "atFtNum", "setEftIcon", "lblBuff", "propCurr", "propNext", "k_110", "k_111", "k_112", "\uff1a", "lblCondition", "playBtnEft", "<u>", "</u>", "equipGroup", "getChildByName", "lblLv", "chm.ArtifactMed", "ZwMainV", "zwPal", "btn_resolve", "hideResl", "zwReso", "tapResolve", "CheckBox", "checkAlert", "hideAlert", "Alert", "selecOk", "showRep", "btn_replace", "hideRep", "zwRep", "selectBol", "onceRep", "btn_oncereplace", "onceUpgrade", "btn_onceupgrade", "askResolve", "btn_oneKey", "ARTF_REPALCE_FIGHTFIGURE", "repFtFig", "askFightFigure_LevelUp", "btn_upgrade", "playFFEft", "showFtOne", "img_onefetter", "showFtTwo", "img_twofetter", "showFtThr", "img_threefetter", "getLockMon", "lab_getzw", "showComPanel", "img_hecheng", "hideComPanel", "ZhanWenComPan", "expClick", "btn_exp", "showChargePanel", "btn_discharge", "oneCharge", "btn_onedischarge", "tipClick", "ZHANWEN_COM_BTN_CLICK", "askComBtnClick", "ZHANWEN_CHARGE_EQUIP", "bagIdArr", "resAr", "ResolveNums", "flag", "lab_add", "selecIndex", "_selectHIndex", "getredNumArr", "effType", "EFF_EQUIP", "effPos", "opea", "getLvlUpData", "EFF_LVLUP", "selctIndex", "playFigEfSuc", "UiArr", "battle_lines_fit", "battle_lines_upgrade", "setFetPal", "showFetter", "zwChargePan", "\u65e0\u6cd5\u62c6\u5378\uff0c\u6ca1\u6709\u8be5\u88c5\u5907", "123_1", "k_149", "k_148", "showTipPan", "\u5f53\u524d\u65e0\u88c5\u5907", "k_142", "chm.ZhanWenMed", "_arr", "_zwdic", "_zwcom", "_zwarr", "_shuxing", "\u6b66\u5668\u57fa\u7840\u5c5e\u6027", "\u5934\u76d4\u57fa\u7840\u5c5e\u6027", "\u9879\u94fe\u57fa\u7840\u5c5e\u6027", "\u8863\u670d\u57fa\u7840\u5c5e\u6027", "\u624b\u956f\u57fa\u7840\u5c5e\u6027", "\u6212\u6307\u57fa\u7840\u5c5e\u6027", "_zwjb", "_comList", "_configList", "parXml", "parZwXml", "parsezwHcXml", "artifacts_json", "ZwInfoVo", "extPoint", "isNewZw", "rate:", "propType", "imgName", "battle_lines_", "getAlAft", "getArtifactLen", "getAftName", "activation", "getNameByID", "getIconByID", "getSIcon", "_0_png", "getTitle", "getActiva", "getBuffDes", "getdes", "upcost", "getZwPos", "fightfigureinterlock_json", "ZwFtVo", "multi", "ZwMulVo", "opennum", "openLv", "getZhanWenJiBan", "fightformula_json", "getComList", "getZwComList", "ZhanWenHcVo", "getZwByBag", "isHas", "checkIsHas", "chm.ArtCfg", "_bagArr", "_heroArr", "changeIndexs", "ARTIFACT_RED_POINT_CHANGE", "checkIfBoRedById", "ArtfGridVo", "redsFun", "ZlingMod", "checkMagicFuse", "checkMagicExchange", "checkTip1Red", "checkTip3Red", "showTipRed", "fazhenRed", "FzModel", "getLtReds", "getRepLst", "getHBZwn", "openNum", "op", "reds", "redShengJiZw", "openpos", "fightfiguresetting_json", "getOLTxt", "k_1305", "7", "8", "isSamePos", "getLvlUpRed", "getMinCost", "zws", "jhNum", "ret", "costNum", "_effType", "_effPos", "getMCostZj", "getZwEfNum", "getZwFtFt", "setZwFtFt", "ckAfRed", "heRed", "hcTabRed", "select_id_change", "artifact_red_point_change", "zhanwen_equip_change", "zhanwen_bag_change", "zhanwen_play_eff", "zhanwen_com_list_update", "zhanwen_com_success", "zhanwen_charge_succ_update", "zhanwen_com_btn_click", "zhanwen_charge_equip", "chm.ArtifactMod", "getPropStr", "k_115", "\u3000\u3000", "YELLOW", "FREY", "ZHANWEN_JIBAN", "\u9576\u5d4c{0}\u79cd\u7d2b\u8272\u54c1\u8d28\u6218\u7eb9({1}/{2})", "JIHUO", "\u6fc0\u6d3b", "WEIJIHUO", "\u672a\u6fc0\u6d3b", "chm.ArtStatic", "chm.ZhanWenHcVo", "chm.ZwFtVo", "splitId", "chm.ZwInfoVo", "chm.ZwMulVo", "ArtifactTipSkin", "xiulian_icon_chuanshi_png", "xiulian_tittle_chuanshi_png", "main_icon_fabao_png", "main_title_fabao_png", "xiulian_icon_fazhen_png", "xiulian_tittle_fazhen_png", "xiulian_icon_zhanwen_png", "xiulian_tittle_zhawen_png", "xiulian_icon_fantian_png", "xiulian_tittle_fantian_png", "main_icon_qiling_png", "main_title_qiling_png", "xiulian_icon_thunder_png", "xiulian_tittle_thunder_png", "_mainIcons", "MainButtonVO", "nameUrl", "MainBtnV", "touchHand", "setButtonRed", "groupTip", "button", "chm.AfTipEui", "ArfEui", "guangEft", "artifact_bg_jpg", "guang", "bhdfat_effect1", "atEft", "artf_replace_fightfigure", "chm.ArtMainV", "heTabSelected", "fetterEffDic", "ZwEui", "afFtNum", "ZwResvEui", "ZwAlertEui", "ZwRepEui", "zwFetter", "ZwFetEui", "ZhanWenComPanel", "tipPanel", "ZhanWenTipPanel", "ZhanWenChargePanel", "initHFNum", "battle_lines_title_png", "battle_lines_bg_jpg", "horizontalCenter", "ZwRepRd", "check_one", "check_two", "check_three", "check_four", "check_five", "check_six", "getZwRd", "ZwRd", "group_A_one", "group_B_one", "group_C_one", "group_A_two", "group_B_two", "group_C_two", "group_A_three", "group_B_three", "group_C_three", "hcTabBar", "btn_org", "btn_red", "addListener", "setZwOpNum", "clkHero", "crtNewRole", "ZHANWEN_TAP", "selectHd", "zwChange", "FIGHTFIGURE_ASK_FOR_REPALCE", "repFF", "onZWJHChange", "hideTipPanel", "updateHcList", "removeListener", "hideManual", "rfHeroRed", "filZw", "setProVal", "setZwjhColor", "isShowHc", "setHcRed", "selectHero", "setHeroRed", "clearSelect", "_selctIndex", "lab_hasNum", "lbl_tag", "costNums", "lab_Num", "upRepPal", "setLabColor", "setZhanWen", "setDate", "zhanwen_purple_effect", "playFESuc", "zhanwen_orange_effect", "zhanwen_red_effect", "group_onefetter", "showFtEf", "group_twofetter", "group_threefetter", "setHeroFight", "lab_vs", "k_1310", "k_1311", "k_1312", "k_1313", "showManual", "classid", "_1_", "_0_", "img_noFigure", "k_1555", "zwFtNum", "lbl_curProp", "img_fuwen", "lbl_nextProp", "hideFetter", "lab_name", "GroupChild_", "propNameText", "propNameTextone", "proplabel_", "showTipPanel", "k_147", "hc_red", "chm.ZwMainV", "chm.ArtfGridVo", "ArtifactGridSkin", "imgRed", "k_108", "artifact_show_change", "chm.ArtifactGrid", "KfRdVo", "chm.KfRdVo", "ArtifactPanelSkin", "chm.ArfEui", "ZhanWenChargeSkin", "ZhanWenChargeRender", "addEvt", "removeEvt", "_heroIndex", "getListInfo", "\u6682\u65e0\u62c6\u5378\u7684\u88c5\u5907", "chm.ZhanWenChargePanel", "ZhanWenComSkin", "ZhanWenComRender", "chm.ZhanWenComPanel", "ZhanWenTipSkin", "removeRwd", "addRwd", "removes", "playTipEff", "effNum", "removeTipEff", "fly2Bag", "chm.ZhanWenTipPanel", "ZhanWenAlertSkin", "chm.ZwAlertEui", "ZhanWenPanelSkin", "chm.ZwEui", "ZhanWenFetterSkin", "chm.ZwFetEui", "ZhanWenReplaceSkin", "chm.ZwRepEui", "ZhanWenResolveSkin", "ZwResRd", "chm.ZwResvEui", "ZwTipEui", "chm.ZwTipEui", "euiComplete", "ZhanWenChargeRenSkin", "btnClick", "lbl_propShow", "img_zhanwen", "lbl_prop", "lbl_propLvl", "Lv.", "chm.ZhanWenChargeRender", "_grids", "_indexs", "ZhanWenComRenderSkin", "grpClick", "grp1", "grp2", "grp3", "lbl_count1", "lbl_count2", "k_146", "\u6218\u7eb9\u4e0d\u8db3\uff0c\u65e0\u6cd5\u5408\u6210", "k_143", "k_144", "k_145", "chm.ZhanWenComRender", "ZhanWenRenderSkin", "selectFun", "lab_open", "battle_lines_json.battle_lines_yuan_png", "battle_lines_checked1_png", "battle_lines_json.battle_lines_linxing_png", "battle_lines_checked2_png", "battle_lines_json.battle_lines_juxing_png", "battle_lines_checked3_png", "battle_lines_json.battle_lines_yuanoff_png", "grouy_lv", "battle_lines_json.battle_lines_linxingoff_png", "battle_lines_json.battle_lines_juxingoff_png", "lab_lv", "lv.", "img_titleTip", "chm.ZwRd", "uiComp", "ZhanWenReplaceRender", "group_vs", "img_role", "img_add", "fightfigure_ask_for_replace", "chm.ZwRepRd", "ZhanWenResolveRenderSkin", "chm.ZwResRd", "_boxCtrlDic", "_progBar", "SprFProgEui", "_boxId", "_findBoxPosId", "targetObject", "_lastX", "_lastY", "_inPk", "removeBox", "BabelBoxModel", "BabelBoxLoop", "createBabelBox", "rspStartProg", "rspComProg", "rspBoxState", "pkStart", "pkEnd", "7719", "onProgEnd", "removeListeners", "REQ_BOX_GET", "checkBoxProg", "getSpingBoxByMyView", "getBoxInfoByBoxId", "onClickBox", "BabelBox", "setBoxInfo", "stopProg", "boxStopTake", "startProg", "boxEndPros", "\u83b7\u5f97\u65d7\u5b50x1", "\u9886\u53d6\u5931\u8d25\uff0c\u65d7\u5e1c\u5df2\u88ab\u5176\u4ed6\u73a9\u5bb6\u9886\u53d6", "BabelModel", "searchBoxEnd", "babel_box_start_pros", "onFindBox", "boxStartPros", "BabelBoxController", "chm.BabelBoxController", "BabelViewMediator", "_scoreRewardNum", "_myScoreNum", "layerScr", "_groupRebornTime", "BableMainloop", "mBableMainKey_loop", "BableMainKey", "mBableMainKey_secend", "defIndex", "_lastRequestReborn", "_attBuffCd", "_defBuffCd", "BabelView", "babelAttackers", "BabelAttackersView", "babelItemDes", "BabelItemDesView", "babelJiFen", "BabelJiFenView", "babelReborn", "BabelRebornView", "babelManRank", "BabelMainRankView", "babelAchieve", "BabelAchieveView", "endPanel", "BabelEndView", "buffesView", "BabelBuffView", "babelNextFloor", "BabelNextFloor", "prepareView", "BabelPrepareView", "group_guildRank", "group_roles", "group_reborn", "group_buff", "startBox", "checkPrepare", "setRebornView", "disposeBox", "clearFuHuo", "btn_clear", "lookReward", "btn_reward", "clickBuffAttack", "buff_att", "clickBuffDefense", "buff_def", "hidBuyItem", "buyBuff", "btn_getitem", "getAllRanks", "lbl_checkRank", "getcanyuRwd", "updateRank", "showEndPanel", "clearBabelEnd", "updateMyScoreTaskInfo", "attackChange", "RebornSuccess", "changeFlagNum", "changeMyScore", "buffCountDown", "updateDefBuff", "LoopData", "updateTargets", "_attShape", "_defShape", "buff1", "buff2", "group_att", "group_def", "_defEff", "defCountDown", "def_time", "defLoop", "defInterval", "defChange", "moveTo", "lineTo", "drawArc", "setAchieve", "BabelConfigModel", "num1", "defBuffCd", "getSetConf", "attBuffCd", "playBaoZhao", "playBuffEff", "tticon_bomb", "defBuffTime", "ttshensheng_eff", "defDelay", "changeDef", "_attEff", "attBuffTime", "ttfennu_eff", "attDelay", "changeAtt", "attCountDown", "attLoop", "att_time", "attInterval", "attChange", "flagNum", "setTimeInfo", "setRankArr", "myScore", "showNextLayer", "lastLayer", "lbl_sltime", "S_SetRebornDisplay", "updateSecend", "setDieTween", "rebornTime", "lbl_fhTime", "k_209", "roleReborn", "img_die", "returnBornCount", "getRebornCost", "k_1058", "babelpay", "k_1520", "typeRank", "playerItems", "group_one", "lbl_myScore", "mmyScoreIndex", "lbl_selfScore", "setAchieveInfo", "layerMaxScore", "Babelchieve", "removeEffct", "layerBonus", "rewardText", "k_1524", "k_564", "lbl_canget", "addEffect", "k_1515", "k_1523", "lbl_nextfloorscore", "addScoreTime", "flagAddScorePercent", "marginScore", "lbl_minscore", "k_1513", "lbl_curfloor", "k_1521", "selfScore", "k_1522", "\u6b63\u5728\u6218\u6597\u4e2d\uff0c\u8bf7\u7a0d\u540e\u8d2d\u4e70...", "getAttSucc", "k_1526", "getBuffInfoByType", "attBuffBuyCount", "getBuffCost", "attEndEff", "clearAtt", "changeGraphics1", "defEndEff", "clearDef", "k_124", "getDefSucc", "defBuffBuyCount", "onPlayerMover", "k_1516", "reqBuyBuff", "\u79ef\u5206\u4e0d\u8db3", "reqTakeRwd", "reqRoleRank", "group_right", "getStartTm", "PlaySetMod", "prepareTime", "_boxController", "BabelMainViewMediator", "chm.BabelMainViewMediator", "_viewMediator", "mainMediator", "_viewMainMediator", "_playerModel", "BabelPlayerModel", "enterBabel", "onExitBabel", "playerAllRank", "setReborn", "BattleEnd", "BattleStart", "k_544", "reqEnterGame", "addView", "batTypeCg", "updateSelfBuffShow", "chm.BabelModule", "BabelRadPanel", "rankpanel", "BabelRankView", "attendPanel", "BabelAttView", "figure_jingmai_png", "shacheng_hegemony_rank_png", "panelChangeHandler", "btn_guildRank", "btn_selfRank", "_type", "closeGameWindow", "awardpanel", "_prevView", "night_fighting_rank_title_png", "night_fighting_reward_title_png", "getPlayerRewardInfo", "getScoreRewardInfo", "list_selfRank", "list_selfScore", "chm.BabelViewMediator", "SELF_RANK", "SELF_REWARD", "ENDVIEW_COUNTDOWN_TIME", "BabelStatic", "chm.BabelStatic", "_boxDic", "rspBoxInfo", "rspSprFesStartPros", "rspSprFesStopPros", "rmvRspEvts", "boxDetail", "organPosInfo", "isTake", "getBoxCDByTp", "getFesConf", "familyBoxCd", "serverBoxCd", "_fesConf", "FestivalBoxSetting_json", "flagid", "BabelBoxInfo", "boxState", "positionX", "positionY", "qual", "flagGatherTime", "minTm", "chm.BabelBoxModel", "chm.BabelBoxInfo", "_data_ScoreReward", "getBabelConf", "NightBiqiRewardVo", "_data_PlayerReward", "playerrank", "_buffInfos", "buffinfo", "buyItemSegment", "buyAttBuffCost", "buyDefBuffCost", "rebornSegment", "rebornCost", "getMonsterId", "portId", "getMonstertime", "rushMonsterCD", "_monsterXYs", "getMapId", "getYuanBao", "clearCdCost", "getBuffes", "buff", "getkillMonsterScore", "killRoleScore", "_mapIdDic", "tongtianzhanchangroom_json", "TongtianBattlefieldSetting_json", "chm.BabelConfigModel", "scoreIndex", "_isBabel", "mScoreRewardName", "mbuffBox", "rspScore", "rspReturnBorn", "rspRankInTime", "rspLayerReward", "rspEnterBabel", "rspGameOver", "rspRoleDeath", "buyBuffSuccess", "rspAllRank", "setRebornSuccess", "changeScoreNext", "rewardTakeState", "setDeath", "rspBuffChange", "buffType", "\u8d2d\u4e70\u6210\u529f", "myScoreReward", "mmyScoreReward", "myScoreIndex", "ScoreRewardName", "mside", "updatePlayer", "pos_x", "pos_y", "updatePlayerRanks", "updateBuffInfo", "buffTimes", "NightBuffVo", "gBufInfo", "NBiqiModCfg", "\u83b7\u5f97", "k_1525", "chm.BabelModel", "enemyListIds", "mSecendAttackKey", "BabelPlayerModel_mSecendAttackKey", "_babelSceneDic", "Max_Players", "Max_Scenes", "_tmOutIds", "_sencePlayers", "mRect", "playerIds", "_myBuffInfo", "showFlag", "getFlag", "BabelFlag", "setFlagNum", "dBuff", "tongtian_defensebuff", "onClkPlayer", "dispatchFabao", "BabelScenePlayerVo", "clearMonster", "\u590d\u6d3b\u4e2d\u2026\u6682\u65f6\u65e0\u6cd5\u79fb\u52a8", "rspKillInfo", "winner", "loser", "onClkMonster", "getMonsterCnt", "rspOtherEnter", "rspMoveNum", "rspLeaveGame", "rspPlayerInfos", "rspBuffInfo", "other", "myXinCity", "myYinCity", "otherId", "transBuff", "getPlayerVoById", "checkUselessPlayer", "chm.BabelPlayerModel", "_rankSource", "BabelJiFenRenSkin", "playerRank", "playerScore", "BabelJiFenRen", "chm.BabelJiFenRen", "BabelRankRenSkin", "lab_playerRank", "lab_familyName", "lab_playerScore", "lab_playerName", "BabelRankRen", "chm.BabelRankRen", "BabelResultRenSkin", "NightBiqiStatic", "lbl_palyerName", "lbl_familyKingName", "lbl_playerScore", "BabelResultRen", "chm.BabelResultRen", "BabelRoleRenSkin", "enemyId", "setEnemyInfo", "grp_flag", "main_head_{1}_{0}_png", "img_head", "lbl_playerName", "shacheng_hegemony_monster_png", "\u602a\u7269", "img_thumb", "BabelRoleRen", "chm.BabelRoleRen", "str", "\u7b2c{0}\u5c42", "\u7b2c{0}\u540d", "BabelRwdRenSkin", "BabelRwdRen", "chm.BabelRwdRen", "BabelScoreRenSkin", "k_1527", "BabelScoreRen", "chm.BabelScoreRen", "BabelAchieveSkin", "chm.BabelAchieveView", "BabelAttackersSkin", "_enmeyCtrlPool", "enemy0", "enemy1", "enemy2", "enemy3", "_enmeyIds", "enemy", "chm.BabelAttackersView", "BabelAttSkin", "chm.BabelAttView", "BabelBoxSkin", "_boxInfo", "checkTakeEffShow", "palyIconEff", "stopTakeEff", "stopIconEff", "_iconEff", "tongtian_flag", "playTakeEff", "_takeEff", "picking_eff", "boxAni", "chm.BabelBox", "BabelBuffSkin", "chm.BabelBuffView", "_countdownTime", "BabelResultSkin", "list_familyRank", "lbl_myIntegral", "BabelMainEndPanel", "updateCountdown", "closeEnd", "lbl_countdown", "k_563", "S", "chm.BabelEndView", "BabelFlagSkin", "chm.BabelFlag", "BabelItemDesSkin", "chm.BabelItemDesView", "BabelJiFenSkin", "chm.BabelJiFenView", "BabelMainRankSkin", "chm.BabelMainRankView", "BabelNextFloorSkin", "img_mask", "grp_tip", "showMask", "kuafu_heidi_png", "showFloor", "hideMask", "overShow", "chm.BabelNextFloor", "_tiped", "BabelPrepareViewSkin", "clkView", "lbl_3", "k_1528", "_leftTm", "doAniShow", "hs_mypoint", "img_1", "img_2", "img_3", "grp_tip_1", "grp_tip_2", "grp_tip_3", "grp_tip_4", "grp_tip_5", "babel_prepare", "pointTimeHandler", "lbl_tm", "enlargeEsay", "chm.BabelPrepareView", "BabelRadSkin", "chm.BabelRadPanel", "BabelRankSkin", "chm.BabelRankView", "BabelRebornSkin", "chm.BabelRebornView", "BabelRwdSkin", "BabelRwdView", "chm.BabelRwdView", "BabelPanelSkin", "achieveEffect", "task_light_effect", "chm.BabelView", "mtm", "hasReq", "msP", "mendTm", "mx", "my", "runToPoint", "interpolate", "chm.BabelScenePlayerVo", "BjiFenVo", "chm.BjiFenVo", "ItemVo", "chm.ItemVo", "BagMed", "muhdp", "cckBu", "loginCop", "itec", "showTi", "btnCrt", "chkSr", "ckUsi", "isOn", "showOtR", "canUseItem", "BAGEXTENDCOUNT", "VStic", "gVal", "addBagBox", "sendBb", "k_151", "akfEpd", "akfItu", "akfCna", "akUSit", "akUsEq", "sendChangeRolePos", "sendChangeAttPos", "changeType", "\u51fa\u6218\u987a\u5e8f\u5207\u6362\u6210\u529f", "\u653b\u51fb\u987a\u5e8f\u5207\u6362\u6210\u529f", "askFamilyChangeName", "chm.BagMdu", "slIx", "gpArs", "slc", "_md", "_mo", "BagV", "bag_png", "img_tilte", "cName", "rename_title_png", "k_1634", "_mgr", "BagMgr", "listEquip", "euiBag", "listOther", "listZhanwen", "sltp", "showGe", "hidego", "spEdc", "cnfSepd", "euiSpace", "closeEpd", "btnCancle", "openStMd", "btnSmelt", "filIup", "itmUh", "btnUse", "euiIu", "bagOk", "bagSlc", "hideSlp", "hideCnp", "onCn", "onChangeName1", "btn_ok1", "zwRol", "btn_fenjie", "onCns", "reqHreoChange", "input", "k_432", "isCheckMsg", "boNoAuthorPltfm", "dlySendmsgF", "msgSecCheck", "BAG_SP_AC", "getBsCb", "Bagjsn", "hideScp", "_useVo", "hideIuP", "showSp", "cgRole", "k_1189", "c_4200", "changeJob", "playIuC", "gETwCf", "getZwC", "BagSR", "group_selec", "img_selec", "sltG", "clkGh", "showBsg", "hideBsp", "setTa", "setRedp", "setRdp", "rfEql", "rfOl", "rfZwl", "rfSp", "lblSpace", "showScfp", "showSfp", "k_152", "changeName", "showCnp", "familychangeNameId", "showChangeFamilyNm", "showIup", "_clpR", "_clpD", "_clpLd", "cmLoop", "top", "stopAlClip", "jobArr", "guild_changename_title_png", "k_1635", "\u4e0d\u80fd\u8d85\u8fc76\u4e2a\u4e2d\u6587\u5b57\u7b26!", "dlySendchagename1", "chm.BagMed", "rfsp", "ta_s_ch", "rfBag", "openSpaceExpand", "eqpCh", "itmCh", "ffch", "ba_rd_ch", "setEqRed", "remEvts", "gtEqps", "getOtl", "gtZwlst", "getBbM", "k_150", "bosRe", "chm.BagMgr", "bagcost_json", "chm.Bagjsn", "_sltp", "_bsr", "eqpSot", "player_json", "changename", "changePos", "itemSort", "chm.BagMod", "BagspdEui", "ItuEui", "ChNaEui", "BagSEui", "CgPosPanel", "ChangeJobPanel", "tabEquip", "tabOther", "tabZhanwen", "sltIxC", "numC", "group_chose", "hideGzw", "hideGeq", "showGot", "showGzw", "groupEquip", "groupOther", "groupZhanwen", "rm", "showSelectPanel", "hideRoleSwitch", "chm.BagV", "BagPanelSkin", "bag_sp_click", "bag_resolve", "chm.BagEui", "countNum", "lastTime", "_bitmapdatas", "_params", "getBlendModel", "blendModel", "disposeBitmapClipData", "BitmapClipData", "chm.BitmapClipData", "BagSelecPanelSkin", "chm.BagSEui", "BagSpaceExpandSkin", "chm.BagspdEui", "BagSelecRenderSkin", "chm.BagSR", "ChangeNameSkin", "chm.ChNaEui", "ItemUsePanelSkin", "chm.ItuEui", "chm.BigDailyBounsVo", "BigRichMoneyModule", "BRMMed", "shoPnl", "shankOne", "getBounsRwd", "rspBigMoneyManInfo", "buySuccess", "chongzhi", "BigMoneyManDoBonus", "showpanel", "updateInfoByLevelChange", "askDaFuFengInfo", "shankOnce", "getBounsReward", "askForGetDuiHuan", "updateBigMoneyInfo", "checkStates", "chm.BRMMdu", "BigRichMoneyViewMediator", "allNums", "secondNums", "gWin", "BRMPnl", "getView", "BRMGetView", "dhPnl", "BRMDhView", "rwdPanel", "BRMRwdsView", "storehouse_headline_png", "storehouse_bg_png", "getDailyBoxRwd", "BigRichBoxRender", "addRule", "clkHander", "twentyClick", "btn_twnClick", "BRM_DICEOVER", "updategetBigRichMoney", "updateDuiHuan", "rspDiceNums", "showResPan", "checkShowDes", "lastFloor", "k_1685", "updateMaFaBing", "checkFloorState", "tip1", "duiRedShow", "tip2", "twentyFlag", "setUpShowing", "k_172", "k_178", "gettotalPrice", "oneClick", "getDuiHuanList", "updateDes", "updateBaseInfo", "startSecShow", "getPanelType", "moduleIds", "checkBox", "isboxClick", "checkRwdStu", "isShowRewards", "\u6b63\u5728\u6295\u63b7\u4e2d\uff0c\u8bf7\u7a0d\u540e...", "setWalking", "k_1684", "chm.BRMMed", "getway_json", "bigmoneyman_json", "target_floor", "chm.BRMCfg", "_isDicing", "getBigRichMoneyConfDic", "_BigRichMoneyConfDic", "target_reward", "floors", "getCurFloor", "count_buy", "count_buy_cost", "buyCounts", "buyTwentyGold", "mainShow", "_waitInfo", "flotFloor", "CHECK_RED_DAILY", "maxGridNum", "_duiActo", "_duiHuanData", "duihuanEndTm", "setDuihuanBtnState", "getTitArByKd", "_duiHuanDic", "checkCHGet", "isget", "getDuiHuanData", "checkActRed", "getTotalNums", "isFloorUp", "getRwdResult", "chm.BRMMod", "BigRichMoneyDhPanelSkin", "BRMItemR", "lbl_head", "k_1280", "chm.BRMDhView", "_lastGridArr", "_gridPoss", "_twoPath", "_posY", "_floorIndex", "BigRichMoneyGetViewSkin", "maskGrp", "_upShowing", "k_173", "k_170", "grp_one", "grp_num2", "grp_num1", "grp_num3", "num2", "price2", "grp_free", "grp_numGold", "lbl_kuo", "lbl_free", "grp_gold", "price1", "group_free2", "frees2", "countDown", "\u6295\u63b71\u6b21", "updateReward", "50", "100", "150", "200", "storehouse_", "250", "500", "floorUpShow", "timeOutId0", "onFloorUpShowEnd", "onShowEnd", "twentyMove", "twentyWalk", "setTwentyPathArr", "storehouse_yao", "foolish_", "nextWalkEnd", "bigrichWalkEnd", "updateFloors", "brm_diceover", "chm.BRMGetView", "BigRichMoneyViewSkinPanelSkin", "chm.BRMPnl", "BigRichRewarsSkin", "lbl_floors", "getShinningIds", "gotoDice", "chm.BRMRwdsView", "chm.BRMBoxVo", "BigRichBoxRenderSkin", "\u5230\u8fbe", "\u5c42", "chm.BigRichBoxRender", "BigRichMoneyRenderSkin", "k_1289", "k_1", "chm.BRMItemR", "asked", "_viewMed", "BossMed", "_smMed", "SMBossMed", "BossMod", "_pmod", "PublicBossMod", "_otherMgr", "BossOtherMgr", "getcallBosscount", "loginCom", "ckOpenRed", "mutexHide", "onSummonSuc", "4014", "pingbiOtherHandler", "QMBossCfgMod", "onBossAutoChange", "onBossAutoChangeSuccess", "onBossAutoEnableChange", "onBossAutoQuitTimeChange", "fillXieZhuPal", "autoFightByHu", "autoWingBoss", "gotoWingFight", "checkEnterType", "getBossOpenLimit", "askAllQMInfo", "askForZhuanShengInfo", "askAllWingInfo", "isFamily", "showPaneltab", "getSMBossData", "bossCallNum", "c_1520", "getBossAutoConfig", "quanminAutoFightTrigger", "starttime", "bossRed", "dispatchBubbleEvent", "k_198", "isPingBi", "checkAutoVipLimit", "autoFightChange2", "startAutoLoop", "autoFight", "isAuto", "askQMBossTX", "bossAutoEnable", "lastquittime", "bossautofight1", "autoFightLoop", "_enterTime", "cdtime", "allArr", "qmNum", "txNumber", "lastsettime", "k_235", "boosName", "askQMBoss", "lastfighttime", "BossFuChouAlert", "ModuleCheckByTime", "checkBossByLvl", "HandUpStates", "getSubState", "getBosslvl", "wingArr", "recordTime", "CD", "chm.BossMdu", "getPortID", "getZSData", "BossV", "zsStart", "infoChange", "getAllBoss", "getWingBoss", "rankinfoChange", "quantimeCom", "hurtRank", "worldBossStart", "zsCheckReward", "setListdata", "oneArr", "one", "lbl_tixing", "all", "k_197", "getAllBossCount", "qmTotal", "lbl_fightnum", "k_561", "QUAN_MING_COUNT", "qmTime", "lbl_huifu", "k_217", "quanmingtime", "k_218", "wingTotal", "WING_COUNT", "wingTime", "wingtime", "lbl_opentime", "zs", "k_180", "21:00", "21:10", "zuanArr", "cdinterval", "zsCD", "btn_enterFight", "k_211", "setCDTxt", "k_213", "playZsEff", "hidetxPanel", "addRulePanel", "tixingExplain", "getWayHandler", "lbl_getvip", "checkZsrank", "CheckquanRank", "checkquanhurtRank", "gotoFight", "gotoSweepFight", "seletedChange", "qiangDuoClick", "grp_qiangDuo", "setTixing", "setTixing2", "gotoZhuanBossFight", "hideRankpanel", "bossRank", "checkChange", "zrewardSeletedChange", "zreward", "showZsRewardPanel", "lbl_checkreward", "hideZsRewardPanel", "hideTip", "tipQd", "btn_qd", "QMBOSS_USE_POTION_POP", "MapBossHpV", "showBossPosionAlert", "Boss_USE_POSION", "BossAlertRveg", "usePosion", "updateLogRed", "wingBoss", "isTx", "checkTixing", "boss_shpm_png", "k_203", "k_204", "lbl_title3", "k_205", "zsRank", "scores", "askZSBossRank", "boss_jsjl_png", "k_200", "k_201", "k_202", "qRank", "askQMBossRank", "qmHurtRank", "askQMHurtRank", "setbossRankData", "askQuanmingBossInfo", "askWingBossInfo", "BossView", "stopZsEff", "k_215", "askZSBoss", "bossVo", "etype", "askSglBossSweep", "oneName", "askSglBoss", "ZYZMod", "k_210", "alerthandler", "setAutoVisible", "showWingTab", "hideWingTab", "qminterval", "alertRe", "qmAddBuff", "oneRed", "allRed", "wingRed", "bossQdPanel", "checkLogRed", "chm.BossMed", "luckyTime", "_isHoldFirst", "_isDeadFirst", "loseCount", "_duration", "_qmModel", "enterQmboss", "leafQmboss", "quanmHurtChange", "hudunStart", "lotteryStart", "lotteryEnd", "showOrHideFuhuo", "zsClearCd", "zsTargetUpdata", "zsgoldNoen", "zscdChange", "qmCheckReward", "monsterNianCheckReward", "recordChange", "updataHold", "clearHoldInfo", "setMap", "removeBossHp", "QUANMIN_BOSS_BUFF_LEVEL_CHANGE", "refreshBuffLvl", "wudiStart", "bosshpV", "_bosshurtMed", "luckyV", "_luckyMed", "hold_guide_img", "hpBarChg", "pureMHpbar", "lbl_hpcount", "k_508", "creatHp", "hd_group", "set_group", "groupBubble", "isdead", "deadHero", "attackedId", "FUHUO_TIME", "getUelArr2", "getUelArr", "setHpbar", "imh_hp", "lbl_zstime", "wudiboss", "getqmID", "qmconfigID", "showLottery", "hideLottery", "lbl_hitName", "lbl_hitjd", "maxhp", "img_hithp", "img_hitHead", "getHeadURL", "KingMod", "checkbox2", "askForReviveClearCD", "lbl_dec", "\u62a4\u76fe\u5f520\u65f6\uff0c\u89e6\u53d1\u62bd\u5956", "lbl_jd", "hdPro", "img_jdt", "btn_fangqi", "lotteryOK", "btn_xuqiu", "k_208", "LUCKY_TIME", "showLotteryTime", "getLuckyReward", "askForEnterLottery", "showFuhuoTime", "fuhuoCD", "publicBossRevivecd", "fuhuoTime", "ZS_Time", "k_509", "zscdHandler", "qmRwdV", "QMBossRwdV", "moNV", "udQmHoldData", "clearHoldData", "rfBuffLv", "showMonsterBubble", "_totalTm", "bossprotectsetting_json", "protectTime", "_startTm", "wudi", "\u62a4\u76fe\u5f520\u65f6\uff0c\u89e3\u9664\u65e0\u654c", "chm.BossOtherMgr", "MapBossHpMed", "chm.MapBossHpMed", "ZSBossLuckyV", "ZSBossLuckyMed", "chm.ZSBossLuckyMed", "dispos", "getItem", "setMsg", "upTo", "fixedY", "addToContainer", "chm.QMBSPvpMsg", "_removeKey", "_count", "_msgBackImg", "boss_killbg_png", "lbl_record", "defaultStayTime", "clearKey", "upMoveY", "QMBSPvpItem", "chm.QMBSPvpItem", "SMBossV", "shenmi_title_png", "lbl_upvip", "k_207", "gotoVip", "updataView", "smbossData", "askSMBoss", "shenmi_di_jpg", "chm.SMBossMed", "readRuleXml", "readPublicBossSetting", "_zsrevivecd", "urlArr", "ruleArr", "ruledesc_json", "RuleDescVO", "bosssingle_json", "port_call_json", "getPortConfById", "zhuanshengportsetting_json", "revivecd", "getRuleDescVOById", "17", "port_wing_json", "_autoJson", "autofightsetting_json", "BossAutoCfgVo", "viplimit", "getBossNumConfig", "bossrevengesetting_json", "boss_xueliangcao4_png", "boss_xueliangcao3_png", "boss_xueliangcao2_png", "boss_xueliangcao1_png", "chm.BossCfgMod", "timeDic", "_zsStart", "rankType", "allAwardDic", "_monsterConfDic", "hurtNum", "inviteCount", "fuchouCount", "helpCount", "logInfoes", "bossLastLogInfo", "bossCurLogInfo", "_skt", "_cfg", "rspAllInfo", "rspSglInfo", "rspQMInfo", "rspWingInfo", "rspZSInfo", "rspQMEnd", "rspQMKillLog", "rspQMAtte", "rspZSRankInfo", "rspQMDieRlv", "rspQMHurtRank", "rspWorldBossMyHurt", "rspEnterScene", "rspBossQMReward", "rspBossZSReward", "rspDefenceStart", "rspDefenceUpdate", "rspLottery", "rspLotteryend", "rspZSBossTarget", "rspZSCD", "rspzsStart", "rspzsEnd", "rspQMAddBuff", "rspQMAddBuffSuc", "rspWudiUpdate", "rspBossRevive", "rspBossTargetInfo", "rspplayerdatachange", "daDaoAutoChange", "startType", "_startType", "port_zhuansheng_json", "BossZSVO", "opentime", "finishtime", "luckbonus", "getZhuanRankReward", "getMonsterConfById", "bossIcon", "getSummonDatas", "summonArr", "BossZHVO", "hprate", "rfBoss", "bossSingle", "getlv", "quanmingTime", "zhuanShengCd", "quanMingMaxCount", "wingCount", "wingMaxCount", "zhuanSheng", "bossQuanMing", "reliveTime", "isFight", "timeCd", "dispatchRed", "rfSglBoss", "boKill", "finish", "rfBossQM", "rfBossWing", "bossWing", "rfBossZS", "bossReliveData", "bossid", "chapter_json", "ports", "BossOneVO", "bossID", "bossJson", "SMBossVO", "bosscall_json", "currentnum", "fightnum", "SUMMONCOUNT", "quanbossTxInfo", "attention", "8527", "getQMBossRank", "getzsRankinfo", "updaqmHurtRank", "names", "hurts", "QuanMrankVO", "maxHP", "getAllBossAward", "holdAward", "otherAward", "quanminBuffLvl", "_quanminBuffLevel", "chkQikByVip", "SIGLEBOSSSWEEP", "_bossAutoEnable", "myHurt", "defenceStart", "remainTime", "rankIndex", "configid", "checkFightID", "askZHBossHelp", "setQuanmingInfo", "qmPvpDead", "qmKiller", "killer", "usegold", "buffLevel", "k_241", "buff_json", "getMonsterSigleValById", "getMonsterSJConf", "monstershow_json", "getMonsterArr", "isApp", "monster_shenji_json", "getBuffInfo", "revenges", "battleBonus", "_battleBonus", "getLogArr", "friendId", "_friendId", "getFuChouInfo", "getLogRed", "quanmin_boss_buff_level_change", "chm.BossMod", "public_boos_loopKey", "_humanNum", "pvpAttackedId", "unCreatePlayerDic", "myDefaultPos", "attackCount", "oldtime", "_qmMod", "otherPlayerDic", "_playerArr", "selfLiveHeroNum", "_mpMgr", "qmmodel", "creatPlayerHandler", "creatBossHandler", "reviveHandler", "skillActionHandler", "deadHandler", "changeEnterTypeHandler2", "4000", "quanmingAttackHold", "quanmingHoldChange", "changeEnterTypeHandler", "pvpBattleEnd", "_isPingBi", "isPBOP", "notifiDead", "moveToOwnerPos", "moveToOwnerEnd", "reciveAttackMsg", "getAvaterByOnlyID", "creatPlayer", "startAttack", "heroId", "deadOther", "onAttackMe", "getSkillID", "getActByZsSk", "playPvpAttack", "seekMyEnd", "removeAvatarHandler", "_holyAvatar", "cleanScreen", "loopOtherPlayerAction", "creatBoss", "getBOSS", "SwbqMod", "bossId", "bossXY", "getBossMo", "SCZBSceneMod", "getBossMonster", "CrSandyPlayerModel", "revieSelf", "resetBossDir", "showFightEffect", "_fightEff", "startPoint", "getMyGou", "k_672", "holdPlayerId", "worldBossVo", "addPlayerToDic", "trimPlayerPoint", "getNewPlayer", "createOtherPlayer", "playerMoverToMonster", "ownerId", "awakeskill", "otherPlayerPointArr1", "encounterXYArr", "otherPlayerPointArr2", "isPvpTarget", "deletePlayerFromDic", "otherPlayerDead", "action", "selfPlayerDead", "skillAction", "buffChanges", "k_671", "serverTargetIDArr", "getTargetIDArrByFightData", "Action", "fillActionData", "seekComplete", "param2", "targetawake", "awake", "triggerCharacter", "getBulletAtack", "setTargets", "svrData", "change", "getPvpAvatar", "clearOtherPlayer", "OtherPlyActVo", "leadOnlyId", "changePlayState", "checkPlayer", "isPlay", "playOtherPlayerActionByOnlyID", "resetPlayStatus", "startOtherAct", "otherSeekComplet", "k_227", "PlayerName", "recordTrim", "rspWorldBoss", "initPlHM", "9600", "enterSwbqBoss", "checkPortID", "checkzhuanPortID", "checkSummonPortID", "checkSwbqPortId", "checkMonsterNianID", "getMapID", "creatBoss2", "k_1322", "checkHero", "checkHoldSamefamliy", "chm.PublicBossMod", "currentHp", "_isdead", "_zsCD", "pvpRecordDic", "_myHurt", "rankName", "lastPlayerId", "k_223", "k_221", "lastName", "k_222", "getRecordArr", "23", "checkID", "monsArInx", "BattlePosMod", "sendFight", "11", "k_592", "28", "getBossID", "mapbossid", "getCptVO", "12", "13", "getQuanMinSetting", "quanmingportsetting_json", "buffItem", "bufflevel", "chm.QMBossCfgMod", "BossTXPnl", "BossTXV", "chm.BossTXV", "showWing", "BossOnePnl", "BossAllPnl", "BossZSPnl", "BossRankPnl", "BossPnl", "FBSDTipMed", "BossQdInfoPanel", "BossOneRnd", "lbb_head", "k_233", "k_206", "BossZSRnd", "boss_title_png", "BossAllRnd", "BossRankRnd", "tab_one", "tab_all", "tab_zhuan", "tab_family", "current", "chm.BossV", "BossZSRwdPnl", "BossZSRwdRnd", "tab_1", "tab_2", "tab_3", "tab_4", "lbl_rewardname", "chm.BossZSRwdV", "HowToPlayPanelView", "imgdi1H", "imgdi1W", "panelH", "maxContH", "HowToPlayPnl", "desc_grp", "desc_scr", "lblx", "lbly", "textHeight", "HowToPlayV", "chm.HowToPlayV", "chm.HowToPlayMed", "_awardArr", "QmBossRewardPanelSkin", "btnBack", "onlootHandler", "btn_loot", "askChallengeQuanmin", "lbl_bossname", "_grid1", "_grid2", "ownerAwardGroup", "otherAwardGroup", "chm.QMBossRwdV", "SMBossPnl", "lbl_fightNum", "chm.SMBossV", "ZSBossLuckyPnl", "chm.ZSBossLuckyV", "MapBossHpSkin", "MapBossHpPnl", "chm.MapBossHpPnl", "_monsterSpeakStart", "_moNMod", "bubble", "BubbleEui", "qm_playername", "qm_hold_head", "qm_hold_family", "btn_usePotion", "moSpeakStart", "set_group2", "btn_checkreward", "qmhold_group", "lbl_hp", "getMonName", "img_bosshead", "getMonIcon", "lbl_myhurt", "k_507", "lose", "sethpText", "qmrank", "lbl_hurtFrist", "MapBossHurtRnd", "onTab", "rankTab", "onTap", "btn_rank", "ckBoxChg1", "checkbox1", "ckBoxChg2", "onPanelAdded", "hp_group", "look_guide_img", "onStageResize", "k_14", "_poLv", "_poId", "_poNum", "speakLoopIdx", "_speakLoopIndex", "setBubble", "qmboss_use_potion_pop", "chm.MapBossHpV", "lbl_hurt", "chm.MapBossHurtRnd", "QmPvpItemRnd", "chm.QmPvpItemRnd", "_typeArr", "checkJilu", "lbl_jilu", "checkHurt", "k_192", "k_193", "btn_cd", "img_hp", "k_194", "setTxt", "k_212", "k_237", "k_236", "lbl_open", "img_opendi", "k_182", "k_181", "lbl_bossName", "chm.BossAllRnd", "BossAutoRenderSkin", "lbl_lv", "lbl_desc1", "BossAutoRnd", "chm.BossAutoRnd", "canSweep", "k_1320", "k_188", "chm.BossOneRnd", "BossQiangDuoRderSkin", "lbl_link", "k_1618", "linkClick", "img_state", "k_1632", "bossName", "BossQdInfoRender", "chm.BossQdInfoRender", "lbl_txt1", "killTime", "lbl_txt2", "lbl_txt3", "chm.BossRankRnd", "checkBoxChange", "BossTXRnd", "chm.BossTXRnd", "k_219", "BossZHRnd", "chm.BossZHRnd", "k_189", "chm.BossZSRnd", "chm.BossZSRwdRnd", "BossAlertRevergeSkin", "cheerupHandler", "btn_cheer", "skinCheckBoxes", "btn_check1", "btn_check2", "syaotowersetting_json", "buffcostid", "getNsp", "ShopJson", "lblGold", "k_12", "k_11", "k_1164", "k_1321", "boss_use_posion", "chm.BossAlertRveg", "BossAllPanelSkin", "chm.BossAllPnl", "_posionId", "BossFuChouAlertSkin", "lbl_shop", "k_1630", "EncounterAdd", "noUsePosion", "btnBuy1", "xiezhuClick", "img_xiezhu", "k_1628", "k_1629", "k_1627", "_fuchouId", "c_1522", "c_1523", "k_1619", "c_1521", "k_1626", "lbl_count_des", "k_1622", "k_1624", "k_1623", "k_1625", "k_1631", "hurtProp", "hurtJMProp", "lbl_buff_des", "_baseGrid", "chm.BossFuChouAlert", "BossonePanelSkin", "chm.BossOnePnl", "BossPanelSkin", "chm.BossPnl", "BossQiangDuoPanelSkin", "showGridTip", "lbl_fuchou", "lbl_xiezhu", "k_1620", "k_1621", "lbl_buy1", "k_294", "buyYsCount", "gotoRule", "updatList", "updateCountInfo", "selfRevengeCount", "bossrevengeCount", "bossrevengeInvitecount", "lbl_fuchou_num", "lbl__xiezhu_num", "lbl_yaoqing_num", "chm.BossQdInfoPanel", "BossRankPanelSkin", "chm.BossRankPnl", "BossTixingSkin", "tab_tixing", "tab_auto", "scroller1", "lbl_autoLimit", "k_234", "chm.BossTXPnl", "BossSummonPanelSkin", "BossZHPnl", "chm.BossZHPnl", "BossZhuanPanelSkin", "chm.BossZSPnl", "BossZhuanRewardSkin", "chm.BossZSRwdPnl", "HowToPlaySkin", "chm.HowToPlayPnl", "MysteryBossSkin", "chm.SMBossPnl", "ZSBossluckyPanelSkin", "chm.ZSBossLuckyPnl", "BossAllVO", "chm.BossAllVO", "chm.BossAutoCfgVo", "BossAutoVo", "chm.BossAutoVo", "BossLogVo", "chm.BossLogVo", "chm.BossOneVO", "chm.BossZHVO", "chm.BossZSRewardVO", "chm.BossZSVO", "otherSkillIdDic", "skillID", "chm.OtherPlyActVo", "chm.SMBossVO", "ChatMed", "ChatMod", "addEventListners", "com", "chatmsg", "schatmsg", "closeTalk", "sendCrsMsg", "chatMsg", "closeName", "clearTalk", "send509", "checkGMCmd", "checkSameMsg", "ChatData", "chatvo", "ChatVO", "channel", "sender", "HeroInfoVo", "sendhead", "sendheadframe", "sendervip", "chm.ChatMdu", "liaotian_title_png", "insertN", "wrd", "WChlRed", "fam", "sys", "SChlRed", "ChatV", "sendMsg", "btn_send", "sendMsgF", "hideGroup", "showRoleInfo", "5301", "wcgList", "5302", "fcgList", "5303", "scgList", "setClk", "btn_set", "lockClk", "btn_lock", "S_C_R_L", "rfSys", "openEmo", "faceBtn", "CLICK_IMG_HEADER", "showButton", "SELECT_TYPE_CHANGE", "cType", "CHAT_FRESH", "chatShow", "CHAT_CLEAR", "clearInput", "settingView", "boLock", "liaotian_lock_1_png", "liaotian_lock_2_png", "sType", "wArr", "wDataCg", "setRed", "lArr", "fDataCg", "sArr", "sDataCg", "txt_message", "resetS", "EmojiPan", "SELECT_EMOJI_EVENT", "sEmo", "k_250", "@", "prompt", "dlySendmsg", "#0", "isView", "k_244", "getVirtualElementAt", "_cArr", "lbl_msg", "cObj", "gCNotice", "Notice_channel", "ChatStatic", "NoticeVO", "noticeId", "replaces", "doWebN", "roleInfoId", "SHOW_PLAYER_INFO", "DataChange", "chm.ChatMed", "getNoticeDes", "notice_json", "getNoticeDM", "dm", "getModuleId", "clientnotice_json", "chm.ChatCMod", "_blackNames", "_boXifu", "_tArr", "_wArr", "_lArr", "_sArr", "nestMsg", "isAsk", "boXifu", "_sType", "stArr", "tArr", "sWArr", "sLArr", "sSArr", "checkBlack", "cTWorVo", "sendMainEuiChat", "World_channel", "Family_channel", "cTSysVo", "liaotian_xitong_png", "System_channel", "liaotian_gonggao_png", "CrossBossChat_channel", "CrossBossNoticeChat_channel", "checkChat", "<font color=\"#0172ff\">", "</font>\uff1a", "msgArr", "emojiArr", "\u300b", "\u300a", "WChlRVo", "headUrl", "crboss", "crossBossInviteInfo", "bossrevengeInviteInfo", "inviteId", "stageId", "limitLevel", "getBossConf", "k_1587", "k_1588", "king_json", "broderUrl", "Head_Url", "boMoon", "sendervipcard", "vipLvl", "senderlevel", "senderid", "boZhiZun", "privilegeCard", "SChlRVo", "GM_Command_Version", "k_242", "res_version", "checkSame", "select_type_change", "chat_fresh", "chat_clear", "CHAT_SHOW_FAMILY_RED", "chat_show_family_red", "chm.ChatMod", "max_chars", "max_speak_cd", "chanel_max_count", "single_msg_char", "msgtime_show_cd", "Cross_channel", "wangzhe_5_head_png", "wangzhe_4_head_png", "wangzhe_3_head_png", "wangzhe_1_head_png", "wangzhe_2_head_png", "@version", "chm.ChatStatic", "RoleView", "tar", "ChatEui", "WchlEui", "SchlEui", "ChatSettingView", "btn_world", "btn_family", "btn_system", "inxChge", "cPan", "k_325", "chm.ChatV", "imgType", "boRePlace", "s_c_r_layout", "chm.SChlRed", "chm.SChlRVo", "emojiTxt", "imgHead", "lastData", "EmojiText", "clkMsg", "fontSize", "rf", "eWidth", "eHeight", "imgMoon", "groupName", "imgVip", "guideman", "liaotian_zun_png", "liaotian_mon_png", "richText", "hasEventListener", "gotoBossPanel", "gotoFuChou", "c_1524", "gotoCrBoss", "11241", "responseBack", "CLICK_HANDLER", "click_handler", "click_img_header", "CLICK_PLAYER_INFO", "click_player_info", "show_player_info", "chm.WChlRed", "_msg", "emoji_reg", "chm.WChlRVo", "_moveDownX", "_moveDownY", "_distancPos", "_lastStageSize", "_lastSideDic", "main_icon_chat_png", "main_icon_chat1_png", "_redImg", "main_title_chat_png", "xifu", "onTouchBegin", "isMoveTap", "_touchStatus", "stageX", "stageY", "TOUCH_MOVE", "onTouchMove", "TOUCH_END", "onTouchEnd", "gotoChat", "setXY", "getPa", "chm.ChatBtn", "ChatSkin", "chm.ChatEui", "ChatSettingSkin", "box_set", "boxClk", "chm.ChatSettingView", "_localPoint", "CREATION_COMPLETE", "addStg", "EmojiPanelSkin", "emoji_size", "faceMaxNum", "emoji_", "faceGroup", "onTch", "clkStg", "rmStg", "select_emoji_event", "chm.EmojiPan", "emojiW", "emojiH", "_defaultW", "_defaultH", "setEmoDefaultWH", "gSize", "addEmoji", "rmEmo", "getEmoji", "$getLinesArr", "emojiY", "<font size = \"", "\">\u3000</font>", "$setWidth", "$setHeight", "pools", "chm.EmojiText", "SystemChannelSkin", "chm.SchlEui", "WorldChannelSkin", "lbl_warn", "*\u6e29\u99a8\u63d0\u793a:\u8bf7\u52ff\u8f7b\u4fe1\u5176\u4ed6\u6e20\u9053\u62c9\u4eba\u4fe1\u606f,\u907f\u514d\u4e0a\u5f53\u53d7\u9a97!", "k_251", "chm.WchlEui", "initData", "gameConfig", "titleConfig", "getTtEleByID", "getTitIcByID", "xiyouStrArr", "CHaoCfgMod", "chm.CHaoCfgMod", "dataChange", "tvo", "titleAddvo", "img_unget", "img_load", "isload", "CHaoItemRnd", "chm.CHaoItemRnd", "TitleModule", "ChengHaoVMed", "rsptitChg", "rspTitleFirstHave", "askForTitld", "horeIndex", "askForTitunld", "arrgeTitIfo", "chm.ChengHaoMdu", "allAddVo", "TitleAddVo", "sendActDress", "readTitleArr", "ChengHaoConf", "_crossConfDic", "titleArr", "TitleVo", "xiyStr", "k_931", "k_932", "k_265", "getTitleAddVo", "plat", "delayTm", "_titleDic", "sortTitil", "sortTitilDic", "loadArr", "currentTitles", "heroIndexs", "TitleloadVo", "heroOnlyID", "titles", "titleTime", "valueOf", "setGetTitles", "att", "sdef", "pdef", "chm.ChengHaoMod", "ChengHaoPanelSkin", "titleList", "ChengHaoPnl", "chm.ChengHaoPnl", "TitleView", "selectHeroIndex", "chenghaoPanel", "titleXqPanel", "TitleXqEui", "onItemHandler", "tabGroup", "toggleChangeHandler", "titleunLoad", "btn_down", "titleLoad", "btn_wear", "_titleContainer", "\u6682\u65e0\u79f0\u53f7", "setXqData", "setXqAllData", "lbl_wf", "lbl_ff", "lbl_gj", "lbl_getdesc", "k_1281", "k_1323", "k_903", "lbl_hpall", "lbl_wfall", "lbl_ffall", "lbl_gjall", "TITLE_UP_DOWN", "TITLE_UP_WEAR", "ChengHaoV", "chm.ChengHaoV", "TitleViewMediator", "title_title1_png", "chm.ChengHaoVMed", "_isEnter", "_autoSearch", "_tmOutId", "_lastTime", "_fontSrc", "shiwei_tips_1_png", "shiwei_tips_2_png", "shiwei_tips_3_png", "shiwei_tips_4_png", "shiwei_tips_5_png", "_fontPool", "_player", "MainCityBoss", "updateMonster", "killMonster", "doAOEAttack", "reqHurtRank", "reqHateAddTm", "clearEnterState", "onMyDead", "onHateAdd", "updateHate", "getHateInterval", "goBossImd", "mapClk", "leftCity", "reborn", "battleStateChange", "autoFightChange", "autoSearch", "removeEvts", "monsterVo", "MainCityMonster", "runToBossPoint", "targetX", "targetY", "checkIfBossInView", "inMyBattle", "_lastAOETime", "monsterMoveEnd", "delayChange", "remainHps", "decHps", "HURT_DIR", "BatRpPlayer", "clearMonsterVo", "playLastHitFont", "monsterMove", "toAutoFight", "battleStartTm", "breakFight", "clkMonster", "searchEnd", "reqPlayMove", "calDistance", "reqAttackMon", "reqHateValue", "playScreenFont", "MainCityBossMgr", "chm.MainCityBossMgr", "MainCityMed", "MaincityMod", "startBoss", "rspCkInCity", "rspEnterCity", "rspExitCity", "rspGetPlayers", "repPlayMove", "repMCUp", "repHrEqp", "repMBEnd", "repMBReborn", "repMCRc", "familyUp", "EnterCity", "reqEtCity1", "refreshTask", "findNpcHandler", "reconection", "enterMain", "exitMainCity", "mustExit", "atkTar", "initBatMy", "askRec", "in_city", "reqEtCity", "reqAttack", "room_id", "rankDic", "playerVoDic", "MainCityVo", "familyname", "hp_percenet", "reqExitCity", "reqInCityGetBonus", "reqGetPls", "target_x", "target_y", "reqPlayRec", "reqSfsp1", "reqSfsp", "reqSfsTake", "initBMPlayer", "removeListen", "clearSpr", "k_183", "k_161", "onMyMove", "initElement", "getPlayerHp", "rmPlayer", "checkTask", "findNpc", "chm.MainCityMdu", "MainCityMgr", "addListen", "startSpr", "alert", "TreAlertEui", "bnAlert", "_bNAlert", "BnAlertEui", "bigGnifeAlert", "_bigGnifeAlert", "gnifeAlert", "_gnifeAlert", "clearBoss", "_sprMgr", "MainCitySMgr", "_bossContrl", "removeRspEvts", "chm.MainCityMed", "_findNpcId", "statueDic", "playerDic", "npcRoleDic", "_safeType", "_ckOtFrame", "_safeEftPols", "_effects", "statues", "chengzhu", "statue_castellan.png", "shacheng_hegemony_png", "fashi", "statue_fashi_0.png", "LastMaster_png", "zhanshi", "statue_zhanshi_0.png", "LastRanker_png", "daoshi", "statue_daoshi_0.png", "LastTaoist_png", "tianxiadiyi", "peerless_png", "MainCityLoop", "eqpUp", "playerMove", "upNpcSta", "myReborn", "checkSafe", "upPlaySta", "recMy", "endMCBat", "sohMbBtn", "updateOtherHp", "updateMyHate", "hideTargetPlayer", "clickTarget", "ckInSafe", "k_468", "k_469", "ch_NpcEffShow", "crtOtPlByMy", "crtEleByMy", "crtEftByMy", "flMapPlaInfo", "setHpPecent", "stopFSta", "taskVo", "TaskMod", "getNPCInfoByNPCID", "Sound_", "playOtherSound2", "NpcID", "TaskID", "SHOW_NPC_DIALOGE", "|", "clearNpcSeleff", "clearElement", "getNpcByTaskId", "mapID", "setState", "targetNode", "nodeX", "nodeY", "onClickNpc", "mobaiBtn", "mobaiTip", "clearNpc", "clearPlayer", "clearEffect", "createStatus", "hp_percent", "getSfArEft", "sfEftPos", "getSafeEffect", "safe_effect", "mapAnimationLayer", "getOtPlaByMy", "upFState", "getOtPlay", "getNpcByMy", "npcDataDic", "getNpc", "mapNodeX", "mapNodeY", "nameurl", "setNpcModule", "getNpcById", "Npc", "dir", "_{0}_{1}", "Statue", "scTip", "SCZBMod", "main_hegemony_icon_png", "mbTap", "cityId", "setAsTarget", "chm.MainCityMgr", "_boxCd", "_boxCdShow", "BoxCDSEui", "_boxPosId", "_findBpId", "MainCitySprFesLoop", "createSpingBox", "onBoxDis", "rspSpr", "startMonitor", "stopMonitor", "getSboxByMy", "getBoxInfoByPosId", "posId", "SprFBoxEui", "inPk", "posIds", "k_1328", "k_1329", "searBRoad", "spr_fes_start_pros", "getMyFamilyId", "k_471", "chm.MainCitySMgr", "initTouch", "_pkStart", "pk_kill_png", "onTouchTap", "SECEND_KEY", "CityPlayer_Fight", "ftEft", "refreshPKBtn", "loopFight", "fighting_effect", "_poos", "getNewCityPlayer", "k_470", "CityPlayer", "chm.CityPlayer", "_avatarImg", "_nameTxt", "k_1325", "_titleImg", "_clubTxt", "k_1326", "onLoadComp", "loadAvaComp", "resetLocation", "city_statue/", "coprsName", "\u226e", "\u226f", "k_1327", "chm.Statue", "BainianAlertSkin", "bainian_mp3", "startPlay", "clk", "setAlpha0", "word_", "chm.BnAlertEui", "hNums", "_selectType", "_myNum", "bigGnifeAlertSkin", "k_493", "k_492", "updateNumValue", "showBuy", "_grid", "grp_select", "grp_buy", "setItemId", "group_btn", "k_526", "getHateAddBuffObj", "k_529", "hateDrugTime", "hateDrugAdd", "k_525", "\u7ea2\u540d\u503c\u5df2\u4e3a0", "chm.bigGnifeAlert", "gnifeAlertSkin", "group_des0", "group_des1", "_myHonor", "k_527", "k_528", "lbl_des0", "k_530", "k_865", "chm.gnifeAlert", "myHerosHp", "mapStatus", "setEffectPoint", "MainCity", "isPingbi", "getNpcData", "getTarPos", "chm.MaincityMod", "_startTime", "guildBoxDic", "svrBoxDic", "getPosDic", "_posDic", "boxpositonsetting_json", "boxXYArr", "repSFSPros", "rspBoxDisappear", "monitorOpenState", "autoDisappear", "take", "endTm", "produceTime", "getNextDropLeftTmInfo", "flushTime", "maxTurns", "getSBoxLft", "svrBStaUp", "chm.MainSBoxMod", "FesBoxInfo", "chm.FesBoxInfo", "TreatAlertSkin", "k_519", "chm.TreAlertEui", "_allShowTm", "BoxDropCDShowSkin", "clearTmOut", "leftTm", "_desc", "k_475", "idx", "k_476", "k_473", "showCD", "hideCD", "BoxDropCD", "tmHandler", "lbl_cd", "chm.BoxCDSEui", "SprFesBoxSkin", "lbl_grp", "ckTakEftSw", "guidbox", "boxShowType", "lbl_fa", "checkEffShow", "cd_grp", "onBoxCD", "stopBoxEff", "SprFesBoxCD", "setCDImg", "playBoxEff", "_boxEff", "citybox_effect", "boxOnAni", "boxDownAni", "chm.SprFBoxEui", "SprFesBoxProgSkin", "stopLoadingEff", "_allTm", "MainCityBoxProgLoop", "playLoadEft", "_loadingEff", "boxloading_eff", "chm.SprFProgEui", "chm.MainCityVo", "CrBossFightViewMediator", "_pkDrops", "_pkDropsTmId", "_rebornShape", "_fightView", "_crBossReborn", "CrBossReborn", "_crBossRecord", "CrBossRecordView", "_crBossResult", "CrBossResultView", "csBarProg", "CrBossBar", "csBossChanel", "CrBossChatChannelEui", "crachpnl", "CrBossAchieveEui", "lababuyppnl", "CrBossBuyPanelEui", "selfDead", "selfFillEqu", "selfReborn", "pkDrops", "monDropsFly", "openRecord", "img_xiang", "closeRecord", "hideSubPanel", "hideResult", "showBarPanel", "stopCsBarProg", "addEvent", "removeEvent", "setReBornTm", "attCount", "buyTiLi", "setDeathEquip", "closeReborn", "reqLofInfos", "setWinGetTime", "crboss_win_reward", "k_367", "winTimeHandler", "removeWinPanelAndLoop", "c_4301", "pkDropsFly", "mapItemLayer", "addItemEff", "grp_thunder", "rmvItemEff", "removeDropItem", "rmvItem", "k_1595", "k_1596", "mapItemDic", "removeMonItem", "chm.CrBossFightViewMediator", "enterCrBoss", "exitCrBoss", "_fightViewMediator", "exitScene", "reqBossInfo", "c_4401", "CrBossViewMediator", "chm.CrBossModule", "csView", "CrBossView", "crossboss_title_png", "CLICK_HOTSPOT", "onFight", "addAttCount", "btn_add", "closeUI", "onOpen", "k_1564", "buyTL", "onFight0", "onFight1", "onFight2", "chm.CrBossViewMediator", "_allArr", "_shieldcd", "_inviteCd", "_tlBuyCnt", "_tlTmOutId", "ownerCount", "assistCount", "attCountBuyCount", "addAttCountTime", "_tuiChuState", "onInvite", "sallArr", "n_32481", "onCenterToken", "n_4502", "onSelfEnter", "_bossDic", "crossboss_json", "getCrossBossIds", "getShieldCD", "crossbosssetting_json", "shieldcd", "getInviteCdCD", "inviteCd", "getSetting", "getHpCnt", "getScenesmonster", "hpconut", "challengeph", "_scenesmonDic", "scenesmonster_json", "getTlCost", "_tlCostArr", "crossbossreward_json", "buyAttCount", "buyAttCountCost", "getTlBuyCnt", "buyAttCountNum", "getReviveCost", "_reviveCost", "reviveCost", "getDecTime", "crossbossphysicaldec_json", "decNum", "c_4302", "n_32480", "11242", "staminaAddTime", "n_11300", "n_32483", "k_1565", "k_1566", "k_1567", "k_1657", "k_1568", "c_4300", "n_32482", "11244", "checkBetRed", "getBetState", "getHours", "getDieBuffTime", "dieBuffTime", "getDieBuffHurt", "dieBuffHurt", "getRebornInfo", "tuiChuState", "n_32484", "11256", "getBossAchieveinfo", "killreward_json", "chm.CrBossModel", "chm.ICrossModel", "egret.EventDispatcher", "isEnterCrboss", "_lastResumeTm", "_rangeDic", "_checkReqCnt", "_rangeItemArr", "_waitFlyMonItems", "_dropEffDic", "_dropEffPool", "_logInfoTm", "_reqCnt", "_centerSocket", "_centerToken", "ip", "connectCenterSocket", "n_4527", "bloodDatas", "n_4528", "values", "\u81ea\u8eab\u6263\u8840\uff1a", "n_4529", "monsterId", "32", "33", "34", "transPlayInfo", "onGameResume", "c_4335", "c_4517", "n_4507", "n_4504", "n_4512", "n_4516", "n_4515", "n_4513", "revivalTime", "n_4531", "equipIds", "physical", "n_4514", "c_4333", "onEnd", "n_4506", "n_4510", "n_4520", "clearMonItem", "rmvRangeItem", "setDropDic", "c_4521", "n_4523", "n_4522", "clearDropEff", "crossboss_pro_", "n_4525", "_logInfos", "c_4524", "getLogInfos", "reqReborn", "c_4331", "reqBuffAddition", "reqLastFamilyRank", "closeCenterSocket", "clearEndTmOut", "rspLeft", "n_4526", "reqLogin", "c_4330", "chm.CrBossPlayerModel", "bitmapClipDataList", "chm.BitmapClipDataPool", "heroInfoDic", "hpChange", "transPlayerInfo", "transMonsterInfo", "isCanAttack", "chm.PvpsInsRoleVo", "compleArray", "drawCustomeLines", "\u5468\u65e5", "\u5468\u4e00", "\u5468\u4e8c", "\u5468\u4e09", "\u5468\u56db", "\u5468\u4e94", "\u5468\u516d", "{0}{1}:{2}-{3}:{4}", "getDay", "getMinutes", "CrBossUtil", "chm.CrBossUtil", "ncltime", "CrBossAchieveSkin", "numimg", "kfcjnumber_{0}_png", "grrop_num", "showPanl", "delayClose", "img_des", "img_numdi", "showIcon", "chm.CrBossAchieveEui", "timeNum", "CrBossAlertSkin", "_alertViews", "okClick", "k_1656", "timeInval", "k_125", "c_4334", "CrBossAlertView", "chm.CrBossAlertView", "_barW", "CrBossBarSkin", "_numDown", "_mint", "quitTime", "quit_eff", "grp_eff", "showBarPro", "_avage", "playLoadingEff", "startPro", "_barTime", "img_num", "fight_num1_", "chm.CrBossBar", "CrBossBuyPanelSkin", "perPrice", "chatSpeakerCost", "936", "groupItem", "hidePanl", "buy", "askForPay", "lblTotal", "c_4303", "chm.CrBossBuyPanelEui", "CrBossChatChannelSkin", "initTab", "CrBossChatRnd", "btn_all", "btn_near", "updateItmLab", "clearlist", "showbuypanl", "showbuyLabaPnl", "img_laba", "grop_buttom", "grop_nochat", "grop_chat", "allList", "upListPostion", "sendmsg", "lab_num", "chm.CrBossChatChannelEui", "QmpvpItemRenderSkin", "CrBossDieImg", "chm.CrBossDieImg", "_lvlType", "bossHeadShow", "_selectBoss", "_bossHpImgs", "_shieldTmId", "_shieldLeftTm", "_inviteTm", "CrBossFightViewSkin", "onRmvFromStage", "boss_hp_grp", "bossinfo_grp", "shield_grp", "btn_grp", "boss_head_grp", "attack_able_grp", "actListChange", "setSelectBoss", "actTarget", "showBossHead", "onBossOwner", "onHpChange", "checkBossShield", "onMonState", "fillHeadInfo", "showThunderQiBao", "showTiLi", "showDieImage", "bossQh", "img_qh", "actBoss", "btn_boss", "actGuishu", "btn_guishu", "grp_myGuishu", "invite", "img_yao", "tiLiClick", "btn_tili_add", "goldClick", "btn_gold_add", "thunderClick", "img_boss_head", "img_owner_head", "grpTiLiClick", "grp_tili", "showSetting", "grp_set", "lbl_num_gold", "lbl_num_guishu", "lbl_num_xiezhu", "lbl_num_tili", "right_other_grp", "attacked_grp", "grouphead", "grp_twoBtn", "grp_tt_tili", "k_1604", "checkBtnShow", "crossboss_fightbtn_1_png", "k_1589", "crossboss_fightbtn_2_png", "k_1590", "k_1591", "k_1593", "k_1594", "k_1592", "k_1583", "k_1585", "getBagMax", "grp_bag", "lbl_maxDes", "k_1572", "k_1571", "attacking", "grp_fighting", "attacked_0", "attacked_1", "attacked_2", "attacked_", "showBossHpBar", "boss_head_", "img_selected", "onBossHpShow", "img_hight", "ownerer_grp", "img_owner_hp", "lbl_owner_name", "img_owner_svr", "crossboss_tag_3_png", " s.", "crossboss_tag_1_png", "crossboss_tag_4_png", "img_boss_hp1", "img_boss_hp0", "lbl_boss_hpcount", "X", "lbl_boss_hp", "shieldCD", "lbl_hd", "img_hd", "img_high", "lbl_boss_name", "getMonNaLv", "attack_able_", "\u9080\u8bf7CD\u4e2d,", "\u79d2\u540e\u53ef\u7ee7\u7eed\u9080\u8bf7", "c_4332", "setPanel", "CrBossSettingView", "showPanelByTL", "chm.CrBossFightView", "_inId", "CrBossHeadSkin", "onClk", "onStateChange", "setHpBar", "S.", "loopSecond", "fightEff", "crossboss_eff_headicon", "doSecond", "CrBossHead", "chm.CrBossHead", "_endTm", "_intervalId", "CrBossRebornSkin", "okHand", "btn_once", "buffHand", "btn_buff", "reviveBuffCost", "k_1599", "lbl_buff_gold", "lbl_once_gold", "setDeathInfo", "k_1600", "lbl_luck_des", "k_1601", "k_1602", "k_1655", "k_1597", "lbl_lose_des", "k_1573", "chm.CrBossReborn", "CrBossRecordViewSkin", "CrBossRecordRender", "chm.CrBossRecordView", "owerTypeImgSource", "rewardTypeImgSource", "crossboss_reward_title_1_png", "crossboss_reward_title_2_png", "crossboss_reward_title_3_png", "CrBossResultViewSkin", "owerName", "imgOwerType", "owerType", "img_rwd", "rewardType", "k_1574", "k_1575", "k_1518", "lbl_rewardType", "owerHead", "rankItems", "setWinData", "lbl_rewardInfo", "k_1576", "k_1577", "k_1579", "k_1578", "clearRewardArr", "rewardGroup", "_rewardGridArr", "main_head_{0}_{1}_png", "chm.CrBossResultView", "CrBossRoleRenSkin", "lbl_surName", "CrBossRoleRen", "chm.CrBossRoleRen", "CrBossRoleRightRenSkin", "CrBossRoleRightRen", "chm.CrBossRoleRightRen", "CrBossSettingSkin", "attackClick", "box_attack", "pbAllClick", "box_pb_all", "pbMyFamPlayer", "box_pb_myFam", "pbMySvrPlayer", "box_pb_mySvr", "chm.CrBossSettingView", "_posArr", "CrBossViewSkin", "_group0InitY", "group_0", "_group1InitX", "group_1", "_group2InitX", "group_2", "onClickHotspot", "lbl_num_0", "lbl_num_1", "lbl_num_2", "lbl_name_0", "lbl_name_1", "lbl_name_2", "listRwd_0", "listRwd_1", "listRwd_2", "_rewards", "stageName", "rewardsShow", "hotspot_0", "hotspot_1", "hotspot_2", "hitTestPoint", "img_boos_0", "img_boos_1", "img_boos_2", "img_notOpen_", "showRewards", "setShowReward", "tween", "playPanelEff", "cubicIn", "removePanelEff", "group_btnEff_0", "group_btnEff_1", "group_btnEff_2", "initBtnEff", "_btnEffArr", "crossboss_eff_enter", "eff_0", "eff_1", "eff_2", "initPanelEff", "_panelEffArr", "crossboss_eff_fenge", "crossboss_eff_collsion", "chm.CrBossView", "grop_msg", "refnearData", "reSysData", "kufuliaot_fj_png", "<font color=#00ff00>", "kufuliaot_xt_png", "chm.CrBossChatRnd", "crossbossrecord_json", "bosstype", "playeId", "playername", "crossboss_record_tag_", "imgResult", "chm.CrBossRecordRender", "_hsOpTm", "maxShowRank", "actState", "_mypoint", "_mypointReach", "getAwardState", "getPointAwardConfByID", "mypoint", "awardStateDic", "buyJBCount", "buyRefreshCount", "reqHS", "getArrestsettingConf", "escortswtime", "k_974", "reqviewInfo", "reqIntegralReward", "gradeid", "refreshBC", "reqJB", "familyid", "clearQJCd", "goImmediately", "reqCarEndShow", "lastCarInfo", "reqMemberRank", "monitorPointChange", "getPointAwardConfArr", "_pointReqIntID", "reqMyPoint", "getPublicskill", "rspEscortCarInfo", "rspFamilyLogInfo", "rspFamilyRankInfo", "rspStateInfo", "rspOneCarInfo", "rspPlayerLogInfo", "rspPlayerRankInfo", "rspSnatchCarInfo", "rspSnatchPersonalInfo", "rspSnatchSpikeShow", "rspBattleResult", "rspEscortOperationRet", "rspEscortEndShow", "rspPointReach", "arrestcount", "_arrestcount", "CrsSvrMod", "ARREST_COUNT_CHANGE", "escortcount", "_escortcount", "ESCORT_COUNT_CHANGE", "RSP_MYPOINT_UPDATE", "myHSCarIdxs", "carinfo", "gradeinfo", "setAardStateDic", "personalpoints", "HS_STATE_INFO", "hsCarinfos", "ESCORT_CAR_INFO", "familyLoginfo", "HS_NEW_LOG", "FAMILY_RNAK_INFO", "playerlogInfo", "PLAYER_LOG_INFO", "familypoint", "familyRankInfo", "familyinfo", "familyRankDic", "rankHeroInfo", "playerRankInfo", "playerinfo", "playerRankDic", "playerid", "PLAYER_RNAK_INFO", "escortstate", "arresttime", "moveCarInfoDic", "HS_MOVE_CAR_INFOS", "ONECARINFO_CHANGE", "RSP_RECEIVE_GRADE", "SNATCH_PERSONAL_INFO", "arrestbuycount", "snatchcdbuy", "snatchNextTm", "snatchcdtime", "refreshcarcount", "refreshcarbuy", "snatchDieInfos", "SNATCH_SPIKE_SHOW", "battleResult", "delayRspBattleResult", "showBattleResult", "ESCORT_OPERATION_RET", "ESCORT_END_SHOW", "gradeinfos", "checkCarIsSelfFamily", "getCargotoAward", "_cargotoConfArr", "arrestcargoto_json", "minpoints", "maxpoints", "CROSSCOINS:0", "getCarBreakAward", "_carlevelAwardConf", "arrestcarlevel_json", "getCarLevelConf", "_carlevelConf", "getFamilylevelConf", "_familylevelConfDic", "arrestfamilylevel_json", "_lastFamilylevelConf", "getFamilyrankConfArr", "_familyrankConfArr", "initFamilyrankConf", "getFamilyrankConfByRank", "_familyrankConfDic", "arrestfamilyrank_json", "minrank", "maxrank", "crosscoin", "getPlayerrankConfArr", "_playerrankConfArr", "initPlayerrankConf", "getPlayerrankConfByRank", "_playerrankConfDic", "arrestplayerrank_json", "_arrestsettingConf", "arrestsetting_json", "_pointAwardConfs", "initPointAwardConf", "_pointAwardConfDic", "pointgrade_json", "getRefreshcarbuyCost", "_refreshcarbuyConf", "refreshcarbuy_json", "_carbuyLastCost", "getArrestbuyCost", "_arrestbuyConf", "arrestbuy_json", "_arrestbuyLastCost", "getClearCDCost", "snatchcdgap", "snatchcdgold", "getSnatchcdbuyConf", "_snatchcdbuyConf", "snatchcdbuy_json", "getHitConf", "_hitConf", "arresthit_json", "getCarTmStrByCarIdx", "_sendtimes", "sendtimeone", "sendtimetwo", "sendtimethr", "getNextSendTm", "getCarSendInfos", "_carSendInfos", "getTmByHMS", "sendTm", "getFamilyCarState", "checkHSCntRed", "checkMoveCarRed", "checkPointRewardRed", "getMyHSState", "CrossHSModel", "chm.CrossHSModel", "CrossHSModule", "CrsHSVMed", "onHSBattleSettle", "onHSBattleEnd", "k_216", "\u73a9\u5bb6", "drops", "rspLeftByClient", "chm.CrsHSMdu", "CrossHSViewMediator", "crossHSView", "CrossHSView", "crossHSRadio", "CrossHSRadio", "hsView", "CrossHSSHView", "carsMoveView", "CrossHSMoveView", "familyRankView", "CrossHSFamilyRankView", "playerRankView", "CrossHSPlayerRankView", "recordView", "CrossHSRecordView", "buyTokenTip", "CrossHSBuyTokenTip", "qjTip", "CrossHSQJTip", "vsView", "CrossHSVsView", "resultView", "CrossHSResultView", "familyCarEndTip", "CrossHSCarEndTip", "fpRankView", "CrossHSFPRankView", "qiangDuoView", "CrossQiangDuoPanel", "carpersonrank_bg_png", "husong_bg_jpg", "yabiao_title_png", "memberrank_title_png", "tabchange", "tab_rob", "tab_escort", "tab_family_rank", "tab_player_rank", "husong_bg_png", "_closeCDId", "moveViewFirstEnter", "checkRadioRed", "img_tip0", "img_tip1", "onSleep", "hideQJTip", "hideBuyTokenTip", "closeLogPanel", "hideCarEndTip", "hideQdPanel", "hideFPRank", "onClkGrab", "btn_grab", "onClkBuyToken", "showLogPanel", "btn_record", "showQDpanel", "group_rob", "onClkHS0", "btn_brown", "family_car_0", "onClkHS1", "family_car_1", "onClkHS2", "family_car_2", "onSelectFCar0", "grp_c", "onSelectFCar1", "onSelectFCar2", "onClkOrder", "btn_order", "onClkRefreshCnt", "btn_refresh", "CLK_MOVE_CAR", "onClkMoveCar", "HS_VS_COLLISION", "vsShowEnd", "CLK_AWARD_BOX", "onClkAwardItem", "hideQDpanel", "showFPRank", "lbl_btn_pra", "onMoveViewInfo", "updateMyPoint", "onOneCarInfo", "onSnatchDie", "onEscortOp", "onPersonalInfo", "onGetPointAward", "showCarEndTip", "hasNewLog", "escortCountChange", "arrestCountChange", "\u9556\u8f66\u8fd8\u672a\u53d1\u8f66\uff0c\u8bf7\u7a0d\u7b49", "setQDlistData", "showQdPanel", "_curView", "onExit", "carpersonrank_bg_jpg", "reqLog", "onEnter", "showQJTip", "carInfo", "\u81ea\u5df1\u516c\u4f1a\u7684\u9556\u8f66", "destroycount", "hitcount", "k_967", "k_992", "showBuyTokenTip", "onClkHS", "onSelectFCar", "selectCar", "k_1012", "k_1013", "tokenmaxcount", "k_260", "k_990", "refreshbuycount", "hideLogPanel", "onViewInfo", "family_car_", "carIdx", "\u6362\u4e00\u6279(", "\u6b21)", "_gridVos", "CROSSSERVER_ITEM_CLICK", "crossserver_item_click", "chm.CrsHSVMed", "FAMILY_LOG_INFO", "RSP_MYPOINT_CHANGE", "QIANGDUO_LIST_UPDATE", "chm.CrossHSEventType", "CrossLogRenderSkin", "areaid", "k_977", "valueone", "k_978", "k_979", "valuethr", "valuetwo", "k_980", "myname", "k_981", "CrossFamilyLogRender", "chm.CrossFamilyLogRender", "CrossHSAwardBoxSkin", "lbl_point", "checkBoxEff", "boxShake", "_boxTweens", "_timeOutIds", "dailybox_effect", "CrossHSAwardBox", "chm.CrossHSAwardBox", "CrossHSCarEndRanderSkin", "k_1000", "lbl_log", "CrossHSCarEndRander", "chm.CrossHSCarEndRander", "CrossHSCarPlayerRenderSkin", "EscortPlayerInfo", "k_851", "guardid", "CrossHSCarPlayerRender", "chm.CrossHSCarPlayerRender", "CrossHSCarRenderSkin", "carlevel", "k_968", "k_1008", "k_1009", "lbl_each", "k_1007", "nownum", "maxnum", "k_966", "playCarEff", "_carEff", "car_eff_", "_fireEff", "carfire_", "CrossHSCarRender", "chm.CrossHSCarRender", "_rankUrls", "rankicon_1_png", "rankicon_2_png", "rankicon_3_png", "CrossHSFamilyItemRenderSkin", "lbl_available", "rank_grp", "familyRank", "lbl_svr_name", "svrName", "cnt", "CROSSCOINS:", "img_grid", "CrossHSFamilyItemRender", "chm.CrossHSFamilyItemRender", "CrossHSFamilyItemVo", "chm.CrossHSFamilyItemVo", "CrossHSFPRenderSkin", "lbl_pos", "CrossHSFPRender", "chm.CrossHSFPRender", "CrossHSPlayerItemRenderSkin", "lbl_svr_score", "CrossHSPlayerItemRender", "chm.CrossHSPlayerItemRender", "endtime", "k_997", "k_982", "k_983", "k_984", "k_985", "k_986", "k_987", "CrossPlayerLogRender", "chm.CrossPlayerLogRender", "CrossQiangduoRenderSkin", "qufu_name", "car_lvl", "\u9556\u8f66\u7b49\u7ea7\uff1a", "husong_count", "CrossQiangduoRender", "chm.CrossQiangduoRender", "CrossHSBuyTokenTipSkin", "grp_choose", "updateCost", "HIJACKINGTOKEN:0", "_jblItem", "k_1001", "k_996", "chm.CrossHSBuyTokenTip", "CrossHSCarEndTipSkin", "\u7ea7\u9556\u8f66", "caricon_", "k_999", "snatchcount", "lesspoint", "GUILDXPHONOR:", "_familyItem", "group_item_0", "PERSONALHONOR:", "crosscurrency", "_playerItem", "group_item_1", "chm.CrossHSCarEndTip", "CrossHSCarInfoViewSkin", "CrossHSCarInfoView", "chm.CrossHSCarInfoView", "CrossHSDieShowViewSkin", "CrossHSDieShowView", "chm.CrossHSDieShowView", "_carState2Url", "_lvlColorDic", "CrossHSFamilyCarSkin", "btn_gray", "btn_green", "k_969", "cartag_3_png", "k_970", "cartag_4_png", "k_971", "cartag_2_png", "k_972", "cartag_5_png", "k_973", "cartag_1_png", "carbg_", "lbl_tmti", "k_1005", "k_1006", "grp_streamer", "streamerEsay", "_esayTmOutId", "img_streamer", "CrossHSFamilyCar", "chm.CrossHSFamilyCar", "CrossHSFamilyRankViewSkin", "k_1017", "updateFamilyInfo", "updateListInfo", "arresttitle", ":0", "lbl_family_score", "lbl_wsb", "k_259", "grop_name", "formatItemInfo", "chm.CrossHSFamilyRankView", "chm.ICrossHSView", "CrossHSFPRankViewSkin", "rspMemberRank", "detailInfo", "memberInfo", "chm.CrossHSFPRankView", "_boxJG", "CrossHSMoveViewSkin", "car_grp", "bg_group", "img_bg_far_0", "img_bg_far_1", "kuafucar_bg2_png", "img_bg_near_0", "img_bg_near_1", "kuafucar_bg1_png", "reqMoveViewInfo", "_carCtrlDic", "updateBoxs", "setBoxListScrollH", "_carCtrlArr", "onClkCar", "crosshsloop", "moveUpdate", "my_point", "k_995", "qjCountdown", "lbl_order", "lbl_refresh", "_awardItemArr", "grp_award", "box_grp", "moveImg", "prisoner_bg1_png", "prisoner_bg2_jpg", "hs_qjcd", "setNextSendText", "k_998", "_qjLoopTime", "qjTimeHandler", "k_1014", "k_1015", "k_1010", "sendTmStr", "k_1011", "nextSendTmHandler", "k_1016", "_startTmOutId", "chm.CrossHSMoveView", "CrossHSPlayerRankViewSkin", "updatePlayerInfo", "fillHerofigure", "fashionWingId", "k_714", "k_715", "player_grp", "none_player", "chm.CrossHSPlayerRankView", "CrossHSQJTipSkin", "k_1004", "lbl_family", "k_1002", "k_1003", "vicpoints", "_winOneItem", "failpoints", "_failItem", "_winItemDic", "group_item_2", "chm.CrossHSQJTip", "CrossHSRadioSkin", "chm.CrossHSRadio", "CrossHSRecordViewSkin", "btn_player", "setScrollV", "chm.CrossHSRecordView", "CrossHSResultViewSkin", "chm.CrossHSResultView", "_curSelectIdx", "CrossHSSHViewSkin", "setHSCntShow", "player_list", "lbl_my_hs_cnt", "k_975", "img_award_des", "cangetbonus_name_png", "getbonus_name_png", "_pointItem", "grp_f_rwd", "_kfbItem", "grp_p_rwd", "guardcount", "getGuardCount", "maxplayer", "img_num_1", "img_num_0", "pnum_", "img_num_t_1", "img_num_t_0", "chm.CrossHSSHView", "CrossHSViewSkin", "chm.CrossHSView", "CrossHSVsViewSkin", "_enemyIdx", "selfGrp", "enemyGrp", "setView", "setCardInfo", "_enemyInfo", "lbl_name0", "lbl_svr0", "img_head0", "getMyHeroHead", "hp_bar0", "myinitnowhp", "mymaxhp", "lbl_name1", "lbl_svr1", "guard_head_png", "hp_bar1", "targetnowhp", "targetmaxhp", "high_ladder_{1}_{0}_png", "killPre", "jinru", "playCollisionEff", "showHpLoss", "mynowhp", "_collisionsEff", "openFrom", "collision_eff", "openRotate", "openFlyout", "chm.CrossHSVsView", "CrossQiangDuoPanelSkin", "cars", "car_level", "myIndex", "group_self", "lbl_liu", "chm.CrossQiangDuoPanel", "donList", "dType", "listRank", "getSettingData", "getDonationData", "honorScoreSource_json", "CrossDonVo", "honorNum", "honorScore", "getSelfHonor", "rspScrossScStatus", "rspFamilyRank", "rspPlayerRank", "donSuccess", "obRed", "isShowDonPanel", "getStatus", "familyScore", "familyRankData", "playerRankData", "changeScore", "\u4e3a\u516c\u4f1a\u589e\u52a0{0}\u70b9\u8363\u8a89", "reqFamilyRank", "reqScrossScStatus", "reqPlayerRank", "donationItem", "CrossRankVo", "getfamilyRwd", "honourNum", "familyInfo", "honorfamilyrank_json", "boxbonus", "CrossHonVo", "guanzhi", "isShowDonationRed", "CrossRankModel", "chm.CrossRankModel", "CrossServerModule", "_controller", "CrossRankViewMediator", "loginIng", "showCrossPanel", "chm.CrossRankModule", "game", "CrossRankView", "honourPanel", "CrossHonourView", "donatePanel", "CrossDonateView", "lbl_self", "k_1025", "CrossRankRen", "CrossHonRen", "CrossDonRen", "clickDes", "hideDonPanel", "hideSelfRankPanel", "updateFam", "showSelfRankPanel", "showDonPanel", "getHonorByDonation", "upMyGH", "updateDon", "_number", "fiveReq", "updateFamData", "updateFamList", "corssfamrank", "fam_name", "fam_lvl", "\u8ddd\u79bb\u7edf\u8ba1\u7ed3\u675f:", "\u8ddd\u79bb\u4e0b\u6b21\u5f00\u542f:", "\u9053\u5177\u6570\u91cf\u4e0d\u8db3", "\u7edf\u8ba1\u671f\u5916\u4e0d\u80fd\u6350\u8d60", "chm.CrossRankViewMediator", "CrossDonateSkin", "setList", "chm.CrossDonateView", "CrossHonourSkin", "lbl_myValue", "chm.CrossHonourView", "CrossRankSkin", "chm.CrossRankView", "CrossDonRenSkin", "\u6350\u8d60\u4e00\u4e2a", "lbl_rwd", "\u516c\u4f1a\u8363\u8a89+", "k_1026", "chm.CrossDonRen", "CrossHonRenSkin", "getOfferId", "chm.CrossHonRen", "CrossRankRenSkin", "chm.CrossRankRen", "chm.CrossDonVo", "chm.CrossHonVo", "chm.CrossRankVo", "CrsSpMed", "askCorssShop", "askShopRequest", "chm.CrsSpMdu", "CrossShopView", "CrsSpPnl", "kuafushop_title_png", "lbl_getway", "k_117", "CROSSSERVER_SHOP_UPDATEDATA", "CROSSSERVER_SHOP_KUAFUBI", "updateviewData", "CROSSSERVER_SHOP_CLICK", "clickList", "getWayClick", "CROSSSERVER_SHOP_LIST", "getShopData", "list_csshop", "corssShop", "crosscoins", "crossShop", "askShopBuy", "crossserver_shop_click", "crossserver_shop_kuafubi", "crossserver_shop_updatedata", "CROSSSERVER_SHOP_UPDATERED", "crossserver_shop_updatered", "crossserver_shop_list", "chm.CrsSpMed", "CrsSvrVMed", "onMainBtnCom", "onRealTm", "_onRealTm", "_onMainBtn", "chm.CrsSvrMdu", "CrossServerViewMediator", "clikItem", "showCrossShop", "btn_shop", "checkShopRed", "kuafu_bg01_jpg", "imgUrl", "condition", "award", "pointRed", "checkPointRed", "btn_enter_", "KFTTMod", "CrSandyModel", "getLvlLimitDesc", "_waitEnterCrossId", "k_1580", "k_1581", "askCrossSvrInfo", "rspStatus", "openCrossModule", "\u8de8\u670d\u6c99\u57ce\u672a\u5f00\u542f", "rspCrossInfo", "getOpenDes", "_openDes", "k_1018", "k_1019", "_imgUrl", "kuafu_name_tianti_png", "kuafu_icon_tianti_png", "kuafu_name_yabiao_png", "yabiao_button_eff", "kuafu_name_shacheng_png", "kuafu_icon_shacheng_png", "kfsc_btn_eff", "kuafu_name_rongyu_png", "dizuo_png", "flag_move", "kuafu_name_BOSS_png", "crossboss_show", "7800", "chm.CrsSvrVMed", "Cost", "CrsSpVo", "realCost", "Vip", "vipcost", "zhekou", "vipdiscount", "playerlevel", "Name", "permit", "crossshop_json", "rspShopInfo", "rspBuyRet", "rspplydatachg", "chm.CrsSvrMod", "CrossShopViewSkin", "CrsSpRnd", "chm.CrsSpPnl", "crtCmplte", "CorssShopRenderSkin", "lbl_counts", "lblVip", "k_1021", "lbldiscount", "imgCostIcon0", "btnClkHdler", "chm.CrsSpRnd", "CrossServerViewSkin", "btn_enter_2", "btn_enter_4", "chm.CrsSvrV", "CSPlaysetRenderSkin", "info_grp", "none_grp", "img_biaoqian", "eff_icon", "eff_red", "onEnterHandler", "enter_btn", "rule_grp", "CSPlaysetRender", "chm.CSPlaysetRender", "chm.CrsSpVo", "KFTTMed", "onMatchClk", "askMatching", "askTTFight", "k_423", "k_424", "k_422", "askBuyCnt", "askDWAward", "askDayAward", "onAutoMatchClk", "goToFight", "chm.KFTTMdu", "KFTTV", "KFTTRadio", "infoV", "KFTTInfoV", "kingliCV", "KFTTKingListCV", "kingliLV", "KFTTKingListLV", "dwAwardV", "KFTTDWAwardV", "vsV", "KFTTVsV", "dwIconV", "KFTTStageV", "winV", "KFTTWinV", "tabchg", "btn_Info", "btn_c_list", "btn_l_list", "btn_dw_award", "goup_bom", "dwGroup", "_pipeing", "seleIdxChg", "ckRadioRed", "checkMatch", "checkDailyAward", "img_tip3", "checkDWAward", "onClkClose", "btn_match", "onAddCntBtnClk", "onBox0Clk", "onBox1Clk", "getallreward", "onBox2Clk", "onBox3Clk", "getreward", "pipeiCom", "onTZCntChg", "onGetDailyAward", "onGetDWAward", "updKingListCV", "onBuyCnt", "_cur", "playPipeiEff", "updTTInfoV", "updKingListLV", "updDWAwardV", "checkBtnEff", "getDWCfg", "getCrossConfDic", "getkuTtCount", "defaultEveryChallengeTimes", "getLeftTZCnt", "lbl_left_cnt", "setDWIcon", "setStars", "allChallengeTimes", "k_1686", "k_1687", "checkDailyEff", "updV", "k_271", "getDuanState", "getStageBonusConf", "k_264", "onstarChg", "oldStar", "oldStage", "_curGet", "showStar", "removePipeiEff", "matchTarget", "showVs", "7807", "onVsCollision", "fightEnd", "7810", "settleInfo", "getBuyCnt", "k_261", "buyCntAlert", "k_214", "buyChallengeTiemsConsume", "k_262", "onBoxClk", "getBoxConf", "dailyBonus", "k_275", "chm.KFTTMed", "getCKings", "otherList", "getLKingInfos", "getMyInfo", "_mergerfight", "singlefight_json", "leftTzCnt", "maxBuyChallengeTiems", "_kfCfgDic", "buyNum", "stageBonus", "weekMaxStage", "dailyBonusNums", "singlefightsetting_json", "getRankReward", "rankScoreSegment", "rankScoreBonus", "getTitleIds", "titleIds", "getBonusOfContinuouVictory", "bonusOfContinuouVictory", "rspSloginResult", "rspFightCntChg", "rspTTInfo", "rspDayAward", "rspDWAward", "rspCKingList", "rspMatching", "rspSError", "rspplayerdatachg", "rspFightEnd", "rspBuyCnt", "preStage", "preStar", "rankNum", "preRankNum", "preTitleId", "weekMaxStar", "logKingInfo", "continuouVictory", "mergerSingleCount", "mergersinglecount", "countData", "kingInfo", "chm.KFTTMod", "CrossTTDWAwardViewSkin", "dwGrp", "lbl_wcy", "lbl_jie", "lbl_star_number", "dw_icon_", "k_273", "maxGrp", "KFTTKingAwardVo", "dw", "dw_name_", "resetdwListSV", "chm.KFTTDWAwardV", "checkEff", "CrossTTAwardItemRenderSkin", "tips", "_itemCtrl", "img_dw", "danbox_eff", "KFTTAwardRnd", "chm.KFTTAwardRnd", "CrossTTInfoViewSkin", "baoxiang", "_dailyboxEffs", "pipei_pro1", "pipei_pro", "_pipeiEff", "match_eff", "baoxiang0", "baoxiang1", "chm.KFTTInfoV", "chm.KFTTKingAwardVo", "_titleIIdToItemId", "CrossTTKingListCViewSkin", "KFTTKingRnd", "updateKingInfo", "KFTTKingVo", "starCount", "titleIId", "king_grp", "none_king", "lbl_cnt", "_titleCtrl", "chm.KFTTKingListCV", "CrossTTKingListLViewSkin", "chm.KFTTKingListLV", "CrossTTKingItemRenderSkin", "showRolePanel", "true", "chm.KFTTKingRnd", "chm.KFTTKingVo", "CrossTTRadioSkin", "chm.KFTTRadio", "_dwEffPoss", "_starPoss", "CrossTTStageViewSkin", "img_show_icon", "img_dw_icon", "_curShowStar", "_curStage", "_dwEff", "blendMode", "ADD", "BlendMode", "iconGrp", "fisrt_dan_effect", "wzStarCntGrp", "wzStarCnt", "dan_normal_effect", "_sxDatas", "_bxPos", "_curGrp", "showStarAni", "_toPos", "showStarTween", "showStarTextTween", "_grpChange", "iconTrans", "playStarEff", "_starEff", "getstar_effect", "lvlGrp", "img_l_star_", "img_star_", "iconsan", "showStarFall", "iconShow", "getStarPos", "img_l_star_0", "img_l_star_1", "img_l_star_2", "img_l_star_3", "img_l_star_4", "img_star_0", "img_star_1", "img_star_2", "img_star_3", "img_star_4", "chm.KFTTStageV", "CrossTTViewSkin", "chm.KFTTV", "CrossTTVsViewSkin", "lbl_dw0", "lbl_dw1", "playVsEff", "_vsEff", "vs_img", "onVsImgSEnd", "vs_effect", "ktEnd", "chm.KFTTVsV", "CrossTTWinViewSkin", "playResultEff", "_resultEff", "resultEffCom", "_settleInfo", "kuafu_victory", "kuafu_fail", "totalFrames", "gotoAndStop", "result_bg", "victory_bg_png", "victory_fail_png", "showAward", "onstarChange", "tt_reward", "lsGrp", "qbDesc", "k_274", "lbl_win", "clearWinArr", "_isGet", "iconJu", "starGrp", "losestar_effect", "starJu", "removeAllStarTween", "starSan", "chm.KFTTWinV", "CrSandyInViewMediator", "csTimerKey", "CrSandyInTimer", "effDic", "_gameMod", "_centerMod", "_uiMgr", "boomWindow", "csInnerPnl", "CrSandyInnerPnl", "csMyFamilyStatPnl", "CrSandyMyFamilyPnl", "csFamilyRankPnl", "CrSandyFamilyRankPnl", "csAttackers", "CrSandyAttackersView", "csClearCdPnl", "CrSandyClearCdPnl", "buyBuffPnl", "CrSandyBuyBuffPnl", "buffInfoPnl", "CrSandyChearupPnl", "resultPnl", "CrSandyResultPnl", "group_setReborn", "lbl_guildState", "k_779", "lbl_buff", "k_1170", "group_attackable", "updateMyScore", "updateSecond", "fieldTypeChange", "showDoorEff", "updateMemberNum", "updateDiaoXiangStartTime", "palaceTime", "updateBaZhuInfo", "_mapEff", "_touchSp", "removeRebornMask", "closeBoom", "onClkShape", "showFamilyRank", "showFamilyState", "askEnterNextField", "btn_nextField", "showClearCdPnl", "clickAchieveHandler", "clickGoldBuff", "grp_gold_buff", "clickGXBuff", "grp_gx_buff", "showBuffInfo", "setRankInTime", "getAchieveSuccess", "setRebornDisplay", "onStatusDestory", "onGetBuffInfo", "getPersistTime", "updateCsTime", "fieldType", "showRebornMask", "updateRebornText", "group_myScore", "dxStartTime", "lbl_nextTime", "k_1169", "set_nextTime", "k_1163", "isStatue", "onTouchDoor", "sameFamilyNum", "curBazhuName", "k_1162", "lbl_stateTitle", "k_1161", "lbl_kingFamilyName", "SCZBRankInTimeVo", "rankInTime", "trans", "familyItems", "lbl_firstScoreValue", "lbl_firstScoreName", "lbl_myFamilyRank", "lbl_myFamilyScore", "showEndView", "updateDxStartTime", "myLevelScore", "lbl_selfScoreAcheive", "scoreName", "lbl_achieveRewardText", "updateFieldType", "setDoorEffPos", "shacheng_hegemony_jifen_png", "reqFamilyState", "shacheng_hegemony_chakan_png", "setFamilyState", "showBuffBuy", "_buffType", "getInspireConf", "k_1160", "k_1159", "kufushacheng_guwu_title_png", "reqBuffInfo", "reqGetAchieve", "mizhen_chuansong", "doorXY", "tryOpenbuyPnl", "reqBuffCnt", "totalGoldCnt", "playChearupEff", "removeChearUpEff", "totalGxCnt", "gx", "setCtrlShow", "EffectDicInfo", "isRun", "effObject", "chm.CrSandyInViewMediator", "CrSandyViewMediator", "_inMediator", "exitCrSandy", "enterCrSandy", "_timOutId", "reqPlayerStatus", "chm.CrSandyModule", "dotCount", "suffix", "_q", "_b", "_z", "titleSrc1", "qinglong_2_png", "baihu_2_png", "zhuque_2_png", "xuanwu_2_png", "titleImgSrc1", "room_bg2_png", "titleSrc2", "qinlong_1_png", "baihu_1_png", "zhuque_1_png", "xuanwu_1_png", "titleImgSrc2", "room_bg1_png", "subWindow", "CrSandyView", "csPrePnl", "CrSandyPrePnl", "csFinalPnl", "CrSandyFinalPnl", "csFamlyStat", "CrSandyFamilyStatPnl", "csAwardPnl", "CrSandyAwardPnl", "csBetPnl", "CrSandyBetPnl", "csBuyTip", "CrSandyBuyTip", "csBetTip", "CrSandyBetConfirmPnl", "kufushacheng_title_png", "tabbar1", "btn_pre", "btn_final", "togglePfStatus", "lbl_betLog", "k_1158", "updateMatchStatus", "showBetPanel", "showBetLog", "noneLastWarInfo", "noneLastRank", "checkIfBtnEff", "showBuyTip", "btn_quanAdd", "updateNum", "updateTicketNum", "updateBetState", "popBetTip", "showVer", "showStage", "noneTime", "removeAllTeamEff", "removeAllCenterEff", "cancelHanler", "crsandy_dotmove", "lastShowStage", "reqStatus", "STAGE_PRE", "reqWarInfo", "reqBetLog", "checkIfShowTime", "STAGE_FINAL", "reqMatchState", "oldPnl", "tmpPnl", "getInfoByVersion", "familys", "togglePfPanel", "getInfosByVerAndStage", "hasWinner", "grp_common", "fightInfo", "groupInfos", "winnerInfos", "grp_ctt", "statusDic", "openGroups", "closeDic", "matchStatus", "myFamilyVo", "lbl_battleNow", "k_1157", "\uff0c", "dotMove", "CrSandyUtil", "k_1156", "lbl_battleNext", "lbl_familyInfo", "isWinner", "k_1142", "isPromote", "k_1154", "k_1153", "k_1155", "k_1188", "playAllTeamEff", "playCenterEff", "k_1152", "k_1151", "bet", "betlog", "myState", "k_1150", "k_1149", "getMyState", "k_1148", "entrylock", "isLocked", "reqEntry", "title_bg", "team", "team_eff", "team_q", "team_b", "team_z", "team_x", "title_q", "title_b", "title_z", "title_x", "title_bg_q", "title_bg_b", "title_bg_z", "title_bg_x", "precenter", "jinji_eff", "img_center", "finalcenter", "juesai_eff", "enterbtn", "2018-10-1 23:59:59", "chm.CrSandyViewMediator", "disposeBitmapFrame", "BitmapFrame", "chm.BitmapFrame", "boFinal", "_infoDic", "groupNames", "k_1147", "k_1146", "k_1145", "k_1144", "stageNames", "k_1143", "unlock", "betStage", "betState", "rspWarInfo", "rspMatchState", "rspPlayerStatus", "rspLoginComplete", "rspBetLogSuccess", "rspBuyVoucherSuccess", "rspCrossCsStatus", "rspScoreReward", "rspDailyReward", "myFamilyNextTime", "CsWarInfoVo", "setInfoDic", "myFamilyId", "myFamilyName", "\u73a9\u5bb6\u6ca1\u6709\u52a0\u5165\u516c\u4f1a", "bazhuInfo", "familyLeaderInfo", "CsFamilyInfoVo", "teamId", "isMyFamilyPromote", "isMyFamilyWin", "pre", "checkBet", "final", "getTeamIdByFamilyId", "_tm", "myBetVo", "preTimes", "preGiveTimes", "preUseTimes", "BetCloseTime", "getConf", "reqBet", "reqBuyTicket", "CsMyBetVo", "singleDatas", "CsBetLimitVo", "preBetIds", "finalTimes", "finalBetIds", "finalGiveTimes", "finalUseTimes", "chm.CrSandyModel", "_field2Map", "_fieldType", "_rebornTime", "lastBazhuName", "gxRankDatas", "notipState", "rspEntry", "addCrEvt", "rspMsg", "rspPlayerEnter", "rspOtherMove", "rspLeave", "rspNextField", "rspStatusDestroy", "rspFamilyState", "rspScoreChange", "rspReborn", "rspKingFamilyChange", "rspBuyBuff", "rspBuffCnt", "rspBuffAddition", "rspEnd", "rmvCrEvt", "reqDailyReward", "reqScoreReward", "reqLastPlayerRank", "token", "initSameFamilyNum", "_sameFamilyNum", "_rankInTime", "cityPhase", "nextFieldTime", "kingFamilyName", "changeBazhu", "scoreRewardIndex", "changeScoreIndex", "_waitFieldInfo", "transNextField", "sameFamilyName", "creatDx", "reqStatusFight", "destoryDx", "sandyFamilyPlayer", "k_1141", "memberStates", "familyMemberItem", "realFamilyRank", "rankItemInfos", "rspLastFamilyRank", "scoreIcon", "getScoreRwdInfo", "_waitBazhuName", "k_1140", "reqNextField", "\u5f00\u59cb\u8fde\u63a5\u8de8\u670d\u6c99\u57ce\u4e2d\u5fc3\u670d", "k_1139", "doCheckAttackDx", "dx", "dxId", "SCZBCfgMod", "getMonRes", "m_", "clearCache", "lastFamilyRank", "monsterXY", "k_1138", "totalCnt", "buffAddition", "k_780", "k_781", "buffDefenderAddition", "chm.CrSandyPlayerModel", "scoreRewardDic", "clientxml", "crsandyclient_json", "getFamilyRewardShow", "preTakememberTitle", "precrosscoin", "pretakeSandyFamilyReward", "prePriticipatememberTitle", "preparticipatecrosscoin", "preparticipateSandyFamilyReward", "finalmemberTitle", "finalcrosscoin", "finaltakeSandyFamilyReward", "finalparticipatecrosscoin", "finalparticipateSandyFamilyReward", "presingleScoreSegment", "presingleScoreBonus", "SCZBRwdVo", "finalsingleScoreSegment", "finalsingleScoreBonus", "CrossSandyCitySetting_json", "persistTime", "getRebornTime", "getClearCdGold", "crosstInspirebuy_json", "getFakeKingFigureData", "heroSex", "heroEquipId", "chm.CsCfg", "bitmapFrameList", "chm.BitmapFramePool", "chm.CrSandyUtil", "CrSandyAttackersSkin", "chm.CrSandyAttackersView", "CrSandyAwardPnlSkin", "list_rwdShow", "CrSandyRwdRender", "fillBonus", "chm.CrSandyAwardPnl", "CrSandyBetConfirmPnlSkin", "betHandler", "isNoTip", "k_1177", "k_1178", "\u4e0d\u8db3", "onBet", "k_1184", "preBetWinBonus", "preBetLoseBonus", "img_quan", "yazhuquan_1_png", "finalBetWinBonus", "finalBetLoseBonus", "yazhuquan_2_png", "k_1185", "lbl_lose", "\u521d\u8d5b\u62bc\u6ce8\u5238", "k_1186", "\u51b3\u8d5b\u62bc\u6ce8\u5238", "k_1187", "chm.CrSandyBetConfirmPnl", "CrSandyBetPnlSkin", "list_bet", "CrSandyBetRender", "list_betLog", "CrSandyBetLogRender", "updateLog", "grp_1", "grp_2", "gongshayazhu_title_png", "updateBet", "yazhujilu_title_png", "lbl_quanTitle", "k_1172", "k_1171", "boPre", "betStatus", "checkPreIfBetWin", "checkFinalIfBetWin", "lbl_quanNum", "chm.CrSandyBetPnl", "CrSandyBuyBuffPnlSkin", "_leftCnt", "k_1165", "k_1166", ", ", "k_1167", "k_1134", "k_1135", "onClkBuy", "chm.CrSandyBuyBuffPnl", "_ticketName", "CrSandyBuyTipSkin", "buyTicket", "setCost", "preBetBuyCost", "finalBetBuyCost", "k_1173", "_costNum", "preLimit", "preFreeTimes", "item_11906_png", "finalLimit", "finalFreeTimes", "item_11907_png", "lbl_quanCnt", "k_1175", "lbl_buyCnt", "k_1176", "k_1174", "lbl_quanName", "\u3010", "\u3011", "maxBuy", "k_1183", "chm.CrSandyBuyTip", "proarr", "\u653b\u51fb: 0", "\u6cd5\u9632: 0", "\u7269\u9632: 0", "CrSandyChearupPnlSkin", "CrSandyPopRender", "k_1168", "lbl_goldtime", "k_1133", "lbl_gxtime", "k_1132", "lbl_totaltime", "k_1131", "lbl_gwrank", "chm.CrSandyChearupPnl", "CrSandyClearCdPnlSkin", "labelDisplay", "okHandler", "tipChange", "noTip", "lbl_yuanbaoNeed", "k_565", "chm.CrSandyClearCdPnl", "CrSandyEnemyViewSkin", "img_crown", "k_1130", "CrSandyEnemyView", "chm.CrSandyEnemyView", "CrSandyFamilyRankPnlSkin", "setFamilyRank", "CrSandyFamilyRankRender", "SCZBGHRankVo", "chm.CrSandyFamilyRankPnl", "CrSandyFamilyStatPnlSkin", "CrSandyStatRender", "CsFamilyStatVo", "chm.CrSandyFamilyStatPnl", "_3", "_4", "numOfGroups", "numOfMembers", "CrSandyFinalPnlSkin", "removeBetEff", "onBetHandler", "btn_bet", "setBetButtons", "kaufushacheng_bg1_jpg", "kingName", "kaufushacheng_bg2_jpg", "isComple", "lbl_qufu", "lbl_kingName", "lbl_familyName", "k_808", "juesai_liebiao1_png", "grp_y", "juesai_liebiao2_png", "juesai_liebiao3_png", "lbl_kingFamily", "weapon", "\u65e0\u6cd5\u89e3\u6790\u9738\u4e3b\u5f62\u8c61\u6570\u636e", "wingLvl", "k_1180", "k_1181", "k_1182", "playBetEff", "yazhu_eff", "chm.CrSandyFinalPnl", "CrSandyInnerPnlSkin", "crSandyInnerPnl", "group_screenLeft", "group_screenRight", "group_screenCenter", "grp_gxTip", "k_778", "lbl_timeLeft", "lbl_memberNum", "k_777", "img_progress1", "img_progress2", "img_progress3", "pro_bar", "procedure_on_png", "procedure_off_png", "k_1126", "k_1125", "k_1124", "k_566", "img_effgold", "img_effgx", "chm.CrSandyInnerPnl", "chm.EffectDicInfo", "CrSandyMyFamilyPnlSkin", "itemRendererSkinName", "SandyCityMainGuildStateRenderSkin", "SCZBGHMemberVo", "chm.CrSandyMyFamilyPnl", "effectList", "promotePath", "leftPoints", "rightPoints", "removeAllBetEff", "CrSandyPrePnlSkin", "CrSandyPreRender", "componetList", "btn_q", "btn_b", "btn_z", "btn_x", "drawPromotePath", "yellowline_2_png", "yellowline_1_png", "_v", "chm.CrSandyPrePnl", "CrSandyResultPnlSkin", "SCZBMainEndRnd", "jiesuan_title{0}_png", "familyKingName", "tokedFamily", "onclkClose", "SCZBEndVo", "currency_activityhead1_png", "sandycityendview", "chm.CrSandyResultPnl", "CrSandyViewSkin", "chm.CrSandyView", "CrSandyBetLogRenderSkin", "img_win", "img_lose", "lbl_netCnt", "gridWin", "grp_win", "gridLose", "grp_lose", "chm.CrSandyBetLogRender", "CrSandyBetRenderSkin", "updateMyBetInfo", "lbl_king", "k_1179", "img_kingHead", "kingHead", "lbl_support", "\u652f\u6301", "scrollRect", "yazhu_btn1_png", "yazhu_btn2_png", "img_betIcon", "lbl_betCnt", "chm.CrSandyBetRender", "CrSandyFamilyRankRenderSkin", "lbl_familyScore", "chm.CrSandyFamilyRankRender", "CrSandyPopRenderSkin", "lbl_gold", "goldCnt", "lbl_gx", "gxCnt", "chm.CrSandyPopRender", "CrSandyPreRenderSkin", "chusai_liebiao1_png", "chusai_liebiao2_png", "chusai_liebiao3_png", "chm.CrSandyPreRender", "CrSandyRwdRenderSkin", "zhanling_title_png", "siqiang_icon_png", "canyu_title_png", "shiliuqiang_icon_png", "bazhu_icon_png", "chm.CrSandyRwdRender", "CrSandyStatRenderSkin", "goldNum", "gxNum", "chm.CrSandyStatRender", "chm.CsBetLimitVo", "familyBaseStr", "leaderHead", "teamAndStatus", "timeStamp", "chm.CsFamilyInfoVo", "chm.CsFamilyStatVo", "CsMyBetSingleVo", "chm.CsMyBetSingleVo", "prayLuckInfos", "preBetFreeNum", "finalBetFreeNum", "preBetBuyLimit", "finalBetBuyLimit", "chm.CsMyBetVo", "chm.CsWarInfoVo", "chm.PvpsScenePlayerVo", "EmMed", "showEmail", "gMail", "openCon", "sRed", "EmMod", "checkIfAmazingTip", "rdMail", "gRwd", "gAlRwd", "askForDelete", "chm.EmMdu", "youjian_title1_png", "fList", "EmRed", "EmV", "gAlMail", "btnGetAll", "delAllMail", "btnDelAll", "CLICK_RENDER", "CloseCon", "getMail", "gElist", "setEmailList", "getAllDeIds", "k_278", "k_279", "boRead", "_contentVo", "setEmailContent", "validateDisplayList", "contont", "lblContent", "chm.EmMed", "checkSocialRed", "MasterMod", "emailRed", "EmRVo", "k_276", "k_277", "checkIfSpecialMail", "k_280", "AmazingMail_Change", "chm.EmMod", "youjian_di1_jpg", "EmPan", "EmCPan", "sh", "chm.EmV", "amazing_mail_bg_png", "img_amazing", "huoqu1_png", "click_render", "RESET_SCROLLV", "reset_scrollV", "chm.EmRed", "chm.EmRVo", "EmailContentPanelSkin", "chm.EmCPan", "EmailPanelSkin", "chm.EmPan", "ZYZBossMed", "ZYZBossV", "btn_true", "btn_false", "metID", "askForMeetBoss", "updata", "metBVo", "LV.", "dropshow", "img_bossicon", "removemonster", "mo", "makeMonster", "zaoyu_beijing1_jpg", "chm.ZYZBossMed", "ZYZMed", "bossMed", "_enemyMod", "EnemyModel", "rspMeetBossInfo", "rspMeetplayerInfo", "rspDeleteMeet", "rspReport_Meet", "rspGetSelfMeetRank", "rspmeetEnd", "rspCountDataChange", "rspEncounterRank", "rspEneGetRevenges", "rspHasRevenge", "rspEnemyDelete", "rspRevengeEnd", "rspCoutDataChg", "rspBuffSuccess", "rspFuhuoTime", "logComplete", "meetInfo", "clickMeet", "endBattle", "curMapChg", "enemyChg", "revengeNumChg", "setRevengeState", "zaoYuFight", "getZaoYuInfo", "enemyRed", "disRed", "getenemyDatachange", "k_289", "showBossPanel", "getMetFgtVO", "meetEndvo", "getMetOpenLmt", "MeetCfgMod", "askForMeetFight", "askZaoYuTime", "askForGetSelfMeetRank", "askForMeetFightInfo", "k_288", "askForMeetSearch", "askForEncounterRank", "getMetPlayer", "delFgtVo", "isStaged", "getMetFgtRpt", "getMetRank", "metBuyNum", "meet", "askForEnemyData", "askEnemyFight", "askbuyCount", "getenemyVO", "deleteEnemy", "buffEndTime", "revengeBuffEndTime", "fgtVos", "chm.ZYZMdu", "rndArr", "ZYZMainV", "zaoyu_title_png", "fightChg", "reportChg", "lbl_buy", "enemyP", "k_287", "getBuyCost", "EnemyCfgMod", "explainClick", "touch", "btn_xund", "gotoMeetFight", "updEnemyV", "countUpd", "buyNumChg", "zyzRankChg", "showZYZRed", "showZYZPosAlert", "ZYZ_USE_POS", "ZYZAlert", "usePos", "yaoShuiCount", "zyzRank", "_timeOut", "enemyArr", "revengeNum", "k_293", "ssCost", "k_282", "updDataV", "reports", "dataP", "nextMetT", "MEET_Time", "meetTime", "myMeet", "k_285", "honor", "lbl_shengwang", "my_rank", "k_286", "lbl_reward1", "lbl_reward2", "linghun", "lbl_reward3", "my_shengwang", "characterbg_job_{0}_{1}_jpg", "img_myhead", "removeRnd", "ZYZFightRnd", "isFightCountFull", "fightCount", "rwdNum", "render_group", "wwCount", "k_292", "getZYZRank", "zyzAlert", "battleVOChg", "fightid", "sendFightPlayEnd", "sendPickupItemEnd", "chm.ZYZMed", "getMet", "meetsetting_json", "metNum", "maxmeetcount", "enmeyNum", "enemycount", "revengecount", "searchcost", "buffItemId", "20", "getMetid", "getMetRwd", "meetreward_json", "getRevengeReward", "revengerewardshow_json", "getMetBossDrop", "bossmeeting_json", "chm.MeetCfgMod", "rewardID", "ZYZFgtVO", "rlv", "rewerd", "getGridVos", "getMetBoss", "portid", "MeetBossVO", "infoId", "MeetRptVO", "winorlost", "getGridVo", "SOUL:1", "readmetrankrwd", "JUNGONG", "COMBATGAINS", "meetrankreward_json", "ZYZRankVO", "rankInfo", "k_291", "ckRank", "chm.ZYZMod", "EncounterAlertSkin", "\u5f53\u524d\u836f\u6c34\u6570\u91cf\u4e0d\u8db3\uff0c\u662f\u5426\u524d\u5f80\u6218\u7ee9\u5546\u5e97\u8d2d\u4e70\uff1f", "zyz_use_pos", "chm.ZYZAlert", "ZYZBossP", "chm.ZYZBossV", "ZYZMainP", "EnemyPanel", "ZYZFgtDataP", "ZYZRank", "group_players", "initTarBar", "EnemyRender", "ZYZFgtDataRnd", "ZYZRankRnd", "btn_players", "btn_fightdata", "btn_revenge", "toggleChg", "zaoyu_jilu_png", "zaoyu_rankreward_png", "zaoyu_revengetitle_png", "chm.ZYZMainV", "\u6b64\u7269\u54c11\u6b21\u53ea\u80fd\u4f7f\u75281\u74f6", "\u836f\u6c34\u6570\u91cf\u4e0d\u8db3", "\u4e0d\u80fd\u8d85\u8fc7\u5f53\u524d\u7ea2\u540d\u503c", "\u52a0\u901f\u836f\u6c34\u6570\u91cf\u4e0d\u8db3", "chm.EncounterAdd", "EncounterBossPanelSkin", "chm.ZYZBossP", "ZaoyuFightdataPanelSkin", "chm.ZYZFgtDataP", "img_result", "zaoyu_cg_png", "zaoyu_shibai_png", "lbl0", "lbl1", "lbl2", "lbl3", "lbl4", "chm.ZYZFgtDataRnd", "ZaoyufightRenderSkin", "lbl_exp", "lbl_weiwang", "lbl_conbatgain", "lbl_linghun", "chm.ZYZFightRnd", "ZaoyuMainPanelSkin", "chm.ZYZMainP", "EncounterRankSkin", "chm.ZYZRank", "chm.ZYZRankRnd", "chm.MeetBossVO", "chm.MeetRptVO", "chm.RuleDescVO", "chm.ZYZFgtVO", "chm.ZYZRankVO", "revengecost_json", "chm.EnemyCfgMod", "_buyCount", "_currentCount", "_buffEndTime", "chm.EnemyModel", "EnemyPanelSkin", "chm.EnemyPanel", "uic", "gotoFightByYaoShui", "btn_yaoshui", "lbl_sehngwang", "chm.EnemyRender", "EnemyVO", "chm.EnemyVO", "FabaoModule", "FbViewMed", "showFabaoPanel", "onBuyHandler", "askShopInfo", "onRefreshHandler", "shopBuyToJiFen", "rspFaobaoInfo", "rspEquipQuenching", "rspFabaoActivate", "rspEquipQuenching2", "rspFabaoJinshiDuihuan", "rspFabaoPartinfo", "rspFaobaoShopBackInfo", "buySucc", "boWakeup", "showTabPanel", "showShop", "fbShop", "isLogin", "sendGetFabaoInfo", "FbPartMod", "sendFaboPartinfo", "repFabaoShopInfo", "repFabaoShopBuy", "repFabaoShopRefresh", "fabaoInfos", "activateConditions", "setRspFbData", "jingshijifen", "setFbJshiJifen", "fabaoJifen", "getSorceUrl", "1.2", "1.4", "1.6", "1.8", "2.0", "3.0", "treasure_mul_", "SendFBSparExtChange", "sendGetFabaoActiveInfo", "sendFabaoUpLvOrStarInfo", "sendFabaoCuiquiInfo1", "sendFabaoCuiquiInfo2", "senfaobaFight", "sendFabaPartAct", "fabaoId", "fabaoPartsId", "sendFabaPartLvup", "buyId", "getShopItemById", "FabaoCfg", "FabaoShopOnlyVo", "myCount", "fabaojifen", "repShopBuyToJiFen", "chm.FbMdu", "_pos", "NeedSHow", "mvo", "radioPanel", "FabaoRadio", "fbLvupPnl", "FaobaoArticactEui", "fbUpstart", "fbCuilnPnl", "FaobaoCuilianEui", "FabaoShop", "fbShopBtn", "FabaoShopBtn", "gwinSelct", "euiSmeltSelect", "SmltSltEui", "partPanl", "FabaoPartEui", "PartLvupPnl", "FabaoPartLvupEui", "partDesc", "FabaoDesc", "fbprDes", "fabaoProDes", "fabao_bg_jpg", "skList", "FbJihuoRndr", "List_itemlist", "FbCqBagGridRnd", "smeltGridArr", "SmeltGrid", "goup", "initShape2", "bag_xuanze_png", "img_actBg", "part_bg_2_jpg", "img_lockbg", "part_bg_1_jpg", "fillSmeltSelectPanel", "hideSelectPanel", "closeSmeltSelectPanel", "refreshSelectEquip", "currendIdx", "getExplain", "onLeftClick", "btn_left", "onRightClick", "btn_right", "OnLvupClick", "OnChuzhanClick", "img_chuzan", "getWayArticact", "OnUpStarClick", "onMaxClick", "btn_Max", "onMinClick", "btn_min", "onAddlick", "onDesClick", "btn_dec", "onCuiquClick1", "btn_cuiqu1", "onCuiquClick2", "btn_cuiqu2", "onJinshiClick", "OnEditChange", "edit_Num", "hideActContPan", "shape2", "shwoActContPan", "onRefCuiEquipbag1", "onRecuiQuEquipScuess", "onActivedUp", "OnLvUpSucess", "updateFabaoData", "updateJinshiJiFen", "onJinshiChangeSucc", "removeSelectEquipHandler", "smeltSelectChangeHandler", "refreshSmeltSelectNum", "onParticonClick", "onPartLvClick", "onPatrlvupSucess", "onPatrACtiveSucess", "onPatrTupoSucess", "onReshPartInfo", "onPartDescClick", "grop_tips", "onTotalProshow", "equip_group", "group_shop", "showShopRed", "getNowSkillInfo", "setSklTipinfo", "getFballPro", "labpro", "getFbSpePro", "speLab", "setbtnState", "showJinshiEff", "flayToBag", "nMaxJinshiJifen", "img_exp", "k_119", "showCanGetJinshiEff", "curtPnl", "playUpEff", "fabaIxd", "fabao_cion_", "treasure_name_", "nMaxchenzNum", "nowChenzNum", "CuquEquipiems", "k_126", "_dely", "shwoGirdNum", "PlayerEffect", "playerFlayEff2", "_dely1", "onshowjifenBag", "boEmpty", "setflyImgShow", "onRefCuiEquipbag", "playerFlayEff", "nType", "deleteReadySmeltArr", "changeReadySmeltArr", "getSmeltSelectList", "refreshSmeltSelectPanel", "getNowSelcEqups", "refreshSelectNum", "/15", "getNowCuiQuNum", "getEquipList", "k_127", "\u662f\u5426\u8403\u53d6", "\u6a59\u88c5\u788e\u7247?", "fabaocuiqu", "setActConPanValue", "jiban", "getFbDataByID", "checkfbLvupOrUpstar", "boManji", "CheckBoActByID", "k_128", "onaddFbidx", "pageidx", "maxPageIxd", "showBtnState", "ondecFbidx", "onSetFabaoicon", "updateFabaopartData", "RemoveItemEff", "RemoveAllEff", "removeLightEff", "group_fight", "showPanlTabState", "showItemEff", "playLightEff", "part_title_4_png", "treasure_title_", "shwoActicveState", "bochuzan", "showFaboNowState", "getActParts", "setFabaoIconPartIcons", "k_118", "RemoveAllPart", "setfabaoActItemList", "k_120", "getfbCfgByType", "lab_spe_pro", "prodes", "getFbLvCfgByType", "setNowStarNum", "k_131", "grp_fightNum", "setProValue", "upLvCost", "upStarCost", "nowCoastID", "getContStrbynum", "lab_needname", "k_123", "showBtnEff", "showLvupBtnEff", "getfbActCfgByType", "FbActVo", "needDesc", "offset", "currencyDesc", "img_itemEff", "checkTip2Red", "tip4", "ckPartTipRed", "_btnLeftEff", "_btnRigthEff", "FabaoLvUpRedIds", "FabaoUpstarRedIds", "grop_left", "grop_right", "_JinshiEff", "getStone_eff", "_getJinshiEff", "getstone_after_eff", "partsId", "setFbPIdx", "onSetPatLvValue", "getNowPartData", "SetPartValue", "getfbPartsByID", "setFbPartIcon", "setFbSkillInfo", "getCurPartsValue", "setPartFightNum", "nlasttime", "getfbPartLvCfgByid", "playpartUPEff", "chm.FbViewMed", "_fabaoLvupConfDic", "_fabaoUpsatrByDic", "_fabaoActDic", "_nameList", "_fabaoPartDic", "_fabaoskilllvDic", "_fbskillIfDic", "_fabaopartActDic", "fabaoUpLv_json", "fabaoUpStar_json", "getfbPartCfgByType", "fabaoParts_json", "getskllvCfgByType", "fabaoSkillLevel_json", "getNowSkillLv", "partsLevel", "skillLevel", "getskilInfCfgByType", "fabaoskill_json", "getskillbase", "getskilLvNeedParslv", "getPartActsNeed", "fabaoPartsActivate_json", "getPartActbasebyid", "activateCost", "getItemCost", "fabaoshop_json", "buyCost", "getShopXml", "_shopXml", "limitcount", "getRefreshCost", "refreshCost", "getFirstShop", "firstShop", "getMaxShopNum", "shopNum", "chm.FabaoCfg", "chm.FabaoShopOnlyVo", "fabaoPartVo", "chm.fabaoPartVo", "_boActive", "boActive", "NowValueDes", "chm.FbActVo", "fabaoIDarr", "fbname", "\u9b42\u7389\u91d1\u94c3", "\u7075\u5b9d\u62a4\u7b26", "\u91d1\u9f99\u52cb\u7ae0", "\u91d1\u521a\u62a4\u76fe", "\u7d2b\u6676\u7389\u74f6", "\u5929\u673a\u6676\u77f3", "\u6df7\u5143\u4e39\u7089", "\u65e0\u5c3d\u5929\u706f", "\u4e07\u5203\u795e\u5251", "SltGVo", "getFbPro", "getfbPartPro", "boisCuiQuEquip", "SltSRVo", "setRspActCondition", "transLvlCost", "_fabaoJifen", "chm.FbMod", "nowparIdx", "1_1", "fbpartInfos", "fbShopInfo", "FabaoLvUpPartRedIds", "fBpartLvbyidRedids", "nowFbid", "nowpartid", "getfbPartDaByID", "nowFBpartinfo", "getNowPartsInfo", "nowSkillinfo", "FbSkillvo", "fabid", "getNowPartsMinLv", "setskilldata", "ckPartLvup", "ckPartIsActByID", "chm.FbPartMod", "skillname", "skillIcon", "baseDes", "nowSkillDes", "isMax", "nextSkillDes", "_nextlv", "buffEff", "<font color=\"#39DB15\">", "nextlvNeed", "_nextlvNeed", "nowlvNeed", "_nowneedLvneed", "nextManzhuNum", "chm.FbSkillvo", "FabaoDescSkin", "FabaoPartTips", "FB_iconName1", " lv", "FB_Des1", "FB_iconImg", "k_137", "FB_Des3", "FB_life1", "\u5f53\u524d\u5c5e\u6027:", "FB_States1", "FB_States2", "FB_BgImg", "Gro_tips", "FB_Gro8", "<font color=\"#39DB15\">4</font>", "FB_iconName0", "FB_States3", "FB_States4", "FB_Des4", "FB_Des2", "\u6ee1\u7ea7\u5c5e\u6027:", "FB_States5", "setTips", "chm.FabaoDesc", "particons", "particonDis", "FabaoPartSkin", "hidepanl", "img_part", "FabaoParticon", "iconParts", "fabao", "_color_0", "img_Jihuo", "treasure_flag_2_png", "labv", "groPro1", "nameImg", "img_fabaoIcon", "skilldata", "lab_skillicon", "lab_skillDes", "k_132", "_LightEff", "fabao_lighteff", "chm.FabaoPartEui", "FabaoParticonSkin", "onbtnclick", "img_tips", "chm.FabaoParticon", "_LightLvupEff", "_maskNum", "boRunLine", "FabaoPartLvUpSkin", "Imgstars", "grostars", "grp_lv", "img_lv", "initGraphics", "partInfo", "lab_Name", "gropLv", "part_title_1_png", "lablv", "k_133", "labnextlv", "part_title_3_png", "k_134", "part_title_2_png", "k_135", "setStarLV", "grop_maxlv", "icon_needicon", "k_136", "gropPro", "imgArw", "labav", "part_ball_1_png", "part_ball_2_png", "getMaskAngle", "part_eff_1", "_awakeEff", "grop_cricle", "godcast_effect03", "part_eff_3", "setlvupLightEff", "_nextmasknum", "maskAni", "part_eff_2", "removeLvupLightEff", "ruanChange", "moldMaskAni", "stopMaskWait", "chm.FabaoPartLvupEui", "fabaoProDesSkin", "titleLab", "\u6240\u6709\u6cd5\u5b9d\u5df2\u589e\u52a0\u57fa\u7840\u5c5e\u6027", "\u6240\u6709\u6cd5\u5b9d\u5df2\u589e\u52a0\u7279\u6b8a\u5c5e\u6027", "chm.fabaoProDes", "FabaoRadioSkin", "chm.FabaoRadio", "FabaoShopSkin", "refreshShop", "askRefresh", "btnRefresh", "list_item", "FbShopListRndr", "showGetWay", "isShinning", "k_875", "chm.FabaoShop", "FabaoShopBtnSkin", "chm.FabaoShopBtn", "FaobaoArticactEuiSkin", "stars", "star1", "star2", "star3", "star4", "star5", "star6", "star7", "star8", "star9", "star10", "topLbl", "lab_NeedDes", "lab_nowC", "img_acticon", "img_ActConState", "treasure_flag_3_png", "TabIndx", "grop_star", "treasure_prop1_png", "treasure_prop2_png", "scrList_jihuo", "grop_lvup", "img_upstar_active", "grop_pro", "tresure_upstar_eff", "chm.FaobaoArticactEui", "FaobaoCuilianskin", "grop_Czcp", "img_lizi", "flyEnd", "TweenGroup_Move", "img_lizi16", "_delay1", "flyEnd2", "twgropMove2", "chm.FaobaoCuilianEui", "playEffComp", "chm.FbCqBagGridRnd", "FabaoJihuoRendeskin", "chm.FbJihuoRndr", "FabaoShopListRenderSkin", "grp_cell", "Q_IMG_S", "k_873", "k_874", "k_20", "FabaoShopBuy", "shop_white_png", "shop_green_png", "shop_blue_png", "shop_purple_png", "shop_orange_png", "shop_red_png", "chm.FbShopListRndr", "FamilyListV", "FamIfLiRd", "guild_title_png", "crtPal", "checkboxs", "checkbox_1", "checkbox_3", "showCrt", "btnCreate", "doCrtFam", "hideCrt", "BTN_CLICK_REQUST", "reqFam", "fname", "joinTo", "flevel", "k_299", "createlimit", "k_300", "createvip", "createcost", "k_302", "flevel1", "k_354", "createlimit1", "delaycreat", "onCreateOk", "onGetFamilys", "getFamilys", "flist", "OtFaIfVo", "noFamily", "FamilyLstMed", "chm.FamilyLstMed", "_flMed", "_fsMed", "FamScreenMed", "tarOpen", "flCrtOk", "falCpWin", "revFcData", "reCopyFight", "TRIAL_RED_CHANGE", "checkTrialOpen", "gotoShouRen", "getInfoByHand", "enterCopy", "autoBuyBuff", "changeEnter", "ftIntion", "setCopyWin", "checkLimit", "limitVO", "FamilyTrialModel", "c_2230", "getReds", "switchPanel", "sendCopyInfo", "faCpData", "showCopyRed", "onLeaf", "reqList", "onImpeachment", "onCheckJoin", "judge", "onKickOut", "setOffer", "setLeader", "setNotice", "setJoinLmt", "donate", "taskId", "onStudy", "onShopBuy", "shopType", "intrusionIndex", "allotItem", "seedRedPack", "grabRedPack", "akfSumBoss", "akfSumHelp", "akfSmBosInfo", "copyFight", "copyRank", "copySwap", "familyUpPublicskill", "getPublicskillReward", "getPublicskilldonate", "FamilyTrialAuto", "_buffTime", "autoBuff", "autoCallBuff", "FAMILY_COPY_FIGHT", "chm.FamilyModu", "_comCnt", "skillBarW", "FamilyScrnV", "summonPanel", "taskView", "heroSkillpanel", "skillView", "GrFaSkRd", "famSkillPanel", "horDonation", "FamilyHorDonRender", "shopPanel1", "shopView", "FamShopLRd", "shopPanel", "BagPanel", "bagView", "MemIfBLRd", "FamBagBoxRd", "msgList", "BagPanel1", "FamRLRd1", "memLstPal", "mainView", "MemInLRd1", "dataPanel", "MemILRd", "hdListPanel", "FamHLRd", "taskListPanel", "FamTLRd", "reqLstPal", "ReqMLRd", "sfPal", "SetOfferRd", "BagRecord", "FamBulRd", "screen", "MemGxLiRd", "faListPal", "FamilyInfoLineSkin", "MAIN_TABBAR_SELECT_CHANGE", "upMainTab", "SHOP_TABBAR_SELECT_CHANGE", "upShopTab", "TASK_TABBAR_SELECT_CHANGE", "upTaskTab", "BAG_TABBAR_SELECT_CHANGE", "upBagTab", "SKILL_TABBAR_SELECT_CHANGE", "changeSkillTab", "showOtPal", "main", "shop", "bag", "hideOtPal", "clickDengLu", "grp_denglu", "BTN_CLICK", "onTakLCk", "rfTakPal", "onHLCk", "leaveFam", "btn_leave", "BTN_CLICK_KICKOUT", "kikMem", "refMaData", "refMemLst", "playReqEft", "openReqLst", "requstListClick", "hideReqLst", "reqLstOk", "BTN_CLICK_REQUST_YES", "onRequstYes", "BTN_CLICK_REQUST_NO", "onRequstNo", "openEdNotice", "editClick", "hideEdNotice", "edNotice", "editNotice", "btnEdit", "faChangeNm", "group_name", "hideFamilyChangeNamePanel", "changeNm", "onFamilyChangeName", "BTN_CLICK_SETOFFER", "openSofPal", "BTN_CLICK_SETLEADER", "openStLdPal", "BTN_CLICK_SETSELFTOLEADER", "upSfToLeader", "hideSoPal", "DATA_SELECT", "onSoffer", "onRelSoff", "btnsetoffer", "hideSLd", "slPal", "onSetRelLead", "ckSltLead", "select1", "select2", "BTN_CLICK_FAMILYSHOPBUY", "onBuyShop", "rfNorShop", "rfOtShop", "rfMLScr", "levFaOk", "gotoGGPal", "lbl_getGx", "setHeroList", "flushHeroSkill", "learnSkill", "btnLearn", "sltSkTap", "onSkDataUp", "fightIntrustion", "rfIntru", "enterBattle", "selecBagItem", "rfBagMem", "rfBagItems", "BTN_CLICK_FAMILYGIVE", "onGvMemItem", "rfRePal", "onRedPakUp", "upRedLogs", "setReds", "grabRedResult", "addSendRedPacPanelListener", "changeBagSelectIndex", "onMove", "gotoSummonFight", "askForHelp", "onSumAR", "copyPanel", "onLookRank", "lbl_lookrank", "onSwapHandler", "btn_swap", "onChall", "refreshRank", "SCZB_DAILYBONUS_GOT", "onHisInfo", "lbl_history", "familSkillUp", "btnGxUp", "btnGzUp", "changeSelecByButton", "onSkillItemClick", "upSkillArrow", "updateSkillDonate", "flushFamilySkill", "flushHDPanel", "updateLoginBtn", "trial", "trialView", "addTrialRule", "TRIAL_PANEL_CHANGE", "trialPanelChange", "ENTER_TRIAL_SCENE", "enterTrialScene", "TRAIL_RESULT", "showTrialResult", "MUTEXT_ALL_ONSTAGE", "mutexOnStage", "TRAIL_SHOW_RWD_SELECT", "showRwdSelect", "TRIAL_MYBUFF_CHANGE", "setTopBuffs", "TRIAL_SCORE_CHANGE", "setTopScore", "TRIAL_SHOW_BUFFS", "showBuffs", "img_swapRed", "isDekaron", "lbl_swap", "k_347", "rankView", "PortRankV", "rankComplete", "port_range_png", "hideRankV", "k_336", "showRedAlert", "showTask", "mainSype", "shopStype", "takStype", "flushSummon", "openCopyPanel", "association_of_fam_bg_jpg", "bagStype", "flushBagPanel", "onOpenBagRecord", "isdonate", "moduleid", "k_326", "k_309", "reqPlayerState", "powerInput", "getItemIndex", "removeItemAt", "k_322", "text1", "text2", "lb1", "k_308", "getStOfVos", "slcOdMem", "k_324", "selectOrder", "k_323", "redPacketCountInputChange", "lbl_all", "redPacketGoldInputChange", "redPacketSend", "btn_give", "doGrabRed", "memberSize", "ORDER_7", "getMeCod", "k_342", "left_time", "k_338", "k_339", "setRedPacketTxt", "k_340", "k_319", "winCopy", "showOtherPanel", "k_220", "setTipVis", "clearChild", "updateBgRed", "checkItemRed", "ckRPRed", "checkGoldRed", "showSkillPanel", "getTaskVos", "FamilyHDVo", "k_1334", "item_30454_png", "k_1335", "k_1336", "\u65f6\u95f4:09:30-22:00(\u534a\u5c0f\u65f6\u4e00\u6b21)", "\u767b\u5f55\u5956\u52b1", "item_11400_png", "\u6bcf\u65e5\u767b\u5f55\u7acb\u5373\u9886\u53d6\u5956\u52b1", "k_357", "\u516c\u4f1a\u8d21\u732e*", "leadername", "fnum", "membercount", "k_304", "k_305", "ORDER_2", "ORDER_5", "cname1", "\u516c\u4f1a\u6539\u540d", "upgrade", "lblProgress", "-/-", "mygx", "myoffer", "left_count", "k_341", "lbl_noItem", "bagIStype", "lbl_myGx", "FamilyShopVo", "10", "disCountIcon", "shop_zhekou", "initSkillSelect", "getSkByHInx", "curSkVo", "element", "skilldesc", "k_353", "#00ff00", "costgx", "skillName", "k_317", "k_318", "setMonster", "changeSummons", "summonBossNew", "rfCopyRed", "skillTabSelect", "getDonateList", "_ghSelectItem", "k_358", "skillNum", "lbl_jidu", "curValue", "k_356", "#FF0000", "costLeftgx", "#00FF00", "costRightgx", "sceneView", "FamilyTrialScene", "FamilyTrialResult", "mutexAllPops", "FamilyTrialBuffBuyAlert", "deleteAllMsg", "FamilyTrialMsg", "setCallBuffCost", "showFamilyChangeNamePanel", "playsNewNameEffect", "chm.FamScreenMed", "FamCpVo", "chm.FamCpVo", "_callEffPool", "_spellsEffs", "playCallEff", "practice_summon_eff", "palyCallComp", "playCallSkill", "playWarSkill", "playSpellsSkill", "playTaoistSkill", "_warEff", "getAngle", "_warEffId", "zhansheng", "fashen", "_taoistEff", "daozun", "FamilyTrialEff", "chm.FamilyTrialEff", "serverDayLmt", "lvlLmt", "vipLmt", "familyLvlLmt", "k_1212", "k_1213", "k_1215", "joinTime", "k_1240", "VO_TrialLimitVO", "chm.VO_TrialLimitVO", "getBuySingleBuffCost", "buySingleBuffCounts", "buySingleBuffCost", "getBuyAllBuffCost", "buyAllBuffCounts", "buyAllBuffCost", "getBuyCallBuffCost", "buyCallBuffCounts", "buyCallBuffCost", "getTotalBuyAllBuffCost", "parseBuffXml", "singleBuffArr", "allBuffArr", "callBuffArr", "negtiveBuffArr", "getBuffByID", "getAddedDebuffProp", "getAddupSingleProp", "getIncHpsProps", "incHps", "VO_TrialBuffVO", "chm.VO_TrialBuffVO", "_myScore", "getWeekResetTm", "scoreReset", "getScoreBonusArr", "scoreBonusArr", "scoreValues", "scoreBonus", "getScoreBonusState", "totalScore", "getDoubleVipLimitVO", "bonusVip", "bonusCost", "VO_TrialScoreVO", "chm.VO_TrialScoreVO", "parsePortXml", "portArr", "getPortDebuffIds", "showBuff", "getAddPortDebuffId", "getPortDebuffDupNums", "getPortMonsterName", "k_1231", "getPortAddupScore", "scoreVictoryBonus", "VO_TrialPortVO", "chm.VO_TrialPortVO", "summonId", "getShenPropByCounts", "familyZhanshenBuff_json", "hurtPercent", "hurtValue", "dogValue", "getCombinedZsIncHpProp", "HP:", "TrialBuffVO", "chm.TrialBuffVO", "itemVictoryBonus", "debuffId", "TrialPortVO", "chm.TrialPortVO", "BAG_ITEM_SELECT_CHANGE", "TRIAL_INFO_CHANGE", "TRIAL_ROUND_CHANGE", "TRIAL_FAMILY_RANK_CHANGE", "TRIAL_BUFF_RANK_CHANGE", "ENTER_NEXT_TRIAL", "BUFF_SELECT_CHANGE", "TRIAL_CALL_TIME_CHANGE", "TRIAL_CALL_END", "TRIAL_DROP_CHANGE", "TRIAL_ENDTIME_CHANGE", "FLUSH_BOX_STATE", "TRIAL_ADD_BUFF", "TRIAL_ADD_DEBUFF", "TRIAL_BUY_BUFF_SUCCESS", "TRIAL_FAMILY_RANK_EFF_ON", "chm.FamilyEvt", "_faCpDic", "curCport", "_bo", "_selectOrder", "_mainStype", "_shopSlType", "_takStype", "_bagStype", "_bagIStype", "getOffer", "FamilyTaskVo", "    ", "SetofferVo", "hascount", "canSelect", "FamilySkillVo", "checkRequstRed", "checkSkillRed", "checkShachengRed", "checkBagRed", "checkTrialRed", "familyCopyDic", "familymagic_json", "monsterid", "portConfig", "firstReward", "propertys", "propertyShow", "_skillTabSelect", "FamDonateVo", "useName", "allcontribution", "main_tabbar_select_change", "shop_tabbar_select_change", "task_tabbar_select_change", "bag_tabbar_select_change", "bag_item_select_change", "ORDER_1", "ORDER_3", "ORDER_4", "ORDER_6", "chm.FamilyMod", "c_2232", "famTrialType", "nowCounts", "getDayLastTmLimit", "setSeconds", "c_2236", "buffVO", "gotoBuy", "getMyBuffBuyCountByID", "scoreVO", "maxBuySingleBuff", "c_2240", "maxBuyAllBuff", "myCallBuffDic", "chm.FamilyTrialAuto", "_posIdx", "_angelArr", "_angels", "_sceneMonsters", "_sceneConjures", "_delayIdDic", "myCallBuffCounts", "buffShowChangeIds", "getTrialXml", "familyCopySetting_json", "getBuffXml", "_buffXml", "familyCopyBuff_json", "getPortXml", "_portXml", "familyCopyConfig_json", "getMaxBuyCount", "maxBuyCounts", "getBuyCostByCount", "buyCountsCost", "_scoreVO", "_buffVO", "scoreIncrease", "SummonCdIncrease", "_limitVO", "serverDays", "familyLevel", "portVO", "_portVO", "getTrialDuration", "maxFightTime", "getMaxRound", "maxRound", "getBonusShow", "client_reward_show", "getMonterXY", "npcBorn", "getPlayerXY", "roleBorn", "getTrialBonusArr", "getTrialDropStr", "dropShow", "myBuffIds", "checkPortDebuff", "checkAddPortDebuff", "initMyPlayer", "heroIds", "copyHeroIds", "\u516c\u4f1a\u8bd5\u7ec3\u521d\u59cb\u5316\u73a9\u5bb6\u5931\u8d25", "getPos", "getMonsterRounds", "getPointByAngel", "checkWalkable", "n_11415", "checkAddzhs", "checkCallSkill", "\u627e\u4e0d\u5230\u653b\u51fb\u8005\uff1a", "\u627e\u4e0d\u5230\u53d7\u51fb\u5bf9\u8c61\uff1a", "seekTargetComplete", "checkDead", "clearDelayDo", "_curDogId", "fromTarget", "familyBuffRank", "_familyBuffRank", "n_2233", "n_2252", "createBuffRole", "setMyBuffBuyCount", "overTime", "setCallBuffTm", "k_1228", "k_1209", "n_2246", "n_2248", "set", "myNormalBuffDic", "setAllBuffBuyCount", "familyAllBuffDic", "onCallBuffCD", "getAllBuffBuyCountByID", "n_2237", "_clearCounts", "clearCounts", "heroInfo", "singleBuff", "familyBuff", "singleBuyAll", "callBuyCounts", "callBuff", "preRun", "addDebuffId", "_monsterRounds", "color", "reqBattle", "c_2238", "n_2231", "_info", "FamilyTrialModel_EnterCountDown", "enterCountDown", "redPoint", "checkTrialActive", "getAddupDrops", "null", "n_2244", "battleState", "roundInfo", "doRightMsg", "single", "k_1238", "pickAllItemComplete", "roundGapCd", "k_1235", "k_1236", "k_1237", "k_1239", "pickupComplete", "familyScoreRank", "_familyScoreRank", "n_2235", "n_2253", "n_11436", "flyTime", "CALL_ZS", "CALL_FS", "CALL_DS", "chm.FamilyTrialModel", "FaBpEui", "FaBoxEui", "FaBRPEui", "FaBREui", "warehouse_title_png", "currentPanel", "FamilyBagV", "chm.FamilyBagV", "FalLstEui", "FaCrtPalEui", "chm.FamilyListV", "FamilyEui", "FalDtPalEui", "FalMLstEui", "FalLstEui2", "SetOfferEui", "SetLeadEui", "EdFaNotEui", "ReqLstEui", "guild_manage_title_png", "curPal", "cname", "stopReqEft", "obtain_effect", "tween1", "tween2", "FamilyMainV", "chm.FamilyMainV", "FamilyTaskV", "FamilyShopV", "FamilySkV", "rpAlert", "RedPacketEui", "FamilyTrialView", "closeHanlder", "backHandler", "guild_challenge_png", "guild_challenging_png", "task_tip", "main_tip", "shop_tip", "skill_tip", "shacheng_tip", "bag_tip", "trial_tip", "chm.FamilyScrnV", "FaSpEui", "FaSpLstEui", "FaSpLstEui1", "guild_shop_title_png", "k_315", "familyshop_loop", "setLeastTime", "chm.FamilyShopV", "FaSkEui", "TabPanel", "FamyGhSklTabPnl", "FamGhSklPnl", "FamilyHorDonPanel", "initHeroList", "imgDI", "guild_skill_title_png", "k_355", "clickHero", "selectHeroByIndex", "currPanel", "chm.FamilySkV", "FaTaskEui", "FaTkLstEui", "FaHdLstEui", "FaCpEui", "guild_task_title_png", "chm.FamilyTaskV", "FamilyTrialResultSkin", "fight_win_png", "setGetTime", "11002", "k_1208", "lastRound", "lbl_scorebuff", "k_1234", "_portState", "k_1202", "getTimeHandler", "chm.FamilyTrialResult", "_oldBuffShowIds", "FamilyTrialSceneSkin", "list_buff", "FamTrialBuffBtn", "list_call", "list_addbuff", "FamTrlBuffShow", "list_decbuff", "shiftBuffType", "btn_shift", "setBuyBuffList", "buff_mode_1_png", "buff_mode_2_png", "checkDiffs", "k_1205", "lbl_callCost", "\u514d\u8d39", "trialscenecountdown", "doCount", "clearCountDown", "k_1221", "k_1206", "lbl_leftTm", "grp_left", "grp_center", "grp_top", "chm.FamilyTrialScene", "trialPnl", "FamilyTrialPanel", "rankPnl", "FamilyTrialRankPanel", "buffPnl", "FamilyTrialBuffPanel", "buffs", "FamilyTrialBuffs", "rwdSelect", "FamilyTrialRwdSelect", "guild_practice_title_png", "guild_scorerank_title_png", "guild_buff_title_png", "currentPnl", "chm.FamilyTrialView", "AlertIconSkin", "chm.RedPacketEui", "onSelect", "itemGrid", "chm.FamBagBoxRd", "onBtnClick", "lbl_detail", "CLICK_LOOK", "useOrderId", "k_328", "targetOrderId", "lbl_send", "k_329", "k_330", "red_log_click_look", "chm.FamBulRd", "onHandClick", "lbl_hand", "isCheckShow", "k_1662", "lblreward", "leftcount", "lblDesc", "imgState", "hd_btn_click", "chm.FamHLRd", "btn_requst", "k_295", "lname", "findex", "fsize", "needCheck", "k_296", "k_297", "k_312", "ButtonType11Skin", "k_313", "ButtonType1Skin", "btn_click_requst", "chm.FamIfLiRd", "chm.FamilyHDVo", "chm.FamilyShopVo", "chm.FamilySkillVo", "chm.FamilyTaskVo", "stopShake", "shake", "FamilyTrialBox", "chm.FamilyTrialBox", "orderId", "k_334", "k_335", "chm.FamRLRd1", "openlimit", "k_310", "k_311", "#B9AB94", "k_316", "quality_img", "btn_click_familyshopbuy", "chm.FamShopLRd", "k_327", "\u6350\u732e", "chm.FamTLRd", "_callEndTm", "FamilyTrialBuffBtnSkin", "img_icon_gray", "buffBuyChange", "callBuffTmChange", "clickBuff", "_gray_png", "clearTimer", "removeBoomEff", "playCd", "callbuffcd", "doFrameCheck", "playBoomEff", "s", "changeGrapics", "_boomEff", "chm.FamTrialBuffBtn", "FamilyTrialBuffRankRenderSkin", "lbl_familyJob", "FamTrlBuffRankRndr", "chm.FamTrlBuffRankRndr", "FamilyTrialBuffRenderSkin", "lbl_gain", "buff_bg_1_jpg", "k_1226", "k_1230", "k_1229", "k_1733", "\u5df2\u53e0\u52a0", "buff_bg_2_jpg", "FamTrlBuffRndr", "chm.FamTrlBuffRndr", "FamTrlBuffRndr2", "chm.FamTrlBuffRndr2", "buffBuySuccess", "FamilyTrialBuffShowSkin", "checkInSameZone", "guild_buff_eff", "guild_debuff_eff", "chm.FamTrlBuffShow", "FamilyTrialRankRenderSkin", "lbl_playName", "lbl_job", "FamTrlRankRndr", "chm.FamTrlRankRndr", "chm.GrFaSkRd", "offername", "chm.MemGxLiRd", "k_306", "k_307", "logouttime", "leavetime", "k_1332", "btn_click_familygive", "chm.MemIfBLRd", "chm.MemILRd", "onBtnClickSetOffer", "btn_setoffer", "onBtnClickKickOut", "btn_kickout", "onBtnClickSetLeader", "btn_setleader", "k_320", "k_321", "btn_click_setoffer", "btn_click_kickout", "btn_click_setleader", "btn_click_setselftoleader", "chm.MemInLRd1", "chm.OtFaIfVo", "btn_yes", "btn_no", "k_314", "btn_click_requst_yes", "btn_click_requst_no", "chm.ReqMLRd", "OnSelect", "data_select", "chm.SetOfferRd", "chm.SetofferVo", "EditFamilyNoticeSkin", "chm.EdFaNotEui", "FamilyBagBoxSkin", "chm.FaBoxEui", "FamilyBagPanelSkin", "chm.FaBpEui", "FamilyBagRecordSkin", "chm.FaBREui", "FamilyBagRedPacSkin", "chm.FaBRPEui", "_lastPort", "_time", "FamilyCopyPanelSkin", "tiaoZhanPanel", "FBTZPnl", "k_343", "timeNumImg", "timeGroup", "img_d1", "mijing_bg1_png", "img_d2", "changeEtype", "btn_challenge", "checkPoint", "lbl_passCount", "k_344", "clearanceCount", "lbl_port", "k_348", "dayMaxCheckPoint", "lbl_higher", "dayMaxPlayerName", "k_1333", "k_346", "maxCheckPoint", "_firstPassGrid", "uimonster", "group_award", "lbl_monsterProp", "k_351", "k_345", "k_349", "familyCopyTime", "onTime", "setTzData", "removeTime", "showTzPal", "hideTzPal", "awardGroup", "chm.FaCpEui", "FamilyCreateSkin", "chm.FaCrtPalEui", "FamilyHDListPanelSkin", "chm.FaHdLstEui", "FamilyDataPanelSkin", "chm.FalDtPalEui", "FamilyListPanelSkin", "chm.FalLstEui", "FamilyListPanel2Skin", "chm.FalLstEui2", "FamilyMemListPanelSkin", "chm.FalMLstEui", "FamilyGhSkillPanelSkin", "chm.FamGhSklPnl", "FamilyPanelSkin", "chm.FamilyEui", "FamilyHorDonSkinPanel", "chm.FamilyHorDonPanel", "FamilyHorDonRenderSkin", "usename", "chm.FamilyHorDonRender", "isShowTip", "isShowScoreTip", "FamilyTrialBuffBuyAlertSkin", "img_buff", "k_1225", "k_1207", "lbl_reset", "costObj", "k_1223", "k_1233", "k_1222", "k_1227", "<font color=\'#12EF07\'>+", "k_1224", "openHandler", "k_1217", "k_861", "grp_container", "chm.FamilyTrialBuffBuyAlert", "FamilyTrialBuffPanelSkin", "familyBuffRankChange", "list_member", "lbl_nobuff", "lbl_nobody", "buffItems", "buffCounts", "chm.FamilyTrialBuffPanel", "TrialPlayerBuffRankVO", "chm.TrialPlayerBuffRankVO", "TrialBuffRankVO", "chm.TrialBuffRankVO", "FamilyTrialBuffsSkin", "list_buff0", "list_buff1", "lbl_nobuff1", "lbl_nobuff2", "set3Id", "chm.FamilyTrialBuffs", "_pool", "FamilyTrialMsg_Loop", "getSingleMsg", "deleteMsg", "chm.FamilyTrialMsg", "FamilyTrialSingleMsgSkin", "_showCon", "k_1232", "FamilyTrialSingleMsg", "chm.FamilyTrialSingleMsg", "_countDownKey", "FamilyTrialPanelLoop", "_buffRankEffKey", "familytrialbuffrankeff", "_buffRankIndex", "FamilyTrialPanelSkin", "guild_practice_bg_jpg", "boxbar", "lbl_familyrank", "k_1194", "k_1195", "k_1204", "buyCopyTime", "offStage", "trialInfoChange", "flushScore", "flushBuffRankEff", "setBonusPreview", "removeCountDown", "removeBtnEffect", "flushEnterCount", "flushCountDown", "k_1200", "k_1196", "doCountDown", "clearBuffBlink", "doBuffBlink", "k_1201", "c_2245", "k_1210", "chm.FamilyTrialPanel", "FamilyTrialRankPanelSkin", "familyRankChange", "list_rank", "c_2234", "k_1199", "lbl_myHistory", "k_1198", "chm.FamilyTrialRankPanel", "FamilyTrialRwdSelectSkin", "btn_single", "btn_double", "lbl_doubleCost", "k_1220", "c_2247", "chm.FamilyTrialRwdSelect", "FamilyGhSkillTabPanelSkin", "chm.FamyGhSklTabPnl", "FamilyScreenSkin", "chm.FaScreenEui", "FamilySkillPanelSkin", "chm.FaSkEui", "FamilyShopPanelSkin", "chm.FaSpEui", "FamilyShopListPanelSkin", "chm.FaSpLstEui", "FamilyShopListPanel1Skin", "chm.FaSpLstEui1", "FamilyTaskPanelSkin", "chm.FaTaskEui", "FamilyTaskListPanelSkin", "chm.FaTkLstEui", "RequstListPanelSkin", "chm.ReqLstEui", "SetLeaderSkin", "chm.SetLeadEui", "SetOfferSkin", "chm.SetOfferEui", "chm.FamDonateVo", "FzMod", "FzViewMed", "FzSubViewMed", "rspFaZhenInfo", "rspFaZhenHc", "getFzInfo", "requestFz", "heroFazhenData", "setRspFzData", "bonusDatas", "chm.FzModule", "FaZhenViewMediator", "lenNum", "renderH", "_mWindow", "_faZhenTab", "FzTabView", "_faZhenUpView", "FzUpView", "_faZhenAwakeView", "FzAwakeView", "_faZhenCompView", "FzCompView", "_tipPanl", "FzTip", "heTipPanel", "_tabBar", "fazhen_bigtitle_png", "k_1241", "heroList_ui", "changeHeroSelect", "getIdBySelect", "setheroList", "initTabReds", "ItemInfo", "updateHeroList", "heroUpReds", "heroLwReds", "upRed", "awakeRed", "hcRed", "fillHeroList", "showFzBarPal", "btn_return", "showEyeTip", "hideEyeTip", "jiHuoSucc", "itemCheck", "showRwdAlert", "createNewRole", "upTabReds", "lwTabReds", "hcReds", "hidPal", "fazhen_bg2_jpg", "fazhen_bg3_jpg", "_curPal", "getFZInfo", "zyIndex", "fzeff", "fzname", "upAllReds", "chm.FzSubViewMed", "_faZhenBarView", "FzBarView", "FzItem", "heroBarReds", "updateFZlist", "itemClick", "chm.FzViewMed", "_heroInfo", "baihu", "qinglong", "zhuque", "xuanwu", "zijing", "_names", "\u767d\u864e\u6cd5\u9635", "\u9752\u9f99\u6cd5\u9635", "\u6731\u96c0\u6cd5\u9635", "\u7384\u6b66\u6cd5\u9635", "\u706b\u96e8\u6cd5\u9635", "\u51b0\u6676\u6cd5\u9635", "specEffDic", "_zyUpIndex", "_heroReds", "redsByType", "lwsByType", "barReds", "_lwDic", "lwIcons", "_lwZzDic", "_fzUpDic", "_upParamDic", "_zyInfoDic", "_zyShowDic", "fzUpParseXml", "lwParseXml", "zyInfoXml", "zzInfoXml", "fazhenlingwuUpLvParam_json", "_lwMaxLen", "getTzXml", "fazhenSetting_json", "featurename", "fazhenLevelDatas", "fazhenId", "FaZhenVo", "getFzUpInfo", "zyShowFig", "lwIds", "lingwu", "fzActCost", "base", "costItem", "costParam", "featureParam", "range", "zhenyanId", "zySkill", "zyCost", "zyEffct", "effectType", "zyParam", "effectParam", "fazhen_title_", "fzlvl", "fzId", "fzUpInfoByCof", "FaZhenUpVo", "getLwSLvl", "getlwAdd", "getUpLimit", "getUpParamInfo", "tzLvl", "getTzLvl", "sxStr", "getLWInfo", "fazhenLingwuDatas", "getNxtTzLvl", "isFzMax", "isLwMax", "getlwMax", "getzyInfos", "FaZhenAwkVo", "zySkillId", "getTipDes", "nxtStr", "curStr", "{rate}", "{fixed}", "{effectRate}", "getSpecEff", "{effect}", "fazhenzhenyanParam_json", "getHcList", "fazhenhecheng_json", "FaZhenComVo", "isfirst", "issecond", "isthird", "getHeroFight", "getLwInfo", "propParam", "getLwZzParse", "propPercent", "getFzLvl", "getZyLvl", "zhenyanLevel", "tabBarReds", "_tabBarReds", "_heroUpReds", "_heroLwReds", "_heroBarReds", "fzUpReds", "fzLwReds", "getlwCost", "getZyUpReds", "fazhenlingwuUpLvShow_json", "fazhenUpLvShow_json", "fazhenUpLvParam_json", "fazhenpassiveShow_json", "getlwByConf", "getLwEffect", "getlwLimit", "k_1257", "k_1256", "effectParam1", "effectParam2", "effectSpecial", "fazhenzhenyanShow_json", "chm.FzModel", "_isHas", "img_icon1", "k_1254", "k_1247", "k_139", "c_4203", "FzComRder", "chm.FzComRder", "FaZhenItemSkin", "effY", "k_1261", "k_1260", "chm.FzItem", "_eyeLvl", "_upItemIndex", "upIndex", "_upEff", "FaZhenAwakeViewSkin", "lwUpLvls", "btn_up", "fazhen_stitle_", "fzinfo", "_heroId", "nxtUpId", "nxtLvl", "_lvls", "k_1244", "k_1243", "costid", "lbl_nxt", "lbl_max", "lbl_cur", "k_1262", "zytotal", "lbl_eDes", "k_1249", "img_s", "lwlvls", "playerEff", "grp4", "grp5", "lbl_jihuo", "k_1252", "lbl_prop1", "sx_cur", "k_1250", "k_1253", "k_1251", "c_4202", "hideBox", "playFigureEffSucess", "chm.FzAwakeView", "FaZhenBarViewSkin", "chm.FzBarView", "FaZhenCompViewSkin", "chm.FzCompView", "FaZhenTabViewSkin", "chm.FzTabView", "FaZhenEyeTipSkin", "k_1242", "zyUpClick", "updatePal", "_counts", "fzInfo", "_fzLvl", "grp_nxt", "grp_up", "k_1255", "img_costIcon", "c_4201", "chm.FzTip", "tzLvls", "pName", "_tipName", "\u94dc\u76ae\u94c1\u9aa8", "\u5e7d\u9b42\u4e4b\u4f53", "\u55dc\u8840\u72c2\u653b", "\u5de8\u4eba\u8840\u8109", "FaZhenUpViewSkin", "initHeroFightNum", "showTzTip", "hideTzTip", "upClick", "btn_study", "fightNum_hero", "heroPropDataChange", "_fzid", "_heroid", "_itemIndex", "img_eye", "fazhen_zhenyan_", "fzLvl", "zyLvl", "lbl_eyeLvl", "img_tz", "lbl_tzLvl", "k_1259", "grp_count", "img_zyRed", "pdefPercentLv", "grp0", "sdefPerentLv", "attPercentLv", "hpPercentLv", "lbl_lvl1", "lb_jiho1", "jiban_bg", "k_1258", "lbl_name2", "lbl_lvl2", "lb_jiho2", "k_1245", "lb2", "chm.FzUpView", "chm.FaZhenAwkVo", "chm.FaZhenComVo", "chm.FaZhenUpVo", "chm.FaZhenVo", "dropArr", "FightRMed", "showzsP", "allLvlInfo", "splitDrops", "cfgID", "configID", "otherData", "qmType", "quanminType", "tarId", "reqEnMoInfo", "setLoseData", "setLoseGetTime", "setWinlbl", "setZSData", "setzsGetTime", "zsobj", "setZSpaneltxt", "BonusData", "rspEnMoInfo", "otherInfo", "selfInfo", "chm.FightRMdu", "FightRV", "removeWinPnl", "winP", "removeLosePnl", "loseP", "removezsPanelAndLoop", "zsP", "FUNC_CLICK_CLOSE", "gotoHouban", "fight_loss_png", "lbl_reward", "\u5171\u51fb\u8d25", "\u540d\u9556\u5e08,\u88ab", "\u516c\u4f1a", "\u51fb\u8d25", "\u51fb\u7834\u9556\u8f66\u5956\u52b1\uff1a", "k_360", "k_365", "k_366", "k_361", "k_362", "showWinP", "fight_jipo_png", "winRwdGrids", "k_363", "lbl_kill", "k_364", "win_reward", "zs_reward", "zswinTime", "lose_reward", "hideWinP", "resetPlayerPos", "showLoseP", "clearLoseArr", "\u88ab", "\u83b7\u5f97\u5956\u52b1\u5982\u4e0b\uff1a", "setIfShowAwd", "groupReward", "addReward", "_losegetTxt", "k_368", "loseTimeHandler", "hideLoseP", "hidezsP", "chm.FightRMed", "_functId", "FightWinP", "FightLoseP", "ZSWinP", "loseRwdGrids", "setPvpListShow", "setPveListShow", "func_click_close", "chm.FightRV", "FightLosePanelSkin", "getWayClk", "btn_get2", "getWayClk2", "btnFirst", "grp_sd", "img_s_bg", "img_des2", "img_s_bg2", "shibai_shouchong_jpg", "_tz", "30:0", "grp_des2", "shibai_huoban_jpg", "_tz2", "5:0", "groupStrong", "FPveLoseRender", "strongerway_json", "----------\u5206\u4eab\u6b21\u6570---------", "shareNumber", "tui", "FPvpLoseRender", "vals", "vale", "addBtnEff", "chm.FightLoseP", "FightWinPanelSkin", "chm.FightWinP", "FightPveLoseRenderSkin", "img_tui", "_shareNumber", "chm.FPveLoseRender", "FightPvpLoseRenderSkin", "lbl_vale", "\u654c\u4eba:", "lbl_vals", "\u6211:", "\u654c\u4eba:Lv.", "\u6211:Lv.", "img_proge", "img_progs", "chm.FPvpLoseRender", "ZhuanshengWinPanelSkin", "chm.ZSWinP", "ForgeMed", "mutexHidePanel", "lvlChange", "fulinDecoCk", "3_0", "fulingDecoArr", "equStrong", "equStone", "equipSoul", "equFulin", "fulinDeco", "chm.ForgeMdu", "touchNum", "suitNum", "isSuit", "_stoneRenderArr", "ForgeV", "forge_duanzao_png", "addEvent2", "seleT", "funcTap1", "forgePnl", "getWayTap", "forgeAlert", "btn_fulinDecompose", "decoFulinEqu", "grp_btn", "TOUCH_RELEASE_OUTSIDE", "clickType", "addNum", "firstTouch", "rfForgeGridLi", "setCostInfo", "TABBAR_SELE_CHG", "STRONG_RED_CHG", "setStrongRed", "STONE_RED_CHG", "setStoneRed", "SOUL_RED_CHG", "setSoulRed", "FULIN_RED_CHG", "setFulinRed", "HERO_RED_CHG", "setHeroLiRed", "playEff3", "playEff2", "removeEvent2", "funcTap", "getCurrCostData", "itemID", "ckFulinLmt", "boOpen", "rlvlLimit", "k_1338", "k_1339", "firstNum", "onTouchClick", "seleHeroIdx", "img_forgeBg", "forge_bor2_jpg", "showFulinTab", "hideFulinTab", "stopPlayEff", "rfHeroLi", "setForgeGridLi", "circleGrids", "setForgeCost", "setStrongPnl", "enhanceNum", "enhancePnl", "groupMove", "setStonePnl", "stoneNum", "stonePnl", "setIfMax", "lblMax", "groupCost", "setSoulPnl", "soulPnl", "setFulinPnl", "fulinNum", "fulinPnl", "group_fulinDecompose", "eff0Show", "k_1340", "fillAlertContent", "getForgeArrByHT", "selePos", "setFightNum", "checkIfMax", "getStrongFihgtNum", "getStrongData", "currAttri", "nextAttri", "getStoneFihgtNum", "getStoneData", "getSoulFihgtNum", "getSoulData", "getFulinFightNum", "getFulinData", "getStrongCost", "getStoneCost", "getFulinCost", "strongRed", "stoneRed", "soulRed", "fulinRed", "chm.ForgeMed", "_enhanceDic", "_stoneDic", "_souleDic", "pEnhance", "pStone", "pSoul", "equipenhance_json", "stone_json", "equipsoul_json", "getEquIdByJP", "hero_json", "getStoneIdByJP", "getSoulIdByJP", "getEquNextId", "getSoulNextId", "getStoneEleByIdLv", "getStoneNameById", "getStonePropByIdLvl", "getEquCostByLvl", "equipenhancecost_json", "getStoneCostByLvl", "stonecost_json", "getSoulCostByLvl", "equipsoulcost_json", "getStoneLvlById", "fulinDic", "_fulinDic", "equipfuling_json", "ForgeFulinSglLvVo", "costStr", "getFulinNextKey", "chm.ForgeCFGMod", "GridIcon", "Forge", "_seleT", "ckHeroRed", "_selePos", "_strongRed", "_stoneRed", "_soulRed", "_fulinRed", "ckStrongRed", "ckStoneRed", "ckSoulRed", "ckFulinRed", "getIdByType", "getLvlByType", "getLvlStrByType", "getSelectPos", "STONE_ROUND", "checkGemLevel", "ForgeStoneRndVo", "StoneIcon", "GridLvlStr", "0_", "lvlLimit", "tabbar_sele_chg", "strong_red_chg", "stone_red_chg", "soul_red_chg", "hero_red_chg", "fulin_red_chg", "chm.ForgeMod", "chm.ForgeStatic", "showFulin", "_nums", "_nums2", "panelShowCheck", "ForgePnl", "ForgeStone", "ForgeFulin", "ForgeSoul", "ForgeEnhance", "ForgeAlert", "upBtn", "UpBtn", "eff1", "k_5", "ctForgeGrids", "initHeroLi", "tapHero", "decoBtnShowCk", "checkVip", "grp_vip", "groupAttri", "k_374", "k_375", "lbl_vip", "GrirdPos", "_aliveDelay", "aliveFunc", "playEff1", "img_chuizi", "_tabEff", "playTab", "_tabEff1", "_hcEff", "duanzao_eff", "_eff2", "playeff2", "playeff", "groupSuccess", "enhance_success", "playEffCp1", "effect1", "zhuling_effect", "playEffCp2", "stop1", "stop2", "chm.ForgeV", "ForgeStoneRenderSkin", "lblAttri", "k_372", "chm.ForgeStoneRnd", "chm.ForgeStoneRndVo", "ForgeAlertSkin", "chm.ForgeAlert", "ForgeEnhanceSkin", "chm.ForgeEnhance", "ForgeFulinSkin", "chm.ForgeFulin", "ForgePanelSkin", "chm.ForgePnl", "ForgeSoulSkin", "chm.ForgeSoul", "ForgeStoneSkin", "chm.ForgeStone", "chm.UpBtn", "chm.ForgeFulinSglLvVo", "CTGMed", "FBTZV", "getFbtData", "getData4Rank", "isStage", "tgV", "img_ChuangTianGuanBg", "zeta_tauri_bg_jpg", "askForCopyinfo", "showrank", "hideBubble", "rankV", "winForFight", "rankChange", "lookLbl", "GoTofight", "ranklimt", "askForRankInfo", "curPortID", "askForMainCopy", "setTiaozhanData", "chm.CTGMed", "FubenCailiaoViewMediator", "FBCLV", "play_copytitle_png", "cailiaoFight", "clArr", "clPnl", "isfight", "isCost", "FBCLMed", "chm.FBCLMed", "autoType", "autoData", "_clMed", "_tzMed", "shutDown", "rspcopyInfo", "rspRankInfo", "copyWin", "ckVipUp", "chgEnter", "clFight", "handupInfo", "resetStatus", "MATERIALCOUNT", "caiLiaoFight", "chuangtianguanFight", "checkTiLi", "copyEnergy", "copyType", "fightType", "operateType", "scene", "getRank", "chm.FubenMdu", "_suprCopyCount", "vip_json", "MATERIALFREE", "getSaodangCost", "copycomuse_json", "UIMonsterr", "getCopyMaterialCount", "getFBOpenLmt", "22", "getSuprCopyCount", "privilegecardCopy_json", "getSuprCopyAwardPre", "showitems", "privilegecardsetting_json", "chm.FubenCfgMod", "_isRed", "stCost", "stconsume", "stRate", "geCLFBCost", "getCLData", "disRedEvt", "getCLOpen", "getFBCLVO", "vipfightNum", "sdNum", "maxCopyRareId", "tzVo", "getFBTZVo", "tzArr", "port_tiaozhan_json", "FBTZVO", "minport", "maxport", "getTZB", "getvipNum", "getFBPortVO", "FBPortVO", "bouns", "getID", "copymaterial_json", "moneyconsume", "saodangconsume", "FBCLVO", "nameIcon", "fuben_baoshi_png", "fuben_jingmai_png", "fuben_hudun_png", "fuben_longhun_png", "fuben_chengjiu_png", "copymateriallvl_json", "ownRank", "getFot3", "k_584", "--", "rankconfig_json", "9", "Clientlimit", "getSuprDrops", "_bonusAwardDic", "getSuprBonusArr", "_bonusStrArrDic", "chm.FubenMod", "BossDialogeBublleSkin", "BossDlgBle", "chm.BossDlgBle", "moArr", "CTGPnl", "zeta_tauri_title_png", "CT", "k_380", "imgPass", "CTGV", "chm.CTGV", "FBPnl", "FBCLPnl", "FBCLRnd", "tab_cailiao", "tab_tiaozhan", "chm.FBCLV", "sele", "FBSDTip", "chm.FBSDTipV", "chm.FBSDTipMed", "tzP", "_timeNum", "_bossDlg", "btnChallenge", "showBubble", "lbl_rank1", "lbl_rank2", "lbl_rank3", "chuangtianguanTiem", "chm.FBTZV", "8601", "costMoney", "k_377", "lbl_limit", "k_385", "k_376", "k_379", "k_382", "chm.FBCLRnd", "ChuangTianguanSkin", "chm.CTGPnl", "FubenCailiaoSkin", "chm.FBCLPnl", "FubenPanelSkin", "chm.FBPnl", "FubenSaodangTipSkin", "chm.FBSDTip", "FubenNewTiaozhanSkin", "chm.FBTZPnl", "chm.FBCLVO", "chm.FBPortVO", "chm.FBTZVO", "FunNoticeMed", "FunNoticeMod", "onredChange", "checkbtn", "boDelFunMainbtn", "c_4703", "chm.FunNoticeMdu", "funPanl", "FunNoticePnl", "skillpart", "tipP", "CBJNTipPnl2", "_shape1", "closeTip", "showSkillTips", "upateBtnstate", "setBtnstate", "getPsvDes", "k_744", "initList", "getmduIdx", "setIdx", "setIdxLoction", "chm.FunNoticeMed", "limitDay", "fundes", "imgres", "FuninfoVo", "chm.FuninfoVo", "_funsDic", "_funsArr", "funsParseXml", "functionprediction_json", "funsArr", "getFunVobyID", "FunNoticeCfg", "chm.FunNoticeCfg", "funDic", "n_4702", "funinfos", "functionId", "gethasRwd", "getRedPoint", "getLeftRed", "getRightRed", "chm.FunNoticeMod", "sillGrids", "grop_grid", "FunGridEui", "setinfo", "NoticeRender", "chm.NoticeRender", "FunGridSkin", "tipsClick", "skillinfo", "getSkill", "god_yu_icon2_png", "chm.FunGridEui", "nstarPos", "funNum", "FunNoticePnlSkin", "nItemWith", "onRvmStage", "scrll", "CHANGE_END", "onMoveEnd", "CHANGE_START", "onstartMove", "onMoveChange", "getRwdClk", "gridItem", "stopAnimation", "c_4701", "idxImgs", "imgrop", "moveIdxLoction", "updateFuseArrow", "setNowValue", "setSelectImage", "yg_bg2_png", "yg_bg3_png", "grop_rwd", "#0cff1d", "#ff1212", "lab_con1", "k_1535", "lab_con2", "k_1536", "lab_fundes", "img_tile", "img_rwdState", "img_btntile", "chm.FunNoticePnl", "GWMed", "GWMod", "chm.GWMdu", "_itemIds", "btnClose1", "RENDER_CLICK", "GWRed", "GETWAY_SHOW", "fillP", "pc", "sGrid", "sList", "groupList", "imgInside", "imgOutSide", "p_y", "sTGrid", "sData", "sTList", "tp_y", "getWayList", "specialSetting", "item_11908_png", "chm.GWMed", "GWRVo", "moduleVo", "getway_show", "chm.GWMod", "GWPan", "GWTPan", "chm.GWV", "GetWayRenderSkin", "euiCom", "rfData", "chm.GWRed", "chm.GWRVo", "GetWayPanelSkin", "chm.GWPan", "GetWayType1PanelSkin", "chm.GWTPan", "_guideV", "_outDealy", "_guaqiaIds", "_lvIds", "_delayGotoStep", "GuideMod", "checkGuide", "lvlchage", "_curVo", "currentNode", "MainbuttonEuiView_button", "GuideRegist", "guideObj", "main_guaji_btn", "main_btn_guanqia", "main_btn_zidong", "gotoStep", "startGuideByLv", "compOk", "completeTarget", "completeDo", "compOk1", "startGdt", "sendPlatreported", "getBeginVo", "startGt", "guideid", "beginDo", "TaskView", "getGuideVo", "\u68c0\u6d4b\u5230\u6709\u89e6\u53d1\u6761\u4ef6\u5374\u6ca1\u6709\u65b0\u624b\u6b65\u9aa4\u7684\u62a5\u9519", "onEnterCity", "showGuidV", "GuideView", "showView", "hideView", "hideGuidV", "isShowMask", "_guideMask", "chm.Guide", "_enterPort", "_beginList", "_guideList", "readGuideXml", "enterPort", "guide_json", "beginList", "BeginVo", "guide", "GuideVO", "nodeArr", "iscom", "node", "GuideNodeVO", "fillNodeVo", "setp", "direction", "chm.GuideMod", "regist", "_objDic", "deleteObj", "MainbuttonEuiView_button_", "PortMainPanelView", "PortMainPanelView_btn_fight", "OpenGuajiView", "guaji_startBtn", "RoleView_hero_btn_changeEquip", "RoleView_panel_btn_back", "NpcDialogeView", "dialogeView_getBtn", "main_btn_share", "main_btn_Skill", "main_btn_skill", "chm.GuideRegist", "COMPTYPE_CLICK", "COMPTYPE_CLOSE", "COMPTYPE_OPENVIEW", "GuideTool", "chm.GuideTool", "GuideInfoSkin", "GuideEui", "chm.GuideEui", "hollowObjetArr", "bgAlpha", "hollowX", "hollowY", "hollowWidth", "hollowHeight", "reInit", "hollow", "GuideMask", "chm.GuideMask", "_guideFrameName", "GuideView_frame", "_guidEft", "_guideNode", "moduleClick", "onFrameLoop", "k_1343", "txt_des", "guide_effect", "doTween", "doTween2", "chm.GuideView", "chm.BeginVo", "chm.GuideNodeVO", "getNodeVo", "chm.GuideVO", "HefuActivityModule", "HfMed", "HfMod", "aEvtLsn", "aLot", "hidePnl", "aGrwd", "rGrwd", "rLotSuc", "rLogs", "rSifs", "onClear", "gabtns", "updDt", "updActs", "sLotrst", "aGrwd1", "aLogs", "aSifs", "aHfRk", "updSif", "chm.HfMdu", "pClassD", "pnlD", "dClsD", "desD", "wdPnl", "HfMPnl", "rkPnl", "HfRkPnl", "flush", "hRkPnl", "rstLst", "activity_hefu_title_png", "activity_hefu_bg2_png", "activity_hefu_bg_jpg", "itmTap", "lftImg", "rgtImg", "scrl", "HF_LGN_REQ", "HfLgnPnl", "aHfRwd", "SHW_CRK", "HfCrkPnl", "sRkPnl", "OP_RF", "rfPnl", "HF_SP_SLT", "HfDD", "reSltShop", "HF_SIF_REQ", "HfSPnl", "aSif", "updRk", "HfDPnl", "sltId", "2018-11-30 0:0:0", "HEFU_LOGIN_REWARD_NEW", "HfStt", "HF_LR", "getById", "sSltAct", "gOpIdx", "sBtnLst", "updArw", "cltkey", "rgDes", "cDes", "rgSub", "cSubPnl", "HfLgnD", "loginDay", "HfSD", "sandyCity", "HfXbD", "limitShop", "HfP4D", "collectFontShop", "HfP3D", "sevenRecharge", "titleRecharge", "HfBD", "bossPoint", "HfD", "HF_S", "HF_XB", "HF_DB", "HEFU_DISCOUNTBAG_NEW2", "HF_SP", "HEFU_SHOP_NEW2", "HF_DRCG", "HEFU_DAILYRECHARGE_NEW", "HEFU_DAILYRECHARGE_NEW2", "HF_CRCG", "HEFU_CONSTANTRECHARGE_NEW", "HEFU_CONSTANTRECHARGE_NEW2", "HF_BS", "HF_DR", "HEFU_VIP", "grpDes", "HfXbPnl", "HfDrPnl", "goldConsume", "HfShpPnl", "HfBPnl", "HfCrPnl", "HfDbrPnl", "HF_CRK", "HEFU_CONSUMERANK_NEW", "HfActVIPPanel", "grpCtt", "pnlbg", "playLeftEff", "removeArwEff", "playRightEff", "stime", "lftEff", "rgtEff", "hf_op_rf", "chm.HfMed", "lbck", "prg", "lobck", "ltck", "libck", "myVal", "svrPrg", "lck", "subTgt", "HfCk", "chm.HfCk", "_stime", "initHf", "btnDic", "hfDic", "rplDic", "btnLst", "getAll", "cBtnVo", "cAct", "HfBtnVo", "boAlv", "HfActVo", "altt", "drst", "cSVo", "rks", "cRkvo", "mergerTime", "mergt", "actGrp", "HfSvo", "HfRkVo", "rwdstr", "rkHead", "glgrwd", "getReplaceIdByHfCount", "updAct", "updBvo", "updataChangeHefuActivitys", "updck", "startt", "endt", "rkVals", "2019-2-23 0:0:0", "2019-3-2 0:0:0", "2019-5-25 0:0:0", "_sltId", "glogs", "gLotsh", "lShObj", "_rst", "gLotRst", "chm.HfMod", "chm.HfStt", "HefuActivityMainPanelSkin", "chm.HfMPnl", "HefuActivityBossDesSkin", "rData", "chm.HfBD", "HefuActivityDesSkin", "lbl_desHead", "lbl_timeHead", "chm.HfD", "oSlt", "sltIdx", "o", "hf_sp_slt", "chm.HfDD", "HefuActivityLoginRewardDesSkin", "chm.HfLgnD", "HefuActivityPay3DesSkin", "k_398", "k_403", "k_1063", "chm.HfP3D", "HefuActivityPay4DesSkin", "group_itemNum", "k_1066", "chm.HfP4D", "HefuActivityShachengDesSkin", "chm.HfSD", "HefuActivityXunbaoDesSkin", "chm.HfXbD", "HefuActivityVIPPanelSkin", "HefuActivityVipBtnRender", "_listPane", "onRemoveFromStage", "_getBtn", "firstBuyIndex", "imgShowTitle", "vip_ads_", "vip_showpic_", "vip_showname_", "imgAlreadyGet", " VIP", "\u793c\u5305", "buyHefuActivityVip", "chm.HfActVIPPanel", "HefuActivityBossPanelSkin", "hLayout0", "hLayout1", "sDt", "fib", "k_64", "hefuactivitybosslist1", "sKey", "chm.HfBPnl", "gArr", "HefuActivityConsumeRankPanelSkin", "list_otherRank", "HfCrkR", "oAdd", "oRmv", "ckRk", "lbl_firstName", "lbl_firstSpent", "sRwdDt", "tgtName", "tgtVal", "k_401", "group_topRank", "shw_crk", "chm.HfCrkPnl", "HefuActivityConstantRechargePanelSkin", "HfR1", "chm.HfCrPnl", "HefuActivityDoubleRechargePanelSkin", "btn_pay", "k_1062", "chm.HfDbrPnl", "HefuActivityDiscountBagPanelSkin", "chm.HfDPnl", "HefuActivityDailyRechargePanelSkin", "chm.HfDrPnl", "dIdx", "HefuActivityLoginRewardPanelSkin", "crtDay", "btnDs", "btn_day1", "btn_day2", "btn_day3", "btn_day4", "btn_day5", "btn_day6", "btn_day7", "imgRs", "img_received1", "img_received2", "img_received3", "img_received4", "img_received5", "img_received6", "img_received7", "onRwv", "_crtDay", "activity_hefu_bg3_png", "activity_hefu_bg5_png", "hf_lgn_req", "chm.HfLgnPnl", "HefuActivityRankListPanelSkin", "k_400", "rkVal", "HfRkR", "chm.HfRkPnl", "HefuActivityShopPanelSkin", "HfR3", "chm.HfShpPnl", "HefuActivityShachengPanelSkin", "list2", "HfR2", "opSMdu", "fStime", "gTmstr", "gf_sif_req", "chm.HfSPnl", "_sV", "HefuActivityXunbaoBagSkin", "DepotRed", "a1", "aAll", "fDlst", "getDepotList", "LotteryMod", "HfXbBPnl", "chm.HfXbBPnl", "lTyp", "rArr", "HefuActivityXunbaoPanelSkin", "rPnl", "LottRPan", "lblOnePrice", "getOneCost", "lblTenPrice", "getTenCost", "initS", "fRst", "fLogs", "btnOne", "btnTen", "btn_bag", "clsRst", "oRClk", "group7", "group8", "updateCostItem", "getCostItemId", "ck1", "ck10", "sRlst", "sRstC", "sRstT", "sRstL", "shRst", "k_438", "hefuOneBuy", "k_439", "hefuTenBuy", "ctime", "oClsRst", "hdRst", "shp", "lblItemCost0", "lblItemCost1", "chm.HfXbPnl", "HefuActivityVipBtnRenderSkin", "vip_btnicon_", "vip_btnname_", "imgFocus", "chm.HefuActivityVipBtnRender", "cComp", "HefuActivityConsumeRankRenderSkin2", "HfRwdR", "lbl_rankname", "chm.HfCrkR", "HefuActivityRender1Skin", "k_1047", "k_1048", "chm.HfR1", "HefuActivityRender2Skin", "chm.HfR2", "HefuActivityRender3Skin", "chm.HfR3", "HefuActivityRankInfoRenderSkin", "HfRwdR2", "chm.HfRkR", "rmvRwd", "HefuRewardRenderSkin", "chm.HfRwdR", "chm.HfRwdR2", "chm.HfActVo", "chm.HfBtnVo", "chm.HfRkVo", "chm.HfRvo", "chm.HfSvo", "HBViewMediator", "openData", "chm.HBModule", "_HBPanel", "HBSysPanel", "_HBGetPanel", "HBSingleRwdPanel", "_hbSendPanel", "HbSendPanel", "_HbChoose", "HbChoose", "_HbGetShow", "HbGetShow", "_HbLog", "HbLog", "_HbBonusShowPanel", "HbBonusShowPanel", "shape1", "getRule", "btn_rule", "hideRulePael", "removeAllPop", "k_1265", "chm.HBViewMediator", "HBVo", "chm.HBVo", "getSingleState", "_singleRedId", "_singleRedTmDic", "singleRedTms", "_sysHBTotalTm", "_singleHBTotalTm", "_infos", "lowNum", "hightNum", "lowGold", "hightGold", "singleRedLimit", "onLogin", "getMaxLen", "_hbRain", "HBRain", "c_2066", "c_2058", "n_2063", "\u9886\u53d6\u7cfb\u7edf\u8282\u65e5\u7ea2\u5305\u6210\u529f command: 2063", "n_2067", "onSysRed", "n_2064", "n_2065", "getLengerndarIds", "bonus2", "checkIfSingleRed", "singleInfo", "n_2055", "n_2057", "getSingleRed", "\u8de8\u670d\u6c99\u57ce\u73a9\u6cd5\u65e0\u6cd5\u9886\u53d6\uff01", "c_2061", "n_2070", "\u6b21\u70b9\u51fb\u7ea2\u5305\u9886\u53d6\u8282\u65e5\u7ea2\u5305\u6210\u529f command: 2070", "n_2073", "\u53d1\u9001\u8282\u65e5\u7ea2\u5305\u6210\u529f command: 2071", "destory", "onSingleRed", "singleRedRuBao", "n_2072", "destoryTime", "n_2069", "redPacketLogs", "getSysHBTotalTm", "promotionRedPacketSetting_json", "getSingleHBTotalTm", "singleRedPersistTime", "getInfoByFig", "Systext", "Sys_redpocket_client_json", "singleRedTakeTimes1", "singleRedTakeTimes2", "singleRedTGold1", "singleRedTGold2", "chm.HBModel", "showbonus1", "bonus1", "showbonus2", "RedPacketVo", "chm.RedPacketVo", "FstHbPanelSkin", "isGridOff", "previewBonus", "img_bonusPreview", "showLog", "img_log", "gift_banner_1_xcx_jpg", "gift_banner_2_xcx_jpg", "gift_banner_1_jpg", "gift_banner_2_jpg", "showId", "k_959", "lbl_leftnum", "grp_cells", "k_1269", "timestamp", "chm.FstHbPanel", "k_1273", "k_1274", "chm.HbBonusShowPanel", "createImg", "_countLbl", "cntChange", "gift_num_icon_png", "_img1", "_img2", "_img3", "chm.HBBtn", "tags", "HbChooseSkin", "gift_bg_3_png", "img_titile", "img_choose1", "gift_choosebg_1_jpg", "img_choose2", "gift_choosebg_2_jpg", "img_choose3", "gift_choosebg_3_jpg", "getRedPakect", "btn_get3", "hideTags", "gift_tag_png", "c_2056", "chm.HbChoose", "speakerIndex", "soundKey", "HbGetShowSkin", "gift_getwish_bg_png", "nickname", "Singletext", "\u4eb2\u7231\u7684\u73a9\u5bb6\u7238\u7238: ", "dialogue", "role_wish_5", "lbl_begin", "lbl_content", "lbl_end", "k_1271", "lbl_from", "k_1272", "lengendaryIcon", "playSpeaker", "img_speaker", "speaker_1_png", "hbgetshow_speaker", "speaker_2_png", "chm.HbGetShow", "HbLogSkin", "gift_bg_4_png", "list_log", "HbLogRender", "chm.HbLog", "HbLogRenderSkin", "gift_head_", "k_1270", "senderName", "hours", "minutes", "seconds", "chm.HbLogRender", "_sysHBImgs", "_singleHBPoolImgs", "_singleHBId", "_downIndex", "_clearTimd", "_imgIdx", "_clearSing", "singleIdx", "onClkSysHB", "sys_gift_icon_png", "setSysShake", "clearAllTween", "removeSysHB", "c_2062", "player_gift_icon_png", "onClkSingleHB", "setSingleShake", "clearSingleTween", "onSingleDown", "tempId", "removeSingleHB", "chm.HBRain", "HBImg", "chm.HBImg", "HbSendPanelSkin", "gift_bg_1_png", "sendRedPockect", "FOCUS_IN", "FocusEvent", "showTishi", "FOCUS_OUT", "hideTishi", "lbl_tishi", "k_1266", "c_2060", "chm.HbSendPanel", "HBSingleRwdSkin", "HBSysGetRder", "gift_num_{0}_png", "grp_num", "lbl_myCount", "k_1275", "lbl_bless", "isBest", "k_1264", "k_1267", "k_1268", "chm.HBSingleRwdPanel", "HBSysGetRderSkin", "grp_best", "chm.HBSysGetRder", "HBSysSkin", "k_1263", "chm.HBSysPanel", "KFRVMed", "rstarArr", "show_group1", "wpan", "move2", "show_group2", "KFRV", "removewpanAndLoop", "sD", "removeStarImg", "kingData", "getDWImg", "KCMod", "lbl_dw", "dan", "oldKingdata", "img_dw2", "lbl_dw2", "addStars", "setStar", "setStar2", "winState", "addStarImg", "oncom", "star_group", "swD", "swgTime", "chm.KFRVMed", "_mdr", "KingMed", "rmdr", "showP", "showM", "cCe", "rOpen", "rMT", "rCEnd", "rRRB", "rpdc", "rcdc", "backInfo", "cRed", "kingFR", "rItems", "rInfo", "rMh", "rCge", "rbct", "rrd", "getKingInfo", "getPipeiData", "kingrewardState", "_endvo", "king", "kingState", "chm.KingMdu", "_me", "_mdl", "KingV", "gshp", "wangzhe_biaoti_png", "zsinfo", "rwdArr", "arPl", "pipei", "btn_pipei", "fPanel", "7000", "ichg", "7001", "ppC", "rwrd", "btn_getReward", "lwPanel", "btn_addnum", "7002", "kicg", "7003", "ccg", "7004", "ppcg", "7005", "rscg", "7006", "scg", "getTTCount", "totalCount", "rKgData", "lbl_jieshu", "wangzhe_qingtong_png", "rPanel", "img_duanw", "wangzhe_baiyin_png", "wangzhe_huangjin_png", "wangzhe_zuanshi_png", "winCount", "lbl_winNum", "lbl_winrate", "k_409", "img_enemy1", "high_ladder_null_png", "lbl_enemyPos", "img_my", "high_ladder_{0}_{1}_png", "imgbg1", "high_ladder_bg_jpg", "imgbg2", "myrank", "myRankVo", "smRank", "ttrewardArr", "rKCost", "k_420", "mbcnt", "k_421", "lbl_state", "k_1344", "pipeiData", "pipeiList", "showEnemy", "chm.KingMed", "kingsetting_json", "maxbuycount", "maxcount", "kingcost_json", "fiveStarArr", "fourStarArr", "threeStarArr", "rfiveStarArr", "rfourStarArr", "rthreeStarArr", "chm.KCMod", "gInfo", "_kingrewardState", "_kingState", "_kingData", "getZuanshidata", "getrankArr", "hisCofigId", "isPulled", "getMyrankInfo", "KRVo", "kuangIcon", "winNum", "kingrankreward_json", "k_410", "KRaVo", "realFighter", "checkpipei", "getRewardArr", "openlevel", "chm.KingMod", "starArr", "starArr2", "KFWPan", "aSImg", "rmSImg", "rmSImg2", "chm.KFRV", "KRRed", "KLWRed", "KLWTRed", "tab_tz", "tab_pm", "tab_sz", "idxcg", "enemyGroup", "lbl_myname", "KPan", "KRPan", "KFPan", "KLWPan", "rmImg", "lbl_mypos", "k_428", "k_427", "adImg", "k_426", "k_425", "cvo", "voArr", "img1", "img2", "img_enemy2", "chm.KingV", "rmGrid", "chm.KLWRed", "k_414", "k_413", "k_412", "k_411", "chm.KLWTRed", "chm.KRRed", "KingFightPanelSkin", "chm.KFPan", "KingFightWinPanelSkin", "lbl_starawd", "grp_awd", "lbl_tzawd", "scr_rwd", "chm.KFWPan", "KingLastweekSkin", "chm.KLWPan", "KingPanelSkin", "chm.KPan", "KingRankPanelSkin", "chm.KRPan", "chm.KRaVo", "chm.KRVo", "LTSuitModule", "LTSuitVMed", "kon", "c_4400", "getLtInfo", "chm.LTSuitMdu", "LTSuitViewMediator", "_wind", "suitPal", "LTSuitView", "leiZhuangPal", "LTLeiSuitView", "cuilianPal", "LTCuiLianView", "radioPal", "LTTabView", "suitTips", "LTSuitTipView", "leiTips", "LTLeiDesTipView", "cuilianTip", "LTCuiLianTip", "resolveListPal", "LTResolveListView", "alertTip", "replacePanel", "exchangePal", "LTExchangeView", "resolvePal", "LTResolveView", "sltWin", "thunder_title_png", "SmeltSltRd", "LTLeiReplaceRder", "heroSuitReds", "heroZiSuitReds", "heroCuiLianReds", "gerRule", "openSuitTips", "grp_icon1", "grp_icon2", "openResovePal", "resoveClick", "openResoveList", "btnReslove", "hideReplacePal", "hideResoveList", "updateResolvList", "openCuiLianTips", "updateAllPanel", "selectBooloen", "showReplacePal", "askReplace", "updateAllReds", "updateLeiZhuangByReplace", "updateTab4Red", "updateReplaceList", "ltAllReds", "ResolveArr", "getResolveArr", "k_1551", "isFirst", "itemType", "idxPage", "heroPage", "updateTabRed", "getSuitTotalLvl", "getTabReds", "k_1557", "k_1712", "thunder_ui_bg_jpg", "thunder_purple_bg_jpg", "checkCuiLianMinByLvl", "thunder_collect_bg_jpg", "thunder_title_2_png", "thunder_convert_bg_jpg", "heroBigCuiLianLvl", "jiBanEff", "yunluolvl", "yunluoLvl", "wanjunLvl", "fillTips", "openLeiTips", "getLvlMin", "showPal", "getReplaceList", "k_1544", "replaceData", "pingfen", "isWear", "c_4407", "leiTingClick", "heroBosIdx", "bagIdx", "c_4404", "chm.LTSuitVMed", "LsuitVo", "chm.LsuitVo", "LtBagVo", "chm.LtBagVo", "cuiLianTip", "_thundConf", "_suitDic", "_initEquip", "_thunderBuffDes", "_equipDic", "_eqpDicByPos", "_cuilianInfo", "cLInfoByLv", "_cuilianupDes", "LtEquipiems", "_lastSlted", "_bagInfo", "item_859", "item_860", "item_861", "item_862", "item_863", "item_864", "posIndex", "posName", "k_1734", "k_1735", "k_1736", "k_1737", "k_1738", "k_1739", "posnameIdx", "_heroBigCuiLianLvl", "_heroEquipAct", "xishu", "_heroZiSuitReds", "_heroSuitReds", "_heroCuiLianReds", "suitReds", "ziZhuangReds", "cuilianReds", "bigCuiLianLvl", "equipActNum", "_heroPage", "_ltConfByType", "suitParseXml", "equipParseXml", "cuiLInfParseXml", "cLUpParseXml", "thdBuffParseXml", "buffParseXml", "getSuitThunder", "thunderpassive_json", "thunderequipTaozhuangUpLv_json", "thunderbuff_json", "getLTSetting", "thundersetting_json", "initEquip", "getThunderEqpConf", "isMaxCuiLian", "thunderequipCuiqu_json", "getCLInfoByCfg", "thunderequipCuiquUpLv_json", "getLtEquips", "bagInfo", "thunderEquipDTO", "getSpecialPropNum", "bagMax", "lastSelected", "n_32550", "n_32551", "boxDatas", "n_32552", "k_1537", "getSuitInfoByHero", "LTSuitVo", "getOneSuitInfo", "tzId", "taozhuangId", "_yunluoLvl", "_wanjunLvl", "getSuitRed", "getThdZzhData", "getOneZiZhuangInfo", "boxIdx", "propDes", "specialStr", "offSpecial", "getBagReds", "getSuitUpReds", "getXiaoHaoBySuit", "getZiSuitRed", "getEquipNumByHero", "thunderZizhuangDataDTOs", "getCuiLianRed", "getOneCuiLianLevel", "heroEquipAct", "getLeiTingMaxNum", "thunderCuiquDataDTOs", "thunderCuiquGridDataDTOs", "getZiZhuangByConf", "getZiZhuangDes", "curDes", "nxtDes", "lzRed", "getCuiLianGzLvl", "getOneCuiLianInfo", "gridId", "getThdCquGridData", "lastSelect", "getLockArr", "getLockState", "checkIsSame", "getMinLvl", "cuiLianVo", "isLock", "isShowLbl", "cuiLianIdx", "isSame", "culianLvl", "nxtCuiLianLvl", "getCuiLCostNum1", "getCuiLianIndex", "getGeZiInfoByConf", "getLockIndex", "associatedIds", "thunderTaozhuangDataDTOs", "getShuXing", "getLTEelById", "getIconDes", "effectRate", "getSuitFightNum", "getZiZhuangFight", "getCuiLianInfo", "checkDiff", "getGeZiInfo", "getShuxing", "HP:0,ATT:0,PDEF:0,SDEF:0", "(+", "_culianLvl", "_nxtCuiLianLvl", "ext", "grade", "lvls", "n_32553", "getLTProps", "getItemConf", "getExchangeConfByType", "levelConsumed", "thunderconvert_json", "getCanExchangeMagicProps", "canChange", "getTotalLvl", "convertLevel", "chm.LTMod", "LtPlayer", "chm.LtPlayer", "gridLinesIdx", "item_41011_png", "item_41012_png", "item_41013_png", "item_41014_png", "item_41015_png", "item_41016_png", "chm.LTStatic", "LTCuiLianTipSkin", "hidePal", "lockCost", "priorityLockCost", "cuiQuId", "k_1539", "c_4406", "chm.LTCuiLianTip", "maxLen", "renderArr", "lastLvl", "LTCuiLianViewSkin", "leftClick", "rightClick", "LTCuiLianRder", "checkBtnState", "isShowEff", "removeGrpTween", "showFapai", "updateShuXing", "desStr", "xiaoHao", "setLineState", "k_1540", "lbl_iconN", "thunder_name_", "checkBtn", "callother", "ondecLtidx", "onaddLtidx", "checkLvls", "k_1559", "c_4405", "k_1541", "chm.LTCuiLianView", "LTExchangeSkin", "tarItemList", "LTExItemRder", "curItemList", "left_btn", "right_btn", "clikExItem", "askExchange", "btn_change", "rspExchange", "_selectExId", "_selectExTarId", "k_458", "updateExchangeView", "setCurrItemList", "setTargetItemList", "refrushSelectItem", "showExchangeBtnEff", "createLtExItmVo", "scroller0", "_selectItemCtrl", "LtExItemSkin", "MagicExItmVo", "curItemGrp", "_exchangeBtnEff", "k_446", "k_1711", "c_4408", "isTar", "clikExTarItem", "clikExCurItem", "checkListBoundary", "measuredHeight", "chm.LTExchangeView", "chm.LTLeiDesTipView", "LTLeiSuitViewSkin", "LTLeiRder", "clickByIdx", "oneBtn", "grp_ganying", "initEequipState", "updateEquips", "updateEff", "setJiBanEff", "updateEquipDes", "grp_fight", "k_1543", "lbl_special", "idex", "thunder_purple_eff_", "LTLeiSelectVo", "lbl_state1", "lbl_des1", "lbl_state2", "lbl_des2", "lbl_state3", "lbl_des3", "k_1558", "k_753", "thunder_feel_eff", "c_4403", "chm.LTLeiSuitView", "LTResolveListViewSkin", "LTRoveRder", "chm.LTResolveListView", "LTResolveViewSkin", "chm.LTResolveView", "LTSuitTipViewSkin", "k_1545", "k_1546", "k_1547", "k_1548", "k_1549", "k_1550", "k_1740", "thunder_skillicon_1_png", "thunder_skillicon_2_png", "lbl_shuxing", "lbl_active", "_hitRole", "thunder_skill_2", "thunder_skill_1", "heroData", "p_10131_{0}_{1}_0", "p_11_{0}_{1}_0", "w_10131_{0}_{1}_0", "w_101_{0}_{1}_0", "chm.LTSuitTipView", "curSelectType", "_selected", "isClick", "curCost", "isShowBtnEff", "LTSuitViewSkin", "LTSuitRder", "turnClick", "initPos", "ltVo", "setGrpEff", "updateSuitInfo", "k_1552", "k_1553", "img_icon2", "activeEff", "thunder_equip_eff_", "fillProp", "nxtProp", "getCurPos", "turnLeft", "k_1542", "k_1560", "k_1561", "k_1562", "k_1563", "c_4402", "chm.LTSuitView", "LTTabViewSkin", "chm.LTTabView", "chm.cuiLianVo", "LTCuiLianRderSkin", "lbl_lock", "k_1538", "checkLock", "refesh", "img_lock", "thunder_tatter_", "playItemEff", "playEffCom", "chm.LTCuiLianRder", "k_1710", "itemGrp", "THUNDER_ITEM_CLICK", "thunder_item_click", "chm.LTExItemRder", "chm.LTLeiSelectVo", "iconName", "LTLeiRderSkin", "refestData", "_selectData", "refestselectData", "k_713", "grp_icon", "thunder_little_", "chm.LTLeiRder", "LTReplaceRderSkin", "chm.LTLeiReplaceRder", "chm.LTRoveRder", "chm.LTSuitVo", "LTSuitRderSkin", "chm.LTSuitRder", "LkRollerViewMediator", "LkRollerModel", "rspOpen", "rspRoll", "rspInfoUpdate", "checkUpdate", "rqOpen", "rqRoll", "curGradeId", "isGradeLast", "mduflags", "curSelectId", "prevItems", "myInfo", "chm.LkRollerModule", "maxItemNum", "LkRollerPanel", "xylp_title_png", "newzhuanpan_bg_png", "xylp_bg_jpg", "getDes", "<font color=\"#38D117\">$1</font>", "refreshItems", "onRoll", "btn_roll", "showBonusTip", "endEffRound", "refreshInfo", "refreshGrade", "playGuangEff", "isHanging", "removeGuangEff", "removeFloatEff", "flyImg", "mdutimers", "rollTimer1", "backInTimer0", "backInTimer1", "backInTimer2", "boxEff", "group_boxlight", "zhuanpanlight_eff", "playFloatEff", "\u9053\u5177\u6570\u91cf\u5f02\u5e38", "LkItemVo", "convert", "LkItem", "setGradeBonusIcon", "showLastGrade", "lkicon_", "getStageBonus", "lbl_bnsName", "prevGradeId", "showNowGrade", "setx", "sety", "lbl_count0", "k_1530", "lbl_count3", "k_1533", "getNextCost", "k_1059", "k_1532", "k_1531", "curRolled", "onSelectIndex0", "onSelectIndex1", "LkShineVo", "isLast", "playBackInEff", "endBackIn", "playBackOutEff", "posx", "posy", "endBackOut", "endFly", "chm.LkRollerViewMediator", "_isOnStage", "endFlag0", "endFlag1", "LkItemSkin", "NUMOFITEM", "img_efflight", "quality_4_png", "quality_5_png", "quality_6_png", "_shineData", "playLastEff", "chm.LkItem", "getItemCfgById", "chm.LkItemVo", "chm.LkShineVo", "getCfg", "_jsn", "luckyturntable_json", "getSettings", "_jsnt", "luckysetting_json", "\u6bcf\u65e5\u5145\u503c\u53ef\u83b7\u5f97\u8f6c\u52a8\u6b21\u6570", "dayvalue", "daycount", "_curGradeId", "_prevGradeId", "_curRolled", "_myInfo", "2018-8-24 0:0:0", "_curSelectId", "chm.LkRollerModel", "LkRollerPanelSkin", "chm.LkRollerPanel", "LockMonMed", "LockMMod", "targetShow", "useMed", "tiaozhan", "upInfo", "gSerTime", "lvChge", "getGiftByGold", "getRewBySweep", "rspOpenView", "rspChallenge", "rspSweep", "rspCD", "rspEnter", "skillAct", "bossHpCg", "rspTowerInfo", "askLockInfo", "reqInfo", "buyQiYuGift", "upDateInfo", "cCopyVo", "daymaxlevel", "lockMDt", "canmaxlevel", "askAddbuff", "k_393", "k_395", "askChallenge", "askBuySweep", "sweepstate", "sweepbonus", "actionPlay", "lastHp", "curHp", "askSweep", "curBossid", "TypeError:S_SSYaoTower_DataChange info is null", "fail", "lockMonType", "selfGetRwd", "useGold", "addRewardPortTime", "buffCount", "rewardPort", "rewardBuy", "maxlevel", "chm.LockMonMdu", "_monArr", "_lvImg", "enterSce", "bonusData", "leavSce", "rfBossDat", "windDat", "LEAVE_MAP_CHANGE", "mapcg", "gFight", "group_numimg", "UsePotion", "grp_att", "showGiftPanel", "grp_gift", "LockMonV", "k_389", "swEnd", "LMWPan", "useGift", "_sce", "LMSPan", "lbl_tg", "k_390", "rewardtimes1cost", "rewardtimes2cost", "lbl_price1", "lbl_price2", "LMSce", "k_1347", "leaveScene", "getLv", "eui.Image", "firstreward", "img_reward", "demon_tower_desc3_png", "demon_tower_desc_png", "ratereward", "demon_tower_gailv_png", "getArr", "LMVM", "LMItem", "showlight", "portGroup", "\u653b\u51fb+", "lbl_giftTime", "alertPal", "giftPal", "chm.LockMonMed", "_buffCount", "_rewardPort", "_rewardBuy", "_addRewardPortTime", "_lData", "copyArr", "readXml", "syaotower_json", "LockMVo", "REWARD", "limitlevel", "tj", "mon", "addTo", "exitLockMonScene", "gTarId", "gAva", "k_1345", "k_1346", "tarCom", "getGiftRwd", "suoyaotashop_json", "_sweepstate", "_sweepbonus", "chm.LockMMod", "chm.LockMVo", "demon_tower_title_png", "LMPan", "LockAlertPanel", "LockGiftAlertPanel", "chm.LockMonV", "ui_m", "LockMonItemSkin", "img_suolian", "img_guan3", "demon_tower_diguanbg2_png", "demon_tower_qidai_png", "lbl_tj", "k_387", "demon_tower_guan3_png", "demon_tower_guanbg_png", "boss_group", "chm.LMItem", "LockMonPanelSkin", "chm.LMPan", "hpcnt", "leftT", "_exit", "LockMonSceneSkin", "btn_usepotion", "btn_useGift", "lockAlert", "giftAlert", "barChge", "_coutNum", "lbl_dj", "k_388", "k_394", "lbl_tjms", "k_391", "lbl_sj", "00:00:", "lbl_attValue", "00:00:0", "lbl_dqms", "chm.LMSce", "LockMonSelecPanelSkin", "btn_one", "btn_two", "btn_three", "chm.LMSPan", "LockMonWinPanelSkin", "lbl_ts", "awards", "sWinTime", "_loop", "lbl_next", "k_392", "LockMon_win_next", "winTm", "chm.LMWPan", "_totalNum", "LockAlertSkin", "_golod", "k_238", "updateNumChoose", "lbl_attDes", "lbl_ysNum", "\u8d2d\u4e70\u6b21\u6570\u5df2\u7528\u5b8c", "\u5269\u4f59", "\u836f\u6c34\u4e0d\u8db3", "\u672a\u9009\u62e9\u9f13\u821e\u65b9\u5f0f", "chm.LockAlertPanel", "LockGiftAlertSkin", "btn_chanel", "getRwdByGold", "showTime", "_countNum", "k_396", "group_select", "chm.LockGiftAlertPanel", "CreateNewViewMed", "_particleOn", "_fakeTxtArr", "_intervalDelay", "CreatNewView", "onInitNameHandler", "refreshView", "group_y", "creatRole", "onTouchLoginHandler", "btnLogin", "onTouchRandomHandler", "btn_dice", "JOB_CHANG_FUNCTION", "JobChangeHandler", "txtNameChange", "txtName", "selectJob", "selectSex", "crt_", "characterbg_job_", "_sj_png", "img_tj", "[\\u4e00-\\u9fa5]", "k_254", "isOppoPlatForm", "getSelectSex", "createUser", "CretUser", "playFakePlayerEnterMsg", "addTxt", "group_player", "getFakeTxt", "k_431", "BG_URL", "show_{0}_{1}_jpg", "chm.CreateNewViewMed", "CreatNewRoleView", "CreateNewEui", "tabBar_job", "tab_zhan_nan", "tab_zhan_nv", "tab_fa_nan", "tab_fa_nv", "tab_dao_nan", "tab_dao_nv", "jobToggleChangeHandler", "select0", "job_chang_function", "chm.CreatNewView", "_plo", "fnd", "_faA", "_terD", "onInN", "rfv", "_gde", "game_start_effect", "onTl", "onRl", "6000", "jobc", "tabjob", "tabSex", "show_", "playMsg", "_pls", "getFt", "CrtMed", "chm.CrtMed", "_cc", "loginLater", "boFehao", "connectType", "_lgMe", "LoginMed", "_ctMNew", "_ctM", "_reM", "ReloginMed", "_create", "rsh", "lio", "sco", "acb", "onGetVersion", "ON_SHOW_CONECT", "onShowConect", "OPPO_PAY_LOGIN", "payLogin", "k_1674", "reqPlatLogin", "\u540e\u7aef\u7248\u672c\u53f7--------------------------------", "vesion", "8.0", "HeroData", "PosEquip", "WingData", "MeridianData", "SkyBox", "PassiveData", "updateParamsObj", "ActiveTask", "ActiveTaskData", "updateParamsCmd", "isFocus", "isSmallLogin", "isGuide", "isAuthorization", "isCheat", "isCollect", "setting", "childsetting", "PlayerData", "serverId", "userId", "loginTime", "lastIP", "curIP", "robot", "LunHuiData", "bossCallBonusCount", "BoxData", "openState", "prevDailyResetTime", "talkEndTime", "closeTime", "CloseReanson", "towerProcess", "taskProcess", "prevFightTime", "ArtifactsData", "quanMingTime", "byMeetTime", "byMeetCount", "isBaiduPlatForm", "isBind", "\u540e\u7aef\u7248\u672c\u53f7\uff1a", "sendLogin", "svrversion", "login_recive", "destroySelView", "scp", "hideCreatePanel", "hdc", "isInCity", "ui_init_progress", "\u6b63\u5728\u51c6\u5907\u4e3a\u4f60\u5f00\u542f\u4e00\u6bb5\u4f20\u5947\u7684\u65c5\u7a0b...", "svrDressArr", "client_ready_complete", "getChangeNameCard", "CLIENT_LOGIN_READY", "onShareAppMessage", "wxsex", "headimgurl", "sharejsonData", "stringify1", "postShareMsg", "nshareType", "myid", "c_4607", "\u5206\u4eab\u8fc7\u6765\u53d1\u9001\u5e08\u5f92\u4fe1\u606f", "fhead", "c_2170", "\u5927\u80c3\u738b", "\u670d\u52a1\u5668\u8fde\u63a5\u4e2d...", ",\u662f\u5426\u9000\u51fa\u6e38\u620f?", "\u4f60\u7684\u8d26\u53f7\u5df2\u88ab\u5c01", "showAlterExtModal", "\u4f60\u5df2\u88ab\u6c38\u4e45\u5c01\u53f7", "\u4f60\u7684\u8d26\u53f7\u6682\u65f6\u88ab\u5c01\uff0c\u5c06\u4e8e", "\u540e\u89e3\u5c01", "websocketIp", "1.websocketIp----------------------", "2.websocketIp----------------------", "websocketPort", "account", "passworld", "connect ws", "fuid", "platShareLog", "dirEnterGame", "rcho", "rcf", "rcs", "csk", "rquitConnect", "soc", "och", "orh", "onReconnect", "okh", "checkVision", "user", "channelid", "sendCreateUser", "chm.LoginMdu", "ca", "cookie_account", "ce", "cookie_service", "cp", "cookie_port", "cookie_plat", "cz", "cookie_zone", "_mu", "LoginView", "loginEui", "txtIP", "txtPort", "ohg", "txtPlat", "txtZone", "txtPassword", "zone", "chm.LoginMed", "_rts", "RecView", "ui", "k_429", "clh", "k_430", "k_433", "k_434", "exitWxGame", "chm.ReloginMed", "CreateNewRoleSkin", "CreateEui", "chm.CreateEui", "CreateNewRoleShenjiSkin", "chm.CreateNewEui", "isAuditTempRes", "character_di1_audit_jpg", "tab_zhan", "tab_fa", "tab_dao", "jobC", "tab_nan", "tab_nv", "chm.CreateView", "LoginSkin", "LoginEui", "chm.LoginEui", "chm.LoginView", "ReconnectionSkin", "RecEui", "chm.RecEui", "chm.RecView", "LotteryMed", "gAlItem", "lotSuc", "lotLogs", "pickUp", "pickUpAl", "lgnComChk", "cqPoint", "dividRed", "chuanqiDividRed", "rLottLog", "rLott", "chm.LotteryMdu", "_rArr", "xubao_title_png", "oraRedPt", "LegRedPt", "depotRedPt", "sTip", "tenClk", "rstClk", "reslutP", "ClRslPan", "rgetOne", "depotP", "rgetAll", "TABBAR_SELECT_CHANGE", "LOTTERY_RESULT", "fResults", "LOGS_REFRESH", "DEPOT_RED_POINT_CHANGE", "fillDepotList", "k_1357", "lotteryOneBuy", "lotteryTenBuy", "_cTime", "img_lotterygetBg", "xunbao_beijing_jpg", "img_lotterygetBg1", "showEffect", "showTitleEff", "_bgEffect", "_bgEffect1", "xunbao_eff1", "hideM", "setGetList", "setRewards", "lbl_icostitem0", "gLogs", "allPoint", "sRedPt", "cqAllPoint", "chm.LotteryMed", "_showXml", "pXml", "lotteryVo", "showArrbyId", "refreshXml", "getShowEquipById", "lottery_json", "\u5728lottery_json \u4e2d\u627e\u4e0d\u5230id>>>>>>", "getCrazy1Cost", "getCrazy10Cost", "getCrazy50Cost", "chm.LotteryCfg", "_red", "_cType", "DepotVo", "tabbar_select_change", "lottery_result", "logs_refresh", "depot_red_point_change", "chm.LotteryMod", "LottDPan", "resetScrollV", "LottDepotV", "chm.LottDepotV", "list_rate_act", "fillDesPal", "lbl_act_des", "\u8fbe\u6807\u5956\u52b1\u9884\u89c8\u5982\u4e0b", "\u5956\u52b1", "lbl_head_act1", "lbl_head_act2", "lbl_title_act1", "lbl_title_act2", "chm.LotteryDes", "xunbao_framebg_png", "changeItemNum", "LottGetV", "LottPan", "chengzhuang_title_png", "shengshi_title_png", "cangku_title_png", "_titelEff", "lbl_oneNum", "lbl_tenNum", "playTitleEff", "moveArea", "xunbao_eff2", "restartEffect", "chm.LotteryV", "sSGrid", "LottGPan", "fillLotteryShow", "chm.LottGetV", "chm.DepotRed", "chm.DepotVo", "chm.LotteryRed", "LotteryDepotPanelSkin", "chm.LottDPan", "LotteryGetPanelSkin", "chm.LottGPan", "LotteryPanelSkin", "chm.LottPan", "chm.LottRPan", "_getIds", "gactVo", "glfcnt", "ggld", "getCanPullId", "gpllId", "ckNew", "getActivityVo", "chm.LRlMod", "LuckyRollerController", "updateLuckyActivity", "rollerStart", "start_btn", "k_49", "lbl_payTip", "k_50", "k_51", "doRotation", "LuckyRollerViewMediator", "chm.LuckyRollerViewMediator", "LuckyRoller10Skin", "LuckyRollerItem", "wheelGroup", "showInfo", "chm.LuckyRoller10Panel", "chm.LuckyRollerItem", "LuckyRollerSkin", "LRP", "chm.LuckyRollerPanel", "MPropMed", "rspExch", "askFuse", "chm.MPropMdu", "_hIdx", "fusePanel", "GridMagicItm", "sXMagicItm", "selChge", "MPropV", "exchPanel", "onFuseMove", "skScroller", "fuseSelInx", "cgSelInx", "btn_fuse", "MAGIC_ITEM_CLICK", "MagicExItm", "hListCg", "hidejibanPanel", "fantian_ditu01_jpg", "getCurFuseLvls", "k_443", "_selExId", "_selETarId", "k_447", "gConf", "upHList", "upFuseV", "upExchV", "curIdx", "fantian_tittle01_png", "fantian_tittle02_png", "cPanel", "showfuseEff", "fantian_equip0", "sFuseList", "setFuseSXlist", "fantian_equip_", "pos2tp", "k_457", "k_440", "k_441", "cost_name", "k_444", "cost_grp", "lvl_max", "nextPropGrp", "next_eff", "k_459", "k_460", "rfSelItm", "checkHeroFuse", "clkCurItm", "clkTarItm", "GridMagicItmVo", "checkMagicItemFuse", "getMagicItmIdByPos", "fantian_icon02_png", "fantian_icon01_png", "getLvlLmtByPos", "sXMagicItmVo", "lvlBegin", "lvlEnd", "k_462", "name1", "nex", "nexProp", "k_463", "subPropIcon", "gCanExcha", "cMgExItmVo", "gMprop", "_selItm", "MagicExItmSkin", "showLightEff", "showFuseBtnEff", "_iEff", "_lightEff", "fantian_effect_0", "setJiBan", "img_curname", "grp_c0", "grp_c1", "grp_nex", "lab_jihuo", "k_465", "lbl_cursx", "lbl_xname", "img_nexName", "img_Nstate", "lab_jihuo1", "k_464", "lbl_nexsx", "\u6fc0\u6d3b\u5c5e\u6027:", "chm.MPropMed", "posLvlLmt", "_eConf", "_fuseType", "skylock_json", "gMagicCfg", "sky_json", "gFuseInfo", "skypassive_json", "k_449", "power1", "k_466", "k_467", "k_450", "k_461", "chm.MPropMod", "MagicPropExchangeEuiSkin", "MPropExEui", "chm.MPropExEui", "MagicPropFuseEuiSkin", "MPropFEui", "chm.MPropFEui", "MagicPropRadioSkin", "MPropREui", "chm.MPropREui", "5600", "sXClick", "iShap", "fantian_ditu_jpg", "addRPanel", "showExchangePanel", "hideExpPanel", "cList", "chm.MPropV", "rvGrid", "k_456", "magic_item_click", "chm.MagicExItm", "chm.MagicExItmVo", "GridMagicItmSkin", "chm.GridMagicItm", "chm.GridMagicItmVo", "magicsxItemSkin", "5601", "chm.sXMagicItm", "chm.sXMagicItmVo", "isFrist", "MainMed", "scm", "shl", "sfl", "ogfh", "ofg", "clha", "ser", "pve", "lmt", "ogb", "agmg", "\u52a0\u5165\u516c\u4f1a\u5373\u53ef\u9886\u53d6", "afm", "getShowVo", "\u5173", "setMt1", "rfMgi", "img_filedred", "mainright", "playVeft", "stopVeft", "playReft", "stopReft", "giftView", "isfull", "showSi", "setMtv", "maintop", "setMainFightNumVisible", "setMaiTopAwdVisible", "changeView", "mainLeft", "vipEffect", "rankEffect", "mdBV", "topBtV", "gro_ef", "socialVis", "hidePv", "HIDE_ITEM_BUTTON", "MazeEvt", "mainEui", "port_drop", "protVo", "\u84dd\u6708\u57ce", "setTopTxt", "isShowIcon", "grp_enemy", "showpv", "showIcTw", "k_497", "chapterName", "showFstI", "askForItemUse", "askForBuyItem", "chm.MainMdu", "optype", "_showMeet", "_loginFirst", "_isPo", "_socialVi", "_chatBtnVi", "_chatMBtnVi", "_bossReviveTime", "_socialShow", "_myDaDaoHurt", "_pmo", "btn_tc", "ButtonBackSkin", "socialBtn", "mbvo", "main_icon_shejiao_png", "main_title_shejiao_png", "MnEft", "group_effect_main", "MainView", "initV", "chatBtn", "hbBtn", "btn_vip", "btn_chongzhi", "img_zhongzhi", "readjson", "MainMgr", "groupChat", "btn_city", "bottom_group", "botomBtV", "rsc", "flHd", "curp", "drawMask", "mGroup", "btn_gua", "img_pk", "battle_mode_png", "peace_mode_png", "playsound", "img_sound", "playSnd", "soundPlay", "getStorage", "main_quiet_png", "main_voice_png", "setting_group", "updateHateValue", "targetChange", "hbChange", "onMyDaDaoHurt", "onDaDaoEnd", "addBossEff", "_bossEff", "dadao_challenge", "group_bos", "moduleGroup", "moduleGroup1", "rmvFamBtnEff", "removeBossEff", "deleteBtnVo", "sbd", "chatVis", "chatMVis", "lbl_meetboss", "skillOpen", "grp_skill", "lbl_skilldes", "k_533", "k_534", "img_skill", "skill_icon_", "img_skilldi", "skill_num_", "reBtnarr", "setButton", "checkCrossOpen", "crossOpen", "goCity", "tcf", "btn_ext", "btnCk", "ckgq2", "btn_guanqia", "ckgq", "btn_alphafight", "clickFight", "showOp", "img_open", "guajiGroup", "mbf", "htgg", "btn_yuanbao_add", "openGif", "setStorage", "group_filed", "hideGjb", "cfbs", "k_520", "img_military", "hideHyp", "hypanel", "ckh", "crp", "tipGroup", "showRedp", "group_collect", "cle", "openCollectPanel", "openFirstRe", "showBuffTime", "updateCountDown", "openHurtPanel", "group_hate", "itemUse", "askForBuyHonorItem", "jjClick", "showSettingPanel", "group_set", "ShareModel", "updateHmValue", "showAmazing", "addFunbtn", "delFunbtn", "showCrbossShow", "forceBattleMode", "updateAmazingPosition", "showCrbossChat", "funNotBtn", "getBtnVo", "onFbtncck", "hideIcT", "setEnemyListShow", "buffCountdown", "group_time", "filed_time", "red_packet_icon_png", "_startPos", "MduGpV", "rfMGAr", "moduleTip", "ifGMG", "showGVo", "img_module", "img_moduledi", "k_514", "openlvl", "lbl_moduledesc", "mdGAr", "k_515", "addFamBtnEff", "ifGetAllGift", "isAutoFight", "stopFeft", "k_1603", "k_226", "k_229", "k_232", "k_230", "endTeamEft", "k_1123", "LEAVE_ROOM", "k_1211", "goShop", "k_516", "FightAutoButtonSkin", "k_502", "playFeft", "remHb", "removeButton", "cfsed", "ON_SDK_MAINBTN_CLK", "vipCg", "vip_lvl", "chaTpower", "showPt", "tipview", "oldVo", "hidePt", "ftwc", "oldPort", " / ", "oldPortID", "topBg", "group3", "lbl_protname", "lbl_guajiTIme", "k_498", "lbl_lastTime", "_guaijiValue", "_lastValue", "setMt2", "setmaintopSuprTxt", "sOrhLok", "setCityBtn", "group_countDown", "group_hateValue", "box_auto", "mainSettingPanel", "mainBossType", "cityEffVo", "img_scene", "main_new_png", "main_zhucheng_png", "main_stay_png", "rewardState", "showMbb", "hideMbb", "bossGroup", "lbl_opendesc", "k_505", "addButton", "retMb", "RSGISTER_BOX", "adMV", "main_icon_boss_png", "hideP", "filSi", "filEi", "filMi", "lbl_money", "rfChat", "emjTxt", "lblChat", "_chatD", "hideChat", "showChatRed", "myHc", "lastCurHp", "lastMaxHp", "hpbwEffect", "mmpC", "lastCurMp", "lastMaxMp", "mpbwEffect", "fshape", "loading_huany_png", "loading_huany_ty_png", "resize", "chkMep", "playMce", "_ltEt", "stopMce", "snowSys", "svsc", "stopCbe", "playcbe", "_mainCbe", "maincity_eff", "_actImg", "paihang_di1_jpg", "_actLbl", "\u6d3b\u52a8\u4e2d...", "isShowSocialbtn", "getMainBtnShowLvl", "checkCTip", "img_down1", "img_down2", "lbl_hate", "k_479", "img_hateTag", "getMyDaDaoHurt", "lbl_bossRevive", "k_482", "bossGrpClick", "daDaoAutoClk", "isCount", "showBossTime", "getMyHurt", "hurtData", "bossCountDown", "MainCityBossCountDown", "bossTime", "k_481", "VIP3\u5f00\u542f", "VIPLVL", "SuperMod", "setAutoEff", "fillEnemyViewList", "_showVo", "_amazingImg", "amazing_tips_png", "openContent", "socialShow", "c_3014", "chm.MainMed", "_protMod", "_meedMod", "setName", "setExp", "stm", "ctp", "portBosswinChange", "vlc", "mbbe", "BATTLE_VO_CHANGE", "battlevoChange", "8404", "fwc", "8403", "8702", "meetBossChange", "8902", "hbc", "ptc", "myHpChange", "myMpChange", "delB", "shB", "refreshChat", "rfh", "enterQuanminboss", "getType", "getLevelMaxExp", "MainCf", "main_mp_hp_change", "hpmpChange", "\u65b0\u624b\u6751", "\u590d\u4ec7", "\u5956\u52b1\uff1a\u88c5\u5907", "k_500", "monsterName", "chm.MainMgr", "getPlayerJson", "chm.MainCf", "_isfull", "sltMInx", "ftwNum", "_ftwNum", "getMnBtnVo", "_qq_png", "showlevel", "showLvl", "_btVType", "_btDid", "mainbutton_json", "rdMgJson", "_mduGArr", "moduleGift_json", "ModuleGiftVo", "giftVO", "gift", "giftBgSrc", "buttonArr", "_mainBtnConfDic", "chm.MainMod", "CollectPanelSkin", "focusreward", "sharesetting_json", "toh", "focusBtn", "clcV", "chm.clcV", "effect_parent", "notRedids", "MnBEui", "_label", "checkIfEffect", "zs_group", "setfunbtnicon", "\u6309\u94ae\u8d44\u6e90\u6570\u7ec4\u957f\u5ea6\u4e0d\u4e00\u81f4", "getCtd", "udataTime", "setCDTime", "funleftTime", "VipGiftSvrMod", "vv", "activityEndTime", "special", "stopPef", "showSlt", "hideSlt", "showBbl", "8517", "shozsd", "VIPGIFT_UPDATE_COUNTDOWN", "VipGiftType", "lbl_zs", "setLblText", "k_510", "boo", "showahd", "chkAsa", "setActive", "..", "...", "bindEffect", "checkStage", "chm.MainBtnV", "MainSkin_qq", "MainSkin_oppo", "MainSkin", "list_chat", "upDatachatList", "showBosschatPanl", "grop_crbossChat", "lab_chat", "MainEui", "chm.MainEui", "MainLeftSkin", "MainLeftEui", "chm.MainLeftEui", "MainSettingSkin", "box_jj", "pbClick", "box_pb", "bossAutoChange", "pkChange", "remoEvts", "MainSettingView", "chm.MainSettingView", "MainTopSkin", "onPickUp", "updateGrpAwd", "group_desc", "_fightAutoEffect", "autofight_eff", "group_awd", "lbl_bc", "k_524", "heroGrop", "gropTou", "lbl_awd_title", "\u81f3\u5c0a\u526f\u672c", "\u516c\u4f1a\u8bd5\u70bc", "awardStr", "MainTopEui", "chm.MainTopEui", "SuprMainRender", "chm.SuprMainRender", "enemyViewList", "enemyDic", "MnLeftV", "MnRbEui", "MnPtV", "MnBpV", "hpEffect", "mpEffect", "ManHyEui", "MduAlertV", "guanqia_eff", "hongxuecao_effect_sj2", "lanxuecao_effect_sj2", "hongbowen_effect_sj2", "mbwGroup", "lanbowen_effect_sj2", "group_left", "xuyqiu", "xieiqiu_huyan", "img_mp", "MainView_groupEffect", "img_bottom_bg", "k_490", "_cltp", "dbGrp", "faEft", "main_vip_rank_effect", "removeEnemyView", "addEnemyView", "updateEnemeyView", "setPos", "MainEnemyView", "chm.MainView", "ModuleGiftPanelSkin", "MduGEui", "chm.MduGEui", "function_trailer_title_png", "modulelist", "MuGRender", "onGh", "onchd", "btnLeft", "btnRight", "k_511", "img_lingqu", "chm.MduGpV", "MainbuttonSkin", "chm.MnBEui", "MainbuttonPanelSkin", "MnBpEui", "chm.MnBpEui", "MainbuttonPanelView", "maxPerLine", "mainBtnSize", "_buttonRemoves", "delayAddDic", "lvlListening", "_updateIds", "removeAllBtn", "checkBtnid", "setbutonpos", "doCrossHuoBan", "checkDelayAdd", "updateButton", "k_1554", "chm.MnBpV", "_bindInfos", "bd", "ef", "chm.MnEft", "_reChargeImg", "rebate_yindao_png", "chm.MnLeftV", "MnPtEui", "lbl_guajiTIme0", "k_503", "lbl_guajiTIme1", "lbl_guajiTIme2", "lbl_guajiTIme3", "chm.MnPtV", "BubbleSkin", "chm.BubbleEui", "MainEnemyViewSkin", "k_531", "chm.MainEnemyView", "MainHuanyPanelSkin", "chm.ManHyEui", "MainPortTipSkin", "chm.MnPtEui", "MainRightButtonSkin", "chm.MnRbEui", "partAdded", "chm.MuGRender", "eui.UIComponent", "egret.DisplayObject", "chm.MainButtonVO", "chm.ModuleGiftVo", "MainCityBossMediator", "hurtRankPnl", "MainCityBossHurtRank", "bossCheckPnl", "MainCityBossCheckPnl", "MainCityBossResultPnl", "showHurtRank", "showEndPnl", "chm.MainCityBossMediator", "nTimeout", "doCheck", "openEnd", "reqMonInfo", "chm.MainCityBossModule", "_speakIndex", "_bossTime", "_autoFight", "_inMyBattle", "_lastgetTm", "_heroHpDic", "bossAutoChnage", "getXml", "mainmonstersetting_json", "getRewardXml", "_rwdXml", "mainmonsterreward_json", "getSpeakXml", "_speakXml", "mainmonsterspeak_json", "getSvrOpenLimit", "openServerDay", "getHateMax", "maxHate", "getMonsterAttRadius", "monsterAttScope", "getMonMoveRate", "monsterMoveTime", "getBossDuration", "workdayReviveTime", "weekendReviveTime", "getSpeakCd", "getSpeak", "_hate", "nextTime", "_nextTime", "weekend", "workday", "_hp", "_hurtData", "doDelayEnd", "n_30011", "n_30012", "MainCityBossVo", "lastUpdateTime", "n_30013", "heroRemainHps", "4603", "n_30014", "n_30021", "onBattleEnd", "clearOtPla", "-----------------\u65b0\u73a9\u6cd5\u4e2d\u5927\u5200\u4f8d\u536b\u7ed3\u675f--\u80dc\u5229------------------", "n_30015", "n_30016", "n_30017", "hateAddTm", "hateaddbuffEndtime", "n_11013", "monXY", "onFly", "_hateAddTm", "neton", "netoff", "dison", "disoff", "onAutoStateChange", "onFightStateChange", "getMCBEvtNameByType", "enventRandomName", "getMCBEvtDescByType", "enventRandomDesc", "n_30025", "\u5230\u8fbe\u6218\u6597\u5df2\u5728\u8fdb\u884c\u4e2d\uff0c\u53c8\u6536\u5230\u5f00\u59cb\u5305", "\u5927\u5200\u4f8d\u536b\u53d1\u5305\u95f4\u9694===========", "getTargetIds", "getRoleByOnlyID", "seekCom", "getParamString", "{0},{1},{2},{3},{4}", "n_11405", "_liveArr", "getLiveArr", "stopMainBossFight", "n_30027", "c_3011", "n_30018", "envents", "MCBEvtPnl", "n_30019", "enventType", "MCBEvtRstPnl", "n_30007", "chm.MainCityBossModel", "_lastPlayTime", "_lastSpeakTime", "getMainMonster", "_monster", "grpBubble", "gapTime", "7746", "shiwei_name_png", "imgBubble", "boss_qipao_png", "lblSpeak", "MIDDLE", "VerticalAlign", "doSpeak", "chm.MainCityMonster", "_reqInvate", "MainBossHpSkin", "onClkHead", "ifShow", "onClkRank", "reqHurtInfo", "n_30026", "k_1719", "k_1720", "selfHurt", "firstHurt", "checkChangeReqRate", "n_30001", "chm.MainBossHp", "MainCityBossCheckPnlSkin", "MainCityBossRwdRender", "MainCityBossHurtRender2", "group_rank", "mainmonsterrewardclient_json", "participationReward", "joinGrid", "chm.MainCityBossCheckPnl", "MainCityBossHurtRankSkin", "updateHateAddTm", "MainCityBossHurtRender", "maincityboss_hateadd", "lblMyHurt", "k_878", "lblMyRank", "k_879", "k_880", "_hateAddLeftTm", "doHateAddLoop", "lbl_hateAdd", "k_491", "onHide", "chm.MainCityBossHurtRank", "MainCityBossHurtRenderSkin", "k_483", "k_484", "k_485", "k_486", "chm.MainCityBossHurtRender", "MainCityBossHurtRender2Skin", "chm.MainCityBossHurtRender2", "MainCityBossResultSkin", "updateResult", "lbl_myHurt", "MainCityBossEnd", "k_487", "chm.MainCityBossResultPnl", "BossZhuanRewardRenderSkin", "chm.MainCityBossRwdRender", "MCBEvtPnlSkin", "clearTm", "rmv", "updateCD", "_evts", "onSelect1", "onSelect2", "onSelect3", "img_", "shiwei_box", "txt_", "txt_cd", "{0}\u79d2", "c_3013", "chm.MCBEvtPnl", "MCBEvtRstPnlSkin", "_evt", "txt_name", "k_1718", "txt_cont", "chm.MCBEvtRstPnl", "chm.MainCityBossVo", "batSta", "MapMed", "initRoleList", "curMap", "csbtnClick", "outCity", "ADD_NPC_DATA_COMPLETE", "addNPC", "ADD_MONSTER_DATA_COMPLETE", "addMons", "rspBr", "rspSso", "clearMapInfo", "CHANGEMAP_MP3", "getNpcVo", "isStop", "k_228", "k_224", "k_225", "setBattleVO", "pick", "lastMonInx", "sendCopyNextRound", "sendFamilyIntrusionNextRound", "chm.MapMdu", "_jiaRenTmId", "_heroDic", "initMgr", "_mapBg", "_mapShadow", "_mapAni", "_mapItem", "_mapAvatar", "_mapImg", "mapBackgound", "_mapItemContainer", "mapBg", "mapMode", "initPlayer", "moveToCenter", "batMgr", "reinitPlayer", "heroLst", "heroMaxHp", "equipChange", "wingChange", "dogSkillAct", "10001", "titleChange", "medalChange", "onLeader", "posChange", "useSkill", "meetData", "8700", "meetBoss", "battleVo", "transPlayer", "fasonDress", "clickMap", "fabaoChange", "initJiaren", "initJiaRenReal", "getFrJrInx", "crtFtPlMons", "getMyById", "summonData", "mapAvatar", "filPlayerInfo", "ckCrtPet", "getMyBJob", "20093", "getPetBodyUrl", "initPlayerInCity", "createMyPlyer", "getCurrentNpcInfo", "playerpoint", "lastPoint", "NBiqiMod", "getPlayInitXY", "MazeMod", "currentMapChange", "clearJiaren", "func", "thisobj", "cancelSelectTart", "clickEffect", "eftRemove", "onclick", "mapSceneAni", "MAP_CLICK", "showMap", "hideMap", "chm.MapMed", "isEnd", "_heuristic", "diagonal", "_straightCost", "_diagCost", "SQRT2", "findPath", "_mapVo", "_open", "_closed", "_startNode", "startNode", "_endNode", "endNode", "buildPath", "floyd", "path", "_floydPath", "floydVector", "hasBarrier", "_path", "floydPath", "getLineFunc", "getUnderNodes", "AStar", "chm.AStar", "k_1362", "acos", "setwei", "chm.MathUtil", "loopIndex", "tsDataDic", "_frmTg", "curFrm", "maxFrame", "oneFrmTime", "frame", "toSfecInx", "toSkF", "toWd", "pkToInx", "waitDropData", "interIx", "loopMeetPickUp", "_batMod", "eventHandler", "PRE_MOVE_COMPLETE", "FindPathV", "MEET_PRE_MOVE_COMPLETE", "metPMComp", "BATTLE_PLAY_END", "toSfEnd", "mainBatEnd", "svrMetEnd", "rserverRevengeEnd", "pkComp", "getAlPl", "setDrops", "getAllDrop", "metPkUp", "battleOtherPlayerArr", "getJiaRenIndex", "getJiaRen", "rmJr", "playData", "initDicData", "preKingFight", "kingFighting", "bossFtMov", "monstArr", "otherPlayerPet", "getTsFrm", "getPlBInx", "getPlInx", "doLoop", "IntervalTime", "doFrame", "loopFrame", "timeStep", "getCurrentTime", "playTs", "actionArr", "playAction", "ActionType", "EVENT", "runTo", "RUNTO", "SEEK", "HPCHANGE", "mpChange", "MPCHANGE", "ATTACK", "ADD_BUFF", "REMOVE_BUFF", "PLAY_DEAD", "HIT_BACK", "playPickup", "PICK_UP", "playEvent", "getRadomDrop", "skTaComp", "pickUpitem", "pickUpAllItem", "pickUpOneItem", "pkAlItemComp", "tioPkOne", "PICK_UP_COMPLETE", "checkLoop", "pick_up_complete", "pre_move_complete", "meet_pre_move_complete", "battle_play_end", "chm.BatRpPlayer", "curFrame", "frmDaDic", "summonsDic", "frameHpDic", "petArr", "cachRoleDic", "ftEleDic", "getRDC", "atkIndex", "toPkIndex", "initFmData", "initSeqs", "roletypes", "actions", "summons", "hpchanges", "BattlePlayer", "playActVo", "playSummon", "attackPet", "getPlByInx", "skTarComp", "stopAlMonWd", "seekMyPlayer", "pkUpOne", "getAlPlayer", "outpkOne", "BATTLE_END", "battle_end_bp", "chm.BattlePlayer", "fillJson", "fillHpChange", "fillPickup", "chm.Action", "gridWidth", "gridHeight", "monPosAr", "monSgNum", "plPosAr", "otPlPosAr", "relPos", "zsIndex", "gouIndex", "fashiIndex", "daoshiIndex", "lastMapid", "monsPosAr", "monInxAd1", "getMapMnPos", "getFsMvPos", "getGridAr", "get16GPos", "getDsMvPos", "getZsMvPos", "getDogMvPos", "getFsMvtPos", "getEcPos", "getOp16GrPos", "getDsMvtPos", "getZsMvtPos", "getDgMvtPos", "getMnEndPos", "getMnGridAr", "get9GridPostion", "getOtPos", "getRvPos16", "getMnGrDir", "getRePos9", "chm.BattlePosMod", "rolesTlDic", "rolesTlReEd", "rolesTlReEded", "timeSliceDic", "frameDataDic", "curBatVo", "initEle", "fgEleAr", "getFtEleAr", "getPlBIx", "mkTs", "initFDa", "TimeSlice", "flPmToTl", "maxTime", "minTime", "getEvtAct", "flSkMvTs", "flHpCAr", "flAcDaAr", "reEtRoleTl", "adFt2Ts", "phAcToTl", "timetag", "timeOut", "getOtPlInx", "flMvAct", "getMvAct", "flSkMvAct", "getSkAct", "getFstAkMon", "getTotalMoveTm", "getMyBaIxs", "BattleRepMod", "chm.BattleRepMod", "RoleTlMdf", "chm.RoleTlMdf", "gloTime", "globalTime", "chm.TimeSlice", "manager", "loopcount", "playTime", "disposed", "_useCtPos", "CMovieClipManager", "\u5bf9\u8c61\u5df2\u88ab\u9500\u6bc1\uff0c\u8bf7\u91cd\u65b0new\u4e00\u4e2a\u65b0\u7684\u53d8\u91cf\u5e76\u5c06\u6539\u5bf9\u8c61\u7f6e\u4e3aundefined", "getMovieData", "mPlaydelayIndex", "mMcData", "loadMc", "movieClip", "DEV_WIDTH", "DEV_HEIGHT", "clearMovieData", "getMData", "use", "setframeRate", "MovieClip", "LOOP_COMPLETE", "mcLoopComplete", "mcComplete", "movieClipData", "movieclipData", "loadComFunc", "gotoAndPlay", "play_complete_mcs", "loop_complete_mcs", "chm.CMovieClip", "olnyId", "_bulletEffect", "bulletComplete", "chm.Bullet100", "timeOutRemoveHitIndex", "moveComplete", "bulletEffect", "palyBulletEff", "skill_effect_yeman", "getBullet11", "Bullet11", "chm.Bullet11", "timeOutShowIndex", "tmOutRmvHit", "fromRole", "timeOutShow", "useSkillEffect", "skill_7_act2_0_2", "skill_effect_2", "hitEffect", "skill_effect_bullet_2", "getBullet12", "Bullet12", "chm.Bullet12", "playHitTime", "formRole", "skill_12_act2_0_3", "playHitComplete", "skill_effect_bullet_3", "getBullet13", "Bullet13", "chm.Bullet13", "timeOutPlayIndex", "timeOutFlyIndex0", "timeOutFlyIndex1", "flyEff0", "setRotation", "flyEff1", "actEff", "hitEff", "timeFlyShow0", "timeFlyShow1", "skill_ds_fly_1", "bullet14_0", "loopSeekMove0", "bullet14_1", "loopSeekMove1", "skill_ds_act_1", "removeFly0", "removeFly1", "removeActEffect", "skill_ds_effect_1", "getBullet14", "Bullet14", "chm.Bullet14", "fromPlayer", "skill_fs_act_1", "skill_fs_effect_1", "getBullet15", "Bullet15", "chm.Bullet15", "timeOutRemoveHitIndex1", "timeOutRemoveHitIndex2", "playHitEffect2", "playHitEffect1", "hitEffect1", "hitEffect2", "skill_fs_effect2_1", "removeHitEffect1", "skill_fs_effect2_2", "getBullet16", "Bullet16", "chm.Bullet16", "skill_ds_act_2", "removeHitEffect", "skill_ds_effect_2", "getBullet17", "Bullet17", "chm.Bullet17", "skill_fs_act4", "getBullet18", "Bullet18", "chm.Bullet18", "skill_ds_act4_2", "getBullet19", "Bullet19", "chm.Bullet19", "bulletEffect0", "bulletEffect1", "skill_effect_5_0", "skill_effect_5_1", "skill_10_act5_0_2", "getBullet2", "Bullet2", "chm.Bullet2", "skill_jj_1_effect4", "skill_jj_1_act4", "getBullet20", "Bullet20", "chm.Bullet20", "skill_fs_act5_0", "skill_fs_effect5_0", "getBullet21", "Bullet21", "chm.Bullet21", "skill_ds_act5_0", "skill_ds_effect5_0", "getBullet22", "Bullet22", "chm.Bullet22", "skill_jj_1_effect5_0", "getBullet23", "Bullet23", "chm.Bullet23", "targetArr", "setTargetArr", "skill_fs_act3_0", "playBackup", "getBackupToxToy", "getBullet24", "Bullet24", "chm.Bullet24", "skill_ds_act3_0", "getBullet25", "Bullet25", "chm.Bullet25", "getBullet26", "Bullet26", "chm.Bullet26", "chm.Bullet27", "chm.Bullet28", "effectName", "fabao_bullit_2", "nowFramekey", "bullet29_", "posX", "posY", "geRotation", "getBullet29", "AttactAction", "nCreatnum", "Bullet29", "chm.Bullet29", "skill_effect_3", "getBullet3", "Bullet3", "chm.Bullet3", "zijingshouhu", "chm.Bullet30", "zijingbaozha", "getBullet31", "Bullet31", "chm.Bullet31", "_bulletEffects", "_cnt", "_poss", "liuxinghuoyu", "getBullet32", "Bullet32", "chm.Bullet32", "chm.Bullet33", "getBullet34", "Bullet34", "chm.Bullet34", "thunder_eff_bleed", "indexNum", "_buffCd", "addToNum", "_playTime", "chm.Bullet35", "skill_6_act1_0_2", "skill_effect_bullet_1", "getBullet4", "Bullet4", "chm.Bullet4", "skill_9_act4_0_2", "skill_effect_4", "getBullet5", "Bullet5", "chm.Bullet5", "skill_20_effect", "getBullet6", "Bullet6", "chm.Bullet6", "skill_11_fly_0_1", "skill_effect_10", "skill_effect_11", "skill_11_hit_1", "getBullet7", "Bullet7", "chm.Bullet7", "skill_effect_9", "skill_14_act4_0_3", "getBullet8", "Bullet8", "chm.Bullet8", "skill_effect_7", "skill_13_act3_0_3", "getBullet9", "Bullet9", "chm.Bullet9", "mvToInx", "toRhInx", "rmHEft", "(<SmartRole>thitarDisplayObj).playerData= ", "_hurtArr", "_ATKsT1", "attackShow", "_atkSt0", "mpremain", "checktarIsSelf", "fabao_skill_19", "chm.BulletAttack", "bulEft", "fuhuo_effect", "hitEft", "getBulletReLive", "chm.BulletReLive", "initMyTeam", "chm.BatStaMgr", "lopDelTime", "qmPtDelay", "batRpPlayer", "battleCfg", "batOver", "rspGBSuc", "leaveMap", "makpet", "enterCity", "PrisonMod", "c_1525", "9608", "fightState", "stopQmPBat", "MazeRoomChangeVo", "absValue", "ROOM_VALUE_CHANGE", "RESET_MAPID", "zhizun", "monsterIndex", "clearMpToFc", "initMonster", "initOtPl", "initEleSeqs", "getTransPoint", "pkupComp", "MainCityHeroHp", "getDaoshi", "serverData", "chm.BattLeMgr", "jiaRenDic", "jrMonDic", "loopTag", "loopStep", "jrInxDic", "batCfg", "\u906d\u9047\u5bf9\u8c61\u5468\u56f4\u6ca1\u6709\u627e\u5230\u53ef\u884c\u8d70\u7684\u70b9", "resetFullHpmp", "monsterHps", "getMonsterByid", "getMo", "NBiqiPMod", "initMeetBoss", "clearMeetBoss", "createOtherPet", "getPlayerSel", "SCZBPlayerMod", "setOPShow", "getPlayerSelect", "ckMtOTPla", "OtherPet", "flPlayerInfo", "startLoopAtk", "id1", "stopLopAtk", "loopAttack", "isMyPlayer", "chm.MapPlayerMgr", "FindPathingSkin", "getEui", "autobattle_effect", "chm.FindPathV", "_playSound", "_nextOSRenderTm", "_nextRTime", "skillFunDic", "playSkBlz", "playSkLd", "playSkHbz", "playSkKjHh", "playSkMfd", "playSkBpX", "playSkLhhf", "playSkSds", "playSkSSzj", "playSkJfp", "playSkSy", "_awakeData", "showSkFont", "getYemanToxToy", "playSkCol", "playZsAtkSk", "getSkillFun", "playSkillFire", "playSkSound", "skill_json", "sdurl", "_mp3", "mfdBullet", "otherSkillPart", "skill_shenlingjiban_act_", "onPlayOSPartCom", "updateOSKill", "hdEff", "checkActAtk", "atkSkPart", "skill_{0}_{1}_{2}_1", "skill_jj_{0}_{1}_{2}_1", "onPlayComp", "upSkEft", "skilleff", "stopAtkSk", "chm.AtkSkPlayer", "bubbleImg", "bubbleLbl", "border", "chm.DiaBubble", "gAngle", "gHasReset", "gInitPos", "gScale", "m_nFabaoID", "gFollowItem", "gCenterPos", "gBody", "gTurnItem", "gOwner", "gTurnTime", "STAR_ANGLE", "gStopTime", "updateTurnPos", "gTurn", "gAngleSpeed", "updataLayer", "isHideFabao", "TARGET_POINT_X", "TARGET_POINT_Y", "gOwnerLastX", "gOwnerLastY", "moveCenterPoint", "MAX_DIS", "MIN_DIS", "SPEED_RATIO", "updateModel", "Fremkey", "gCreateTime", "chm.FaBao", "jsonData", "CMovieClipData", "chm.CMovieClipData", "npp", "_lastSyncMoveTime", "shengji_effect", "_loopKey", "showNearMonsHP", "RUN_SOUND", "chm.MyPlayer", "_mduImg", "imgTkSta", "join_task_png", "selectEff", "npc_xz", "chm.Npc", "chm.OtherPet", "chm.OtherPlayer", "_groupDic", "_loadDic", "mcResDic", "getGroupName", "_group", "getJsonName", "getTextureName", "createGroup", "loadGroup", "onResourceLoadComplete", "MovieClipDataFactory", "enableCache", "generateMovieClipData", "onResourceLoadError", "getjsonData", "getTexture", "MovieclipSouce", "GROUP_COMPLETE", "GROUP_LOAD_ERROR", "chm.CMovieClipManager", "_bgKey", "_playBgSnd", "_playSnd", "_failout", "_gameAct", "playKeyDic", "_loadMap2", "_soundMap2", "_failout2", "stopBgSnd", "gameAct", "playBgSnd", "_bgSound", "_bgChanle", "onLoadBg", "onLoadOnce", "completeFun", "inQueue", "soundInQueue", "loadOtherSd2", "SOUND_LOAD_COMPLETE", "loadOtherSdComplete2", "getSoundPlayer", "loopTm", "stopOtherSound2", "chm.SoundMgr", "SoundLoader", "chm.SoundLoader", "playing", "SOUND_COMPLETE", "SoundPlayer", "chm.SoundPlayer", "_soundDic", "playSnds", "getResourceInfo", "resourcePath", "getSoundItem", "netUrl", "stopOtherSound2s", "VivoSound", "chm.VivoSound", "_downLoading", "_curTime", "_tempPath", "readyPlay", "qg", "tempFilePath", "download vivo sound success:", "download", "_audio", "createInnerAudioContext", "src", "volume", "offEnded", "onEnded", "doStop sound:", "exeCallBack", "_callBack", "VivoSoundItem", "chm.VivoSoundItem", "run_mp3", "CREATE_ROLE", "createRole_mp3", "popUi_mp3", "changeMap_mp3", "chm.SoundStatic", "monsPool", "uiMonsPool", "otPlayerPool", "getMyPlayer", "getUIMonster", "getPlayer", "playerPool", "npcPool", "chm.UIMonsterr", "chm.RoleUnit", "setIntervalIndex", "setTimeOutIndex", "gameTime", "_dtloopTime", "frameLoopDic", "doNextFrameDic", "timeoutDic", "intervalDic", "secondLoopDic", "frameTimer", "onFrameTimerIntvel", "gameTimer", "onGameTimerIntval", "originDelay", "removeNextFrame", "chm.Loop", "getWingRes", "getWeaponRes", "getWeaponJob", "equip id=", ",can not find res!", "getBodyRes", "chm.BattleCfgMod", "rdDcount", "_battleVO", "battleConfig_json", "zhashi", "shenshou", "battle_vo_change", "CLEAR_BATTLE_DATA", "clear_battle_data", "BATTLE_UPDATE_HPMP", "chm.BattleMod", "mapDic", "_curMapId", "initCfgMap", "map_json", "MapConfigVO", "hasData", "mapObj", "replaceStr", "x:", "\"x\":", "y:", "\"y\":", "fillMapVO", "noWalks", "masks", "k_1376", "p_", "_{0}_{1}_", "cb_", "01", "02", "03", "w_", "pet_", "getTitleIconByID", "fabao_eff_", "calPaths", "correctOut", "path2Point", "current_map_change_mm", "leave_current_map_change", "chm.MapMod", "fight_blood_2_png", "fight_blood_1_png", "chm.MonsterHpBar", "fight_blood_3_png", "chm.SelfHpBar", "mapUrl", "map_{0}_jpg", "toGridIndex", "chm.MapConfigVO", "wingID", "petZsLevel", "chm.MapPlaData", "chm.QuanMrankVO", "mduIDs", "MasterMed", "c_4603", "c_4601", "showSociTip", "chm.MasterMdu", "delyt", "masterpnl", "MasterEui", "apppnl", "ApprenticeEui", "radpnl", "MasterRadioEui", "scrotip", "socialTipsEui", "explainPnl", "ExplainEui", "mobai", "MobaiRwdEui", "priateChatPnl", "MasterPrivChatEui", "titlePan", "MasterTitleEui", "onIdxChange", "title_school_png", "list_task", "MtaskRnd", "onBsClk", "btn_baishi", "exitMaster", "btn_exit", "onMobaiClick", "btn_mobai", "onshowExit", "img_tx", "onhideExit", "updtaskInfo", "updMatserInfo", "updStudentInfo", "onfinishTask", "setRedoint", "updateChatBtn", "showTitlePanl", "lab_Title", "refbtn", "getboCanbeMaster", "MasterCfg", "isOut", "studens", "k_824", "k_823", "k_822", "isChatOpen", "setPanelInfo", "grop2", "grop1", "setvalue", "getRedbyID", "chatAllRed", "txt_input", "k_821", "k_820", "c_4611", "c_4619", "chm.MasterMed", "taskParseXml", "discipleTask_json", "getTaskByid", "getMaxNowSNum", "mastersetting_json", "discipleCounts", "getMaxCSNum", "maxDiscipleCounts", "getmobaiRwd", "getTitlearr", "titlearr", "matertitle_json", "chm.MasterCfg", "actids", "isMoBai", "lastChatVo", "curChatVo", "firstDiscipleNum", "addActID", "delActid", "n_4602", "disciples", "n_4604", "masterId", "mPower", "mHead", "mName", "mVip", "n_4606", "n_4608", "n_4610", "n_4612", "isShowbtnbyID", "n_4616", "getServierid", "n_4618", "checkChatInfo", "receiveId", "getTuDiArr", "MterCtvo", "isOnLine", "chatTuDiRed", "k_825", "chatShiFuRed", "checkNumById", "lastShiFuVo", "getChatArr", "n_4620", "chm.MasterMod", "Mtaskvo", "chm.Mtaskvo", "chm.MterCtvo", "onzhuchuClk", "btn_expel", "btn_zhuchu", "ontxClick", "isout", "k_819", "c_4609", "grp_jindu", "lab_jd", "lab_online", "k_816", "lbl_ser", "img_qinchuan", "isFirstDisciple", "ApprenRnd", "chm.ApprenRnd", "ApprenticeSkin", "list_Ntudi", "list_Ltudi", "lbl_copy", "k_817", "lbl_actcode", "setCopyClipData", "btn_yaoqing", "inviteClk", "addBtn", "k_1643", "onhideExitbtn", "exitbtn", "setClipboardData", "lbl_Nownum", "lbl_lastnum", "lab_nos1", "lab_nos2", "chm.ApprenticeEui", "ExplainSkin", "school_teacher_bg_xcx_jpg", "school_teacher_bg_jpg", "img_loc1", "school_xz_png", "school_wxz_png", "img_loc2", "onFuseMove1", "chm.ExplainEui", "MasterChatRderEui", "chm.MasterChatRderEui", "MasterSkin", "img_keyBg", "friendpk_role", "lbl_fnum", "img_mobai", "k_828", "lbl_sid", "chm.MasterEui", "renderArrs", "MasterPrivChatSkin", "chat_list1", "chat_list2", "MasterTuDiRderEui", "tudi_grp", "updatePanelList", "selectIndx", "title_chat_student_png", "updateRder", "updateChatList", "title_chat_teacher_png", "_clickId", "scroller2", "clickVo", "k_826", "c_4617", "chm.MasterPrivChatEui", "MasterRadioSkin", "chm.MasterRadioEui", "MasterTitleSkin", "list_tltle", "MasterTitleRnd", "initshape", "closePanl", "chm.MasterTitleEui", "titleurl", "neednum", "lab_des", "k_1644", "titleid", "getTitleVo", "school_icon_bg1_png", "clothes_nodressed_png", "isTitleLoad", "chm.MasterTitleRnd", "MasterTuDiRderSkin", "refeshInfo", "icon_chat_3_png", "icon_chat_2_png", "icon_chat_1_png", "chm.MasterTuDiRderEui", "MobaiRwdSkin", "close_btn", "c_4615", "showCardReward", "gorpRewad", "chm.MobaiRwdEui", "taskid", "c_4605", "LEVEL", "CTIANGUAN", "MAINPROGRESS", "chm.MtaskRnd", "urlsDic", "mianbtnDic", "socialTipsSkin", "mids", "main_icon_school_png", "main_title_school_png", "main_icon_mail_png", "main_title_mail_png", "btnGrop", "removePanl", "chm.socialTipsEui", "maze_click_map", "PICKUP_BOX", "maze_pickup_box", "PICKUP_BOX_LAST", "maze_pickup_box_last", "ITEM_USE", "maze_item_use", "SHOW_AWARD", "maze_show_award", "HIDE_OTHER_PLAYER", "maze_hide_other_player", "RESET_ROOM_BOX", "maze_reset_room_box", "UPDATE_ROOM_ITEMNUM", "maze_update_room_itemnum", "PICKUP_PROGRESS_END", "maze_pickup_progress_end", "maze_leave_room", "LEAVE_ROOM_TIMEOUT", "maze_leave_room_timeout", "ASK_OTHER_PLAYER_INFO", "ask_other_player_info", "PORTAL_STATE_CHANGE", "maze_portal_state_change", "BUY_ITEM", "maze_buy_item", "SHOW_TIP", "maze_show_tip", "ENTER_MAZE_PLAY", "maze_enter_maze_play", "REFRESH_FIRST_INFO", "maze_refresh_first_info", "COLLECT_END", "maze_collect_end", "ASK_SVR_MOVE", "maze_ask_svr_move", "CLEAR_ALL_TWEEN", "maze_clear_all_tween", "maze_hide_right_panel", "maze_reset_mapid", "CLEAR_MAZE", "maze_clear_maze", "maze_room_value_change", "SHOW_LAST_RIGHT_PORTAL", "maze_show_last_right_portal", "chm.MazeEvt", "MazeModule", "MazeVMed", "openMaze", "pickupBox", "pickupBoxFast", "useItem", "leaveRoom", "askEnterMazeAgain", "askSvrMove", "clearMaze", "reconnection", "rspMazeEnterSuccess", "rspMazeLeave", "rspUseItemSuccess", "rspBoxStateChange", "rspFirstInfoChange", "rspMazeItemNumChange", "rspPlayerStateChange", "rspPlayerMove", "askEnterMaze", "askMazeTransmit", "askLeaf", "askMove", "moveToTarget", "askUseItem", "askPickupReady", "askPickUp", "enterMaze", "\u8fdb\u5165\u65b0\u7684\u697c\u5c42\uff1a", "roomId", "clearLeave", "MazePlyMod", "clearSceneLeave", "\u79bb\u5f00\u697c\u5c42", "removePlayer", "updateSglPly", "updSglPlyMv", "useItemNum", "gateState", "changePortalState", "boxFlyIntoBag", "setCurBoxState", "itemNum", "firstInfo", "isInMaze", "onMyPlayerMove", "pickupIndex", "chm.MazeMdu", "MazeViewMediator", "_lastBoxIds", "MazeConfig", "MazeMainPnl", "rightpanel", "MazeMainRtPnl", "awardPanel", "MazeAwdPnl", "MazeProg", "_arrow", "MazeArrow", "MazeTip", "portalStateChange", "showAwardPanel", "hideOtherPlayer", "updateShowMazeBoxAfterPick", "updateItemNum", "hideItemBtn", "resetCurMapId", "playRoomChangeEff", "showLastRightPortal", "refreshLastBoxCount", "mazeInfoUpdate", "getMapIdByRoom", "lastMapId", "setRoomId", "getCurBonusCount", "setBonusCount", "maze_countdown", "refreshMapEffect", "refreshMapArrow", "getBoxVOArr", "MazeBoxView", "addOneBoxToDic", "maze_box_update", "updateBoxView", "initOthPly", "startSceneLoop", "HASBOUGHT", "clearLastRoomIdCache", "stopArrow", "_lastUpdateTm", "updateShowMazeBox", "getMazeBoxByMyView", "getCurBoxDic", "clearOneBoxByIndex", "getPickupBoxView", "lbl_type", "removeBoxEff", "removeLastEff", "clearAllDoorEffs", "getCurRoomId", "getMaxRoomCount", "MazePortalVO", "posXY", "touchSp", "onTouchEvent", "portalVOArr", "clearOneDoorEffByIndex", "portal", "startArrow", "initArrowState", "k_549", "getCurMazeItemNum", "refreshItemNum", "pingbiState", "_groupTip", "_imgTip", "mizhenevent_1_png", "downfloor_", "mizhenevent_3_png", "mizhenevent_2_png", "upfloor_", "mizhenevent_4_png", "effEnd", "chm.MazeVMed", "MazeBoxViewSkin", "setBoxData", "group_effect", "group_owner", "checkIfLastTimeLimit", "getLastBoxCostByType", "k_547", "playCollectEff", "boxBottomEff", "boxCollectEff", "removeCollectEff", "boxLastEff", "canget", "needbuy", "BOX_SRC", "mizhenbox_1_png", "mizhenbox_2_png", "mizhenbox_3_png", "mizhenbox_4_png", "mizhenbox_6_png", "mizhenbox_7_png", "mizhenbox_8_png", "mizhenbox_9_png", "chm.MazeBoxView", "tenBonusArr", "twenBonusArr", "firstBonusArr", "initJson", "_roomJson", "mazeroom_json", "_settingJson", "mazesetting_json", "getLevelLimit", "openLimited", "4080", "PLAYERLEVEL:", "getCamUseItemVO", "itemEffect", "MazeItemVO", "mizheneye_", "getMazeRewarConfig", "exploreReward", "tenthexploreReward", "twentyexploreReward", "getMazeProgTime", "boxCd", "getItemPrice", "getBuyTime", "itemCost", "getLastPosArr", "lastboxposition", "lastRoomBoxCost", "getLastRoomBoxFreeTime", "lastRoomArriveTime", "getMazeDuration", "roomsNum", "chm.MazeConfig", "_arriveT", "_numOfPortal", "_isInMaze", "_lastMapId", "curBoxDic", "_roomId", "_lastRoomId", "numOfPortal", "_initX", "_initY", "_buyTime", "itemBuyNum", "arriveTime", "_useStates", "_boxVOArr", "clearBoxDic", "MazeBoxVO", "getBoxNameByType", "calculateLeftPortalNum", "checkIfMazeOpen", "k_1486", "k_542", "k_543", "checkIfFirstPlayer", "_firstInfo", "_moveToTarget", "k_1377", "k_1378", "k_1379", "k_1380", "k_1381", "k_1382", "k_1383", "_pickupIndex", "pickupStartTime", "_pickupStartTime", "checkIfPickFirstBox", "chm.MazeMod", "_otherPlayerDic", "MAX_PLAYER", "_playerNum", "_pingbiState", "playerID", "crtOthPly", "getMazePlayer", "MazePlayer", "simplePlayerInfo", "fillMapPlayerInfoDataByInfo", "addLoopAI", "maze_scene_loop", "loopSceneCheck", "chm.MazePlyMod", "_arrowStateArr", "MazeArrowSkin", "GREEN_ARROW_SRC", "initArrowVisible", "showRight", "delWrong", "RED_ARROW_SRC", "delAni", "arrow_red_png", "arrow_green_png", "chm.MazeArrow", "_tenGridArr", "_TwenGridArr", "_firstGridArr", "MazeAwardPanelSkin", "mizhenjiangli_png", "hideAwardPanel", "fillGridArr", "tenBonus", "twnBonus", "firstBonus", "fillAwardPanel", "group_explore", "group_first", "group_ten", "group_twen", "spMask", "chm.MazeAwdPnl", "MazeItemRenderSkin", "touchEvent", "removeItemEff", "removeCurEff", "lbl_buyTip", "k_550", "k_551", "k_552", "playHaveEff", "playScaleAni", "k_548", "MazeItemRender", "chm.MazeItemRender", "_lblAlpha", "MazeMainPanelSkin", "$onRemoveFromStage", "lbl_roomId", "k_545", "lbl_bonusCount", "k_546", "chm.MazeMainPnl", "_lastNumArr", "MazeMainRightPanelSkin", "lastCount", "chm.MazeMainRtPnl", "maze_pickup_progress", "chm.MazeProg", "MazeTipSkin", "buyHandler", "mazeitemconfig_json", "canbuy", "group_buy", "chm.MazeTip", "chm.MazeBoxVO", "chm.MazeItemVO", "changeAI", "stopLoopAI", "chm.MazePlayer", "chm.MazePortalVO", "chm.MazeRoomChangeVo", "MilitaryRankModule", "MilitRkVMed", "rspChopChange", "rspRkPlyIf", "askPlyIfdt", "getRankdatainfo", "top3ids", "setTop3PlayerInfo", "chm.MilitRkMdu", "MilitaryRankViewMediator", "_currentPosition", "MilitRkV", "position_title1_png", "showRank", "euiMiliRank", "btn_info", "getWeiwang", "hideInfo", "euiMiliRkIf", "hideRank", "rankList", "onSwithIfHdler", "lastBtn", "nextBtn", "CONFIG_ID_CHANGE", "configIdChange", "JUNGONG_CHANGE", "jungongChange", "RANK_ROLE_CHANGE", "refRole", "img_militaryrankBg", "position_bg_jpg", "refreshProp", "firstEff", "refreshBar", "resetView", "xbtx_eff", "refreshRole", "getTop3Players", "title_des", "k_553", "position_", "prop_now", "prop_next", "k_554", "lbl_bar", "showMilitaryRankInfo", "frhMiliRkIf", "refreshStatistics", "rank_next", "rank_icon", "desLbl", "k_558", "income", "hideMilitaryRankInfo", "hideRankList", "chm.MilitRkVMed", "chop_json", "chm.MilitaryRankConfig", "_jungong", "_configId", "_top3Players", "_preConfigId", "MilitaryRankListVO", "rankLevel", "jungong_change", "config_id_change", "rank_role_change", "chm.MilitRkMod", "MilitaryRankListView", "MilitRkLst", "MilitRkLstRnd", "lbl_myrank", "MilitRkLstV", "chm.MilitRkLstV", "MilitaryRankView", "MilitRkPnl", "MilitRkIf", "nomanImg", "chm.MilitRkV", "lbl_rank_title", "lbl_jungong", "lbl_yue", "img_yue", "paihang_v", "chm.MilitRkLstRnd", "MilitaryRankInfoSkin", "chm.MilitRkIf", "MilitaryRankListSkin", "chm.MilitRkLst", "MilitaryRankPanelSkin", "chm.MilitRkPnl", "chm.MilitaryRankListVO", "MoldingMed", "mHdPa", "akfMold", "akfTp", "chm.MoldingMdu", "_selectPos", "_waitIndex", "MoldingMod", "MoldingV", "initGrc", "onGirdClik", "figure_title1_png", "pal", "rspBtnClk", "wclk", "showMst", "master", "showSkTip", "closePop", "ppal", "skTipPal", "hroLstCg", "zhChge", "hro_point", "updateHLst", "ckShowRed", "sltHro", "hroRdAr", "updateBs", "ckIcEft", "setBtnState", "topo_jie", "getTLv", "maxLv", "getBlsCfg", "getSkLv", "sk_icon", "getMoSta", "getTpCfg", "lblCostName", "upProp", "prop_tp", "k_1385", "lblPropL", "lblPropR", "k_1386", "addPr2", "getProStr", "arrow", "k_1387", "k_1388", "sltPos", "cast_quan", "cgGraic", "stopMwat", "godcast_effect01", "godcast_effect02", "_iconEffs", "_iconLocks", "fazhen_lock_png", "playTpEft", "_tupoEff", "_lastLv", "ckEagWay", "ckTpLmt", "k_1389", "tranCst", "showGetway", "chm.MoldingMed", "getSlNum", "_bleCfg", "bless_lv_json", "_maxLv", "getSkCfg", "_blessSkillConf", "blesspassive_json", "_sl2Sk", "skillLv", "blesssetting_json", "mxSkLv", "skLv2Lv", "getPsDes", "HURT_DOUBLE", "{", "{pram0}", "pram0", "{pram1}", "pram1", "k_6", "_sshowRed", "red_point", "chm.MoldingMod", "MoldingSpiritSkin", "MoldEui", "chm.MoldEui", "MoldProEui", "TipSkPal", "crtGrids", "initHrLst", "MoldRound", "GridRoundIcon", "ckHro", "chm.MoldingV", "MoldingPropEuiSkin", "hunL0", "k_725", "hunL1", "k_726", "hunL2", "k_727", "hunR0", "hunR1", "hunR2", "topR", "k_723", "tupoL", "tupoR", "chm.MoldProEui", "GridMoldRoundSkin", "loaded", "_inited", "chm.MoldRound", "TipSkillPanelSkin", "mk", "k_757", "chm.TipSkPal", "_vewMed", "MoonMed", "rspPrivilegeCardInfo", "getPrivilegeCardInfo", "askForBuy", "getData", "mvMed", "zhizunTime", "suprCopyCount", "chm.MoonMdu", "MoonV", "yueka_title_png", "REOPEN_REFREH", "addR", "MOONCARD_GIRD_TOUCH", "MoonCardRender", "MOONCARD_BTN_TOUCH", "selecId", "MOON_CARD_ID", "ReCData", "ZHIZUN_CARD_ID", "_listTimeOut", "mooncard_loop", "k_560", "k_559", "reopen_refresh", "chm.MoonMed", "_icons", "yueka_icon1_png", "yueka_zhizun1_png", "yueka_newtitle2_png", "yueka_zhizun_png", "_mey", "_zhizunTime", "zzParseXml", "monthcard", "property", "_boxAdd", "maxstoryexp", "_bossCount", "quanminbossAddNum", "_ttCount", "tiantiAddNum", "_kuTtCount", "crossTiantiAddNum", "_poiCount", "prisonerNum", "getZhiZunTime", "getPoisCount", "getMonList", "MoonCardVo", "isBuy", "chm.MoonMod", "_bgName", "yueka_bg6_jpg", "yueka_bg5_jpg", "MoonEui", "gef", "yueka_kuangkuang_png", "img_bg0", "yueka_newtitle_png", "moonCard1", "moonCard", "mon1", "mon2", "group_zz", "yueka_zhanshi1_png", "yueka_newtitle1_png", "k_1071", "img_life", "k_1072", "yueka_zhanshi2_png", "yueka_zhizunchenghao1_png", "yueka_zhizunchengha_png", "chm.MoonV", "MoonCardRenSkin", "isDoubleCard", "\u672a\u8d2d\u4e70", "\u5143\u62a2\u8d2d", "mooncard_gird_touch", "mooncard_btn_touch", "chm.MoonCardRender", "chm.MoonCardVo", "MoonCardPanelSkin", "chm.MoonEui", "isIn", "NBiqiMed", "_mmed", "NBiqiMMed", "reqPlayers", "upScore", "atkReq", "tarChge", "onPickBox", "resEnter", "resEnd", "resChge", "resTurn", "resRank", "resOtherIn", "resKill", "resBuff", "resPoCg", "resLeave", "resMov", "resDeath", "resreBorn", "reScr", "rePlaInf", "resScrRe", "resAllRank", "resBuffInfo", "reqEnterNight", "reqPick", "sEnd2", "getTargetInfoByID", "sEnd3", "mapChge", "zhanJI", "monsterTypeId", "setAttackFail", "k_164", "enterNightBiqi", "nextPharse", "nextTurnInfo", "setNextTurnInfo", "NightBiqiPointVO", "changeBoxBuff", "updateDelInfo", "setMyScore", "resScrCg", "showFlyEffect", "reqAutoReborn", "chm.NBiqiMdu", "NBiqiPan", "rpanel", "NBiqiRPan", "apanel", "NBiqiAPan", "initTabBar", "togChge", "closeWin", "night_fighting_json.night_fighting_rank_title_png", "night_fighting_json.night_fighting_reward_title_png", "_preV", "getPRwdInfo", "gScrRwd", "chm.NBiqiMed", "_myScr", "_rwdNum", "_rebornT", "mainKey", "mNightBiqiMainKey_secend", "mNightBiqiMainKey_loop", "_lreborn", "mpan", "NBiqiMP", "mache", "NBiqiAchP", "matk", "NBiqiMAP", "mrank", "NBiqiMRP", "mreborn", "NBiqiRoP", "enemyV", "NBiqiMEV", "clearAlt", "NBiqiCDP", "endpan", "NBiqiMEP", "group_selectRole", "set_time", "enemyGroups", "initAttackableGroups", "grayM", "cRank", "touchGetAchieve", "SetFuhuo", "C_ImmediateReborn", "hideAlertV", "onBuffTap", "mian_list", "atkChge", "enterAffiche", "nightBiqiEnd", "lb_myLabel", "NightBiqiachieve", "lab_combatgains", "tweenCom2", "tweenCom", "upSec", "sRebornV", "upRbTxt", "employGold", "setYuanbao", "mNoAlertTip", "Reborn", "nextSideTime", "lbl_nextTime0", "k_567", "k_568", "lbl_sltime0", "chm.NBiqiMMed", "chm.NightBiqiStatic", "_myRwdName", "_myScrRwd", "_myScrIdx", "points", "trans2", "phase", "getNew", "NightBuffItem", "k_1318", "chm.NBiqiMod", "jifenReward", "nightbiqi_json", "jifen", "_data_r", "playerReward", "getBuffPos", "_buffPos", "buffPos", "refreshTime", "_mXYs", "NightBiQiSetting_json", "chm.NBiqiModCfg", "mPlayers", "mNum", "mMonsters", "_selMstKey", "tarIds", "mAttKey", "NightBiqiPlayer_mod_mAttKey", "mdelay", "_nSceDic", "max_pl", "max_sce", "nightBQFrameKey", "_lastSecend", "_halfSecend", "delPlayer", "del", "disTarChge", "getPlayerVo", "delayDelPlayer", "hpRadio", "onPKTouchTap", "trans3", "getTargetInfos", "checkTargetIsenemy", "checkSce", "checkMonster", "moId", "onPKTouchTap2", "desTime", "searchEnd2", "fillPlayerInfo", "NightScenePlayerVo", "chm.NBiqiPMod", "NightBiqiAwardSkin", "NBiqiRRed", "NBiqiARed", "chm.NBiqiAPan", "NightBiqiPanelSkin", "chm.NBiqiPan", "NightBiqiRankSkin", "NBiqiRkRed", "chm.NBiqiRPan", "_effMc", "_txtImg", "tongyong_di1_png", "setBmp", "_txt", "_idx", "night_fighting_fudian", "chm.NightBuffItem", "NightBiqiMainAchieveSkin", "chm.NBiqiAchP", "NightBiqiMainCDClearAlertSkin", "chm.NBiqiCDP", "_eGrps", "_mGrps", "NightBiqiMainAttackableSkin", "upMov", "moveEnd", "isMoveIng", "chm.NBiqiMAP", "NightBiqiMainEndSkin", "NBiqiMERed", "upd", "chm.NBiqiMEP", "NightBiqiMainEnemySkin", "mdata", "ENEMY_CLICK", "night_enenmy_click", "chm.NBiqiMEV", "NightBiqiMainPanelSkin", "NBiqiBRed", "chm.NBiqiMP", "NightBiqiMainGuildRankSkin", "NBiqiGRed", "chm.NBiqiMRP", "NightBiqiMainSetrebornSkin", "chm.NBiqiRoP", "NightBiqiAwardRenderSkin", "k_768", "chm.NBiqiARed", "NightBiqiRankoneRenderSkin", "chm.NBiqiRkRed", "NightBiqiRankRenderSkin", "chm.NBiqiRRed", "NightBiqiBuffRenderSkin", "lab_buff", "R", "chm.NBiqiBRed", "_rCo", "lbl_firstScore", "chm.NBiqiGRed", "NightBiqiMainEndRenderSkin", "chm.NBiqiMERed", "palyerName", "myIntegral", "NightBiqiRankVo", "NightBiqiEndVo", "chm.NightBiqiEndVo", "chm.NightBiqiPointVO", "playScore", "playScoreStr", "chm.NightBiqiRankVo", "chm.NightBiqiRewardVo", "chm.NightBuffVo", "chm.NightScenePlayerVo", "OlMed", "rspShare", "c_2159", "OFF_LINE", "onShare", "getDbLinebons", "chm.OLMdu", "bofist", "_shareGold", "_shareExp", "_showShare", "sharePanel", "OffLineShare", "onBtnSure", "hideShare", "doShare", "videoget", "btn_Vieoqd", "onchagebtn", "setBtnshow", "vdieoArr", "getVideReward", "falid", "ON_SDK_SHOW_VIDEOAD", "setTimeout", "k_1191", "k_1190", "lbl_yue2", "expMonthCardInc", "moneyMonthCardInc", "lbl_shen2", "expMagicWeaponInc", "lbl_shen", "moneyMagicWeaponInc", "lbl_zhuangbei", "equipcount", "lbl_fu1", "moneyRevengeBuffInc", "lbl_fu2", "expRevengeBuffInc", "lbl_fabao1", "moneyFabaoInc", "lbl_fabao2", "expFabaoInc", "lbl_shouquan1", "moneyAuthorizationInc", "lbl_shouquan2", "expAuthorizationInc", "sell", "lbl_man", "k_570", "lbl_offtime", "k_571", "k_569", "showlv", "VideoGiftMod", "doubleTimes", "checkShare", "chm.OlMed", "OffLineShareSkin", "chm.OffLineShare", "OfflineSkin", "isSHowVido", "gropVide", "chm.OLPan", "CZDecoMed", "decoEui", "CZDecoEui", "list_equip", "CZDecoRnd", "updEquLi", "updCQEquLi", "tapDeco", "clickLink", "group_link0", "group_link1", "group_link2", "updLi", "resID", "lab_text", "\u5206\u89e3\u88c5\u5907\u5c06100%\u8fd4\u8fd8\u76db\u4e16\u788e\u7247", "\u5206\u89e3\u88c5\u5907\u5c06100%\u8fd4\u8fd8\u6a59\u88c5\u788e\u7247", "getResList", "rfEquLi", "send1501", "send1502", "CZCfgMod", "group_link", "orLi", "cqLi", "chm.CZDecoMed", "oldItemNum", "oldCQItemNum", "me", "CZMed", "decoMe", "updateUI", "updEqu", "updItemEqu", "updItem", "onGetEquipHandler", "OE_SHOW_DECO", "showDecomposeAlert", "getCQInfo", "getEquLiByQua", "closePanel", "chgEqu", "CZDecoVo", "fjName", "fjNum", "chm.CZMdu", "czEui", "CZEui", "cqeui1", "cqeui2", "CZCQEquHefuEui", "cqEui", "decoAlert", "CZDecoAlert", "effOra", "seleIdx", "changeSelectEquip", "changeSelectChuangQiEquip", "onPoint", "onCQPoint", "lbl_getSuiPian", "lbl_getSuiPIan", "choosehero_bg_png", "orgEqus", "img_equip", "tapGrid", "clickSpecialGrid", "tapSJ", "btn_shengji", "tapHC", "btn_hecheng", "tapSP", "tapCQSP", "tapCQA", "btn_hechengTip1", "tapCQB", "btn_hechengTip2", "img_item3", "tapCQC", "btn_hechengTip3", "img_quitay3", "tapCQD", "img_item4", "btn_hechengTip4", "img_quitay4", "tapCQE", "tapCQF", "tapCQSJ", "tapCQHC", "viewResize", "img_orangeequipBg", "img_orangeequipBg0", "img_legendaryBg", "img_legendaryBg0", "panelVisable", "rfEqu", "rfOrInfo", "orVO", "lbl_level0", "img_item0", "levelNum", "k_574", "send1409", "send1423", "cqVo", "send1433", "send1425", "EQUID_SJ", "EQUID_XL", "EQUID_HAT", "send1424", "setGetEff", "playGetEff", "stopGetEff", "showTab", "equDic", "cqData", "beTj", "zhuansheng_str", "{0}   {1}", "chm.CZMed", "cfg", "chm.CZCfgMod", "_seleIdx", "chkOrDvd", "_dividRed", "_cqIdx", "wearEqu", "_wearEqu", "_orLi", "_cqLi", "getEqu", "bestEqu", "boRecommond", "_equDic", "_allPoint", "_cqPoint", "_cqAllPoint", "getEquLmt", "isMatch", "_cqData", "getWearEqu", "CZWearEquVo", "getEquVO", "CZEquVo", "chm.CZMod", "OrangeEquipDecompositionAlertSkin", "onDecompose", "chm.CZDecoAlert", "_dataJson", "k_575", "img_quitay", "k_573", "lbl_fenjie", "checkIfShenjie", "\u76db\u4e16\u795e\u6212\u4e0d\u53ef\u88ab\u5408\u6210,\u662f\u5426\u786e\u8ba4\u5206\u89e3?", "oeShowDeco", "chm.CZDecoRnd", "arrayDupRemove", "pickElmsFromArrayByProp", "pickElmsFromArrayByProps", "findmindIdxFarr", "chm.ArrayUtil", "LegendaryEquipmentHefuSkin", "img_select3", "img_select4", "lbl_level3", "lbl_level4", "chm.CZCQEquHefuEui", "OrangeEquipDecompositionSkin", "chm.CZDecoEui", "OrangeEquipSkin", "chm.CZEui", "chm.CZDecoVo", "chm.CZEquStatic", "CZVo", "valueNum", "chm.CZEquVo", "chm.CZVo", "chm.CZWearEquVo", "EquipAlertV", "showEqpAlert", "EqpAlertMed", "chm.EqpAlertMed", "_lastLvl", "_eqpMed", "OtherPopMod", "onGetEquip", "openNewSkill", "_skLmtAr", "_skMed", "SklAlertMed", "EqpCpVo", "compareEquip", "chm.OtherPopMdu", "_delayTime", "SkillAlertV", "btn_act", "k_517", "chm.SklAlertMed", "chm.OtherPopMod", "EqpAlertEui", "onEquip", "euipBtn", "lblname", "setLeftTime", "AddEquipAlertTime", "chm.EquipAlertV", "MduAlertEui", "onGet", "startPos", "main_title_boss_png", "k_512", "main_icon_guaji_png", "main_title_guaji_png", "k_513", "k_532", "k_535", "k_536", "k_541", "k_538", "k_539", "k_540", "chm.MduAlertV", "SklEqpEui", "chm.SkillAlertV", "AddEquipEuiAlertSkin", "chm.EqpAlertEui", "AddModuleEuiAlertSkin", "chm.MduAlertEui", "AddSkilEuiAlertSkin", "chm.SklEqpEui", "PtnerMed", "rNRole", "sHList", "lCom", "cCom", "fillHeroInfo", "PtnerMod", "send1422", "chm.PtnerMdu", "huoban_kaiqi_png", "PtnerV", "5201", "sIdx", "leftH", "btn_turnLeft", "rightH", "btn_turnRight", "group_click_right", "group_click_left", "qYPart", "btn_qiyong", "5200", "img_partnerBg", "huoban_beijing1_jpg", "selectpartVo", "k_576", "limitType1", "limitType2", "hasJob", "partnerList", "k_577", "k_578", "tureDir", "showIndex", "pVo", "sPVo", "chm.PtnerMed", "gHero", "gHeroLmt", "gLvLmt", "PtnerCMod", "chm.PtnerCMod", "_pVo", "limit1", "limit2", "PtnerVo", "PartVo", "_sVo", "chm.PtnerMod", "p0", "group_role", "p1", "p2", "img_role0", "img_role1", "img_role2", "initTar", "PtnerEui", "PartEui", "btn_man", "btn_woman", "tChge", "chm.PtnerV", "PartUISkin", "chm.PartEui", "PartnerSkin", "chm.PtnerEui", "chm.PartVo", "chm.PtnerVo", "_isFirstLogin", "PlayerSetMed", "reqHandAutoInfo", "checkAuto", "sendChangeLeader", "c_4801", "stopCheck", "_checkZz", "resetPlayerStatus", "startCheck", "leaseTime", "checkZhiZun", "getAutoConfs", "arrStates", "childStates", "c_4803", "chm.PlayerSetMdu", "PlayerSetV", "show_title_png", "showLogout", "logoutBtn", "playerSet", "\u6e05\u7406\u6210\u529f\uff01", "clearBtn", "cgLeader", "\u786e\u5b9a\u8981\u9000\u51fa\u6e38\u620f\u5417\uff1f", "isMeizuPlatForm", "exitBtn", "checkstate", "setHeroInfo", "_changeType", "changeLeader", "hidestate", "rolePosClick", "btn_pos", "playerPos", "attPosClick", "askChangePos", "changeRolsSucc", "selectIcon", "k_1398", "k_1399", "k_1400", "cgPosRole", "chm.PlayerSetMed", "_thisObjArr", "_funArr", "_ctrlArr", "ButtonCloseSkin", "setExtBack", "_extBack", "getStageCtrl", "getUpperCtrl", "compare", "setParents", "chm.BackResponse", "ChangeAutoBoxSkin", "grp_checkBox", "getChildState", "img_gou", "checkStatus", "k_1675", "k_1676", "k_1677", "ChangeAutoBoxRder", "chm.ChangeAutoBoxRder", "propStr", "hcArr", "ChangeAutoSkin", "ChangeAutoRder", "btn_yijian", "btnYiJian", "rspRender", "updateTimes", "updateGold", "upList", "getHandUpCigSet", "openHangupCost", "#DFC9AA", "k_1671", "getProps", "k_1668", "k_1664", "k_1663", "k_1669", "k_1665", "k_1670", "hangup_banner_bg_2_jpg", "hangup_banner_bg_1_jpg", "autoOneStatus", "k_1716", "k_1717", "c_4805", "getNxtStstus", "getChildStats", "k_1666", "c_4804", "k_1715", "ChangeAutoPanel", "chm.ChangeAutoPanel", "ChangeAutoRderSkin", "lists", "img_check", "img_no_check", "childDes", "CRderVo", "scrol", "chm.ChangeAutoRder", "_isTouch", "guji_jqr_png", "_verifyPoint", "_offPoint", "chm.HandUpBtn", "wingBossType", "chm.HandUpStates", "firstLogin", "curOneType", "_autoStates", "infoTimes", "isMainBossFight", "isMainBoss", "isEnter", "autoFightBegin", "autoFightEnd", "bossAutoFight", "bossInMyFight", "autoStates", "resetTime", "checkNum", "checkTimes", "getAutoConfMap", "checkAutoTm", "checkMBossByTime", "_autoConfs", "initConf", "_autoConfMap", "hangupAssistant_json", "ChangeAutoVo", "superVip", "rspNum", "choose1", "n_4802", "onStatus", "lastChild", "_curEnterType", "n_11400", "hangupsetting_json", "checkZzAndVip", "k_1661", "k_1713", "k_1714", "k_1667", "chm.ModuleCheckByTime", "famNeed", "checkPrison", "checkTT", "checkLockMon", "checkMainCityBoss", "checkPlay", "checkEncounter", "checkFamByTab", "checkCrossTT", "checkSmelt", "checkWingBoss", "checkFamTrial", "checkFam", "_mainBossTime", "expireTime", "escortCount", "lab", "lab1", "gotoHandUp", "PlaySetMed", "grp_zhizun", "sumaryEui", "grop_share", "chm.ModuleIfDo", "chm.ChangeAutoVo", "chm.CRderVo", "ChangeJobInfoPanelSkin", "lbl_value3", "setBook", "lbl_value4", "setAwake", "lbl_value5", "lbl_value6", "setZhuZai", "lbl_value7", "lbl_value8", "setFanTian", "lbl_value9", "lbl_value10", "lbl_value11", "BookCfgMod", "getPsvPwr", "getPassivePower1ById", "getSkillId", "ChangeJobInfoPanel", "chm.ChangeJobInfoPanel", "ChangeJobNewRderSkin", "radioClick", "radio1", "radio2", "deleteData", "zhuanzhi_text0", "oldType", "grp_radio", "radio_nan", "radio_nv", "roleSwitch_num_", "numIdx", "deleteDatas", "ChangeJobNewRder", "chm.ChangeJobNewRder", "ChangeJobOldRderSkin", "infoBtnClick", "img_info", "headClick", "isGray", "ChangeJobOldRder", "chm.ChangeJobOldRder", "oldJobInfo", "newJobArr", "\u6218\u58eb", "\u6cd5\u5e08", "\u9053\u58eb", "\u7537", "\u5973", "ChangeJobPanelSkin", "grp_old", "upSetData", "showJobInfo", "deleteHero", "changeSex", "ChangeJobVo", "jobList", "job_grp", "k_1611", "k_1605", "k_1608", "k_1609", "c_4024", "k_1607", "k_1610", "_jobView", "chm.ChangeJobPanel", "chm.ChangeJobVo", "selectArr", "_images", "characterbg_job_0_1_jpg", "characterbg_job_1_2_jpg", "characterbg_job_1_3_jpg", "ChangePosPanelSkin", "CgPosRender", "decItem", "img3", "CgPosVo", "_t", "\u89d2\u8272\u5df2\u5207\u6362\uff0c\u70b9\u51fb\u4e0b\u65b9\u53d6\u6d88", "sele3", "sele1", "sele2", "\u8bf7\u9009\u62e9\u89d2\u8272\u987a\u5e8f", "\u89d2\u8272\u663e\u793a\u987a\u5e8f\u672a\u66f4\u6362\uff0c\u8bf7\u91cd\u65b0\u6392\u5e8f", "\u6fc0\u6d3b3\u89d2\u8272\u540e\u624d\u53ef\u4f7f\u7528", "k_153", "k_154", "\u524d\u5f80\u5546\u57ce", "huanwei_text2_png", "gongji_text2_png", "huanwei_text4_png", "gongji_text4_png", "img_posDes", "huanwei_text3_png", "gongji_text3_png", "k_155", "k_156", "chm.CgPosPanel", "chm.CgPosRender", "chm.CgPosVo", "ChangeLeaderPanelSkin", "CgLeadEui", "chm.CgLeadEui", "HeroInfoRenderSkin", "show_zhanshi_{0}_jpg", "show_fashi_{0}_jpg", "show_daoshi_{0}_jpg", "HeroInfoRd", "chm.HeroInfoRd", "_imges", "huanwei_head_1_0_png", "huanwei_head_2_1_png", "huanwei_head_3_1_png", "_jobs", "role_text1_png", "role_text2_png", "role_text3_png", "PlayerPosPanelSkin", "list_pos", "PlayerPosRender", "list_fight", "lbl_actived", "RolePosVo", "huanwei_head_", "PlayerPosPanel", "chm.PlayerPosPanel", "PlayerPosRenderSkin", "shunxu_", "chm.PlayerPosRender", "PlayerSetPanelSkin", "PlayerSetEui", "chm.PlayerSetEui", "changeAuto", "chm.PlayerSetV", "chm.HeroInfoVo", "chm.RolePosVo", "PlaySetModule", "addEventListen", "checkRedPoint", "checkActityTime", "onLoginReady", "showPlayRed", "reqCopyReward", "reqCopyInfo", "showRedPoint", "reqNextTime", "trimRedData", "delayRequstEnter", "playRedArr", "timeTypes", "getISInSWBQTime", "setPlayRedArr", "startTimes", "rspCopyInfo", "rspCopyReward", "rsqShareSuc", "setPlayRedDic", "--------------------\u5206\u4eab\u6210\u529f \u901a\u77e5\u670d\u52a1\u7aef--------------------", "ShareEnergySuc", "S_SScene_GetCopyCountsRewad_Sucess--------------\u8fd4\u56de", "k_1511", "k_1612", "askForsuprCopy", "chm.PlaySetMdu", "PlaySetMediator", "_maxSuprCount", "PlaySetEuiView", "play_title_png", "suprCountChange", "onTZClick", "btn_tz", "\u6ca1\u6709\u6311\u6218\u6b21\u6570", "chm.PlaySetMed", "redPointData", "tabRedDic", "analyserConfig", "getList", "_playObj", "refreshPlaySetData", "playSumary_json", "PlaySetVo", "lvLimit", "limitDesc", "isShowRule", "ruledesc", "SwbqCfgMod", "_pretime", "_prepareTime", "_soilderTime", "playStartTmDic", "_shareEnergy", "_copyEnergy", "getMaxEnergy", "_countdown", "getEnergyCfg", "energyJsn", "copyenergysetting_json", "getRecoverRate", "getRecoverCost", "buyBonus", "getFightCost", "fightCost", "chm.PlaySetMod", "lbl_tiliNum", "13000", "CailiaoRnd", "chm.CailiaoRnd", "PayAlert2Skin", "onPop", "onOk", "#F4BE07", "k_1508", "k_1512", "onEnergy", "k_1509", "tipPop", "\u60a8\u7684\u4f53\u529b\u5df2\u8fbe\u6700\u5927\u4e0a\u9650!", "BUY", "1.\u9014\u6e38 - share ---------", "shareSuc", "2.\u9014\u6e38 - share ---------", "\u89e6\u53d1\u6210\u529f\u56de\u8c03\uff1ashareSuc", "LINK", "PayAlert", "chm.PayAlert", "timerKey", "PlaySetEui", "PlaySetEuiSkin", "PayBtn", "btn_share", "13001", "13003", "countDownChange", "13005", "k_1510", "#19EA45", "onCountDown", "chm.PlaySetEui", "GameSumaryView", "nselected", "alertEui", "list_supr", "personTab", "limitTab", "cailiaoTab", "suprTab", "onListClick", "8607", "fubenFightClick", "8602", "8608", "\u5927\u5200\u4f8d\u536b\u672a\u5f00\u542f", "updateZhizunView", "PlaySetItemEui", "k_303", "img_zhizun", "zhizun_bg_jpg", "chm.PlaySetEuiView", "SuprRender", "chm.SuprRender", "PlaySetItemEuiSkin", "k_480", "\u5956\u52b1\u9884\u89c8", "k_1401", "lblLimitTime", "lblLink", "BossCountDown", "onCheckMainCityBoss", "k_489", "k_488", "chm.PlaySetItemEui", "ruleDesc", "chm.PlaySetVo", "PortMed", "portChange", "roundChange", "chapterprocessChange", "_maxProtNum", "getProtData", "chm.PortMdu", "getchapter", "PortMainV", "port_name_png", "rewardpanel", "portChg", "rewardStateChg", "chapterProcessChg", "rankChg", "rank_group", "ask4RankInfo", "getFrontThree", "chapterVO", "checkState", "addreward", "ask4MainBoss", "onAlert", "ask4ChapterBonus", "img_PortBg", "port_back_jpg", "chm.PortMed", "_rewardState", "_currentNum", "_portConfDic", "rspChapterBonus", "getrankVO", "getrankVOArr", "PortVO", "monsterIcon", "totalPort", "maxPortID", "minPortID", "currentPort", "dropID", "dropCount", "PortShowVO", "chapterVOArr", "port_chapter_json", "PortChapterVO", "drop", "guideNextStep", "guideId", "portshow_json", "getPortArr", "MONEY:", ",EXP:", "\u5173\u5361\u5b88\u536b\uff1a", "\u5956\u52b1\uff1a\u5143\u5b9d\u3001\u91d1\u5e01\u3001\u88c5\u5907\u3001\u6750\u6599", "\u5956\u52b1\uff1a\u6a59\u88c5\u788e\u7247\u3001\u91d1\u5e01", "\u5956\u52b1\uff1a\u7ecf\u9a8c\u3001\u91d1\u5e01", "\u5956\u52b1\uff1a\u9f99\u9cde\u788e\u7247\u3001\u91d1\u5e01", "\u5956\u52b1\uff1a\u9f99\u7eb9\u788e\u7247\u3001\u91d1\u5e01", "\u5956\u52b1\uff1a\u795e\u7fbd\u788e\u7247\u3001\u91d1\u5e01", "MONEY:300000,112:4", "MONEY:300000,113:4", "MONEY:300000,104:20", "MONEY:600000,112:8", "MONEY:600000,113:8", "MONEY:600000,104:30", "MONEY:1200000,112:16", "MONEY:1200000,113:16", "MONEY:1200000,104:30", "MONEY:1200000,346:3", "\u95ef\u5929\u5173\uff1a", "\u5956\u52b1\uff1a\u6218\u7eb9\u3001\u6218\u7eb9\u7cbe\u534e", "chm.PortMod", "PortMainEui", "PortRewardEui", "btn_getreward", "rewardgrid", "k_582", "img_monster", "lbl_monsterName", "jdt", "lbl_chapter", "k_581", "k_580", "chm.PortMainV", "PortRank", "paihang_title_png", "PortRankRnd", "chm.PortRankV", "lbl_prot", "chm.PortRankRnd", "PortMainPanelSkin", "figure_jingyan2_png", "figure_jingyan1_png", "chm.PortMainEui", "PortRankSkin", "chm.PortRank", "PortRewardPanelSkin", "chm.PortRewardEui", "chm.PortChapterVO", "chm.PortRankVO", "chm.PortShowVO", "chm.PortVO", "PrisonMed", "showPrison", "onStart", "rqsCleanCd", "rqsOKGold", "rqsRfQlt", "rqsRob", "rqsRevenge", "rqsReceive", "rqsRecord", "rqsShowRed", "dartId", "robberyCount", "freeRfCount", "freeRefreshCount", "darts", "k_611", "k_612", "k_613", "records", "redLogPoint", "akfV", "akfStart", "askforFinish", "akfOKGold", "akfRfQual", "askforRob", "akfRev", "akfRec", "receive", "askforRecord", "askforFlush", "preAskTime", "k_620", "akfOR", "chm.PrisonMdu", "bgImages", "dartviews", "imageW", "prisonW", "PrisonV", "sltPanel", "PrnSelectRd", "reAlertPal", "PrLogRd1", "logPanel", "PrnLogRd", "showSelect", "doFlush", "btn_flush", "closeSelect", "closeLog", "startDart", "okGold", "rfQua", "fastFinish", "fast_finish", "doAlertBtn", "closeAlert", "pull", "pullByGold", "dartIdCg", "esCountUp", "robCountUp", "dartsUp", "recordsUp", "goldUp", "PRISON_USE_POTION", "PrnAlReEui", "prnUsePos", "9007", "doRevenge", "9008", "doRob", "showRAPal", "itemClk", "getDICfg", "PrisonCfg", "fixedReward", "cannotImage", "expiretime_loop", "timet", "closeRdAlt", "dartCount", "count0", "costAcer", "qualityBuyCount", "#ccc9c3", "k_600", "consume0", "gold0", "k_601", "doubleRaward", "getPrisonItem", "PrnItemEui", "altPalVo", "otherName", "timeh", "rewardt", "k_607", "k_608", "revengeReward", "spareRobCount", "k_616", "k_609", "k_610", "percent", "mvUpBg", "hideLog", "hideSelect", "prisonitem_loop", "prisoner_bg2_png", "k_617", "k_618", "hideReAlert", "DartVo", "EscortRecord", "otherPlayerId", "showPPAlert", "#0180f0", "#9d2bbb", "#d85521", "k_615", "k_625", "k_614", "clearCdAcer", "showReAlert", "robRecords", "notip", "prAlRev", "chm.PrisonMed", "dartconfig_json", "dart_json", "chm.PrisonCfg", "_epiTime", "_dartId", "_esCount", "_robCount", "_freeRfCount", "_darts", "_records", "_batBonus", "_redLogP", "chm.PrisonMod", "PrnMainEui", "PrnLogEui", "PrnSltEui", "PrnArtEui", "PrnRwAltEui", "prisoner_yajie_title_png", "chm.PrisonV", "k_602", "k_603", "k_604", "chm.PrLogRd1", "PrisonAlert2Skin", "group_potion", "prison_use_potion", "chm.PrnAlReEui", "PrisonAlertSkin", "chm.PrnArtEui", "PrisonRenderSkin", "prisonName", "k_619", "prisonTime", "k_605", "<font color=\'#cd1b1f\'>0</font>", "prisonEffect", "_move_2", "k_606", "chm.PrnItemEui", "PrisonLogSkin", "chm.PrnLogEui", "isRobWin", "k_621", "k_622", "k_624", "k_623", "chm.PrnLogRd", "PrisonMainSkin", "chm.PrnMainEui", "PrisonRewardAlertSkin", "chm.PrnRwAltEui", "prisoner_lvl", "chm.PrnSelectRd", "PrisonSelectSkin", "chm.PrnSltEui", "RankMed", "_rMed", "RRoleMed", "cPInfo", "CHAT_INFO", "pChge", "rRInfo", "rRWInfo", "rRPInfo", "openRank", "showRole", "askPalyerInfodata", "askForWorship", "rPlayer", "gRData", "chm.RankMdu", "rRXMl", "RankV", "lbl_mobai", "rIndxChge", "rankPlayerInfo", "checkPlayerInfo", "rankChge", "playerChange", "ownChge", "title_group", "rankVo", "gTitle", "worship", "gHJob", "gIdx", "k_698", "lbl_lingqu", "chm.RankMed", "RoleViewMediator", "wEquip", "heroChange", "rChgeTab", "resizeRoleView", "selectSkill", "img_heroBg", "figure_beijing2_jpg", "img_wingBg", "figure_beijing1_jpg", "img_skillBg", "figure_beijing3_jpg", "img_meridianBg", "figure_pulse_jpg", "stopEff", "filList", "filheroF", "fillEquip", "wearEquipArr", "fillMasterSuit", "masterSuitUIArr", "fillTeJie", "teJieUIArr", "fillWing", "lbl_cost_tisheng", "k_710", "k_709", "level_group", "maxLevel", "group_wingInfo", "w_num", "lbl_openTip", "k_711", "btn_jihuo", "itemcost", "k_699", "lbl_cost_wingtisheng", "fillSkill", "sSkill", "filSelSkill", "skillArr", "lbl_cost_quanbuTisheng", "next_lbl_des", "fillMeridian", "lbl_valueNext", "setMeridianFight", "startEff", "mEff", "mCur", "img_p", "meridian_effect", "meridian_effect_current", "setWingFight", "clickChaKan", "showValueList", "HeroValueMgr", "fillTTInfo", "singleFightInfo", "grp_tt", "lbl_jie_tt", "lbl_star_tt", "img_icon_tt", "fillMyFamInfo", "lbl_fam_name", "hList", "selHero", "wearChge", "suitChge", "tejieChge", "wingChge", "merChge", "skillChge", "heroFChge", "chm.RRoleMed", "RankCfg", "chm.RankCfg", "_rPlayer", "_pData", "rankindex", "RZLVo", "zhizunCard", "otherValue", "RankVO", "limitparam", "chm.RankMod", "RankPanelSkin", "RankPan", "chm.RankPan", "group4", "lbl_name4", "lbl_lv4", "img_yue4", "group_vip", "img_vip4", "k_501", "rank_img", "paihang_TOYP_png", "k_691", "setKingRankdata", "k_686", "paihang_little_friend_png", "k_692", "k_693", "k_694", "k_695", "k_696", "lbl_other", "k_697", "group_vip2", "lbl_winnum", "k_687", "lbl_mydw", "RankRed", "chm.RankRed", "paihang_di2_png", "verticalCenter", "getnameArr", "tab_", "chm.RankV", "group_TeJie", "group_masterSuit", "initSuit", "initTeJie", "initSkillG", "btn_changeEquip", "btn_orangeEquip", "btn_zhuhun", "imgZhuhunTip", "lbl_chakan", "chenghao_group", "grp_tt0", "long_group", "group_tisheng", "group_jihuo", "group_shengjie", "group_dan1", "group_dan2", "btn_shengJie", "btn_tisheng", "lbl_costname", "lbl_jingjieTip", "togBtn_skill", "k_688", "initWingFightNum", "initMeridianFightNum", "RolePan", "HeroEui", "WingEui", "SkillEui", "MeridianEui", "clickH", "togBtn_hero", "togBtn_feather", "togBtn_meridian", "jineng_title_png", "showReBornData", "RebornMod", "k_708", "img_masterSuit", "img_TeJie", "clkEquip", "GRIDSKILLCOUNT", "group_bg", "img_skillGrid", "h_num", "m_num", "clkSkillG", "chm.RRoleV", "chm.RankVO", "chm.RZLVo", "ReRollerMed", "rolleUp", "rspRoData", "resRRGSuc", "rspRollerLogs", "checkIfRollerRed", "akfRData", "askForRoll", "curRoSta", "k_701", "repRolLog", "filStar", "turntablestates", "curScore", "startRoll", "rollLog", "rollEui", "chm.ReRolMdu", "startEui", "RollStarsEui", "RollEui", "zhuanpan-tittle4_png", "hidePanel1", "hidePanel2", "RECHARGE_ROLLER_ENTER", "flRoll", "RECHARGE_ROLLER_ROLL", "askRoll", "tempPanel", "chm.ReRollerMed", "getSetCfg", "getAllitems", "turnTable_json", "getRItem", "turntablesetting_json", "ReRolCfg", "chm.ReRolCfg", "starCtAr", "starsSAr", "starsVAr", "_allItems", "RollItemRd", "Score", "scoreCost", "preTurn", "getAllItems", "_curRSta", "_curScore", "_rollLog", "recharge_roller_enter", "recharge_roller_roll", "chm.ReRolMod", "TYPE_BLUE", "TYPE_PURPLE", "TYPE_GOLD", "RENDER_BGSRC_ARR", "zhuanpan_kuang1_jpg", "zhuanpan_kuang2_jpg", "zhuanpan_kuang3_jpg", "RENDER_STARSRC_ARR", "zhuanpan_star01_png", "zhuanpan_star02_png", "zhuanpan_star03_png", "ReRolStatic", "chm.ReRolStatic", "itemGroups", "RechargeRollerPanelSkin", "group9", "group10", "group11", "group12", "rollAsk", "btn_start", "list_getShow", "RollGSRd", "img_selectbox", "k_704", "zhuanpan_master1_jpg", "UNIT_DEGREE", "pointIndex", "RechargeRollerGetShowVo", "itemValue", "itemQColor", "_pointIndex", "MAX_ITEM_LEN", "chm.RollEui", "RechargeRollerItemSkin", "_setid", "_gridVo", "itemImg", "img_itemBg", "chm.RollItemRd", "RechargeRollerStarsPanelSkin", "list_lvlStars", "RollStaRd", "btn_enterRoller", "maxScore", "scoreArr", "zhuanpan_master2_jpg", "k_700", "lbl_lvl0", "lbl_scoretotal", "k_703", "k_1403", "RechargeRollerStarStateVo", "starcount", "k_902", "chm.RollStarsEui", "RechargeRollerGetShowRenderSkin", "k_702", "chm.RollGSRd", "RechargeRollerStarListRenderSkin", "img_plugin", "RollListRd", "chm.RollListRd", "RechargeRollerStarRenderSkin", "list_stars", "chm.RollStaRd", "chm.RechargeRollerGetShowVo", "chm.RechargeRollerStarStateVo", "searchAdd", "CREATE", "FIGHT", "FIND_NPC", "find_npc", "RobotData", "chm.RobotData", "_robotStart", "_timeDelay", "RobotMod", "startRob", "clearRobot", "startRobot", "chm.RobotMdu", "robPlayers", "selectAIData", "aiDatas", "targetPos", "coatids", "coatid", "weaponids", "weaponid", "randomName", "maxNum", "RobotCap", "startAI", "stopLoop", "RobotCreate", "addScene", "removeScene", "chm.RobotMod", "atkey", "actIndex", "isInscene", "act_AI", "_dfKey", "robotAI_Fight", "doAI", "setHand", "createMons", "_mvDelay", "findMonEnd", "release", "updateFea", "delayHurt", "fightRender", "getRbMon", "RobotMons", "getRbPlayer", "RobotPlayer", "weaponId", "chm.RobotCap", "chm.RobotMons", "chm.RobotPlayer", "_lastHeroNum", "oldLevel", "RoleMed", "hideModule", "onChgLv", "onEqu", "askHeroProp", "askForHeroProp", "checkEquipRed", "updateDanData", "reqRoleSwitch", "cZzRed", "checkZhuhunRed", "checkRebornRed", "checkWingRed", "checkWingEquipRed", "checkWingEquipComposeRed", "checkGrowRed", "checkFlyRed", "checkMeridianRed", "onBtnCreate", "itemChg", "heroliChg", "checkTejieRed", "checkDressRed", "EQU_RED_SHOW", "ZHUZAI_RED_SHOW", "REBORN_RED_CHG", "TEJIE_RED_SHOW", "WING_RED_SHOW", "MERIDIAN_RED_SHOW", "WING_DAN_RED_SHOW", "c_4583", "c_4580", "danDatas", "ckEquRed", "ckTejieRed", "ZZMod", "ckDrsRed", "getOrangeRed", "ckWingRed", "ckWingEquRed", "ckWingEquComposeRed", "boEquipShowRed", "boTejieShowRed", "tZzRed", "boWingShowRed", "boWingEquipRed", "boMeridianRed", "GrowTotRed", "flyTotRed", "dIconRed", "chm.RoleMdu", "oldSendTime", "oldSelfMoney", "oldVipLevel", "oldRLv", "oldyuMaoItem", "item_721_png", "item_722_png", "_effName", "figure_zizhijihuo_png", "figure_feishengjihuo_png", "_lvlNas", "\u5341\u4e00", "\u5341\u4e8c", "\u5341\u4e09", "\u5341\u56db", "\u5341\u4e94", "\u5341\u516d", "_roleMod", "_rebornMod", "rebornExpPanel", "RebornExpRnd", "addEvents2", "hideDanPanel", "roleChgTab", "clickHeroEquip", "changeEquip", "clickOrange", "clickZhuhun", "clickChenghao", "clickMingcheng", "clickLongWen", "wingTSPT", "wingTSYM", "btn_wingtisheng", "wingJihuo", "wingShengJie", "btn_shengjie", "wingAuto", "wingLvOne", "showWingEqu", "showDanPanel", "yuyiDan", "clickJingMai", "zsLvlUpClick", "rebornView", "openExpPanel", "lab_getXw", "RealmPnl", "closeExpPanel", "REBORN_EXP_EXCHANGE", "askForExpExchg", "lblGetWay", "clickReinc", "reinc_group", "UPD_WINGEUI_SHIFTBTN", "updWingSftBtn", "CHANGE_WING_WEAR", "changeWingWear", "updateDanPanel", "checkAutoLabel", "fillActiveEff", "tab_change", "tabChange", "wearEquChg", "wingInfoChg", "meriInfo", "tishi", "setZhunhunRed", "suitsInfoChg", "setLongWenRedPoint", "teJieInfoChg", "REBORN_DATA", "fillRebornPanel", "FILL_EXP_DATA", "fillRebornExpChg", "setRebornRed", "setJueseRed", "setWingRed", "setMeriRed", "equipTip", "rfRedHeroLi", "WING_AUTO_START", "wingAutoStart", "wearDressRet", "checkLunHuiOp", "dispWingStage", "rfWingShow", "onWingEuiRemove", "change_role_herofigure", "herofigureChg", "onHeroSltChg", "WING_WEAR_OFF", "roleWingWearOff", "removeEvents2", "stopMeriEff", "startMeriEff", "img_rebornBg", "figure_beijing4_jpg", "selectHeroByIdx", "setWearEffect", "serverWingShowStage", "equipRedArrForHero", "playWearBtnEffect", "stopPlayWearBtnEffect", "refreshTip", "showTeJieUpgrade", "setDispWingStage", "WING_MONEY", "send1404", "WING_YUMAO", "send1403", "send1405", "levelitem", "k_728", "levellimit", "levelexp", "sendLevelUpOneStage", "k_724", "checkIfCanAuto", "checkWingAutoLvlLimit", "askForWingOneKey", "setWingAuto", "k_719", "k_718", "oldWingVO", "fightNum_wing", "GrowRed", "setGrowRed", "flyRed", "setFlyRed", "runExp", "runExp1", "k_1411", "send1408", "56", "k_946", "meridianEffects", "meridianCurrent", "fillMeri", "setMeriFight", "filltween", "setDanFight", "setZhuhunRed", "setLongWenRedPoints", "img_longTip", "askForRebornLvUp", "askForAddRebornExp", "showRebornExpPanel", "hideRebornExpPanel", "setRebornCurrAtt", "setCurrAtt", "setRebornNextAtt", "setNextAtt", "setRebornFight", "setFight", "setRebornCurrLvl", "setCurrLvl", "setRebornUpCost", "setUpCost", "setRebornUpOwn", "setUpOwn", "setHighRebornPanel", "setRebornExpArr", "setRebornGetEff", "setRebornUpEff", "stopUpEff", "rItemId", "setWingEquipRed", "redtip", "checkTriencRed", "img_treincTip", "checkIfShiftBtnShow", "wingOffList", "askForWearWing", "getPage0Red", "wingRedArrForHero", "meridianRedArrForHero", "equipRedPoint", "zzPRed", "_wingSelectHeroIndex", "setServerWingShowStage", "wingExpDic", "k_717", "lastStar", "k_1409", "k_762", "k_763", "k_761", "_autoDelay", "askForUpDelayByFair", "askForUpDelayByMoney", "longWenRed", "checkIfCanGetExp", "getMaxLv", "RebornCfgMod", "getRebornPropVoByLvl", "getRebornPropDesByLvl", "getInitRebornProps", "REBORN_HIGH_LIMIT2", "REBORN_HIGH_LIMIT", "k_839", "getRebornCostByLvl", "getExpRenderVos", "yuyi_title_zizhi_png", "lbl_sx", "\u7279\u6b8a\u5c5e\u6027", "img_icons", "\u7279\u6b8a\u5c5e\u6027\uff08\u7fbd\u7ffc\u57fa\u7840\u5c5e\u6027\u52a0\u6210\uff09", "yuyi_title_feisheng_png", "_lvl", "group_low", "group_max", "img_jihuo", "lbl_high", "lbl_low1", "k_759", "critrate", "getStr", "lbl_low2", "\x0A", "askDanUp", "k_760", "k_764", "\x0A\x0A", "k_1660", "chm.RoleMed", "_rebornDic", "zhuanshengsettings_json", "zhuansheng_json", "getNameByLv", "getPropByLv", "getCostByLv", "getExpNum", "exchangecount", "getExpChgNum", "levelzsexp", "getExpItem1", "getExpItem1Num", "getExpItem2", "item2", "getExpItem2Num", "chm.RebornCfgMod", "_zsJson", "checkIfCanUp", "getXiuweiRed", "getZSTaskRed", "totalTimes", "changeTimes", "boExpChange", "_rItemId", "createExpRenderVos", "_expRenderArr", "RebornExpRndVo", "expAdd", "n_32570", "reborntasks", "zhuanshengTasks", "getRtaskByid", "n_32571", "rbxwRwdtasks", "takes", "rankPlayerID", "n_20001", "rankPlayer", "_rankPlayer", "n_20000", "xwRewdarr", "getRebrontaskDic", "maxvalue", "takeState", "getCanLvup", "reborn_data", "reborn_red_chg", "chm.RebornMod", "_grow", "_fly", "_taskinfDic", "totalProgess", "initXwRewd", "k_707", "k_4", "getSkillIDByJob", "winglevel_json", "wingstar_json", "wingconfig_json", "getWingMaxLv", "getPassiveJson", "passive_json", "skillsetting_json", "getFirstSkillIDByJob", "jingmailevel_json", "jingmaistage_json", "jingmaiconfig_json", "wing id=", "body id=", "getTejieCfgByIdx", "ring1_json", "longsoul_json", "shield_json", "ring2_json", "getValByIdx", "getBuffRateByID_Lv", "getBuffExtByID_Lv", "getSpecialProp", "getGrowData", "winggrow_json", "wingflyup_json", "getRebroninfo", "highsuicide_json", "taskLevel", "RebornTaskInfoVo", "getTotalProgess", "xiuweireward_json", "chm.RoleCfgMod", "_wingAuto", "_dispWingStage", "_serverWingShowStage", "_equipRedPoint", "_wingEquipRedPoint", "_wingEquipRedPoint2", "_equipRedArrForHero", "_tejieRedArrForHero", "_wingRedArrForHero", "_wingEquipRedArrForHero", "_meridianRedArrForHero", "_wingExpDic", "_zhanWenRedArrForHero", "rspRoleWingWearChange", "rspRoleFasionOff", "rspRoleFashionPut", "rspDanUpSucc", "_oldWingVO", "k_721", "oneKeyLimitLv", "6080", "wingEquipRedPoint", "wingEquipRedPoint2", "tejieRedArrForHero", "zzHeroRed", "wingEquipRedArrForHero", "zhanWenRedArrForHero", "_boEquipShowRed", "getJobList", "ckEquLv", "contrastSelfEqu", "isMath", "orderTotalRed", "ckWingEquLv", "contrastSelfWingEqu", "ckSelfWingCanComp", "getNextConfig", "orderWingEquTotalRed", "_boTejieShowRed", "_longWenRed", "tejieRedDic", "_tejieRedDic", "_boWingShowRed", "boWingEquipShowRed", "_boWingEquipShowRed", "boWingCompseEquipShowRed", "_boWingCompseEquipShowRed", "getAllequips", "WINGEQU_RED_SHOW", "_boMeridianRed", "wingIndex", "send1417", "send1418", "send1419", "send1420", "wingShow", "fashionId", "k_1410", "dressDic", "equipState", "dressPtype", "sendHeroid", "sendDressid", "_GrowRed", "_GrowTotRed", "_flyRed", "_flyTotRed", "equ_red_show", "wingequ_red_show", "tejie_red_show", "zuzai_red_show", "wing_red_show", "meridian_red_show", "wing_auto_start", "wing_dan_ren_show", "upd_wingeui_shiftbtn", "change_wing_wear", "wing_wear_off", "LONGWEN_REN_POINT_SHOW", "longwen_red_point_show", "chm.RoleMod", "RebornEui", "upEffect", "RebornRealmPnl", "reRoadV", "RebornRoadPanel", "reTtaskPnl", "RebornTaskPanel", "reRankPanl", "RebornRankPanel", "rankRwdPnl", "ReRankrwdEui", "k_833", "propCurr2", "propNext2", "lblCurr", "k_829", "taskRedchange", "xwRedchange", "lblOwn", "img_eff", "lbl_ownTitle", "\u62e5\u6709\u4fee\u4e3a\uff1a", "groupGetWay", "groupGetEffect", "lbl_costTitle", "img_costbg", "img_ownbg", "k_1408", "onShowjinjie", "btn_jinjie", "onshowReRoad", "btn_Zhanshen", "lab_showLoad", "onZhuanshenClk", "btnUp2", "onhideRealm", "onhideReRoad", "showRankPanl", "lab_rwd", "updateRwdInfo", "updateTaskInfo", "ownplayerChange", "onBtnStateChange", "onTabchange", "k_1652", "k_1653", "c_4582", "showpanl", "grop_cntent", "nowshowIdx", "img_tips1", "setServerValue", "setSortID", "sortID", "lab_title", "k_1654", "img_tips2", "k_1649", "RebornV", "chm.RebornV", "WingDanEui", "btnWearEffect", "initMasterSuit", "initDanFightNum", "img_TeJie2", "img_TeJie3", "figure_title5_png", "touchGridHandler", "touchHeroEquip", "fightNum_meridian", "danFight", "chm.RoleV", "RbrankRwdRender", "chm.RbrankRwdRender", "removegrid", "lblExpCharge", "groupInfo", "k_832", "lblTimes", "lblLeastItem", "imgRedPoint", "k_830", "lblItemName", "k_835", "k_2", "k_831", "reborn_exp_exchange", "chm.RebornExpRnd", "chm.RebornExpRndVo", "maxbarwith", "grp_kon", "reborn_rank_tag_1_png", "reborn_rank_tag_2_png", "RebornRankRender", "chm.RebornRankRender", "onRemve", "ntaskid", "c_4584", "Lab_tile", "grp_Item", "titleRes", "k_1650", "k_1651", "lab_Des", "???", "RebornRealmRender", "chm.RebornRealmRender", "taskIcon", "nowvalue", "takeReward", "c_4581", "RebornTaskLine", "chm.RebornTaskLine", "NormalProp", "TeJieUpgradeSkin", "0/0", "longlin", "longwen", "hushen", "clickUpGrade", "clickGetRes", "btn_getRes", "upgradeTejieEff", "STOP_TEJIE_BTN_EFF", "stopPlayTejieBtnEffect", "expBarGroup", "updateExpBar", "updatePropTxt", "updateCostPosition", "getIfShowBar", "getPropValueObj", "costGroup", "TEJIESTATE_CHANGE", "initTeJieInfo", "fillTitle", "k_716", "needCostItem", "lbl_xiaohao", "TEJIE_TITLE", "k_1404", "k_1405", "k_1406", "playTejieBtnEffect", "chm.TeJieSJEui", "img_tejieBg", "furnace_bg_jpg", "stop_tejie_btn_eff", "chm.TeJieSJMgr", "TeJieVO", "chm.TeJieVO", "HeroValueSkin", "_showIndex", "heroPropdataChange", "clickLeftHandler", "clickRightHandler", "setShowIndex", "acrosspdef", "acrosssdef", "fn", "stronghurt", "antistrong", "decstrong", "lbl_value12", "lbl_value13", "hit", "lbl_value14", "choas", "lbl_value15", "antichoas", "lbl_value16", "inchurt", "lbl_value17", "dechurt", "lbl_value18", "recoveryhp", "lbl_value19", "holydechurt", "lbl_value20", "holyatt", "lbl_value21", "block", "lbl_value22", "breach", "chm.HeroValueEui", "chm.HeroValueMgr", "HeroSkin", "chm.HeroEui", "MeridianSkin", "chm.MeridianEui", "RebornPanelSkin", "k_1647", "chm.RebornEui", "RebornExpPanelSkin", "fill_exp_data", "chm.RebornExpEui", "RebornRankPanelSkin", "k_1648", "chm.RebornRankPanel", "RebornRealmPnlSkin", "lab_xiuwei", "chm.RebornRealmPnl", "RebornRoadPanelSkin", "chm.RebornRoadPanel", "RebornTaskPanelSkin", "chm.RebornTaskPanel", "RebornRankrwdSkin", "img_tiltle", "reborn_title_", "mailReward", "1+", "mailReward2", "2+", "mailReward3", "3+", "mailReward4", "4-10+", "chm.ReRankrwdEui", "RolePanelSkin", "chm.RolePan", "WingDanSkin", "img_window", "chm.WingDanEui", "WingSkin", "shiftWingDisp", "shiftWingWear", "group_wingWear", "chm.WingEui", "CheckEquVo", "chm.CheckEquVo", "HeroLiRndVO", "chm.HeroLiRndVO", "chm.RebornTaskInfoVo", "figure_mabi_png", "figure_longhun_png", "figure_hudun_png", "figure_hushen_png", "chm.RoleStatic", "SCZBMainMed", "mSCZBMainKey", "mSandyCityMainKey_secend", "mEnd2Ti", "_groupRebornT", "_startDXT", "_myScoreN", "_scoreRwdN", "SCZBV", "mainV", "SCZBMainV", "bociV", "SCZBBociV", "guildRankV", "SCZBMainGuildRankV", "playerRankV", "SCZBMainPlayerRankV", "guildStateV", "SCZBMainGuildStateV", "enemyV1", "SCZBMainEnemyV", "endV", "SCZBMainEndV", "clearAlertV", "SCZBMainCDClearAlertV", "setMainPanelView", "fieldTypeChg", "enemyV2", "enemyV3", "enemyV4", "upd2", "showGuildState", "enterNeiCheng", "btn_neicheng", "showClearAlertView", "hideClearAlertView", "9604", "panelChg", "attackChg", "S_Tuichu", "closeEndView", "closeMain", "reqSandyNextField", "isDXState", "k_775", "FIELD_WAICHENG", "FIELD_DIANQIAN", "k_776", "FIELD_PALACE", "group_Score", "img_scoreBg", "setSandyCityBoci", "updPos", "_endMask", "clrCdCost", "GUILD_RANK", "SameNum", "updMemberNum", "getMoSel", "getTargetInfo", "searchEnd3", "reqMonsterFight", "reqPlayerFight", "perT", "updPlaysetT", "updRebornT", "isDefend", "k_1412", "k_1413", "k_1414", "S_SetFamilyRank", "S_SetPlayerRank", "SCZBPlayerRankVo", "S_SetRankInTime", "S_SetFamilyState", "S_ShowEndView", "k_1415", "reqTuichu", "showFlyEff", "initMapEffect", "clearMapEff", "chm.SCZBMainMed", "SCZBMed", "_mainMed", "_playerMod", "rspInfo", "reqEnterBattle", "battleStart", "onMapChg", "attackPlayer", "attackMo", "updPlayerScore", "askRequestIds", "resSSandyCity_Enter", "resSandyMove", "resSandyLeave", "resSandyOtherEnter", "resSandyNextField", "resSSandyCity_End", "resStatusDestroy", "resRankInTime", "resSSandyCity_Entry", "resFamilyRank", "resSSandyCity_PlayerRank", "resSSandyCity_FamilyState", "resLastFamilyRank", "resSSandyCity_LastPlayerRank", "resSSandyCity_Reborn", "resBuffAddition", "resKingFamilyChange", "resStatusScore", "resDailyReward", "resScoreChange", "resScoreReward", "resKillInfo", "resPlayerInfo", "reqEnter", "_isInSCZB", "onClkMap", "k_1419", "reqBuffState", "FieldTypeChg", "clearMo", "destoryDX", "creatDX", "creatMo", "ScoreRwdName", "reqPlayerMove", "enterDate", "9607", "initSame", "curBZName", "lastBZName", "updStaDest", "updStatusDestory", "updateEnd", "chgFeild", "updMove", "updDel", "setOtherEnter", "updEntry", "updateEntryInfo", "S_SetLastFamilyRank", "S_SetLastPlayerRank", "chgBZ", "k_782", "getDailySucess", "9621", "chgMyScore", "chgScoreNext", "setPlayerKill", "updPlayers", "chm.SCZBMdu", "SCZBKingVo", "kingGHName", "_secendKey", "SandyCityMediator_loop", "_dailyBonusGot", "entryV", "SCZBGuildRankV", "selfRankV", "SCZBSelfRankV", "guildRwdV", "SCZBGuildRwdV", "selfRwdV", "SCZBSelfRwdV", "alertV", "img_backBg", "shacheng_hegemony_bg_jpg", "disposePanel", "showPlayI", "btn_enterSandCity", "lbl_prevResult", "showRewardAlert", "group_get", "btn_guildReward", "btn_selfReward", "hideRewardAlert", "getDailyReward", "9603", "enterCoolT", "k_1416", "9606", "setEntryView", "k_769", "k_770", "fillHeroFigure", "startT", "getKingRwd", "setKingRewardData", "toggleBtnVisi", "getGuildRwd", "GUILD_REWARD", "getPlayerRwd", "getScoreRwd", "shacheng_hegemony_reward1_png", "dailyBonusGot", "k_1417", "k_1418", "getDailyRwd", "setTotalData", "kingFix", "group_kingFamilyFix", "otherFix", "group_otherFamilyFix", "SCZBRwdFlyVo", "toked", "lastFamilyName", "enterCoolTime", "SCZBLastGHRankVo", "lbl_lastKingFamilyName", "k_767", "SCZBLastPlyrRankVo", "chm.SCZBMed", "String_WAICHENG", "\u5916\u57ce", "String_DINQIAN", "\u6bbf\u524d", "String_PALACE", "\u7687\u5bab", "URL_PRO_INACTIVED", "URL_PRO_ACTIVED", "chm.SCZBStatic", "_dxId", "_moId", "moRf", "_moRf", "moXY", "_moXY", "_perT", "_clrCdCost", "_kingRwd", "clanReward", "SandyCity_client_json", "bazhuBonus", "_guildRwd", "_playerRwd", "_scoreRwd", "kingPos", "otherPos", "MobaiReward", "diaoxiang", "SandyCitySetting_json", "chm.SCZBCfgMod", "scoreRwdName", "palaceT", "myFaimlyName", "isLastBZ", "_scTip", "myScoreRwd", "myScoreIdx", "rankGH", "rankMyGHIdx", "rankRankIdx", "myGHScore", "chgScoreIdx", "mfieldType", "9610", "9618", "9617", "clearNtc", "addEnterNtc", "enterTime", "_guideMovie", "shacheng_hegemony_title_png", "shacheng_icon_effect", "showSCIcon", "onAddSCBtn", "onRemoveSCBtn", "sczb_dailybonus_got", "chm.SCZBMod", "mplayerNum", "mtIds", "mSecendAckKey", "SandyCityPlayer_mSecendAttackKey", "mSameNum", "mdelayDel", "_sceneDic", "mplayerHeros", "9615", "startLopAck", "getPlayerVO", "disTargetChg", "clearLop", "doCkOutScene", "doCkAckDX", "doCkUpdAck", "DX", "9620", "updPlayer", "checkBZInHG", "checkTargetI", "9614", "9619", "onPKTap", "getTargets", "rfMapPlayer", "9611", "SCZBScenePlayerVo", "chm.SCZBPlayerMod", "mMos", "m2Key", "SandyCityPlayer_creatMonster", "mplyrInfos", "checkCreat", "onPKTap2", "9612", "mDX", "chm.SCZBSceneMod", "gridArr1", "gridArr2", "SandyCityAlertSkin", "chm.SCZBAlertV", "SandyCityEntrySkin", "lbl_guild", "chm.SCZBEntryV", "SandyCityGuildRankSkin", "SandyCityRenderSkin", "chm.SCZBGuildRankV", "occupyRewardArr", "SandyCityGuildRewardSkin", "SCZBRwdRnd", "removeOccupyrewardGrid", "group_occupyReward", "chm.SCZBGuildRwdV", "SandyCitySelfRankSkin", "SandyCityRenderSkin1", "chm.SCZBSelfRankV", "SandyCitySelfRewardSkin", "SCZBSelfScoreRwdRd", "chm.SCZBSelfRwdV", "SandyCityPanelSkin", "chm.SCZBV", "_proWidth", "SandyCityBociSkin", "img_progress0", "_lbls", "lbl_progress0", "lbl_progress1", "lbl_progress2", "k_773", "updatePro", "pro_Skin", "chm.SCZBBociV", "SandyCityMainCDClearAlertSkin", "checkComplete", "chm.SCZBMainCDClearAlertV", "SandyCityMainEndSkin", "9616", "chm.SCZBMainEndV", "SandyCityMainEnemySkin", "enenmy_click", "chm.SCZBMainEnemyV", "SandyCityMainGuildRankSkin", "SandyCityMainGuildRankRenderSkin", "chm.SCZBMainGuildRankV", "SandyCityMainGuildStateSkin", "chm.SCZBMainGuildStateV", "SandyCityMainPlayerRankSkin", "SCZBMainPlyrRankRnd", "chm.SCZBMainPlayerRankV", "SandyCityMainRebornAlertSkin", "setRebornAlertText", "lbl_rebornAlert", "k_774", "SCZBMainRebornAlertV", "chm.SCZBMainRebornAlertV", "_enemyGroups", "_moveGroups", "SandyCityMainPanelSkin", "achieveEff", "updMoveGrid", "chm.SCZBMainV", "_rankColor", "SandyCityMainEndRenderSkin", "familyScoreStr", "chm.SCZBMainEndRnd", "SandyCityEnenyListRenderSkin", "SCZBMainEnemyLiRnd", "chm.SCZBMainEnemyLiRnd", "SandyCityMainPlayerRankRenderSkin", "chm.SCZBMainPlyrRankRnd", "SandyCityMainPanelRenderSkin", "k_772", "SCZBMainRankTimeRnd", "chm.SCZBMainRankTimeRnd", "chm.SCZBRwdRnd", "chm.SCZBSelfScoreRwdRd", "SCZBAckPlayerVo", "chm.SCZBAckPlayerVo", "chm.SCZBEndVo", "headURL", "guildJob", "chm.SCZBGHMemberVo", "chm.SCZBGHRankVo", "chm.SCZBKingVo", "chm.SCZBLastGHRankVo", "chm.SCZBLastPlyrRankVo", "vipURL", "k_771", "chm.SCZBPlayerRankVo", "chm.SCZBRankInTimeVo", "chm.SCZBRwdFlyVo", "chm.SCZBRwdVo", "chm.SCZBScenePlayerVo", "GMMed", "sendServ", "askForAdd", "askReword", "chm.GMMdu", "_logDic", "_sendLogArr", "_sendLogNum", "_minLogNum", "_maxlLog", "chDic", "GmV", "resUI", "LabelRd", "commonUseList", "logname", "logid", "logtype", "resList", "itemList", "equiplist", "wingequiplist", "tasklist", "task_json", "chooseRes", "onBtn", "qd_btn", "commonUse_btn", "res_btn", "item_btn", "equip_btn", "wingequip_btn", "task_btn", "sendPort", "btn_send_port", "idSearch", "txtIdInput", "simpleChineseSearch", "txtIdInput_simpleChinese", "chongzhiSelfHandler", "btn_chongzhiSelf", "chongzhiAllHandler", "btn_chongzhiAll", "sendReword", "btn_reword", "recordSendLog", "LogVo", "lognum", "upSdAr", "delSLog", "txtListNumInput", "typeTxt", "txt_input_port", "txt_input_reword", "typenum_txt", "k_1420", "initKey", "trim", "chm.GMMed", "chm.LogVo", "GMEui", "chm.GmV", "10999", "chm.LabelRd", "SendTestResPanelSkin", "chm.GMEui", "ShareGiftModule", "ShareGiftViewMed", "rspShareData", "askShareData", "askGetAwardInfo", "lgcomp", "showPanel1", "logAskShareData", "firstInvite", "c_2161", "ShareDataVo", "chm.ShareGiftMdu", "ShareGiftViewMediator", "shareGiftPanel", "ShareGiftPanel", "addUpPanel", "shareClose", "addUpClose", "fenxiang_button_png", "fenxiang_png", "fenxiang_bg_jpg", "share_btn", "ljShareClose", "back_btn", "askInviteData", "invite_btn", "question_btn", "shareStateChange", "getShareConfLen", "chm.ShareGiftViewMed", "chm.ShareDataVo", "getShareConf", "_conf", "sharereward_json", "ShareRewardVo", "getFirstRwd", "_firstRwd", "_shareData", "ckRedTotal", "boshowred", "shareCheckTime", "\u8c03\u7528\u5206\u4eab\u7edf\u4e00\u5165\u53e3\uff1aextraInfo = ", "platShare", "chm.ShareGiftModel", "chm.ShareRewardVo", "AddUpSharepanelSkin", "addUplist", "AddUpShareRender", "isTaken", "shareNum", "chm.AddUpSharePanel", "ShareGiftPanelSkin", "shareBack", "fenxiang_qq_png", "shareGiftList", "chm.ShareGiftPanel", "AddUpShareRenderSkin", "getAward", "get_btn", "addUpAwardId", "awardList", "inviteallnum", "\u6210\u529f\u9080\u8bf7", "\u4e2a\u597d\u53cb", "invitednum", "\uff08", "\uff09", "chm.AddUpShareRender", "SLMed", "replaceSuccess", "rspCanjuanComp", "miJireplaceSuccess", "mijiSkillInfo", "playerShowBack", "longinComplete", "askCombie", "askjiujiCombie", "reqJiujiActiveState", "getLuckyData", "askForReplacement", "skillRed", "BookMod", "bookRed", "jiujiRedPoint", "isHengChengRed", "checkPlayJiujiEff", "checkPlayAwake", "useIds", "askForPassiveLearn", "bookId", "askForPassiveLevelUp", "askForPassiveBOB", "askForBookSplit", "books", "send C_CBook_Split:", "send1406", "skillIndex", "send1407", "reqAwakeUp", "reqCanjuanComp", "moduleTypes", "playState", "qLplayState", "sBplayState", "JiuJiRender", "reqMijiSkill", "levelUpFinalBook", "studyFinalBook", "chm.SLMdu", "_bookModel", "_rebornModel", "SLV", "bookList", "bookV", "XFRnd", "bookSele", "SLBookRnd", "selT", "openReplace", "askForBookOut", "backout", "openSelect", "getBook", "rfSelectBook", "askForLearnPassive", "tapSkillTS", "tapQuanBuTS", "btn_quanbuTisheng", "selectBookGrid", "onXinItem", "askForBookLevelUp", "btnUpLv", "onClkAwake", "btn_awake", "awakeP", "onClkAwakeLeft", "onClkAwakeRight", "awakeGetWayTap", "canjuanGetWay", "canjuanP", "canjuanComp", "btn_comp", "colseCanjuan", "onCanjuanComp", "checkAwakeBtnEff", "updateJiuJiAgain", "jiujigetway", "get_way", "jiujiPanel", "jiujihecheng", "showjiujiTip", "jiujiLvlUp", "ckAwakeTab", "checkJiuJiTabShow", "changePanel", "fillBookPanel", "fillSelectBookDes", "fillBookCombineList", "jiujiUp", "selectSkill2", "skillInfoChg", "onAwakeUp2", "skillRedChg", "bookRedChg", "awakeRedChg", "jiuJiRedChange", "removeAni", "getPsvLvUpCost", "costNum0", "costImg0", "costQuality0", "learnId", "getPsvId", "replaceIds", "k_844", "splitConfir", "getBookLevel", "k_845", "getBookBOCost", "getBookBO", "showBookReplace", "closeReplace", "hideBookReplace", "levelUpId", "showBookSelect", "getBooks", "ckLearn", "boLearn", "setSelectBtnState", "setBooksForLearn", "setSelBookDesShow", "hideBookSelect", "onGetWay", "selectSkillInfo2", "seleHero", "img_bookBg", "figure_beijing_png", "hideCanjuan", "setGridBooks", "setOpenDes", "setSelectBookDes", "k_842", "k_843", "setBookCombineList", "combineP", "selectSkillInfo", "fillSelectSkill", "setFuncBtn", "updAwake", "curShowIdx", "showIdx2RealIdx", "showCanjuan", "k_1425", "onAwakeUp", "playAwakeEff", "2_1", "tabAwake", "tabBook", "tabJiuJi", "onClkLeft", "onClkRight", "costData", "bonusCnt", "combineSuccess", "updCostShow", "ckAwakeBtnEff", "rfHeroLiSelT0", "awakeInfoChg", "jiuJiChange", "getGridBookArr", "getTotalFight", "getBookDes", "getBagBooks", "oldHeroIndex", "rfHeroLiSelT1", "rfHeroLiSelT2", "updateJiuJiInfo", "updateAgain", "getHeChengLvl", "\u9700\u8981", "\u8f6c\u5f00\u542f", "jiujiComPanel", "showXinFaTip", "c_4026", "c_4025", "activation_mode_title1_png", "jjxf_eff", "activation_mode_title2_png", "\u9053\u5177\u4e0d\u591f", "onjiujiUp", "getjiujiConf", "2_3", "refreshHeroListBySelectType3", "chm.SLMed", "_tjDic", "_psvDic", "_bookIds", "_objIds", "getTJArr", "getPsvEff", "getPsvCost", "getRate", "getPram0", "getPram1", "getPassiveBackOut", "getPsvName", "getBookIds", "getOpenLvLmt", "mijiskillsetting_json", "getOpenVipLmt", "openVip", "getBOCost", "backoutcost", "257:1", "chm.BookCfgMod", "_gainInfo", "_bookJson", "_learnId", "_levelUpId", "_replaceBk", "setReplaceBook", "clearReplaceBooks", "delReplaceBook", "addGain", "cutGain", "gainInfo", "clearGainInfo", "k_836", "continue", "canUp", "k_1423", "getNextOpen", "isStudy", "BookRndVo", "splitCount", "getSplitBooks", "SLBookDesVo", "getGridBookVo", "getBookLvUpCost", "ckStudy", "chm.BookMod", "662", "663", "\u5929\u795e\u5e87\u62a4", "\u9b54\u795e\u9644\u8eab", "_jiujiList", "_jiujiConfs", "finalpassive_json", "getJiuJiset", "getBagJiuByQuity", "finalCompoundItem", "finalCompoundLimit", "isBtnEff", "COMBINE_SKILL_SUCCESS", "combine_skill_success", "ASK_SKILL_COMBINE", "ask_skill_combine", "COMBINE_SKILL_SUCCESS_COUNTS", "combine_skill_success_counts", "chm.JiuJiModel", "maxSkill", "_awakeRed", "_jiujiRend", "_show2reals", "_selT", "_skillRed", "7500", "_bookRed", "7501", "7504", "_awakeCfgDic", "getAwakeCfgs", "_awakeCfgs", "awakeskill_json", "_awakeUpCfgDic", "getSkillIdArr", "_skillIdArrs", "_canjuancostDic", "shoppingmall_json", "checkAwakeSkillRed", "getShowSkillIdxArr", "chm.SLMod", "ShilianTuJianSkin", "listXinfa", "BookTJRnd", "onTabHandler", "seletTab", "lblProp", "SLBookTJV", "chm.SLBookTJV", "SLBookP", "k_834", "btn_tujian", "tujianPanel", "SLBookV", "chm.SLBookV", "SLP", "SLBokCombineP", "SLBookSelP", "SkillAwake", "JiuJiPanel", "JiuJiCombinePanel", "CJComp", "initHero", "initSkillGrid", "SLBookDes", "tabReborn", "selIdxChg", "figure_beijing_jpg", "jj_xinfa_bg_jpg", "clickSkillGrid", "chm.SLV", "boCheck", "chm.BookRndVo", "chm.BookTJRnd", "JiuJiRenderSkin", "chm.JiuJiRender", "SkillAwakeRenderSkin", "SLAwakeRnd", "chm.SLAwakeRnd", "_init", "lblLearn", "gou_01_png", "SLBokCombineRnd", "chm.SLBokCombineRnd", "ShilianBookDesSkin", "chm.SLBookDes", "chm.SLBookDesVo", "ClickHandler", "chm.SLBookRnd", "lockImg", "k_1424", "chm.XFRnd", "BookSelectAlertSkin", "BookSelAlert", "chm.BookSelAlert", "CanjuanCompSkin", "useGrp", "_itemId", "item_name", "item_icon", "item_cnt_add", "item_cnt", "cost_cnt", "_compEff", "playEffectComplete", "hecheng_effect", "chm.CJComp", "selectIndexArr", "clickIds", "JiuJiCombinePanelSkin", "img_lizi1", "img_lizi2", "img_lizi3", "onListTapHandler", "onDelClick", "imgIcon0", "imgIcon1", "imgIcon2", "onCombineHandler", "btnCombine", "combineLine", "initImgHp", "setCombineList", "hechengEffect", "jiujiArr", "combineId", "successGroup", "group_combine", "imgIconCombine", "imgQualityCombine", "lblNameCombine", "k_858", "k_849", "k_850", "k_848", "luckyTimes", "/100", "chm.JiuJiCombinePanel", "JiuJiPanelSkin", "onClkClkItem", "updateSkillItem", "updateCurSkill", "iconname", "nameicon", "group_cur", "group_next", "effectRate2", "fixed", "checkjiujiEff", "isShowBtn", "img_miji", "_dizuoEff", "dizuo_eff", "chm.JiuJiPanel", "_maxCnt", "_leftLineX", "_itemPoss", "SkillAwakeSkin", "_skillItemArr", "skillGrp", "_tweening", "updSkill", "updCurSkill", "jinengjuexing_frame", "jinengjuexing_lock_png", "k_856", "img_line_", "_costId", "k_1487", "prop_c_grp", "prop_n_grp", "_curUpConf", "_nextUpConf", "title_n", "k_1488", "lbl_cur_pro", "k_857", "lbl_next_pro", "k_854", "k_855", "k_738", "turnBtn", "onTweenEnd", "_tweenTimeId", "jinengjinjie_jx", "chm.SkillAwake", "_frameTime", "_showItemImg", "_showTitleWorld", "_noshowLvlIds", "_showBtnLinkIds", "noShowLvAndNaIds", "SkillAwakeEffViewSkin", "leaveMod", "btn_Clk", "zhanLingTab", "_position", "checkIsShowLvl", "changeAwakeTit", "checkIsBtn", "showTitleName", "showItemEffs", "fillFashion", "img_podium", "_intervalNum", "k_936", "k_939", "k_937", "k_938", "k_934", "_heroIdx", "grp_name", "activation_name_png", "activation_name_3_png", "activation_name_2_png", "get_title_name_png", "get_fashion_name_png", "activation_name_1_png", "school_student_cs_png", "img_awake", "_itemEffs", "_itemImg", "isPodiumShow", "playDragonEff", "img_dragon", "grp_hero", "grp_light_eff", "_hideDelay", "_curIdx", "_ImgActive", "showItemAwakeEff", "wing_fashion46_png", "wing_fashion52_png", "wing_fashion55_png", "wing_fashion10_png", "wing_fashion58_png", "_heroPosDelay", "_dragonEff", "grp_dragon_eff", "dragonfly_effect", "spotlight_effect", "awake_play_complete", "chm.SkillAwakeEffV", "SkillSkin", "chm.SkillEui", "selIdxArr", "ShilianBookCombinePanelSkin", "booklist", "onListTap", "onCombine", "hcEff", "bookArr", "chm.SLBokCombineP", "ShilianBookPanelSkin", "chm.SLBookP", "ShilianBookReplacePanelSkin", "partRemoved", "grid_gain", "SLBookReplaceP", "chm.SLBookReplaceP", "ShilianBookSelectPanelSkin", "chm.SLBookSelP", "ShilianPanelSkin", "chm.SLP", "ShopMed", "_m", "ShopMod", "tgo", "msr", "hsr", "mhp", "agh", "HONOR_SHOP_REFRESH", "otb", "rsb", "rsm", "rcd", "rhc", "ctb", "fmg", "fso", "fms", "fml", "ofc", "fol", "fho", "NEXT_REFRESH_TIME", "fmu", "sendBubbleVo", "sta", "_mt", "clearBubble", "k_862", "flushtime", "stf", "sms", "afb", "afu", "afy", "gnb", "sfc", "shopflush", "shs", "stp", "fsl", "ftl", "gsm", "sml", "smm", "smu", "grf", "smg", "gss", "ssl", "smc", "ghl", "smo", "gns", "stl", "chm.ShopMdu", "ShopV", "tp", "R_t", "shop_title_png", "R_h", "R_m", "R_s", "lbl_getWay", "k_869", "epl", "MISERY_SHOP_BUY", "SCORE_SHOP_BUY", "afs", "TOOL_SHOP_BUY", "onc", "cnc", "abn", "HONOR_SHOP_BUY", "abh", "TextEvent", "ogw", "_normalId", "sbg", "sbp", "goldImage", "lblMyGold", "freeLabel", "k_863", "lblMyScore", "lTi", "sTi", "k_860", "refresh_loop", "lop", "k_859", "hlu", "dayPermit", "soldout", "k_868", "chm.ShopMed", "_std", "pxm", "shop_json", "shopsetting_json", "flushcost", "ghs", "chm.ShopJson", "_stp", "_lt", "_st", "_mso", "gsi", "O_m", "priceType", "priceIcon", "gob", "disCount", "shows", "O_s", "goldPrice", "scorePrice", "O_t", "_sfc", "_hsi", "_hnd", "O_h", "costItemStr", "honorPrice", "daypermit", "buyType", "next_refresh_time", "honor_shop_refresh", "chm.ShopMod", "sp", "P_a", "P_m", "P_c", "P_o", "P_s", "P_n", "tb", "slt", "nch", "_tmp", "chm.ShopV", "ShopHonorRenderSkin", "lbl_limitBuy", "k_866", "k_867", "cd1b1f", "389d23", "honor_shop_buy", "chm.R_h", "\u8bc4\u5206\u2191", "imgCostIcon", "misery_shop_buy", "chm.R_m", "lblPrice1", "lblPrice2", "score_shop_buy", "chm.R_s", "tool_shop_buy", "chm.R_t", "ShopPanelSkin", "chm.P_a", "ShopScorePanelSkin", "chm.P_c", "ShopMiseryPanelSkin", "chm.P_m", "chm.P_n", "ShopToolPanelSkin", "chm.P_o", "ShopHonorPanelSkin", "chm.P_s", "chm.O_h", "chm.O_m", "chm.O_s", "chm.O_t", "SmeltMed", "tarOp", "rspMelEqs", "oneSmelt", "SmeltMod", "suc", "saReips", "setSaes", "askForSmelt", "smeltEquip", "chm.SmeltMdu", "SmeltV", "winS", "stAseips", "bag_ronglian_png", "sltUI", "k_877", "sectUI", "op_slt_pa", "openSspa", "rm_st_pa", "rmSltEps", "slt_rd", "sltsc", "gotoAutoHand", "clslts", "eqpc", "fl_slt_pa", "flsspa", "smt_arr", "flsltp", "tb_slt", "cl_pal", "clSpa", "num_chg", "rfssln", "getSltsL", "rfSlpa", "getSsL", "rfsspa", "rsl", "rfssn", "delRsAr", "crslAr", "rRrSAr", "akfokst", "getOInxs", "k_1429", "akfslt", "getSInxs", "img_smeltBg", "recover_bg1_jpg", "/9", "ckoksbvl", "chm.SmeltMed", "chm.EqpCpVo", "_atSltEqs", "_rtses", "_asEps", "getEob", "divAbL", "up", "down", "rmBt", "getBtEps", "rmFa", "ONEKEYSMELTOPEN", "chm.SmeltMod", "SmltEui", "\u4e00\u952e\u56de\u6536", "\u56de\u6536", "chm.SmeltV", "SmeltGridSkin", "equipGrid", "emtGck", "groupEmpty", "epGCk", "playEftCom", "chm.SmeltGrid", "groupGrid", "cksc", "chm.SmeltSltRd", "SmeltPanelSkin", "chm.SmltEui", "SmeltSelectPanelSkin", "chm.SmltSltEui", "chm.SltGVo", "chm.SltSRVo", "SuperMed", "redCk", "ckIfRch", "chm.SuperMdu", "SuperV", "SuperRd", "zhizun_biaoti_png", "flPal", "gotoGet", "getAtIco", "setAtIco", "getFNum", "setAddFightNum", "setArtifactDes", "getRLst", "setRewardList", "setGDes", "gExp", "k_1050", "chm.SuperMed", "_boGet", "chm.SuperMod", "SuperEui", "bhdfat_effect", "chm.SuperV", "chm.SuperRd", "SupremePanelSkin", "chm.SuperEui", "SwbqModule", "SwbqMed", "rspPhaseChg", "rspMoHpChg", "rspSplayerStateChg", "rspProtectReborn", "rspProtectBoss", "rspRankResult", "rspSoilderRwd", "fightMo", "fightBOSS", "endSoilderMo", "endSoilder", "rebornTofight", "rebornStartCD", "bqMapClick", "setCurMap", "leaveMapChg", "stopAutoFight", "k_884", "reqSoilderFight", "reqBossFight", "endFight", "SwbqMgr", "reqQuickReborn", "showBoundsMsg", "setDead", "doAutoCk", "reqSoilderRank", "reqSoilderRwd", "updStep", "updMos", "updPlyrs", "deadT", "deadTime", "initBociInfo", "FUHUO_CD", "updSglMo", "updateSglPlyr", "updSideRwd", "updRank", "myhurt", "updGHSHRank", "chm.SwbqMdu", "_secendK", "SwbqMediator_KEY", "_rebornSecendK", "SwbqMediatorReborn_KEY", "SwbqRwdV", "SwbqSideV", "pro", "SwbqProgressV", "SwbqHurtRankV", "enter", "SwbqBossEnterV", "nextTimeChg", "enterBossView", "zlvl", "sendBossFight", "updEnterT", "_enterT", "loopSecendTime", "set_bo", "k_881", "k_882", "_endT", "stopAutoEff", "set_auto", "phaseChange", "shouwei_boss_tx_png", "list_familyDamageRank", "SwbqGHSHRankRnd", "SwbqGHRankVo", "damage", "lbl_myFamilyName", "openRankV", "imgBtnHurt", "openReward", "rebornNow", "closeReward", "changePingbiSet", "changeFuhuoSet", "btn_Ok", "roundChg", "changeEnterType", "getSoilerEndT", "upSideChild", "lbl_boNum", "getBoci", "setBociInfo", "playAutoEff", "setFamilyD", "setleiji", "updData", "fmailyRankItemInfos", "familyHurtRatio", "familyHurt", "updSelfGHSHRank", "lbl_myFamilyDamageRank", "lbl_myFamilyDamage", "updRebornV", "autoEff", "fight_auto_effect", "chm.SwbqMed", "RankReward", "port_shouweibiqi_json", "SwbqRwdVO", "rwds", "getFmyRwd", "FamilyReward", "initSWBQCfg", "ProtectBiQiSetting_json", "pigs", "portIds", "startTimeCron", "readCron", "_prepareT", "_soilderT", "soilderTime", "pretime", "_pigs", "_ports", "_bossIds", "_hour", "_min", "_secends", "getBOSSByIdx", "getPortMoNum", "getMoByRud", "getInTime", "SwbqData", "chm.SwbqCfgMod", "_moDic", "_plyrDic", "_npcM", "_npcD", "_effD", "_effM", "_scnRect", "initNpc", "npcData", "Swbq", "effectData", "cjBQPlyr", "getSWBQPlayer", "SwbqPlayer", "cjBQMo", "getSWBQMon", "SwbqMo", "removeMo", "removePlyr", "getSwbqMo", "getSWbqOneTgt", "BOSS", "rfMos", "SWBQ_SCEND_LOOP", "cjNpc", "SwbqNpc", "loopCk", "chm.SwbqMgr", "_inSwbq", "_moHpDic", "_phase", "_isDead", "_bossId", "_nextT", "onTapMon", "_lrDic", "hurtRadio", "chm.SwbqMod", "Lbl", "chm.SwbqDlgBub", "chm.SwbqMo", "_timeIdx", "rfHeight", "rfDefStyle", "bubbleEnd", "chm.SwbqNpc", "_key", "_isLife", "attackTarget", "_lastTgt", "chm.SwbqPlayer", "SwbqEnterSkin", "lbl_boci", "lbl_zhuan", "chm.SwbqBossEnterV", "SwbqHurtRankSkin", "SwbqLblCellRnd", "SwbqLblRenderSkin", "chm.SwbqHurtRankV", "lbl_percent", "img_up", "img_down", "chm.SwbqLblCellRnd", "Pro_lenth", "SwbqBociSkin", "bociFirst", "guard_boci2_png", "lblbociFirst", "createLbl", "bociEnd", "lblbociEnd", "jizhuImgs", "jizhuLbls", "pro_num", "guard_zhu_png", "chm.SwbqProgressV", "SwbqRwdRnd", "chm.SwbqRwdRnd", "SwbqRewardSkin", "listFamilyRwd", "tglSeleChg", "group_family", "_rwdD", "_rwdDF", "group_leiji", "chm.SwbqRwdV", "SwbqSideSkin", "chm.SwbqSideV", "SwbqFamilyDamageRankRenderSkin", "---", "lbl_familyDamage", "chm.SwbqGHSHRankRnd", "SwbqBossVO", "chm.SwbqBossVO", "chm.SwbqGHRankVo", "chm.SwbqRwdVO", "NpcDMed", "getBtn", "askForTakeBonus", "unData", "nameLbl", "Taskdialoge", "sAward", "cAward", "bounsArr", "k_898", "chm.NpcDMed", "_tMed", "TaskMed", "_dMed", "_tmod", "_npcMod", "taskChange", "scurMap", "battleWin", "shdia", "ASK_FIGHT_NEWCOMER", "rfTask", "askNewFight", "taskArr", "NEW_T_TYPE", "monsterIds", "reqTask", "chm.TaskMdu", "lvlGuide", "readtaskXML", "TaskV", "5500", "tchge", "LvUpGPan", "findMonster", "onPrisonView", "k_893", "k_891", "k_887", "sguajiV", "k_894", "k_892", "k_886", "lbl_taskname", "_guajV", "GuajV", "chm.TaskMed", "_sMon", "_mapNpcDic", "checkNpcDelay", "_findNpcid", "_timeOutDelay", "_mDic", "mapChange", "startTask", "changeNpcState", "reInitMap", "npc_json", "980|3250", "getNpcIdByTaskID", "clearAllMonster", "newcomer_Monster_walk", "_moveTimeDelay", "checkMonsterState", "getLastTaskByid", "clearMonsterByid", "myPlayerPosChange", "findNpcEnd", "randomWalkToMonster", "NPC", "defaultPoint", "createNpcInMyView", "createNpc", "delayAddMonster", "onClickMonster", "addOneMonster", "monsterPos", "getMonsterEndXY", "monIndexByTaskVo", "findMonsterEnd", "readNpcXMl", "_npcDataDic", "npc_data_add", "monster_data_add", "chm.NPCMod", "TaskVo", "setBouns", "monsterIndexs", "getBounsImage", "getTask", "chm.TaskMod", "OGJPan", "guaji_bg", "loading_guaji_ty_png", "startBtn", "loading_guaji_png", "chm.GuajV", "NPCDPan", "chm.NpcDV", "taskEffect", "TaskPan", "sao_group", "chm.TaskV", "LvlUpGuidePanelSkin", "chm.LvUpGPan", "NpcDialogePanelSkin", "chm.NPCDPan", "OpenGuajiPanelSkin", "chm.OGJPan", "TaskPanelSkin", "chm.TaskPan", "chm.TaskVo", "TestMed", "initBtn", "chm.TestMdu", "TestV", "TestRnd", "lbl_ver", "lbl_usename", "lbl_svrVer", "Test", "clickSendGM", "btn_sendGm", "btnStop", "txt_id", "txt_type", "txt_count", "gm_btn", "tapGMBtn", "GM", "cs_btn", "CS", "chm.TestMed", "TestP", "chm.TestV", "moduleName_btn", "onOpenModule", "draw_node", "chm.TestRnd", "TestPanelSkin", "chm.TestP", "TitleMed", "10007", "dressActAsk", "10008", "dressWearAsk", "10009", "dressUp", "rspFSAct", "rspFSput", "rspFSAc2", "rspFSRem", "rspFSLvl", "akfADress", "askPutDress", "askFashion", "k_1448", "fsDau", "k_1449", "fsDAct", "fsDP", "fsDrAct2", "fsDR", "baseid", "heroid", "isFashionFun", "chm.TitleMdu", "TitleV", "title_title3_png", "dressList", "_dressView", "DressItemRD", "ckTabRed", "itemTab", "actHand", "act_button", "takeoff_btn", "huanhua_btn", "actDress", "clkCst", "lbl_cost1", "onCardClick", "lbl_cost0", "clickUp", "act_shengji", "dressProp", "wearDress", "getDrsAr", "_selectHeroIndex", "tabRedArr", "showDP", "hideDP", "getHLvl", "costs", "getUpNum", "dressHeroid", "\u9053\u5177\u6570\u91cf\u4e0e\u9053\u5177\u5361\u5747\u4e0d\u8db3", "heroRedArr", "img_DressBg", "title_bg_jpg", "chm.TitleMed", "getFahionIconByID", "chm.TitleCfg", "dresByTime", "_intval", "props", "ckADTime", "adCheck", "costcard", "openday", "checkOpenDay", "DressVo", "cardName", "getFsILvl", "weared", "pushTimeVo", "startTm", "checkActPeriod", "getDressConfById", "checkDelayTm", "getDressConfDic", "_dressConfDic", "activateBeginTime", "activateEndTime", "delayshow", "setOverTm", "k_1447", "fashionlvl", "chm.TitleMod", "indexinfo", "DressPanelSkin", "unselect_group", "select_group", "showHroFig", "k_731", "k_758", "tip_shengji", "isChild", "lbl_xuyao", "shengji", "lbl_dressName", "k_730", "initHF", "_selectDressType", "DressEui", "chm.DressEui", "titlePanel", "TitleEui", "DressPropEui", "tabWeapon", "tabwing", "togChg", "chm.TitleV", "img_huanhua", "chm.DressItemRD", "DressPropEuiSkin", "dress0", "HP:0,ATT:0,PDEF:0,SDEF:0,STRONG:0", "chm.DressPropEui", "TitlePanelSkin", "chm.TitleEui", "TitleXqPanelSkin", "chm.TitleXqEui", "chm.DressVo", "chm.TitleAddVo", "chm.TitleloadVo", "chm.TitleVo", "VideoMed", "changeday", "rspBgWatch", "rspVideoData", "logAskVideoData", "askBgWatch", "askgetRewVido", "userStr", "updVideoInfo", "chm.VideoMdu", "videopanl", "VideoGiftEui", "videReward", "VideoRewardEui", "showRewad", "closeViopanl", "askWatchData", "watc_btn", "onCloseAll", "k_1192", "showRewardpan", "showVideReward", "chm.VideoMed", "ntimes", "videRewDic", "initVideoData", "updateBtnState", "lastWatchTime", "watchTimes", "maxTimes", "onlineTime", "DelBtn", "watchvideo_json", "chm.VideoGiftMod", "VideoGiftSkin", "imgbg", "chm.VideoGiftEui", "VideoRewardSkin", "btnQd", "videRewad", "k_1193", "chm.VideoRewardEui", "_lastGold", "_lastReqTime", "_mvMed", "VipMed", "_pvMed", "VipPMed", "tOpen", "rchk", "rcFirstInfo", "goldChange", "platsdk", "totalRechargeYb", "tyIosRmbLimt", "?userId=", "&serverId=", "\u89e6\u53d1\u7d2f\u8ba1\u5145\u503cRequest\uff1a", "responseType", "TEXT", "HttpResponseType", "onCheckComp", "onCheckError", "chargeNum", "check chargeNum ", "isOk", "gsLv", "oPVMed", "openFirstView", "pvMed", "sVHide", "aHide", "agetRrd", "chm.VipMdu", "vip_title_png", "check_hide", "initD", "VipV", "oPPan", "sVLv", "askForGetReward", "showHidePro", "S_V_C", "vChge", "k_954", "k_953", "showvLv", "gVMax", "img_VipBg", "vip_di3_jpg", "sIcon", "imgShowVip", "sCIcon", "vipCurr", "sNIcon", "vipNext", "sPro", "sMVip", "sBtm", "imgBottom", "sneedP", "k_1053", "lblNeedPay", "sRwdS", "sState", "cLBtn", "getVDes", "getVExp", "getVRwd", "getVSrc", "gVMaxE", "k_950", "vip_yimanji_png", "k_1052", "chm.VipMed", "delarr", "_scrollV", "VipPV", "fPan", "VFPRed", "VPRed", "faPan", "VFAPRed", "VIP_PAY_CLICK", "V_F_P_C", "gVList", "sPanel", "getFirstRechargeId", "getRId", "getDelidx", "chm.VipPMed", "getRArr", "reward2", "VRVo", "chm.ReCData", "_showlv", "vip_lvl{0}_png", "gDes", "zengsong", "getRemainder", "URLLoader", "gankqqtoken", "gameid", "appid", "openid", "session_key", "?token=", "&gameid=", "&appid=", "&uid=", "&openid=", "&session_key=", "https://qqapi.djsh5.com/qqapi/apps/pay/getbalance/", "dataFormat", "URLLoaderDataFormat", "onReadComplete", "URLRequest", "method", "URLRequestMethod", "errcode", "remainder", "REMAINDERCHANGE", "\u83b7\u53d6\u661f\u5e01\u6210\u529f", "\u83b7\u53d6\u661f\u5e01\u5931\u8d25", "vip_lv_chge", "chm.VipMod", "_vDic", "_max", "VIP_BOTTOM_SRC", "bons", "vip_lvl1_xuanchuan_jpg", "vip_lvl2_xuanchuan_jpg", "vip_lvl3_xuanchuan_jpg", "vip_lvl4_xuanchuan_jpg", "vip_lvl5_xuanchuan_jpg", "vip_lvl6_xuanchuan_jpg", "vip_lvl7_xuanchuan_jpg", "vip_lvl9_xuanchuan_jpg", "vip_lvl10_xuanchuan_jpg", "vip_lvl11_xuanchuan_jpg", "vip_lvl12_xuanchuan_jpg", "vip_lvl13_xuanchuan_jpg", "vip_lvl14_xuanchuan_jpg", "vip_lvl15_xuanchuan_jpg", "chm.VStic", "VPPan", "VFPPan", "VFAPan", "vip_chongzhi_png", "rebate_title_png", "rebate_bg_xcx_jpg", "rebate_bg_jpg", "chm.VipPV", "VPan", "chm.VipV", "k_1114", "k_1115", "k_957", "k_958", "k_951", "imgRec", "v_fra_p_clk", "VIP_FIRST_PAY_CLICK", "vip_first_pay_click", "chm.VFAPRed", "v_frt_p_clk", "chm.VFPRed", "k_948", "k_1064", "X100\u5143\u5b9d ", "imgFirst", "vip_shouchong_png", "X100\u5143\u5b9d", "vip_remai_png", "group_id", "lblGiveYB", "lblGiveMon", "%:", "vip_pay_click", "chm.VPRed", "chm.VRVo", "VipFirstAgainPanelSkin", "img_id", "new_shouchong_banner_xcx_jpg", "chm.VFAPan", "VipFirstPayPanelSkin", "---VipFirstPay-isQQPlatForm", "reqRemainder", "getRemainderChange", "---getRemainder---", "\u83b7\u53d6\u661f\u5e01\u6570\u91cf:", "moneyNum", "k_1699", "chm.VFPPan", "VipPanelSkin", "chm.VPan", "VipPayPanelSkin", "---VipPay-isQQPlatForm", "remainderChange", "chm.VPPan", "VipGiftModule", "VipGiftVMed", "openWallowPanel", "chm.VipGiftMdu", "VipGiftViewMediator", "text_NO._{0}_png", "VipGiftV", "VIPGIFT_HIDE_PANEL", "VIPGIFT_CHANGE_YUANBAO", "VIPGIFT_HIDE_DOWN", "hideCountdown", "yuanbaoChange", "vipcountdown", "img_vipname", "text_vip_", "group_num", "k_956", "chm.VipGiftVMed", "vipgift_json", "rspVipGiftInfo", "rspRwdSuccess", "chm.VipGiftSvrMod", "vipgift_hide_panel", "vipgift_change_yuanbao", "vipgift_update_countdown", "vipgift_hide_down", "chm.VipGiftType", "vipGiftSkin", "chm.VipGiftV", "_akRec", "_media", "WelfareMed", "trOpen", "dsdc", "exhRec", "rspGetAward", "ckNotice", "checkFaqChange", "WelfareMod", "FAQ/index.php?&ver=1", "faqVer", "faq_change", "noticeLoad", "notice/index.php?chid=", "qqgroup", "notice_content", "daiStas", "akAcode", "k_523", "card", "akfDs", "askGetAward", "hasCollet", "hasGetcheatRwd", "CHEAT_CLICK_STATE", "isSpecialLogin", "hasGetSupendRwd", "secenid", "c_2138", "\u60ac\u6d6e\u5956\u52b1", "isShowSuped", "chm.WelfareMdu", "font", "<b><font color =\"#e1a32a\">", "font1", "</font></b>", "<font color = \"#e6e2db\">", "font2", "<b><font color = \"#e1a32a\">", "ress", "wp", "WelfGRd", "dalSpal", "DaSnGdRd", "lbl_version", "App: ", "clientVersion", "app_version", "akfCe", "codPal", "WELFARE_CLICK", "cgPal", "DAILY_SIGN_CLICK", "ckDs", "upDs", "changeId", "getAward_btn", "collectPnl", "getCheatRew", "cheatpanl", "cheatBtn", "flCode", "ACTION_CODE", "WelfareStatic", "flNotice", "NOTICE", "flDlSn", "DAILY_SIGN", "flSCYG", "YUGAO", "showFaq", "FAQ", "showVqp", "VIPQQ", "showCollect", "COLLECT", "showCheat", "CHEAT", "showSupend", "SUSPEND", "flBtLst", "pldiosActKeyFlag", "refsflst", "getBtnLst", "setBtnLst", "setCode", "clearCode", "showDs", "not_red", "showNotice", "setNCot", "ybSta", "showScc", "k_1457", "k_1458", "k_1459", "showCode", "notPal", "showDaSgn", "getDaSns", "showSCC", "img_ShaChengComing", "scomPal", "FAQ/index.php?platform=", "readComp", "showVpQ", "showSups", "A", "acet", "Q:", "Q", "A:", "faqPal", ";", "CanGetColletRwd", "k_1633", "k_1534", "c_2136", "chm.WelfareMed", "notice_change", "_hasGetcheatRwd", "wxsecenids", "wxQQsecenids", "_hasGetSupendRwd", "_not_red", "chkDStas", "_daiStas", "7.0.5", "compareVersion", "7.0.6", "notShowxuanfu", "vipKf", "chkVQOpen", "_btnAr", "WelfGVo", "buttonIcon", "isShowActKey", "bdids", "oppids", "tyids", "_dailyBo", "_yugaostate", "_daiSns", "dailysign_json", "DaSnVo", "rewardVo", "getVpdfCfg", "vipKfLst", "_vipKefuIds", "_vipKf", "vipkefu_json", "WelfVQVo", "platformid", "qqnum", "showqr", "qrsource", "bgsource", "getShareXml", "cheat_click_state", "chm.WelfareMod", "sign_in_icon_png", "fuli_jihuoma2_png", "fuli_gonggao2_png", "fuli_faq_png", "vipqq_icon_png", "fuli_yugao_png", "main_icon_collect_png", "fuli_fangpian_png", "main_icon_wechat_png", "fuli_qiandao_title_png", "fuli_jihuoma2_title_png", "fuli_gonggao2_title_png", "fuli_faq_title_png", "fuli_kefu_title_png", "fuli_yugao_title_png", "main_title_shoucang_png", "fuli_fangpian_title_png", "fuli_fuchuang_title_png", "chm.WelfareStatic", "WelfEui", "AcodeEui", "NoticeEui", "DaiSgnEui", "SccEui", "FAQEui", "vpqPal", "VQEui", "CollectEui", "CheatEui", "suspenp", "SuspendPnl", "fillVIPQQContent", "fuli_di_jpg", "chm.WelfareV", "tip_bg", "sign_in_daybg_png", "sign_in_doublebg_png", "k_1456", "gou", "can", "daily_sign_click", "chm.DaSnGdRd", "chm.DaSnVo", "welfare_click", "chm.WelfGRd", "chm.WelfGVo", "ActionCodePanelSkin", "chm.AcodeEui", "CheatSkin", "fuli_fangpian_bannner_jpg", "CheatReward", "chm.CheatEui", "CollectRePanelSkin", "xcxshoucang_bg1_jpg", "process_img", "xcxshoucang_bg2_QQ_jpg", "xcxshoucang_bg2_jpg", "chm.CollectEui", "DailySignPanelSkin", "chm.DaiSgnEui", "FAQPanelSkin", "chm.FAQEui", "NoticePanelSkin", "chm.NoticeEui", "ShaChengComing", "chm.SccEui", "SuspendPnlSkin", "fuchuang_jpg", "chm.SuspendPnl", "VIPQQPanelSkin", "lbl_qq", "vip_kefu_jpg", "chm.VQEui", "WelfarePanelSkin", "chm.WelfEui", "chm.WelfVQVo", "CBZBMed", "changeWing", "chgSelIdx", "selIdx", "CBZBMod", "askOneKeyLoad", "askLevelUpEquip", "askLevelUpEquipInPos", "askEquipConvert", "chm.CBZBMdu", "CBZBV", "oneKeyLoadEquip", "btn_onkey", "onTishengInPos", "btn_compOrLevel", "onClickCell", "cell2", "cell3", "onTisheng", "onClickEquip", "equipcell0", "equipcell1", "equipcell2", "equipcell3", "showSkillTip", "hideSkillTip", "showJiban", "onConvertLiItemTap", "list_covnert", "convertP", "changeSelIdx", "convertleft_btn", "convertright_btn", "convern", "convert_btn", "onSelectHero", "flushEquip", "flushCompose", "onSelectTabCellBar", "updCostLab", "updateCurrentEquip", "onUpSuc", "convertSuc", "setHeroLi", "clkEquIdx", "equipcell", "equipbg", "getCurVlu", "fn_wing", "skillopen", "skillopenLimit", "k_750", "k_749", "createPropStr", "flushCells", "selPos", "getCfgs", "tabCellBar", "getSkinArr", "currentGrid", "equip2", "compose", "level1", "equip1", "power0", "prop1", "prop0", "composeEff", "k_737", "updTabRed", "ckComposeRedByObj", "ckComposeRed", "cellredtip", "rfEquipCells", "equip_select", "god_yu_bg_jpg", "k_1461", "k_1460", "lb3", "lb_state0", "topLbl0", "tipline", "lb0", "k_751", "k_752", "k_754", "lb_state", "tipP2", "loadEff", "composeEff2", "k_755", "cost_group", "compose_1", "level_0", "level_1", "power_0", "prop_0", "k_746", "power_2", "power_1", "prop_2", "prop_1", "k_747", "k_748", "costLabel", "group_default", "selcet_img", "selectGridIndex", "selcetgrid", "reMovefillConvert", "convert_img", "replacegold", "lb_expend", "fillConvertPanelTwo", "clickGrid", "group_convert", "k_756", "fillConvert", "chm.CBZBMed", "allEqus", "getWingEquLvLmt", "jlDic", "wingpassive_json", "extendpropsetting_json", "wingequip", "getWingEquGold", "chm.CBZBCfgMod", "_selIdx", "_selPos", "_clkEquIdx", "getHeroCBEquCostRed", "chm.CBZBMod", "CBZBPnl", "CBJNTipPnl", "CBZBCvtPnl", "god_yu_title1_png", "selPosChg", "levelup", "chm.CBZBV", "WingRenderSkin", "group_wing", "removedataGrid", "CBZBRnd", "chm.CBZBRnd", "TipWingSkillSkin", "chm.CBJNTipPnl", "TipWingSkillSkin2", "chm.CBJNTipPnl2", "WingEquipConvertSkin", "chm.CBZBCvtPnl", "WingEquipInfoSkin", "CBZBInfoPnl", "chm.CBZBInfoPnl", "WingEquipSkin", "chm.CBZBPnl", "ZlingViMed", "rspZhanLingInfo", "rspZhanLingStateChange", "rspSynthesisSuccess", "showZhanLingPanel", "checkItemChange", "checkLvl", "setLogin", "getZhanLingInfo", "showActiveEff", "getRZD", "animalsLv", "weaponLv", "animalLevelUp", "ZhanLingSynthesis", "fragmentId", "eaponLevelUp", "chm.ZlingMule", "ZhanLingViewMediator", "_flag", "nameList", "shenqi_name_0", "shenling_name_0", "shenqi_eff_0", "shenling_eff_0", "shenqijiban_icon", "shenqijiban_name", "shenlingjiban_icon", "shenlingjiban_name", "rateValue", "gaWin", "ZlingRadEui", "artPanel", "ZlingartV", "anPanel", "comPanel", "ZlingComV", "qiling_show_bg_jpg", "hecheng_bg_jpg", "ZlingRen", "selIndChan", "cJiBan", "img_jiban", "hidP", "heCC", "updateCm", "updateA", "activeUp", "curPanel", "activation_miji_text2_png", "activation_miji_text3_png", "qilinghecheng_title_png", "5\u672c\u5377\u8f74\u6709\u6982\u7387\u5408\u62101\u4e2a\u968f\u673a\u7075\u9b44", "qiling_title_png", "getZhanLvlConf", "qiLingIds", "shenBingIds", "getMaxLvl", "checkMyBag", "concatString", "showArtEffect", "setZhanLingItemList", "ZlingCon", "getName", "pos1tp", "k_1027", "img_iconName", "setComList", "getZlPos", "ZlItemVo", "getSQType", "checkZL", "k_1028", "k_1029", "k_1030", "needLv", "checkSelfLvl", "\u6218\u7075", "\u795e\u5175", "getZLConf", "getjbData", "k_1031", "k_1032", "lbl_jihuo1", "lbl_jihuo2", "lb_cur", "getpDesById", "jiban1", "lb_nex", "showJibanPanel", "fillJiBanInfo", "showJiBanEff", "qljb_eff_1", "qljb_eff_2", "_nameEff", "_effectName", "tip3", "checkIsActive", "activation_mode_title4_png", "activation_mode_title3_png", "checkLvlByType", "chm.ZlingViMed", "ZhanLingVo", "chm.ZhanLingVo", "_zltT", "_zLAnByType", "valhallaanimal_json", "valhallaweapon_json", "getVcon", "valhallasetting_json", "synthesisItemId", "animalSkillNeddLv", "weaponSkillNeedLv", "getjiBanData", "valhallapassive_json", "_zhanlingConf", "BREACK", "chm.ZlingCon", "gridNum", "shenqi_01_png", "shenqi_02_png", "shenqi_03_png", "shenqi_04_png", "shenling_01_png", "shenling_02_png", "shenling_03_png", "shenling_04_png", "gridName", "\u8840\u996e\u4e4b\u5203", "\u4ff1\u706d\u4e4b\u523a", "\u566c\u9b42\u4e4b\u65a9", "\u706b\u9e9f\u4e4b\u6247", "\u96f7\u9706\u795e\u5c06", "\u5e9a\u91d1\u7f57\u5239", "\u65e0\u8d66\u4fee\u7f57", "\u51b0\u971c\u9b45\u7075", "_isLogin", "getSQLvlConf", "qiling_frame_png", "special_book_png", "chm.ZlingMod", "chm.ZlItemVo", "ZhanLingHeChengRenderSkin", "ZlingHCRen", "chm.ZlingHCRen", "ZhanLingArtRender", "chm.ZlingRen", "ZhanLingArticactEuiSkin", "chm.ZlingartV", "sIndexS", "imgPos", "_rotat", "ZhanLingComposeEuiSkin", "listHandler", "imgIcon3", "imgIcon4", "lastId", "bArr", "lList", "\u6b63\u5728\u5408\u6210\u4e2d,\u8bf7\u7a0d\u7b49...", "k_1033", "5\u672c\u53ec\u5524\u4e66\u5fc5\u5b9a\u5408\u62101\u4e2a\u968f\u673a\u7075\u9b44", "\u5377\u8f74\u4e0e\u53ec\u5524\u4e66\u4e0d\u80fd\u6df7\u7528", "k_1034", "k_1035", "img_weihao", "successItemId", "hecheng_huiru", "_hechengEffect", "hecheng_baozha", "imgIcon5", "lblName5", "_scaleEffect", "removeScale", "showQuanEffect", "_secendIndex", "showFuWenEffect", "k_1036", "hecheng_yuan", "chm.ZlingComV", "ZhanLingRadioSkin", "chm.ZlingRadEui", "ZZMed", "send1413", "send1414", "send1415", "send1421", "chm.ZZMdu", "list_zhuzaiEquip", "lbl_getRes", "JhClk", "sjClk", "sjieClk", "dcClk", "btn_decompose", "upClk", "jjClk", "chgeIdx", "S_CHGE", "sInfocg", "rfItem", "zzPosCg", "img_upgradeBg", "img_jinjieBg", "img_decomposeBg", "sHero", "sTar", "fillList", "fillMSuit", "fillZZLv", "upLimitLevel", "upLimitLevel_num", "k_960", "upCostItemID", "lbl_levelCostName", "upCostItemCount", "lbl_jilv", "k_961", "upSuccessRate", "serverLevel", "currentLevelValueStr", "nextLevelValueStr", "sSjFt", "fillZZStar", "group_close", "num_sj", "starCostItemID", "lbl_starCostName", "starCostItemCount", "currentStarValueStr", "nextstarValueStr", "sShFight", "rfSel", "rfEList", "lbl_retItemCount", "suitVo", "boCanAlive", "boLevel", "boUpgrade", "rfSuit", "sLRed", "sPRed", "zzPaRed", "getItemVO", "chm.ZZMed", "initSuitConf", "getSuitJson", "_suitConf", "getSuitLvlConf", "_suitLvlConf", "getSuitStarConf", "_suitStarConf", "chengzhang", ",ATT:", ",STRONG:", "ATT:", ",PDEF:", ",ANTISTRONG:", ",SDEF:", "suitshow_json", "ZZCMod", "chm.ZZCMod", "_heroA", "_tRed", "_pRed", "_pageRed", "chm.ZZMod", "iniMSuit", "initSjNum", "initSjFNum", "ZZEui", "ZZUEui", "ZZDui", "ZZJEui", "ZZJEEui", "zhuzai_bg_jpg", "togBtn_upgrade", "togBtn_jinjie", "togBtn_decompose", "zhuzai_title_png", "zhuzai_fenjie_png", "clkGrid", "num_sji", "chm.ZZV", "ZhuZaiDecomposeSkin", "chm.ZZDui", "ZhuZaiSkin", "chm.ZZEui", "ZhuZaiJinjieEquipSkin", "chm.ZZJEEui", "ZhuZaiJinjieSkin", "chm.ZZJEui", "ZhuZaiUpgradeSkin", "chm.ZZUEui", "TEXT_1", "{0}\uff1a{1}", "TEXT_2", "{0} {1}", "TEXT_3", "{0}%", "(+{0})", "TEXT_5", "       \u5df2\u6ee1\u7ea7", "chm.SuitStatic", "upprobablility", "gLv", "gAcInfo", "gLvInf", "gStInf", "gLmtLv", "gLvNum", "activationcost", "starFightNum", "probability", "advanced", "chm.SuitVo", "iOS", "os", "Mac OS", "isAndroid", "Android", "deciveType", "android", "PlatFormStatic", "chm.PlatFormStatic", "c_2239", "c_2242", "c_2243", "c_2249", "c_2125", "c_2127", "lastIndex", "c_2129", "c_2131", "c_2132", "c_2134", "c_2137", "c_3983", "c_2162", "convertId", "heroBoxIndex", "bagBoxIndex", "cuiquId", "takeId", "isNewPlayer", "c_4614", "agree", "c_2080", "normalBonus", "specialBonus", "endBonus", "c_2172", "c_2174", "c_2176", "c_2178", "c_2180", "c_2182", "c_2183", "c_4501", "c_4503", "c_4505", "c_4508", "c_4511", "inviter", "inviterStageId", "c_3012", "chm.NetSender", "cmdDic", "objDic", "initCmd", "QuanMingAttentionInfo", "result", "ValhallaInfo", "SimplePlayerItem", "MazeBox", "famliy", "SimplePlayerInfo", "PromotionVo", "BigMoneyManVo", "PromotionTaskVo", "configVersion", "rmb", "SimpleOtherPlayerInfo", "TaskVO", "StorageData", "HeroPropData", "encode", "FashionVo", "old", "SimplePlayerFightInfo", "ActionData", "HpChange", "BuffChange", "SummonData", "SimpleHeroInfo", "PetInfo", "buffData", "QuanMingData", "ZhuanShengData", "chapter", "SummonBossState", "HeroWingEquip", "HeroFuling", "MeetLogData", "RevengeVO", "MailVO", "LotteryLogVO", "ShopItemVO", "guideStep", "finishs", "ShopPermitItem", "BossSingleObj", "BossQuanMingObj", "RankSingleData", "KingData", "KingDataVO", "KingRankData", "KingCheckVO", "CountData", "ClientTitleData", "buffExp", "pulled", "AchieveState", "KeyValueElement1", "FamilyInfo", "FamilyData", "JoinRequestInfo", "MemberInfo", "FamilyMemberData", "OtherFamilyInfo", "FamilyBuyData", "FamilySkillData", "FamilyStorageItem", "FamilyStorageUseLog", "FamilyRed", "FamilyRedLog", "NightBiQiSimplePlayerItem", "NightBiQi_RankInTimeContent", "NightBiQiPointChange", "NightBiQiPlayerRankItem", "RobRecord", "firstBreakName", "clearancePercent", "SYaoTowerDataInfo", "TurnTableLogVO", "InvestTurnTableLogVo", "LuckTurntableInfo", "ArrestGradeInfo", "ArrestCarInfo", "EscortCarInfo", "ArrestFamilyRankInfo", "ArrestPlayerRankInfo", "ArrestCarlogInfo", "ArrestPlayerlogInfo", "ArrestHitInfo", "SnatchDieInfo", "ArrestMemberRankInfo", "CrossShopInfo", "CenterKingWeekData", "RankFirstInfo", "MainCityPlayer", "ProtectPlayerInfo", "RankItem", "SandyCityFamilyRankItem", "SandyCityPlayerRankItem", "SandyFamilyPlayer", "SandyCity_RankInTimeContent", "SandySimplePlayerItem", "SandyCityFamilyMemberItem", "FestivalBoxDetails", "FestivalBoxDisappear", "TongtianBattlefieldSimplePlayerItem", "TongtianBattlefield_RankInTimeContent", "TongtianBattlefieldPlayerRankItem", "gatherRoleId", "TongtianBattlefieldBoxInfo", "clientId", "appId", "FabaoInfo", "MapIntElement", "FabaoshopIteminfo", "FabaoPartsInfo", "SCrossSandyCityFamilyInfo", "PlayerInspireInfo", "CrossCityFightPlayerResult", "CrossCityPrayLuckFamilyInfo", "HonorRankFamilyInfo", "HonorRankPlayInfo", "ownScore", "ItemBuyVo", "PromotionLuckyFishVo", "Mainmonster_RankInTimeContent", "KeyValueElement2", "playerDetails", "SharePlayerVo", "friendDetails", "ShareJiZanVo", "defenderDetails", "weChatName", "weChatSex", "weChatHead", "PromotionLuckyTurnLogVo", "FamilySkillInfo", "FamilyMemberSkillInfo", "FamilyCopyBuffInfoVo", "FamilyCopyScoreInfoVo", "FamilyCopyHeroInfoVo", "FamilyCopyNormalBuffVo", "FamilyCopyCallBuffVo", "HeroFazhenData", "familyCopyMonster", "FamilyCopyBoss", "\u5145\u503c\u989d\u5ea6", "PromotioSingleRedVo", "SingleRedTakeDetail", "itemCounts", "HeroThunderDataDTO", "ThunderBoxDTO", "BossRevengeVO", "ZhuanshengTask", "MultiHeroDecHp", "CrossBosslogInfo", "DiscipleInfo", "TaskInfo", "MasterChatMessageVo", "SpecialBonusInfoVo", "FunctionInfoVo", "ShareEatVo", "rateNum", "nowDefender", "ShareEatLogVo", "MultiBloodData", "MultiSimpleInfo", "MultiMove", "MultiActionData", "MultiAttackInfo", "MultiDropItemInfo", "actorHp", "PlayerCrossTopInfo", "PromotionRewardTurnLogVo", "moneytree", "singlebosswin", "worldbosskill", "worldbosspartake", "loginday", "meetcount", "kingcount", "zsbosscount", "JoinPlayer", "operaterId", "joinHero", "JoinHero", "chopRank", "drangonBall", "BattleSkill", "passiveSkill", "BattlePassiveSkill", "specialSkillLevel", "allAddition", "BattleAddition", "awakes", "passiveLevel", "familyCopyProcess", "maxFamilyCopyProcess", "copyBonusState", "ZhuanShengScoreObj", "upTime", "winsCount", "hisWinCount", "preRecoveryTime", "prevEnemyFlushTime", "FamilyLog", "FamilyBuyCountData", "eventId", "pId", "loginActivityId", "superShopId", "dailyRechargeId", "dailyResetTime", "loginRecord", "loginStates", "dailyRechargeRecord", "dailyRechargeProgress", "superShopProgress", "superShopStates", "senderjunxian", "CrossBossInviteInfo", "BossrevengeInviteInfo", "FightData", "lingqi", "hasCard", "SandyCityPlayerTargetItem", "SandyCitySimpleHeroInfo", "AFamilyCarRewardInfo", "allpoint", "pid", "ACarGotoPlayerInfo", "targetid", "gatherRoleIds", "preResult", "finalResult", "MainmonsterPlayerRankItem", "pk", "discountRate", "FamilyCopyBuffItemVo", "FazhenLevelDataDTO", "FazhenLingwuDataDTO", "lingwuId", "redId", "ThunderTaozhuangDataDTO", "ThunderCuiquGridDataDTO", "ThunderCuiquDataDTO", "ThunderZizhuangDataDTO", "ThunderEquipDTO", "sourceId", "sourceName", "diestate", "MultiPlayerInfo", "MultiMonsterInfo", "MultiAttackMonsterData", "MultiHurtInfo", "MultiHeroInfo", "MultiBuffInfo", "chm.NetWorkSystem", "usePackEtc1Ktx", "ignoreResource", "convertURL", "fileSuffix", "createCompressTextureResourceInfo", "supportedCompressedTexture", "pvrtc", ".pvr.ktx", "pvrtc.ktx", "onLoadStart", "etc1.ktx", "ImageProcessor", "onRemoveStart", "CompressTextureProcessor: onRemoveStart = ", "CompressTextureProcessor: onRemoveStart lose resource = ", ".jpg", "jpeg", "CompressTextureProcessor", "RES.processor.Processor", "PackETC1KTXProcessor data is null:", "createCompressedTexture", "$bitmapData", "etcAlphaMask", "\u4f7f\u7528\u5408\u5e76\u7eb9\u7406", "ktxData", "ktx:", " is invalid", "resourceConfig", "scale9grid", "$dispose", "PackETC1KTXProcessor", "_themeComplete", "_configComplete", "_languageComplete", "_gamePreLoadComplete", "_resPath", "lastWebConfigUrl", "_percent", "_errorCount", "beginStartupLoad", "resoucePre", "CONFIG_LOAD_ERROR", "loadConfigError", "CONFIG_COMPLETE", "onConfigComplete", "resName", "default.res.json", "loadConfig", "loadTimout", "loadERR", "clearTimeout", "showErrPanl", "k_1463", "startLoadingLanguage", "onLanguageLoadComplete", "language load failed", "GROUP_PROGRESS", "onResourceProgress", "onItemLoadError", "default.thm.json", "web", "wxCode", "default.thm_json", "getKeyByAlias", "Theme", "onThemeLoadComplete", "doAITween", "oncfgbinLoadError", "onZipLoadComplete", "k_1465", "gamePreload", "getGroupByName", "const_json", "checkLoadingComplete", "config\u52a0\u8f7d\u9519\u8bef-data = ", "?v", "\u89e3\u6790\u914d\u7f6e\u5931\u8d25", "k_1466", "itemsLoaded", "itemsTotal", "Group:", " has failed to load,start reload", "\u7f51\u7edc\u52a0\u8f7d\u4e2d\u65ad\u8bf7\u9000\u51fa\u91cd\u8bd5", "RestartAlertView", "resource/", "GameLoading", "chm.GameLoading", "_qufuLoading", "qufuLoading", "\u6e38\u620f\u521d\u59cb\u5316...", "simulateProgress", "QUFU_CONNECT_GAME", "reconnectGame", "gameLoading", "DEACTIVATE", "ACTIVATE", "showlogo", "enterGame", "_modlueManager", "\u52a0\u8f7d\u6e38\u620f\u6a21\u5757", "chm.LoadManager", "chm"];
        return path.normalize(url).split(path.sep + 'resource')[0];
    };
    return FileCrc32;
}());
function run(baseUrl) {
    new FileCrc32(baseUrl);
}
exports.run = run;
